/* DomGDocumentTest.c generated by valac 0.34.13, the Vala compiler
 * generated from DomGDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* DomGDocumentTest.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gxml/gxml.h>
#include <gee.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_DOM_GDOCUMENT_TEST (dom_gdocument_test_get_type ())
#define DOM_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTest))
#define DOM_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTestClass))
#define IS_DOM_GDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DOM_GDOCUMENT_TEST))
#define IS_DOM_GDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DOM_GDOCUMENT_TEST))
#define DOM_GDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DOM_GDOCUMENT_TEST, DomGDocumentTestClass))

typedef struct _DomGDocumentTest DomGDocumentTest;
typedef struct _DomGDocumentTestClass DomGDocumentTestClass;
typedef struct _DomGDocumentTestPrivate DomGDocumentTestPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _DomGDocumentTest {
	GXmlTest parent_instance;
	DomGDocumentTestPrivate * priv;
};

struct _DomGDocumentTestClass {
	GXmlTestClass parent_class;
};


static gpointer dom_gdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType dom_gdocument_test_get_type (void) G_GNUC_CONST;
enum  {
	DOM_GDOCUMENT_TEST_0_PROPERTY
};
#define DOM_GDOCUMENT_TEST_STRDOC "<?xml version=\"1.0\"?>\n" \
"<!-- Comment -->\n" \
"<Sentences>\n" \
"  <Sentence lang=\"en\">I like the colour blue.</Sentence>\n" \
"  <Sentence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence>\n" \
"  <Authors>\n" \
"    <Author>\n" \
"      <Name>Fred</Name>\n" \
"      <Email>fweasley@hogwarts.co.uk</Email>\n" \
"    </Author>\n" \
"    <Author>\n" \
"      <Name>George</Name>\n" \
"      <Email>gweasley@hogwarts.co.uk</Email>\n" \
"    </Author>\n" \
"  </Authors>\n" \
"</Sentences>\n"
#define DOM_GDOCUMENT_TEST_HTMLDOC "\n" \
"<html>\n" \
"<body>\n" \
"<p class=\"black\">Text content</p>\n" \
"<p id=\"p01\">p01 p id</p>\n" \
"<p class=\"black block\">Two classes</p>\n" \
"<p class=\"   time request hole   \">Three classes</p>\n" \
"</body>\n" \
"</html>\n"
#define DOM_GDOCUMENT_TEST_XMLDOC "<?xml version=\"1.0\"?>\n" \
"<root>\n" \
"<project xmlns:gxml=\"http://live.gnome.org/GXml\">\n" \
"<code class=\"parent\"/>\n" \
"<code class=\"node parent\"/>\n" \
"<page class=\"node\"/>\n" \
"<page class=\"parent node hole\"/>\n" \
"</project>\n" \
"<Author name=\"You\" />\n" \
"</root>\n"
void dom_gdocument_test_add_tests (void);
static void __lambda191_ (void);
static void ___lambda191__gtest_func (void);
static void __lambda192_ (void);
static void ___lambda192__gtest_func (void);
static void __lambda193_ (void);
static void ___lambda193__gtest_func (void);
static void __lambda194_ (void);
static void ___lambda194__gtest_func (void);
static void __lambda195_ (void);
static void ___lambda195__gtest_func (void);
static void __lambda196_ (void);
static void ___lambda196__gtest_func (void);
static void __lambda197_ (void);
static void ___lambda197__gtest_func (void);
static void __lambda198_ (void);
static void ___lambda198__gtest_func (void);
static void __lambda199_ (void);
static void ___lambda199__gtest_func (void);
static void __lambda200_ (void);
static void ___lambda200__gtest_func (void);
static void __lambda201_ (void);
static void ___lambda201__gtest_func (void);
static void __lambda202_ (void);
static void ___lambda202__gtest_func (void);
static void __lambda203_ (void);
static void ___lambda203__gtest_func (void);
static void __lambda204_ (void);
static void ___lambda204__gtest_func (void);
DomGDocumentTest* dom_gdocument_test_new (void);
DomGDocumentTest* dom_gdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);


static gpointer _g_object_ref0 (gpointer self) {
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 139 "DomGDocumentTest.c"
}


static void __lambda191_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomElement* root = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gboolean _tmp8_ = FALSE;
		GXmlDomHTMLCollection* _tmp9_ = NULL;
		GXmlDomHTMLCollection* _tmp10_ = NULL;
		GXmlDomHTMLCollection* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		GXmlDomHTMLCollection* _tmp14_ = NULL;
		GXmlDomHTMLCollection* _tmp15_ = NULL;
		GXmlDomHTMLCollection* _tmp16_ = NULL;
		gpointer _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		GXmlDomHTMLCollection* _tmp22_ = NULL;
		GXmlDomHTMLCollection* _tmp23_ = NULL;
		GXmlDomHTMLCollection* _tmp24_ = NULL;
		gpointer _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlDomHTMLCollection* _tmp29_ = NULL;
		GXmlDomHTMLCollection* _tmp30_ = NULL;
		GXmlDomHTMLCollection* _tmp31_ = NULL;
		gpointer _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error_);
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 191 "DomGDocumentTest.c"
			goto __catch196_g_error;
		}
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 74 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 75 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_document_get_document_element (doc);
#line 75 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 75 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		root = _tmp4_;
#line 76 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (root != NULL, "root != null");
#line 77 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (root, GXML_TYPE_DOM_ELEMENT), "root is DomElement");
#line 78 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) root);
#line 78 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 78 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 78 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Sentences") == 0, "root.node_name == \"Sentences\"");
#line 78 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 79 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_node_has_child_nodes ((GXmlDomNode*) root);
#line 79 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp8_, "root.has_child_nodes ()");
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = gee_collection_get_size ((GeeCollection*) _tmp11_);
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp13_ == 3, "root.children.size == 3");
#line 80 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp11_);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = gee_list_get ((GeeList*) _tmp16_, 0);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = (GXmlDomElement*) _tmp17_;
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp18_);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "Sentence") == 0, "root.children[0].node_name == \"Sentence\"");
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 81 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = gee_list_get ((GeeList*) _tmp24_, 0);
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = (GXmlDomElement*) _tmp25_;
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_element_get_attribute (_tmp26_, "lang");
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "en") == 0, "root.children[0].get_attribute (\"lang\") == \"en\"");
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 82 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) root);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = gee_list_get ((GeeList*) _tmp31_, 0);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = (GXmlDomElement*) _tmp32_;
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp33_);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "I like the colour blue.") == 0, "root.children[0].node_value == \"I like the colour blue.\"");
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 83 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (root);
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 312 "DomGDocumentTest.c"
	}
	goto __finally196;
	__catch196_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = e->message;
#line 85 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 85 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:85: %s", _tmp39_);
#line 85 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 86 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 339 "DomGDocumentTest.c"
	}
	__finally196:
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 70 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 350 "DomGDocumentTest.c"
	}
}


static void ___lambda191__gtest_func (void) {
#line 69 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda191_ ();
#line 358 "DomGDocumentTest.c"
}


static void __lambda192_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomNodeList* _tmp3_ = NULL;
		GXmlDomNodeList* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		gpointer _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		gpointer _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		GXmlDomNodeList* _tmp22_ = NULL;
		GXmlDomNodeList* _tmp23_ = NULL;
		gpointer _tmp24_ = NULL;
		GXmlDomNode* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlDomElement* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		GXmlDomElement* auths = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomHTMLCollection* _tmp38_ = NULL;
		GXmlDomHTMLCollection* _tmp39_ = NULL;
		GXmlDomHTMLCollection* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlDomElement* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		GXmlDomNodeList* _tmp46_ = NULL;
		GXmlDomNodeList* _tmp47_ = NULL;
		GXmlDomNodeList* _tmp48_ = NULL;
		gint _tmp49_ = 0;
		gint _tmp50_ = 0;
		GXmlDomNodeList* _tmp51_ = NULL;
		GXmlDomNodeList* _tmp52_ = NULL;
		GXmlDomNodeList* _tmp53_ = NULL;
		gpointer _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
#line 94 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error_);
#line 94 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 94 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 429 "DomGDocumentTest.c"
			goto __catch197_g_error;
		}
#line 94 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 94 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 95 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (doc, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 96 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 96 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 96 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 96 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "doc.child_nodes != null");
#line 96 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp10_ == 2, "doc.child_nodes.size == 2");
#line 97 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gee_list_get ((GeeList*) _tmp13_, 0);
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = (GXmlDomNode*) _tmp14_;
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_COMMENT), "doc.child_nodes[0] is DomComment");
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 98 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = gee_list_get ((GeeList*) _tmp18_, 1);
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = (GXmlDomNode*) _tmp19_;
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT), "doc.child_nodes[1] is DomElement");
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 99 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) doc);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 1);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = (GXmlDomNode*) _tmp24_;
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_name (_tmp25_);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "Sentences") == 0, "doc.child_nodes[1].node_name == \"Sentences\"");
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp28_);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 100 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 101 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_document_get_document_element (doc);
#line 101 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 101 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 101 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp31_ != NULL, "doc.document_element != null");
#line 101 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 102 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = gxml_dom_document_get_document_element (doc);
#line 102 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 102 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 102 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_DOM_ELEMENT), "doc.document_element is DomElement");
#line 102 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element (doc);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp37_);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 2);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = (GXmlDomElement*) _tmp41_;
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp37_);
#line 103 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		auths = _tmp42_;
#line 104 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_node_get_node_name ((GXmlDomNode*) auths);
#line 104 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 104 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 104 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, "Authors") == 0, "auths.node_name == \"Authors\"");
#line 104 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) auths);
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp50_ == 5, "auths.child_nodes.size == 5");
#line 105 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) auths);
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = gee_list_get ((GeeList*) _tmp53_, 4);
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = (GXmlDomNode*) _tmp54_;
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_TEXT), "auths.child_nodes[4] is DomText");
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp55_);
#line 106 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp53_);
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (auths);
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 606 "DomGDocumentTest.c"
	}
	goto __finally197;
	__catch197_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 108 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = e->message;
#line 108 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = g_strconcat ("Error: ", _tmp56_, NULL);
#line 108 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 108 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:108: %s", _tmp58_);
#line 108 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 109 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 633 "DomGDocumentTest.c"
	}
	__finally197:
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 90 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 644 "DomGDocumentTest.c"
	}
}


static void ___lambda192__gtest_func (void) {
#line 89 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda192_ ();
#line 652 "DomGDocumentTest.c"
}


static void __lambda193_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomDocument* _tmp4_ = NULL;
		GXmlDomHTMLCollection* _tmp5_ = NULL;
		GXmlDomHTMLCollection* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
		GXmlDomHTMLCollection* _tmp9_ = NULL;
		gpointer _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GXmlDomHTMLCollection* _tmp14_ = NULL;
		gpointer _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlDomHTMLCollection* lc = NULL;
		GXmlDomDocument* _tmp19_ = NULL;
		GXmlDomHTMLCollection* _tmp20_ = NULL;
		GXmlDomHTMLCollection* _tmp21_ = NULL;
		gint _tmp22_ = 0;
		gint _tmp23_ = 0;
		GXmlDomHTMLCollection* _tmp24_ = NULL;
		gpointer _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GXmlDomHTMLCollection* _tmp30_ = NULL;
		gpointer _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		GXmlDomElement* nid = NULL;
		GXmlDomDocument* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		GXmlDomElement* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error_);
#line 117 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 117 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 714 "DomGDocumentTest.c"
			goto __catch198_g_error;
		}
#line 117 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 117 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 118 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 118 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 119 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 119 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_elements_by_tag_name (_tmp4_, "p");
#line 119 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		le = _tmp5_;
#line 120 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = le;
#line 120 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = gee_collection_get_size ((GeeCollection*) _tmp6_);
#line 120 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 120 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp8_ == 4, "le.size == 4");
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = le;
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = gee_list_get ((GeeList*) _tmp9_, 0);
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = (GXmlDomElement*) _tmp10_;
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_attribute (_tmp11_, "class");
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "black") == 0, "le[0].get_attribute (\"class\") == \"black\"");
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp13_);
#line 121 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp11_);
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = le;
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) _tmp14_, 1);
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = (GXmlDomElement*) _tmp15_;
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_element_get_attribute (_tmp16_, "id");
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "p01") == 0, "le[1].get_attribute (\"id\") == \"p01\"");
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 122 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 123 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = doc;
#line 123 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_document_get_elements_by_class_name (_tmp19_, "black");
#line 123 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lc = _tmp20_;
#line 127 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = lc;
#line 127 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = gee_collection_get_size ((GeeCollection*) _tmp21_);
#line 127 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 127 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp23_ == 2, "lc.size == 2");
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = lc;
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = gee_list_get ((GeeList*) _tmp24_, 0);
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = (GXmlDomElement*) _tmp25_;
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp26_);
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "p") == 0, "lc[0].node_name == \"p\"");
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 128 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = lc;
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = gee_list_get ((GeeList*) _tmp30_, 0);
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = (GXmlDomElement*) _tmp31_;
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = gxml_dom_element_get_attribute (_tmp32_, "class");
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "black block") == 0, "lc[0].get_attribute (\"class\") == \"black block\"");
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp34_);
#line 129 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = doc;
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = gxml_dom_non_element_parent_node_get_element_by_id ((GXmlDomNonElementParentNode*) _tmp35_, "p01", &_inner_error_);
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		nid = _tmp36_;
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lc);
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 130 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 835 "DomGDocumentTest.c"
			goto __catch198_g_error;
		}
#line 131 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = nid;
#line 131 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp37_ != NULL, "nid != null");
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = nid;
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp38_);
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "p") == 0, "nid.node_name == \"p\"");
#line 132 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp41_);
#line 133 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = nid;
#line 133 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_element_get_attribute (_tmp42_, "id");
#line 133 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 133 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "p01") == 0, "nid.get_attribute (\"id\") == \"p01\"");
#line 133 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (nid);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lc);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 874 "DomGDocumentTest.c"
	}
	goto __finally198;
	__catch198_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 135 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = e->message;
#line 135 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = g_strconcat ("Error: ", _tmp45_, NULL);
#line 135 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 135 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:135: %s", _tmp47_);
#line 135 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp47_);
#line 136 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 901 "DomGDocumentTest.c"
	}
	__finally198:
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 113 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 912 "DomGDocumentTest.c"
	}
}


static void ___lambda193__gtest_func (void) {
#line 112 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda193_ ();
#line 920 "DomGDocumentTest.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 940 "DomGDocumentTest.c"
}


static void __lambda194_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomHTMLCollection* _tmp6_ = NULL;
		GXmlDomHTMLCollection* _tmp7_ = NULL;
		GXmlDomHTMLCollection* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		GXmlDomHTMLCollection* _tmp14_ = NULL;
		GXmlDomHTMLCollection* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		gpointer _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		GXmlDomHTMLCollection* lc = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomElement* _tmp27_ = NULL;
		GXmlDomElement* _tmp28_ = NULL;
		GXmlDomHTMLCollection* _tmp29_ = NULL;
		GXmlDomHTMLCollection* _tmp30_ = NULL;
		gint _tmp31_ = 0;
		gint _tmp32_ = 0;
		gpointer _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gpointer _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gboolean _tmp42_ = FALSE;
		GXmlDomHTMLCollection* lc2 = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		GXmlDomElement* _tmp44_ = NULL;
		GXmlDomElement* _tmp45_ = NULL;
		GXmlDomHTMLCollection* _tmp46_ = NULL;
		GXmlDomHTMLCollection* _tmp47_ = NULL;
		gint _tmp48_ = 0;
		gint _tmp49_ = 0;
		GXmlDomHTMLCollection* lc3 = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomElement* _tmp51_ = NULL;
		GXmlDomElement* _tmp52_ = NULL;
		GXmlDomHTMLCollection* _tmp53_ = NULL;
		GXmlDomHTMLCollection* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		gint _tmp56_ = 0;
		GXmlDomHTMLCollection* lc4 = NULL;
		GXmlDomElement* _tmp57_ = NULL;
		GXmlDomElement* _tmp58_ = NULL;
		GXmlDomElement* _tmp59_ = NULL;
		GXmlDomHTMLCollection* _tmp60_ = NULL;
		GXmlDomHTMLCollection* _tmp61_ = NULL;
		gint _tmp62_ = 0;
		gint _tmp63_ = 0;
#line 141 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:141: %s", "Doc: " DOM_GDOCUMENT_TEST_HTMLDOC);
#line 142 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error_);
#line 142 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 142 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1025 "DomGDocumentTest.c"
			goto __catch199_g_error;
		}
#line 142 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 142 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 143 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (doc, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = gxml_dom_document_get_document_element (doc);
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp5_);
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = gee_collection_get_size ((GeeCollection*) _tmp8_);
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp10_ == 1, "doc.document_element.children.size == 1");
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 144 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_document_get_document_element (doc);
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_element_get_elements_by_tag_name (_tmp13_, "p");
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 145 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		le = _tmp15_;
#line 146 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) le);
#line 146 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 146 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp17_ == 4, "le.size == 4");
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = gee_list_get ((GeeList*) le, 0);
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = (GXmlDomElement*) _tmp18_;
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_element_get_attribute (_tmp19_, "class");
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "black") == 0, "le[0].get_attribute (\"class\") == \"black\"");
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 147 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) le, 1);
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = (GXmlDomElement*) _tmp22_;
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = gxml_dom_element_get_attribute (_tmp23_, "id");
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp25_, "p01") == 0, "le[1].get_attribute (\"id\") == \"p01\"");
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp25_);
#line 148 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (doc);
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_element_get_elements_by_class_name (_tmp28_, "black");
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 149 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lc = _tmp30_;
#line 153 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = gee_collection_get_size ((GeeCollection*) lc);
#line 153 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 153 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp32_ == 2, "lc.size == 2");
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = gee_list_get ((GeeList*) lc, 0);
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = (GXmlDomElement*) _tmp33_;
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp34_);
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = _tmp36_;
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "p") == 0, "lc[0].node_name == \"p\"");
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp37_);
#line 154 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = gee_list_get ((GeeList*) lc, 0);
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = (GXmlDomElement*) _tmp38_;
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_element_get_attribute (_tmp39_, "class");
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = string_contains (_tmp41_, "black");
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp42_, "\"black\" in lc[0].get_attribute (\"class\")");
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp41_);
#line 155 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_document_get_document_element (doc);
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = gxml_dom_element_get_elements_by_class_name (_tmp45_, "time");
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp45_);
#line 156 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lc2 = _tmp47_;
#line 157 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = gee_collection_get_size ((GeeCollection*) lc2);
#line 157 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 157 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp49_ == 1, "lc2.size == 1");
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = gxml_dom_document_get_document_element (doc);
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = gxml_dom_element_get_elements_by_class_name (_tmp52_, "time request");
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp52_);
#line 158 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lc3 = _tmp54_;
#line 159 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = gee_collection_get_size ((GeeCollection*) lc3);
#line 159 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 159 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp56_ == 1, "lc3.size == 1");
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = gxml_dom_document_get_document_element (doc);
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp60_ = gxml_dom_element_get_elements_by_class_name (_tmp59_, "time request hole");
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 160 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lc4 = _tmp61_;
#line 161 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp62_ = gee_collection_get_size ((GeeCollection*) lc4);
#line 161 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 161 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp63_ == 1, "lc4.size == 1");
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lc4);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lc3);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lc2);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lc);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1230 "DomGDocumentTest.c"
	}
	goto __finally199;
	__catch199_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 163 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp64_ = e->message;
#line 163 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp65_ = g_strconcat ("Error: ", _tmp64_, NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 163 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:163: %s", _tmp66_);
#line 163 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp66_);
#line 164 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 1257 "DomGDocumentTest.c"
	}
	__finally199:
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 140 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 1268 "DomGDocumentTest.c"
	}
}


static void ___lambda194__gtest_func (void) {
#line 139 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda194_ ();
#line 1276 "DomGDocumentTest.c"
}


static void __lambda195_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomDocument* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomHTMLCollection* _tmp8_ = NULL;
		GXmlDomHTMLCollection* _tmp9_ = NULL;
		GXmlDomHTMLCollection* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		GXmlDomDocument* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomHTMLCollection* _tmp17_ = NULL;
		GXmlDomHTMLCollection* _tmp18_ = NULL;
		GXmlDomHTMLCollection* _tmp19_ = NULL;
		gpointer _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomDocument* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomHTMLCollection* _tmp26_ = NULL;
		GXmlDomHTMLCollection* _tmp27_ = NULL;
		GXmlDomHTMLCollection* _tmp28_ = NULL;
		gpointer _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomHTMLCollection* _tmp31_ = NULL;
		GXmlDomHTMLCollection* _tmp32_ = NULL;
		GXmlDomHTMLCollection* _tmp33_ = NULL;
		gpointer _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* e = NULL;
		GXmlDomDocument* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
		GXmlDomHTMLCollection* _tmp40_ = NULL;
		GXmlDomHTMLCollection* _tmp41_ = NULL;
		GXmlDomHTMLCollection* _tmp42_ = NULL;
		gpointer _tmp43_ = NULL;
		GXmlDomElement* _tmp44_ = NULL;
		GXmlDomHTMLCollection* _tmp45_ = NULL;
		GXmlDomHTMLCollection* _tmp46_ = NULL;
		GXmlDomHTMLCollection* _tmp47_ = NULL;
		gpointer _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomDocument* _tmp51_ = NULL;
		GXmlDomDocument* _tmp52_ = NULL;
		GXmlDomDocument* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		GXmlDomNode* _tmp57_ = NULL;
		GXmlDomElement* _tmp58_ = NULL;
		GXmlDomNode* _tmp59_ = NULL;
		GXmlDomNode* _tmp60_ = NULL;
		GXmlDomNode* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GXmlDomElement* _tmp67_ = NULL;
		GXmlDomElement* _tmp68_ = NULL;
		GXmlDomElement* _tmp69_ = NULL;
		GXmlDomElement* _tmp70_ = NULL;
		GXmlDomElement* _tmp71_ = NULL;
		GXmlDomElement* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		GXmlDomElement* _tmp76_ = NULL;
		GXmlDomNodeList* _tmp77_ = NULL;
		GXmlDomNodeList* _tmp78_ = NULL;
		GXmlDomNodeList* _tmp79_ = NULL;
		GXmlDomElement* _tmp80_ = NULL;
		GXmlDomNodeList* _tmp81_ = NULL;
		GXmlDomNodeList* _tmp82_ = NULL;
		GXmlDomNodeList* _tmp83_ = NULL;
		gint _tmp84_ = 0;
		gint _tmp85_ = 0;
		GXmlDomElement* _tmp86_ = NULL;
		GXmlDomNodeList* _tmp87_ = NULL;
		GXmlDomNodeList* _tmp88_ = NULL;
		GXmlDomNodeList* _tmp89_ = NULL;
		GXmlDomNode* _tmp90_ = NULL;
		GXmlDomNode* _tmp91_ = NULL;
		GXmlDomElement* _tmp92_ = NULL;
		GXmlDomNodeList* _tmp93_ = NULL;
		GXmlDomNodeList* _tmp94_ = NULL;
		GXmlDomNodeList* _tmp95_ = NULL;
		GXmlDomNode* _tmp96_ = NULL;
		GXmlDomNode* _tmp97_ = NULL;
		GXmlDomElement* _tmp98_ = NULL;
		GXmlDomNode* _tmp99_ = NULL;
		GXmlDomNode* _tmp100_ = NULL;
		GXmlDomNode* _tmp101_ = NULL;
		GXmlDomElement* _tmp102_ = NULL;
		GXmlDomNode* _tmp103_ = NULL;
		GXmlDomNode* _tmp104_ = NULL;
		GXmlDomNode* _tmp105_ = NULL;
		GXmlDomElement* _tmp106_ = NULL;
		GXmlDomNode* _tmp107_ = NULL;
		GXmlDomNode* _tmp108_ = NULL;
		GXmlDomNode* _tmp109_ = NULL;
		GXmlDomElement* _tmp110_ = NULL;
		GXmlDomNode* _tmp111_ = NULL;
		GXmlDomNode* _tmp112_ = NULL;
		GXmlDomNode* _tmp113_ = NULL;
		GXmlDomNode* t = NULL;
		GXmlDomElement* _tmp114_ = NULL;
		GXmlDomNodeList* _tmp115_ = NULL;
		GXmlDomNodeList* _tmp116_ = NULL;
		GXmlDomNodeList* _tmp117_ = NULL;
		GXmlDomNode* _tmp118_ = NULL;
		GXmlDomNode* _tmp119_ = NULL;
		GXmlDomNode* _tmp120_ = NULL;
		GXmlDomNode* _tmp121_ = NULL;
		GXmlDomNode* _tmp122_ = NULL;
		GXmlDomNode* _tmp123_ = NULL;
		GXmlDomNode* _tmp124_ = NULL;
		GXmlDomNode* _tmp125_ = NULL;
		GXmlDomNode* _tmp126_ = NULL;
		GXmlDomNode* _tmp127_ = NULL;
		GXmlDomNode* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
		GXmlDomNode* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		gchar* _tmp134_ = NULL;
		gchar* _tmp135_ = NULL;
		GXmlDomElement* _tmp136_ = NULL;
		GXmlDomNode* _tmp137_ = NULL;
		GXmlDomNode* _tmp138_ = NULL;
		GXmlDomNode* _tmp139_ = NULL;
		gchar* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		GXmlDomElement* _tmp143_ = NULL;
		GXmlDomNode* _tmp144_ = NULL;
		GXmlDomNode* _tmp145_ = NULL;
		GXmlDomNode* _tmp146_ = NULL;
		gboolean _tmp147_ = FALSE;
		GXmlDomElement* _tmp148_ = NULL;
		GXmlDomNode* _tmp149_ = NULL;
		GXmlDomNode* _tmp150_ = NULL;
		GXmlDomNode* _tmp151_ = NULL;
		GXmlDomElement* _tmp152_ = NULL;
		GXmlDomNode* _tmp153_ = NULL;
		GXmlDomNode* _tmp154_ = NULL;
		GXmlDomNode* _tmp155_ = NULL;
		gchar* _tmp156_ = NULL;
		gchar* _tmp157_ = NULL;
		gchar* _tmp158_ = NULL;
		GXmlDomNode* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlDomNode* _tmp161_ = NULL;
		GXmlDomElement* cn = NULL;
		GXmlDomElement* _tmp162_ = NULL;
		GXmlDomElement* _tmp163_ = NULL;
		gchar* _tmp164_ = NULL;
		gchar* _tmp165_ = NULL;
		gchar* _tmp166_ = NULL;
		GXmlDomElement* _tmp167_ = NULL;
		gchar* _tmp168_ = NULL;
		gchar* _tmp169_ = NULL;
		GXmlDomElement* _tmp170_ = NULL;
		GXmlDomNodeList* _tmp171_ = NULL;
		GXmlDomNodeList* _tmp172_ = NULL;
		GXmlDomNodeList* _tmp173_ = NULL;
		GXmlDomElement* _tmp174_ = NULL;
		GXmlDomNodeList* _tmp175_ = NULL;
		GXmlDomNodeList* _tmp176_ = NULL;
		GXmlDomNodeList* _tmp177_ = NULL;
		gint _tmp178_ = 0;
		gint _tmp179_ = 0;
		GXmlDomNode* _tmp180_ = NULL;
		GXmlDomElement* _tmp181_ = NULL;
		GXmlDomNode* _tmp182_ = NULL;
		GXmlDomElement* cn2 = NULL;
		GXmlDomElement* _tmp183_ = NULL;
		GXmlDomElement* _tmp184_ = NULL;
		gchar* _tmp185_ = NULL;
		gchar* _tmp186_ = NULL;
		gchar* _tmp187_ = NULL;
		GXmlDomElement* _tmp188_ = NULL;
		gchar* _tmp189_ = NULL;
		gchar* _tmp190_ = NULL;
		GXmlDomElement* _tmp191_ = NULL;
		GXmlDomNodeList* _tmp192_ = NULL;
		GXmlDomNodeList* _tmp193_ = NULL;
		GXmlDomNodeList* _tmp194_ = NULL;
		GXmlDomElement* _tmp195_ = NULL;
		GXmlDomNodeList* _tmp196_ = NULL;
		GXmlDomNodeList* _tmp197_ = NULL;
		GXmlDomNodeList* _tmp198_ = NULL;
		gint _tmp199_ = 0;
		gint _tmp200_ = 0;
		GXmlDomElement* _tmp201_ = NULL;
		GXmlDomNodeList* _tmp202_ = NULL;
		GXmlDomNodeList* _tmp203_ = NULL;
		GXmlDomNodeList* _tmp204_ = NULL;
		gpointer _tmp205_ = NULL;
		GXmlDomNode* _tmp206_ = NULL;
		GXmlDomElement* _tmp207_ = NULL;
		gchar* _tmp208_ = NULL;
		gchar* _tmp209_ = NULL;
		gchar* _tmp210_ = NULL;
		GXmlDomElement* _tmp211_ = NULL;
		GXmlDomElement* _tmp212_ = NULL;
		gboolean _tmp213_ = FALSE;
		GXmlDomElement* _tmp214_ = NULL;
		GXmlDomElement* _tmp215_ = NULL;
		gboolean _tmp216_ = FALSE;
		GXmlDomElement* e0 = NULL;
		GXmlDomDocument* _tmp217_ = NULL;
		GXmlDomElement* _tmp218_ = NULL;
		GXmlDomElement* _tmp219_ = NULL;
		GXmlDomElement* _tmp220_ = NULL;
		GXmlDomHTMLCollection* _tmp221_ = NULL;
		GXmlDomHTMLCollection* _tmp222_ = NULL;
		GXmlDomHTMLCollection* _tmp223_ = NULL;
		gpointer _tmp224_ = NULL;
		GXmlDomElement* _tmp225_ = NULL;
		GXmlDomHTMLCollection* _tmp226_ = NULL;
		GXmlDomHTMLCollection* _tmp227_ = NULL;
		GXmlDomHTMLCollection* _tmp228_ = NULL;
		gpointer _tmp229_ = NULL;
		GXmlDomElement* _tmp230_ = NULL;
		GXmlDomElement* _tmp231_ = NULL;
		gchar* _tmp232_ = NULL;
		gchar* _tmp233_ = NULL;
		gchar* _tmp234_ = NULL;
		GXmlDomDocument* _tmp235_ = NULL;
		GXmlDomElement* _tmp236_ = NULL;
		GXmlDomElement* _tmp237_ = NULL;
		GXmlDomElement* _tmp238_ = NULL;
		GXmlDomHTMLCollection* _tmp239_ = NULL;
		GXmlDomHTMLCollection* _tmp240_ = NULL;
		GXmlDomHTMLCollection* _tmp241_ = NULL;
		gpointer _tmp242_ = NULL;
		GXmlDomElement* _tmp243_ = NULL;
		GXmlDomNodeList* _tmp244_ = NULL;
		GXmlDomNodeList* _tmp245_ = NULL;
		GXmlDomNodeList* _tmp246_ = NULL;
		GXmlDomElement* _tmp247_ = NULL;
		gint _tmp248_ = 0;
		GXmlDomElement* e1 = NULL;
		GXmlDomDocument* _tmp249_ = NULL;
		GXmlDomElement* _tmp250_ = NULL;
		GXmlDomElement* _tmp251_ = NULL;
		GXmlDomElement* _tmp252_ = NULL;
		GXmlDomHTMLCollection* _tmp253_ = NULL;
		GXmlDomHTMLCollection* _tmp254_ = NULL;
		GXmlDomHTMLCollection* _tmp255_ = NULL;
		gpointer _tmp256_ = NULL;
		GXmlDomElement* _tmp257_ = NULL;
		GXmlDomHTMLCollection* _tmp258_ = NULL;
		GXmlDomHTMLCollection* _tmp259_ = NULL;
		GXmlDomHTMLCollection* _tmp260_ = NULL;
		gpointer _tmp261_ = NULL;
		GXmlDomElement* _tmp262_ = NULL;
		GXmlDomElement* _tmp263_ = NULL;
		gchar* _tmp264_ = NULL;
		gchar* _tmp265_ = NULL;
		gchar* _tmp266_ = NULL;
		GXmlDomDocument* _tmp267_ = NULL;
		GXmlDomElement* _tmp268_ = NULL;
		GXmlDomElement* _tmp269_ = NULL;
		GXmlDomElement* _tmp270_ = NULL;
		GXmlDomHTMLCollection* _tmp271_ = NULL;
		GXmlDomHTMLCollection* _tmp272_ = NULL;
		GXmlDomHTMLCollection* _tmp273_ = NULL;
		gpointer _tmp274_ = NULL;
		GXmlDomElement* _tmp275_ = NULL;
		GXmlDomNodeList* _tmp276_ = NULL;
		GXmlDomNodeList* _tmp277_ = NULL;
		GXmlDomNodeList* _tmp278_ = NULL;
		GXmlDomElement* _tmp279_ = NULL;
		gint _tmp280_ = 0;
		GXmlDomElement* e2 = NULL;
		GXmlDomDocument* _tmp281_ = NULL;
		GXmlDomElement* _tmp282_ = NULL;
		GXmlDomElement* _tmp283_ = NULL;
		GXmlDomElement* _tmp284_ = NULL;
		GXmlDomHTMLCollection* _tmp285_ = NULL;
		GXmlDomHTMLCollection* _tmp286_ = NULL;
		GXmlDomHTMLCollection* _tmp287_ = NULL;
		gpointer _tmp288_ = NULL;
		GXmlDomElement* _tmp289_ = NULL;
		GXmlDomHTMLCollection* _tmp290_ = NULL;
		GXmlDomHTMLCollection* _tmp291_ = NULL;
		GXmlDomHTMLCollection* _tmp292_ = NULL;
		gpointer _tmp293_ = NULL;
		GXmlDomElement* _tmp294_ = NULL;
		GXmlDomElement* _tmp295_ = NULL;
		gchar* _tmp296_ = NULL;
		gchar* _tmp297_ = NULL;
		gchar* _tmp298_ = NULL;
		GXmlDomDocument* _tmp299_ = NULL;
		GXmlDomElement* _tmp300_ = NULL;
		GXmlDomElement* _tmp301_ = NULL;
		GXmlDomElement* _tmp302_ = NULL;
		GXmlDomHTMLCollection* _tmp303_ = NULL;
		GXmlDomHTMLCollection* _tmp304_ = NULL;
		GXmlDomHTMLCollection* _tmp305_ = NULL;
		gpointer _tmp306_ = NULL;
		GXmlDomElement* _tmp307_ = NULL;
		GXmlDomNodeList* _tmp308_ = NULL;
		GXmlDomNodeList* _tmp309_ = NULL;
		GXmlDomNodeList* _tmp310_ = NULL;
		GXmlDomElement* _tmp311_ = NULL;
		gint _tmp312_ = 0;
		GXmlDomElement* _tmp313_ = NULL;
		GXmlDomNode* _tmp314_ = NULL;
		GXmlDomNode* _tmp315_ = NULL;
		GXmlDomNode* _tmp316_ = NULL;
		GXmlDomElement* _tmp317_ = NULL;
		gboolean _tmp318_ = FALSE;
		GXmlDomElement* _tmp319_ = NULL;
		GXmlDomNode* _tmp320_ = NULL;
		GXmlDomNode* _tmp321_ = NULL;
		GXmlDomNode* _tmp322_ = NULL;
		GXmlDomElement* _tmp323_ = NULL;
		gboolean _tmp324_ = FALSE;
		GXmlDomElement* _tmp325_ = NULL;
		GXmlDomNode* _tmp326_ = NULL;
		GXmlDomNode* _tmp327_ = NULL;
		GXmlDomNode* _tmp328_ = NULL;
		GXmlDomElement* _tmp329_ = NULL;
		gboolean _tmp330_ = FALSE;
		gboolean _tmp331_ = FALSE;
		GXmlDomElement* _tmp332_ = NULL;
		GXmlDomNode* _tmp333_ = NULL;
		GXmlDomNode* _tmp334_ = NULL;
		GXmlDomNode* _tmp335_ = NULL;
		GXmlDomElement* _tmp336_ = NULL;
		gboolean _tmp337_ = FALSE;
		gboolean _tmp338_ = FALSE;
		GXmlDomElement* _tmp345_ = NULL;
		GXmlDomElement* _tmp346_ = NULL;
		GXmlDomNodeDocumentPosition _tmp347_ = 0;
		gboolean _tmp348_ = FALSE;
		GXmlDomElement* _tmp349_ = NULL;
		GXmlDomNode* _tmp350_ = NULL;
		GXmlDomNode* _tmp351_ = NULL;
		GXmlDomNode* _tmp352_ = NULL;
		GXmlDomElement* _tmp353_ = NULL;
		gboolean _tmp354_ = FALSE;
		gboolean _tmp355_ = FALSE;
		GXmlDomElement* _tmp362_ = NULL;
		GXmlDomElement* _tmp363_ = NULL;
		GXmlDomNodeDocumentPosition _tmp364_ = 0;
		GXmlDomElement* _tmp365_ = NULL;
		GXmlDomNode* _tmp366_ = NULL;
		GXmlDomNode* _tmp367_ = NULL;
		GXmlDomNode* _tmp368_ = NULL;
		GXmlDomElement* _tmp369_ = NULL;
		gboolean _tmp370_ = FALSE;
		GXmlDomElement* _tmp371_ = NULL;
		GXmlDomElement* _tmp372_ = NULL;
		GXmlDomNode* _tmp373_ = NULL;
		GXmlDomNode* _tmp374_ = NULL;
		GXmlDomNode* _tmp375_ = NULL;
		GXmlDomNodeDocumentPosition _tmp376_ = 0;
		GXmlDomElement* _tmp377_ = NULL;
		GXmlDomElement* _tmp378_ = NULL;
		GXmlDomNodeList* _tmp379_ = NULL;
		GXmlDomNodeList* _tmp380_ = NULL;
		GXmlDomNodeList* _tmp381_ = NULL;
		gpointer _tmp382_ = NULL;
		GXmlDomNode* _tmp383_ = NULL;
		gboolean _tmp384_ = FALSE;
		GXmlDomElement* _tmp385_ = NULL;
		GXmlDomElement* _tmp386_ = NULL;
		GXmlDomNodeList* _tmp387_ = NULL;
		GXmlDomNodeList* _tmp388_ = NULL;
		GXmlDomNodeList* _tmp389_ = NULL;
		gpointer _tmp390_ = NULL;
		GXmlDomNode* _tmp391_ = NULL;
		GXmlDomNodeDocumentPosition _tmp392_ = 0;
		GXmlDomElement* b = NULL;
		GXmlDomDocument* _tmp393_ = NULL;
		GXmlDomElement* _tmp394_ = NULL;
		GXmlDomElement* _tmp395_ = NULL;
		GXmlDomElement* _tmp396_ = NULL;
		GXmlDomHTMLCollection* _tmp397_ = NULL;
		GXmlDomHTMLCollection* _tmp398_ = NULL;
		GXmlDomHTMLCollection* _tmp399_ = NULL;
		gpointer _tmp400_ = NULL;
		GXmlDomElement* _tmp401_ = NULL;
		GXmlDomElement* _tmp402_ = NULL;
		gchar* _tmp403_ = NULL;
		gchar* _tmp404_ = NULL;
		gchar* _tmp405_ = NULL;
		GXmlDomElement* ng = NULL;
		GXmlDomDocument* _tmp406_ = NULL;
		GXmlDomElement* _tmp407_ = NULL;
		GXmlDomElement* _tmp408_ = NULL;
		GXmlDomNodeList* _tmp409_ = NULL;
		GXmlDomNodeList* _tmp410_ = NULL;
		GXmlDomNodeList* _tmp411_ = NULL;
		GXmlDomElement* _tmp412_ = NULL;
		GXmlDomElement* _tmp413_ = NULL;
		gchar* _tmp414_ = NULL;
		gchar* _tmp415_ = NULL;
		GXmlDomElement* _tmp416_ = NULL;
		gchar* _tmp417_ = NULL;
		gchar* _tmp418_ = NULL;
		GXmlDomElement* _tmp419_ = NULL;
		gboolean _tmp420_ = FALSE;
		GXmlDomElement* ng2 = NULL;
		GXmlDomDocument* _tmp421_ = NULL;
		GXmlDomElement* _tmp422_ = NULL;
		GXmlDomElement* _tmp423_ = NULL;
		GXmlDomNodeList* _tmp424_ = NULL;
		GXmlDomNodeList* _tmp425_ = NULL;
		GXmlDomNodeList* _tmp426_ = NULL;
		GXmlDomElement* _tmp427_ = NULL;
		GXmlDomElement* _tmp428_ = NULL;
		gchar* _tmp429_ = NULL;
		gchar* _tmp430_ = NULL;
		GXmlDomElement* _tmp431_ = NULL;
		gchar* _tmp432_ = NULL;
		gchar* _tmp433_ = NULL;
		GXmlDomElement* _tmp434_ = NULL;
		gboolean _tmp435_ = FALSE;
		GXmlDomElement* _tmp436_ = NULL;
		GXmlDomDocument* _tmp437_ = NULL;
		GXmlDomElement* _tmp438_ = NULL;
		GXmlDomElement* pn = NULL;
		GXmlDomElement* _tmp439_ = NULL;
		GXmlDomElement* _tmp440_ = NULL;
		GXmlDomElement* p = NULL;
		GXmlDomDocument* _tmp441_ = NULL;
		GXmlDomElement* _tmp442_ = NULL;
		GXmlDomElement* _tmp443_ = NULL;
		GXmlDomElement* _tmp444_ = NULL;
		GXmlDomHTMLCollection* _tmp445_ = NULL;
		GXmlDomHTMLCollection* _tmp446_ = NULL;
		GXmlDomHTMLCollection* _tmp447_ = NULL;
		gpointer _tmp448_ = NULL;
		GXmlDomElement* _tmp449_ = NULL;
		GXmlDomElement* _tmp450_ = NULL;
		gchar* _tmp451_ = NULL;
		gchar* _tmp452_ = NULL;
		gchar* _tmp453_ = NULL;
		GXmlDomElement* cp0 = NULL;
		GXmlDomElement* _tmp454_ = NULL;
		GXmlDomHTMLCollection* _tmp455_ = NULL;
		GXmlDomHTMLCollection* _tmp456_ = NULL;
		GXmlDomHTMLCollection* _tmp457_ = NULL;
		gpointer _tmp458_ = NULL;
		GXmlDomElement* _tmp459_ = NULL;
		GXmlDomElement* _tmp460_ = NULL;
		gchar* _tmp461_ = NULL;
		gchar* _tmp462_ = NULL;
		gchar* _tmp463_ = NULL;
		GXmlDomElement* _tmp464_ = NULL;
		gchar* _tmp465_ = NULL;
		gchar* _tmp466_ = NULL;
		GXmlDomElement* _tmp467_ = NULL;
		GXmlDomElement* _tmp468_ = NULL;
		gboolean _tmp469_ = FALSE;
		GXmlDomElement* _tmp470_ = NULL;
		GXmlDomNode* _tmp471_ = NULL;
		GXmlDomNode* _tmp472_ = NULL;
		GXmlDomNode* _tmp473_ = NULL;
		GXmlDomElement* _tmp474_ = NULL;
		gboolean _tmp475_ = FALSE;
		GXmlDomElement* _tmp476_ = NULL;
		GXmlDomElement* _tmp477_ = NULL;
		GXmlDomElement* _tmp478_ = NULL;
		GXmlDomNode* _tmp479_ = NULL;
		GXmlDomNode* _tmp480_ = NULL;
		GXmlDomElement* ppn = NULL;
		GXmlDomElement* _tmp481_ = NULL;
		GXmlDomHTMLCollection* _tmp482_ = NULL;
		GXmlDomHTMLCollection* _tmp483_ = NULL;
		GXmlDomHTMLCollection* _tmp484_ = NULL;
		gpointer _tmp485_ = NULL;
		GXmlDomElement* _tmp486_ = NULL;
		GXmlDomElement* _tmp487_ = NULL;
		gchar* _tmp488_ = NULL;
		gchar* _tmp489_ = NULL;
		gchar* _tmp490_ = NULL;
		GXmlDomElement* _tmp491_ = NULL;
		gboolean _tmp492_ = FALSE;
		GXmlDomElement* _tmp493_ = NULL;
		gchar* _tmp494_ = NULL;
		gchar* _tmp495_ = NULL;
		GXmlDomElement* _tmp496_ = NULL;
		GXmlDomDocument* _tmp497_ = NULL;
		GXmlDomElement* _tmp498_ = NULL;
		GXmlDomElement* pn2 = NULL;
		GXmlDomElement* _tmp499_ = NULL;
		GXmlDomElement* _tmp500_ = NULL;
		GXmlDomElement* _tmp501_ = NULL;
		GXmlDomElement* _tmp502_ = NULL;
		GXmlDomNode* _tmp503_ = NULL;
		GXmlDomNode* _tmp504_ = NULL;
		GXmlDomElement* _tmp505_ = NULL;
		GXmlDomHTMLCollection* _tmp506_ = NULL;
		GXmlDomHTMLCollection* _tmp507_ = NULL;
		GXmlDomHTMLCollection* _tmp508_ = NULL;
		gint _tmp509_ = 0;
		gint _tmp510_ = 0;
		GXmlDomElement* _tmp511_ = NULL;
		GXmlDomHTMLCollection* _tmp512_ = NULL;
		GXmlDomHTMLCollection* _tmp513_ = NULL;
		GXmlDomHTMLCollection* _tmp514_ = NULL;
		gpointer _tmp515_ = NULL;
		GXmlDomElement* _tmp516_ = NULL;
		GXmlDomElement* _tmp517_ = NULL;
		GXmlDomHTMLCollection* _tmp518_ = NULL;
		GXmlDomHTMLCollection* _tmp519_ = NULL;
		GXmlDomHTMLCollection* _tmp520_ = NULL;
		gpointer _tmp521_ = NULL;
		GXmlDomElement* _tmp522_ = NULL;
		gchar* _tmp523_ = NULL;
		gchar* _tmp524_ = NULL;
		gchar* _tmp525_ = NULL;
		GXmlDomElement* _tmp526_ = NULL;
		GXmlDomHTMLCollection* _tmp527_ = NULL;
		GXmlDomHTMLCollection* _tmp528_ = NULL;
		GXmlDomHTMLCollection* _tmp529_ = NULL;
		gpointer _tmp530_ = NULL;
		GXmlDomElement* _tmp531_ = NULL;
		gchar* _tmp532_ = NULL;
		gchar* _tmp533_ = NULL;
		GXmlDomElement* _tmp534_ = NULL;
		GXmlDomDocument* _tmp535_ = NULL;
		GXmlDomElement* _tmp536_ = NULL;
		GXmlDomElement* pn3 = NULL;
		GXmlDomElement* _tmp537_ = NULL;
		GXmlDomElement* _tmp538_ = NULL;
		GXmlDomElement* _tmp539_ = NULL;
		GXmlDomElement* _tmp540_ = NULL;
		GXmlDomElement* _tmp541_ = NULL;
		GXmlDomElement* _tmp542_ = NULL;
		GXmlDomNode* _tmp543_ = NULL;
		GXmlDomNode* _tmp544_ = NULL;
		GXmlDomElement* _tmp545_ = NULL;
		GXmlDomHTMLCollection* _tmp546_ = NULL;
		GXmlDomHTMLCollection* _tmp547_ = NULL;
		GXmlDomHTMLCollection* _tmp548_ = NULL;
		gint _tmp549_ = 0;
		gint _tmp550_ = 0;
		GXmlDomElement* _tmp551_ = NULL;
		GXmlDomHTMLCollection* _tmp552_ = NULL;
		GXmlDomHTMLCollection* _tmp553_ = NULL;
		GXmlDomHTMLCollection* _tmp554_ = NULL;
		gpointer _tmp555_ = NULL;
		GXmlDomElement* _tmp556_ = NULL;
		GXmlDomElement* _tmp557_ = NULL;
		GXmlDomHTMLCollection* _tmp558_ = NULL;
		GXmlDomHTMLCollection* _tmp559_ = NULL;
		GXmlDomHTMLCollection* _tmp560_ = NULL;
		gpointer _tmp561_ = NULL;
		GXmlDomElement* _tmp562_ = NULL;
		gchar* _tmp563_ = NULL;
		gchar* _tmp564_ = NULL;
		gchar* _tmp565_ = NULL;
		GXmlDomElement* _tmp566_ = NULL;
		GXmlDomHTMLCollection* _tmp567_ = NULL;
		GXmlDomHTMLCollection* _tmp568_ = NULL;
		GXmlDomHTMLCollection* _tmp569_ = NULL;
		gpointer _tmp570_ = NULL;
		GXmlDomElement* _tmp571_ = NULL;
		gchar* _tmp572_ = NULL;
		gchar* _tmp573_ = NULL;
		GXmlDomElement* _tmp574_ = NULL;
		GXmlDomHTMLCollection* _tmp575_ = NULL;
		GXmlDomHTMLCollection* _tmp576_ = NULL;
		GXmlDomHTMLCollection* _tmp577_ = NULL;
		gpointer _tmp578_ = NULL;
		GXmlDomElement* _tmp579_ = NULL;
		gchar* _tmp580_ = NULL;
		gchar* _tmp581_ = NULL;
		GXmlDomElement* _tmp582_ = NULL;
		GXmlDomDocument* _tmp583_ = NULL;
		GXmlDomElement* _tmp584_ = NULL;
		GXmlDomElement* pn4 = NULL;
		GXmlDomElement* _tmp585_ = NULL;
		GXmlDomElement* _tmp586_ = NULL;
		GXmlDomElement* _tmp587_ = NULL;
		GXmlDomElement* _tmp588_ = NULL;
		GXmlDomElement* _tmp589_ = NULL;
		GXmlDomElement* _tmp590_ = NULL;
		GXmlDomNodeList* _tmp591_ = NULL;
		GXmlDomNodeList* _tmp592_ = NULL;
		GXmlDomNodeList* _tmp593_ = NULL;
		gpointer _tmp594_ = NULL;
		GXmlDomNode* _tmp595_ = NULL;
		GXmlDomNode* _tmp596_ = NULL;
		GXmlDomNode* _tmp597_ = NULL;
		GXmlDomElement* _tmp598_ = NULL;
		GXmlDomHTMLCollection* _tmp599_ = NULL;
		GXmlDomHTMLCollection* _tmp600_ = NULL;
		GXmlDomHTMLCollection* _tmp601_ = NULL;
		gint _tmp602_ = 0;
		gint _tmp603_ = 0;
		GXmlDomElement* _tmp604_ = NULL;
		GXmlDomHTMLCollection* _tmp605_ = NULL;
		GXmlDomHTMLCollection* _tmp606_ = NULL;
		GXmlDomHTMLCollection* _tmp607_ = NULL;
		gpointer _tmp608_ = NULL;
		GXmlDomElement* _tmp609_ = NULL;
		GXmlDomElement* _tmp610_ = NULL;
		GXmlDomHTMLCollection* _tmp611_ = NULL;
		GXmlDomHTMLCollection* _tmp612_ = NULL;
		GXmlDomHTMLCollection* _tmp613_ = NULL;
		gpointer _tmp614_ = NULL;
		GXmlDomElement* _tmp615_ = NULL;
		gchar* _tmp616_ = NULL;
		gchar* _tmp617_ = NULL;
		gchar* _tmp618_ = NULL;
		GXmlDomElement* _tmp619_ = NULL;
		GXmlDomHTMLCollection* _tmp620_ = NULL;
		GXmlDomHTMLCollection* _tmp621_ = NULL;
		GXmlDomHTMLCollection* _tmp622_ = NULL;
		gpointer _tmp623_ = NULL;
		GXmlDomElement* _tmp624_ = NULL;
		gchar* _tmp625_ = NULL;
		gchar* _tmp626_ = NULL;
		GXmlDomElement* _tmp627_ = NULL;
		GXmlDomHTMLCollection* _tmp628_ = NULL;
		GXmlDomHTMLCollection* _tmp629_ = NULL;
		GXmlDomHTMLCollection* _tmp630_ = NULL;
		gpointer _tmp631_ = NULL;
		GXmlDomElement* _tmp632_ = NULL;
		gchar* _tmp633_ = NULL;
		gchar* _tmp634_ = NULL;
		GXmlDomElement* _tmp635_ = NULL;
		GXmlDomElement* _tmp636_ = NULL;
		GXmlDomHTMLCollection* _tmp637_ = NULL;
		GXmlDomHTMLCollection* _tmp638_ = NULL;
		GXmlDomHTMLCollection* _tmp639_ = NULL;
		gpointer _tmp640_ = NULL;
		GXmlDomElement* _tmp641_ = NULL;
		GXmlDomNode* _tmp642_ = NULL;
		GXmlDomNode* _tmp643_ = NULL;
		GXmlDomElement* _tmp644_ = NULL;
		GXmlDomHTMLCollection* _tmp645_ = NULL;
		GXmlDomHTMLCollection* _tmp646_ = NULL;
		GXmlDomHTMLCollection* _tmp647_ = NULL;
		gint _tmp648_ = 0;
		gint _tmp649_ = 0;
		GXmlDomElement* _tmp650_ = NULL;
		GXmlDomHTMLCollection* _tmp651_ = NULL;
		GXmlDomHTMLCollection* _tmp652_ = NULL;
		GXmlDomHTMLCollection* _tmp653_ = NULL;
		gpointer _tmp654_ = NULL;
		GXmlDomElement* _tmp655_ = NULL;
		GXmlDomElement* _tmp656_ = NULL;
		GXmlDomHTMLCollection* _tmp657_ = NULL;
		GXmlDomHTMLCollection* _tmp658_ = NULL;
		GXmlDomHTMLCollection* _tmp659_ = NULL;
		gpointer _tmp660_ = NULL;
		GXmlDomElement* _tmp661_ = NULL;
		gchar* _tmp662_ = NULL;
		gchar* _tmp663_ = NULL;
		gchar* _tmp664_ = NULL;
		GXmlDomElement* _tmp665_ = NULL;
		gboolean _tmp666_ = FALSE;
		GXmlDomElement* _tmp667_ = NULL;
		GXmlDomHTMLCollection* _tmp668_ = NULL;
		GXmlDomHTMLCollection* _tmp669_ = NULL;
		GXmlDomHTMLCollection* _tmp670_ = NULL;
		gpointer _tmp671_ = NULL;
		GXmlDomElement* _tmp672_ = NULL;
		gchar* _tmp673_ = NULL;
		gchar* _tmp674_ = NULL;
		GXmlDomElement* _tmp675_ = NULL;
		GXmlDomElement* _tmp676_ = NULL;
		gchar* _tmp677_ = NULL;
		gchar* _tmp678_ = NULL;
		gchar* _tmp679_ = NULL;
		GXmlDomElement* _tmp680_ = NULL;
		gchar* _tmp681_ = NULL;
		gchar* _tmp682_ = NULL;
		GXmlDomElement* _tmp683_ = NULL;
		gchar* _tmp684_ = NULL;
		gchar* _tmp685_ = NULL;
		GXmlDomElement* _tmp686_ = NULL;
		gchar* _tmp687_ = NULL;
		gchar* _tmp688_ = NULL;
		gchar* _tmp689_ = NULL;
		GXmlDomHTMLCollection* l = NULL;
		GXmlDomDocument* _tmp690_ = NULL;
		GXmlDomElement* _tmp691_ = NULL;
		GXmlDomElement* _tmp692_ = NULL;
		GXmlDomElement* _tmp693_ = NULL;
		GXmlDomHTMLCollection* _tmp694_ = NULL;
		GXmlDomHTMLCollection* _tmp695_ = NULL;
		gint _tmp696_ = 0;
		gint _tmp697_ = 0;
		gpointer _tmp698_ = NULL;
		GXmlDomElement* _tmp699_ = NULL;
		gpointer _tmp700_ = NULL;
		GXmlDomElement* _tmp701_ = NULL;
		gpointer _tmp702_ = NULL;
		GXmlDomElement* _tmp703_ = NULL;
		gpointer _tmp704_ = NULL;
		GXmlDomElement* _tmp705_ = NULL;
		gchar* _tmp706_ = NULL;
		gchar* _tmp707_ = NULL;
		gchar* _tmp708_ = NULL;
		gpointer _tmp709_ = NULL;
		GXmlDomElement* _tmp710_ = NULL;
		gchar* _tmp711_ = NULL;
		gchar* _tmp712_ = NULL;
		gchar* _tmp713_ = NULL;
		gpointer _tmp714_ = NULL;
		GXmlDomElement* _tmp715_ = NULL;
		gchar* _tmp716_ = NULL;
		gchar* _tmp717_ = NULL;
		gchar* _tmp718_ = NULL;
		GXmlDomDocument* _tmp719_ = NULL;
		GXmlDomElement* _tmp720_ = NULL;
		GXmlDomElement* _tmp721_ = NULL;
		GXmlDomElement* _tmp722_ = NULL;
		GXmlDomHTMLCollection* _tmp723_ = NULL;
		GXmlDomHTMLCollection* _tmp724_ = NULL;
		GXmlDomHTMLCollection* _tmp725_ = NULL;
		gint _tmp726_ = 0;
		gint _tmp727_ = 0;
		GXmlDomHTMLCollection* lnst = NULL;
		GXmlDomDocument* _tmp728_ = NULL;
		GXmlDomElement* _tmp729_ = NULL;
		GXmlDomElement* _tmp730_ = NULL;
		GXmlDomElement* _tmp731_ = NULL;
		GXmlDomHTMLCollection* _tmp732_ = NULL;
		GXmlDomHTMLCollection* _tmp733_ = NULL;
		gint _tmp734_ = 0;
		gint _tmp735_ = 0;
		GXmlDomElement* nnst = NULL;
		GXmlDomElement* _tmp736_ = NULL;
		gchar* _tmp737_ = NULL;
		gchar* _tmp738_ = NULL;
		gchar* _tmp739_ = NULL;
		GXmlDomHTMLCollection* lns = NULL;
		GXmlDomDocument* _tmp740_ = NULL;
		GXmlDomElement* _tmp741_ = NULL;
		GXmlDomElement* _tmp742_ = NULL;
		GXmlDomElement* _tmp743_ = NULL;
		GXmlDomHTMLCollection* _tmp744_ = NULL;
		GXmlDomHTMLCollection* _tmp745_ = NULL;
		gint _tmp746_ = 0;
		gint _tmp747_ = 0;
		GXmlDomElement* _tmp748_ = NULL;
		GXmlDomElement* _tmp749_ = NULL;
		GXmlDomElement* _tmp750_ = NULL;
		GXmlDomElement* _tmp751_ = NULL;
		gchar* _tmp752_ = NULL;
		gchar* _tmp753_ = NULL;
		gchar* _tmp754_ = NULL;
		GXmlDomHTMLCollection* lcl = NULL;
		GXmlDomDocument* _tmp755_ = NULL;
		GXmlDomElement* _tmp756_ = NULL;
		GXmlDomElement* _tmp757_ = NULL;
		GXmlDomElement* _tmp758_ = NULL;
		GXmlDomHTMLCollection* _tmp759_ = NULL;
		GXmlDomHTMLCollection* _tmp760_ = NULL;
		gint _tmp761_ = 0;
		gint _tmp762_ = 0;
		GXmlDomElement* _tmp763_ = NULL;
		GXmlDomElement* _tmp764_ = NULL;
		GXmlDomElement* _tmp765_ = NULL;
		GXmlDomElement* _tmp766_ = NULL;
		GXmlDomElement* _tmp767_ = NULL;
		GXmlDomElement* _tmp768_ = NULL;
		gchar* _tmp769_ = NULL;
		gchar* _tmp770_ = NULL;
		gchar* _tmp771_ = NULL;
		GXmlDomElement* _tmp772_ = NULL;
		GXmlDomElement* _tmp773_ = NULL;
		gchar* _tmp774_ = NULL;
		gchar* _tmp775_ = NULL;
		gchar* _tmp776_ = NULL;
#line 172 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error_);
#line 172 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 172 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2077 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 172 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 172 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 173 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 173 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element (_tmp4_);
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp7_);
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == 1, "doc.document_element.children.size == 1");
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 174 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_get_document_element (_tmp13_);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp16_);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = (GXmlDomElement*) _tmp20_;
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp21_ != NULL, "doc.document_element.children[0] != null");
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 175 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = doc;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp25_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gee_list_get ((GeeList*) _tmp28_, 0);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = (GXmlDomElement*) _tmp29_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp30_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gee_list_get ((GeeList*) _tmp33_, 1);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = (GXmlDomElement*) _tmp34_;
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp35_ != NULL, "doc.document_element.children[0].children[1] != null");
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp30_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 176 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = doc;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_document_get_document_element (_tmp36_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp39_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gee_list_get ((GeeList*) _tmp42_, 0);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = (GXmlDomElement*) _tmp43_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp44_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = gee_list_get ((GeeList*) _tmp47_, 1);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = (GXmlDomElement*) _tmp48_;
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp44_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 177 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _tmp49_;
#line 178 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = e;
#line 178 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp50_);
#line 178 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 178 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = doc;
#line 178 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp52_ == G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument), "e.owner_document == (DomDocument) doc");
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = e;
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp54_);
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp57_ != NULL, "e.parent_node != null");
#line 179 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = e;
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp59_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp58_);
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp62_ = gxml_dom_node_get_node_name (_tmp61_);
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "body") == 0, "e.parent_node.node_name == \"body\"");
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp64_);
#line 180 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp61_);
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp65_ = e;
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp66_ = gxml_dom_node_get_parent_element ((GXmlDomNode*) _tmp65_);
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp67_ = _tmp66_;
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp68_ != NULL, "e.parent_element != null");
#line 181 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp68_);
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp69_ = e;
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp70_ = gxml_dom_node_get_parent_element ((GXmlDomNode*) _tmp69_);
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp73_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp72_);
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "body") == 0, "e.parent_element.node_name == \"body\"");
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp75_);
#line 182 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp76_ = e;
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp76_);
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp79_ != NULL, "e.child_nodes != null");
#line 183 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp80_ = e;
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp81_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp80_);
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp83_ = _tmp82_;
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp84_ = gee_collection_get_size ((GeeCollection*) _tmp83_);
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp85_ == 1, "e.child_nodes.size == 1");
#line 184 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp83_);
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp86_ = e;
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp90_ = gxml_dom_node_list_item (_tmp89_, 0);
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp91_ != NULL, "e.child_nodes.item (0) != null");
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 185 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp92_ = e;
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp93_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp92_);
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp96_ = gxml_dom_node_list_item (_tmp95_, 0);
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp97_, GXML_TYPE_DOM_TEXT), "e.child_nodes.item (0) is DomText");
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp97_);
#line 186 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp95_);
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp98_ = e;
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp99_ = gxml_dom_node_get_previous_sibling ((GXmlDomNode*) _tmp98_);
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp101_ != NULL, "e.previous_sibling != null");
#line 187 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp102_ = e;
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp103_ = gxml_dom_node_get_previous_sibling ((GXmlDomNode*) _tmp102_);
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp105_, GXML_TYPE_DOM_TEXT), "e.previous_sibling is DomText");
#line 188 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp106_ = e;
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_node_get_next_sibling ((GXmlDomNode*) _tmp106_);
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp109_ != NULL, "e.next_sibling != null");
#line 189 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp109_);
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp110_ = e;
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp111_ = gxml_dom_node_get_next_sibling ((GXmlDomNode*) _tmp110_);
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp113_, GXML_TYPE_DOM_TEXT), "e.next_sibling is DomText");
#line 190 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp113_);
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp114_ = e;
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp115_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp114_);
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp118_ = gxml_dom_node_list_item (_tmp117_, 0);
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp119_ = _tmp118_;
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 191 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		t = _tmp119_;
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp120_ = t;
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp121_ = gxml_dom_node_get_previous_sibling (_tmp120_);
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp122_ = _tmp121_;
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp123_ == NULL, "t.previous_sibling == null");
#line 192 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp124_ = t;
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_node_get_next_sibling (_tmp124_);
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp127_ == NULL, "t.next_sibling == null");
#line 193 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp127_);
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp128_ = t;
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp129_ = gxml_dom_node_get_text_content (_tmp128_);
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp131_ != NULL, "t.text_content != null");
#line 194 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp132_ = t;
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp133_ = gxml_dom_node_get_text_content (_tmp132_);
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp135_, "p01 p id") == 0, "t.text_content == \"p01 p id\"");
#line 195 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp135_);
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp136_ = e;
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp137_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp136_);
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp139_ = _tmp138_;
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_text_content (_tmp139_);
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp142_, "\n\n\n\n\n") == 0, "e.parent_node.text_content == \"\\n\\n\\n\\n\\n\"");
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp142_);
#line 196 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp139_);
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp143_ = e;
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp144_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp143_);
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp147_ = gxml_dom_node_has_child_nodes (_tmp146_);
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp147_, "e.parent_node.has_child_nodes ()");
#line 197 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp148_ = e;
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp149_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp148_);
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_node_normalize (_tmp151_);
#line 198 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp151_);
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp152_ = e;
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp153_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp152_);
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp155_ = _tmp154_;
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp156_ = gxml_dom_node_get_text_content (_tmp155_);
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp158_ = _tmp157_;
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp158_ == NULL, "e.parent_node.text_content == null");
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp158_);
#line 199 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp155_);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp160_ = e;
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp161_ = gxml_dom_node_clone_node ((GXmlDomNode*) _tmp160_, FALSE, &_inner_error_);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp159_ = _tmp161_;
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2548 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp162_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp159_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp159_) : NULL);
#line 200 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		cn = _tmp162_;
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp163_ = cn;
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp164_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp163_);
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp166_ = _tmp165_;
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp166_, "p") == 0, "cn.node_name == \"p\"");
#line 201 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp166_);
#line 202 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp167_ = cn;
#line 202 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp168_ = gxml_dom_element_get_attribute (_tmp167_, "id");
#line 202 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 202 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp169_, "p01") == 0, "cn.get_attribute (\"id\") == \"p01\"");
#line 202 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp169_);
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp170_ = cn;
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp171_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp170_);
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp172_ = _tmp171_;
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp173_ != NULL, "cn.child_nodes != null");
#line 203 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp173_);
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp174_ = cn;
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp175_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp174_);
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp177_ = _tmp176_;
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp178_ = gee_collection_get_size ((GeeCollection*) _tmp177_);
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp179_ == 0, "cn.child_nodes.size == 0");
#line 204 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp181_ = e;
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp182_ = gxml_dom_node_clone_node ((GXmlDomNode*) _tmp181_, TRUE, &_inner_error_);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp180_ = _tmp182_;
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2625 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp183_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp180_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp180_) : NULL);
#line 205 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		cn2 = _tmp183_;
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp184_ = cn2;
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp185_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp184_);
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp187_, "p") == 0, "cn2.node_name == \"p\"");
#line 206 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp187_);
#line 207 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp188_ = cn2;
#line 207 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp189_ = gxml_dom_element_get_attribute (_tmp188_, "id");
#line 207 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp190_ = _tmp189_;
#line 207 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp190_, "p01") == 0, "cn2.get_attribute (\"id\") == \"p01\"");
#line 207 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp190_);
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp191_ = cn2;
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp192_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp191_);
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp194_ != NULL, "cn2.child_nodes != null");
#line 208 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp194_);
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp195_ = cn2;
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp196_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp195_);
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp198_ = _tmp197_;
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp199_ = gee_collection_get_size ((GeeCollection*) _tmp198_);
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp200_ == 1, "cn2.child_nodes.size == 1");
#line 209 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp198_);
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp201_ = cn2;
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp202_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp201_);
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp203_ = _tmp202_;
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp204_ = _tmp203_;
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp205_ = gee_list_get ((GeeList*) _tmp204_, 0);
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp206_ = (GXmlDomNode*) _tmp205_;
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp206_, GXML_TYPE_DOM_TEXT), "cn2.child_nodes[0] is DomText");
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp206_);
#line 210 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp204_);
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp207_ = cn2;
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp208_ = gxml_dom_node_get_text_content ((GXmlDomNode*) _tmp207_);
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp210_ = _tmp209_;
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp210_, "p01 p id") == 0, "cn2.text_content == \"p01 p id\"");
#line 211 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp210_);
#line 212 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp211_ = e;
#line 212 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp212_ = cn;
#line 212 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp213_ = gxml_dom_node_is_equal_node ((GXmlDomNode*) _tmp211_, (GXmlDomNode*) _tmp212_);
#line 212 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (!_tmp213_, "!e.is_equal_node (cn)");
#line 213 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp214_ = e;
#line 213 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp215_ = cn2;
#line 213 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp216_ = gxml_dom_node_is_equal_node ((GXmlDomNode*) _tmp214_, (GXmlDomNode*) _tmp215_);
#line 213 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp216_, "e.is_equal_node (cn2)");
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp217_ = doc;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp218_ = gxml_dom_document_get_document_element (_tmp217_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp219_ = _tmp218_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp220_ = _tmp219_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp221_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp220_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp222_ = _tmp221_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp223_ = _tmp222_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp224_ = gee_list_get ((GeeList*) _tmp223_, 0);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp225_ = (GXmlDomElement*) _tmp224_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp226_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp225_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp227_ = _tmp226_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp228_ = _tmp227_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp229_ = gee_list_get ((GeeList*) _tmp228_, 0);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp230_ = (GXmlDomElement*) _tmp229_;
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp228_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp225_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp223_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp220_);
#line 214 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e0 = _tmp230_;
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp231_ = e0;
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp232_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp231_);
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp233_ = _tmp232_;
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp234_ = _tmp233_;
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp234_, "p") == 0, "e0.node_name == \"p\"");
#line 215 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp234_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp235_ = doc;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp236_ = gxml_dom_document_get_document_element (_tmp235_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp237_ = _tmp236_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp238_ = _tmp237_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp239_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp238_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp240_ = _tmp239_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp241_ = _tmp240_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp242_ = gee_list_get ((GeeList*) _tmp241_, 0);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp243_ = (GXmlDomElement*) _tmp242_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp244_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp243_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp245_ = _tmp244_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp246_ = _tmp245_;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp247_ = e0;
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp248_ = gee_list_index_of ((GeeList*) _tmp246_, (GXmlDomNode*) _tmp247_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp248_ == 0, "doc.document_element.children[0].child_nodes.index_of (e0) == 0");
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp246_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp243_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp241_);
#line 216 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp238_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp249_ = doc;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp250_ = gxml_dom_document_get_document_element (_tmp249_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp251_ = _tmp250_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp252_ = _tmp251_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp253_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp252_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp254_ = _tmp253_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp255_ = _tmp254_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp256_ = gee_list_get ((GeeList*) _tmp255_, 0);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp257_ = (GXmlDomElement*) _tmp256_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp258_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp257_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp259_ = _tmp258_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp260_ = _tmp259_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp261_ = gee_list_get ((GeeList*) _tmp260_, 1);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp262_ = (GXmlDomElement*) _tmp261_;
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp260_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp257_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp255_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp252_);
#line 217 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e1 = _tmp262_;
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp263_ = e1;
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp264_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp263_);
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp265_ = _tmp264_;
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp266_ = _tmp265_;
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp266_, "p") == 0, "e1.node_name == \"p\"");
#line 218 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp266_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp267_ = doc;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp268_ = gxml_dom_document_get_document_element (_tmp267_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp269_ = _tmp268_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp270_ = _tmp269_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp271_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp270_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp272_ = _tmp271_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp273_ = _tmp272_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp274_ = gee_list_get ((GeeList*) _tmp273_, 0);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp275_ = (GXmlDomElement*) _tmp274_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp276_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp275_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp277_ = _tmp276_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp278_ = _tmp277_;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp279_ = e1;
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp280_ = gee_list_index_of ((GeeList*) _tmp278_, (GXmlDomNode*) _tmp279_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp280_ == 1, "doc.document_element.children[0].child_nodes.index_of (e1) == 1");
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp278_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp275_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp273_);
#line 219 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp270_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp281_ = doc;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp282_ = gxml_dom_document_get_document_element (_tmp281_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp283_ = _tmp282_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp284_ = _tmp283_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp285_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp284_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp286_ = _tmp285_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp287_ = _tmp286_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp288_ = gee_list_get ((GeeList*) _tmp287_, 0);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp289_ = (GXmlDomElement*) _tmp288_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp290_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp289_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp291_ = _tmp290_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp292_ = _tmp291_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp293_ = gee_list_get ((GeeList*) _tmp292_, 2);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp294_ = (GXmlDomElement*) _tmp293_;
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp292_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp289_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp287_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp284_);
#line 220 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e2 = _tmp294_;
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp295_ = e2;
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp296_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp295_);
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp297_ = _tmp296_;
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp298_ = _tmp297_;
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp298_, "p") == 0, "e2.node_name == \"p\"");
#line 221 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp298_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp299_ = doc;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp300_ = gxml_dom_document_get_document_element (_tmp299_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp301_ = _tmp300_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp302_ = _tmp301_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp303_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp302_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp304_ = _tmp303_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp305_ = _tmp304_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp306_ = gee_list_get ((GeeList*) _tmp305_, 0);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp307_ = (GXmlDomElement*) _tmp306_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp308_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp307_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp309_ = _tmp308_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp310_ = _tmp309_;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp311_ = e2;
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp312_ = gee_list_index_of ((GeeList*) _tmp310_, (GXmlDomNode*) _tmp311_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp312_ == 2, "doc.document_element.children[0].child_nodes.index_of (e2) == 2");
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp310_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp307_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp305_);
#line 222 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp302_);
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp313_ = e;
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp314_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp313_);
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp315_ = _tmp314_;
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp316_ = _tmp315_;
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp317_ = e0;
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp318_ = gxml_dom_node_contains (_tmp316_, (GXmlDomNode*) _tmp317_);
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp318_, "e.parent_node.contains (e0)");
#line 223 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp316_);
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp319_ = e;
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp320_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp319_);
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp321_ = _tmp320_;
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp322_ = _tmp321_;
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp323_ = e1;
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp324_ = gxml_dom_node_contains (_tmp322_, (GXmlDomNode*) _tmp323_);
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp324_, "e.parent_node.contains (e1)");
#line 224 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp322_);
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp325_ = e;
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp326_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp325_);
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp327_ = _tmp326_;
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp328_ = _tmp327_;
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp329_ = e2;
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp330_ = gxml_dom_node_contains (_tmp328_, (GXmlDomNode*) _tmp329_);
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp330_, "e.parent_node.contains (e2)");
#line 225 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp328_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp332_ = e1;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp333_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp332_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp334_ = _tmp333_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp335_ = _tmp334_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp336_ = e0;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp337_ = gxml_dom_node_contains (_tmp335_, (GXmlDomNode*) _tmp336_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp338_ = _tmp337_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp335_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp338_) {
#line 3058 "DomGDocumentTest.c"
			GXmlDomElement* _tmp339_ = NULL;
			GXmlDomNode* _tmp340_ = NULL;
			GXmlDomNode* _tmp341_ = NULL;
			GXmlDomNode* _tmp342_ = NULL;
			GXmlDomElement* _tmp343_ = NULL;
			gboolean _tmp344_ = FALSE;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp339_ = e0;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp340_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp339_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp341_ = _tmp340_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp342_ = _tmp341_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp343_ = e1;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp344_ = gxml_dom_node_contains (_tmp342_, (GXmlDomNode*) _tmp343_);
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp331_ = _tmp344_;
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp342_);
#line 3081 "DomGDocumentTest.c"
		} else {
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp331_ = FALSE;
#line 3085 "DomGDocumentTest.c"
		}
#line 226 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp331_, "e1.parent_node.contains (e0) && e0.parent_node.contains (e1)");
#line 227 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp345_ = e1;
#line 227 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp346_ = e0;
#line 227 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp347_ = gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp345_, (GXmlDomNode*) _tmp346_);
#line 227 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp347_ == GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING, "e1.compare_document_position (e0) == DomNode.DocumentPosition.PRECEDING");
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp349_ = e1;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp350_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp349_);
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp351_ = _tmp350_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp352_ = _tmp351_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp353_ = e2;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp354_ = gxml_dom_node_contains (_tmp352_, (GXmlDomNode*) _tmp353_);
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp355_ = _tmp354_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp352_);
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp355_) {
#line 3115 "DomGDocumentTest.c"
			GXmlDomElement* _tmp356_ = NULL;
			GXmlDomNode* _tmp357_ = NULL;
			GXmlDomNode* _tmp358_ = NULL;
			GXmlDomNode* _tmp359_ = NULL;
			GXmlDomElement* _tmp360_ = NULL;
			gboolean _tmp361_ = FALSE;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp356_ = e2;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp357_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp356_);
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp358_ = _tmp357_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp359_ = _tmp358_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp360_ = e1;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp361_ = gxml_dom_node_contains (_tmp359_, (GXmlDomNode*) _tmp360_);
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp348_ = _tmp361_;
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp359_);
#line 3138 "DomGDocumentTest.c"
		} else {
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp348_ = FALSE;
#line 3142 "DomGDocumentTest.c"
		}
#line 228 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp348_, "e1.parent_node.contains (e2) && e2.parent_node.contains (e1)");
#line 229 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp362_ = e1;
#line 229 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp363_ = e2;
#line 229 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp364_ = gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp362_, (GXmlDomNode*) _tmp363_);
#line 229 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp364_ == GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING, "e1.compare_document_position (e2) == DomNode.DocumentPosition.FOLLOWING");
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp365_ = e1;
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp366_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp365_);
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp367_ = _tmp366_;
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp368_ = _tmp367_;
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp369_ = e1;
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp370_ = gxml_dom_node_contains (_tmp368_, (GXmlDomNode*) _tmp369_);
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp370_, "e1.parent_node.contains (e1)");
#line 230 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp368_);
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp371_ = e1;
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp372_ = e1;
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp373_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp372_);
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp374_ = _tmp373_;
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp375_ = _tmp374_;
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp376_ = gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp371_, _tmp375_);
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp376_ == (GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING), "e1.compare_document_position (e1.parent_node) == (DomNode.DocumentPosition.CONTAINS & DomNode.DocumentPosition.FOLLOWING)");
#line 231 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp375_);
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp377_ = e1;
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp378_ = e1;
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp379_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp378_);
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp380_ = _tmp379_;
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp381_ = _tmp380_;
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp382_ = gee_list_get ((GeeList*) _tmp381_, 0);
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp383_ = (GXmlDomNode*) _tmp382_;
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp384_ = gxml_dom_node_contains ((GXmlDomNode*) _tmp377_, _tmp383_);
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp384_, "e1.contains (e1.child_nodes[0])");
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp383_);
#line 232 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp381_);
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp385_ = e1;
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp386_ = e1;
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp387_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp386_);
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp388_ = _tmp387_;
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp389_ = _tmp388_;
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp390_ = gee_list_get ((GeeList*) _tmp389_, 0);
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp391_ = (GXmlDomNode*) _tmp390_;
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp392_ = gxml_dom_node_compare_document_position ((GXmlDomNode*) _tmp385_, _tmp391_);
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp392_ == (GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING), "e1.compare_document_position (e1.child_nodes[0]) == (DomNode.DocumentPosition.CONTAINED_BY & DomNode.DocumentPosition.PRECEDING)");
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp391_);
#line 233 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp389_);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp393_ = doc;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp394_ = gxml_dom_document_get_document_element (_tmp393_);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp395_ = _tmp394_;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp396_ = _tmp395_;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp397_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp396_);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp398_ = _tmp397_;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp399_ = _tmp398_;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp400_ = gee_list_get ((GeeList*) _tmp399_, 0);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp401_ = (GXmlDomElement*) _tmp400_;
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp399_);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp396_);
#line 234 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		b = _tmp401_;
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp402_ = b;
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp403_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp402_);
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp404_ = _tmp403_;
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp405_ = _tmp404_;
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp405_, "body") == 0, "b.node_name == \"body\"");
#line 235 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp405_);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp406_ = doc;
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp407_ = gxml_dom_document_create_element_ns (_tmp406_, "http://git.gnome.org/browse/gxml", "gxml:MyNode", &_inner_error_);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ng = _tmp407_;
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 236 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3298 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp408_ = b;
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp409_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp408_);
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp410_ = _tmp409_;
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp411_ = _tmp410_;
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp412_ = ng;
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp411_, (GXmlDomNode*) _tmp412_);
#line 237 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp411_);
#line 238 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp413_ = ng;
#line 238 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp414_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp413_, "http://git.gnome.org/browse/gxml");
#line 238 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp415_ = _tmp414_;
#line 238 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp415_, "gxml") == 0, "ng.lookup_prefix (\"http://git.gnome.org/browse/gxml\") == \"gxml\"");
#line 238 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp415_);
#line 239 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp416_ = ng;
#line 239 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp417_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp416_, "gxml");
#line 239 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp418_ = _tmp417_;
#line 239 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp418_, "http://git.gnome.org/browse/gxml") == 0, "ng.lookup_namespace_uri (\"gxml\") == \"http://git.gnome.org/browse/gxml\"");
#line 239 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp418_);
#line 240 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp419_ = ng;
#line 240 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp420_ = gxml_dom_node_is_default_namespace ((GXmlDomNode*) _tmp419_, "gxml:http://git.gnome.org/browse/gxml");
#line 240 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (!_tmp420_, "!ng.is_default_namespace (\"gxml:http://git.gnome.org/browse/gxml\")");
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp421_ = doc;
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp422_ = gxml_dom_document_create_element_ns (_tmp421_, "http://live.gnome.org/GXml", "OtherNode", &_inner_error_);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ng2 = _tmp422_;
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 241 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3375 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp423_ = b;
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp424_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp423_);
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp425_ = _tmp424_;
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp426_ = _tmp425_;
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp427_ = ng2;
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp426_, (GXmlDomNode*) _tmp427_);
#line 242 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp426_);
#line 243 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp428_ = ng2;
#line 243 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp429_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp428_, "http://live.gnome.org/GXml");
#line 243 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp430_ = _tmp429_;
#line 243 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp430_ == NULL, "ng2.lookup_prefix (\"http://live.gnome.org/GXml\") == null");
#line 243 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp430_);
#line 244 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp431_ = ng2;
#line 244 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp432_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp431_, NULL);
#line 244 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp433_ = _tmp432_;
#line 244 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp433_, "http://live.gnome.org/GXml") == 0, "ng2.lookup_namespace_uri (null) == \"http://live.gnome.org/GXml\"");
#line 244 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp433_);
#line 245 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp434_ = ng2;
#line 245 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp435_ = gxml_dom_node_is_default_namespace ((GXmlDomNode*) _tmp434_, "http://live.gnome.org/GXml");
#line 245 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp435_, "ng2.is_default_namespace (\"http://live.gnome.org/GXml\")");
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp437_ = doc;
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp438_ = gxml_dom_document_create_element (_tmp437_, "p", &_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp436_ = _tmp438_;
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3454 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp439_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp436_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp436_) : NULL);
#line 246 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		pn = _tmp439_;
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp440_ = pn;
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp440_, "id", "insertedp01", &_inner_error_);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 247 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3499 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp441_ = doc;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp442_ = gxml_dom_document_get_document_element (_tmp441_);
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp443_ = _tmp442_;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp444_ = _tmp443_;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp445_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp444_);
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp446_ = _tmp445_;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp447_ = _tmp446_;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp448_ = gee_list_get ((GeeList*) _tmp447_, 0);
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp449_ = (GXmlDomElement*) _tmp448_;
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp447_);
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp444_);
#line 248 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		p = _tmp449_;
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp450_ = p;
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp451_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp450_);
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp452_ = _tmp451_;
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp453_ = _tmp452_;
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp453_, "body") == 0, "p.node_name == \"body\"");
#line 249 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp453_);
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp454_ = p;
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp455_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp454_);
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp456_ = _tmp455_;
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp457_ = _tmp456_;
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp458_ = gee_list_get ((GeeList*) _tmp457_, 0);
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp459_ = (GXmlDomElement*) _tmp458_;
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp457_);
#line 250 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		cp0 = _tmp459_;
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp460_ = cp0;
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp461_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp460_);
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp462_ = _tmp461_;
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp463_ = _tmp462_;
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp463_, "p") == 0, "cp0.node_name == \"p\"");
#line 251 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp463_);
#line 252 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp464_ = cp0;
#line 252 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp465_ = gxml_dom_element_get_attribute (_tmp464_, "class");
#line 252 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp466_ = _tmp465_;
#line 252 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp466_, "black") == 0, "cp0.get_attribute (\"class\") == \"black\"");
#line 252 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp466_);
#line 253 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp467_ = p;
#line 253 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp468_ = cp0;
#line 253 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp469_ = gxml_dom_node_contains ((GXmlDomNode*) _tmp467_, (GXmlDomNode*) _tmp468_);
#line 253 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp469_, "p.contains (cp0)");
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp470_ = cp0;
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp471_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp470_);
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp472_ = _tmp471_;
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp473_ = _tmp472_;
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp474_ = cp0;
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp475_ = gxml_dom_node_contains (_tmp473_, (GXmlDomNode*) _tmp474_);
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp475_, "cp0.parent_node.contains (cp0)");
#line 254 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp473_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp476_ = p;
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp477_ = pn;
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp478_ = cp0;
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp479_ = gxml_dom_node_insert_before ((GXmlDomNode*) _tmp476_, (GXmlDomNode*) _tmp477_, (GXmlDomNode*) _tmp478_, &_inner_error_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp480_ = _tmp479_;
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp480_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 255 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3650 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp481_ = p;
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp482_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp481_);
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp483_ = _tmp482_;
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp484_ = _tmp483_;
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp485_ = gee_list_get ((GeeList*) _tmp484_, 0);
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp486_ = (GXmlDomElement*) _tmp485_;
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp484_);
#line 256 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ppn = _tmp486_;
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp487_ = ppn;
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp488_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp487_);
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp489_ = _tmp488_;
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp490_ = _tmp489_;
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp490_, "p") == 0, "ppn.node_name == \"p\"");
#line 257 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp490_);
#line 258 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp491_ = ppn;
#line 258 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp492_ = gxml_dom_element_has_attribute (_tmp491_, "id");
#line 258 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp492_, "ppn.has_attribute (\"id\")");
#line 259 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp493_ = ppn;
#line 259 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp494_ = gxml_dom_element_get_attribute (_tmp493_, "id");
#line 259 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp495_ = _tmp494_;
#line 259 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp495_, "insertedp01") == 0, "ppn.get_attribute (\"id\") == \"insertedp01\"");
#line 259 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp495_);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp497_ = doc;
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp498_ = gxml_dom_document_create_element (_tmp497_, "p", &_inner_error_);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp496_ = _tmp498_;
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3743 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp499_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp496_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp496_) : NULL);
#line 260 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		pn2 = _tmp499_;
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp500_ = pn2;
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp500_, "id", "newp", &_inner_error_);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 261 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3798 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp501_ = p;
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp502_ = pn2;
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp503_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp501_, (GXmlDomNode*) _tmp502_, &_inner_error_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp504_ = _tmp503_;
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp504_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 262 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3855 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp505_ = p;
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp506_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp505_);
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp507_ = _tmp506_;
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp508_ = _tmp507_;
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp509_ = gxml_dom_html_collection_get_length (_tmp508_);
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp510_ = _tmp509_;
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp510_ == 8, "p.children.length == 8");
#line 263 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp508_);
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp511_ = p;
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp512_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp511_);
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp513_ = _tmp512_;
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp514_ = _tmp513_;
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp515_ = gee_list_get ((GeeList*) _tmp514_, 7);
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp516_ = (GXmlDomElement*) _tmp515_;
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp516_, GXML_TYPE_DOM_ELEMENT), "p.children[7] is DomElement");
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp516_);
#line 264 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp514_);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp517_ = p;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp518_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp517_);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp519_ = _tmp518_;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp520_ = _tmp519_;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp521_ = gee_list_get ((GeeList*) _tmp520_, 7);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp522_ = (GXmlDomElement*) _tmp521_;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp523_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp522_);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp524_ = _tmp523_;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp525_ = _tmp524_;
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp525_, "p") == 0, "p.children[7].node_name == \"p\"");
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp525_);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp522_);
#line 265 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp520_);
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp526_ = p;
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp527_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp526_);
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp528_ = _tmp527_;
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp529_ = _tmp528_;
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp530_ = gee_list_get ((GeeList*) _tmp529_, 7);
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp531_ = (GXmlDomElement*) _tmp530_;
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp532_ = gxml_dom_element_get_attribute (_tmp531_, "id");
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp533_ = _tmp532_;
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp533_, "newp") == 0, "p.children[7].get_attribute (\"id\") == \"newp\"");
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp533_);
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp531_);
#line 266 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp529_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp535_ = doc;
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp536_ = gxml_dom_document_create_element (_tmp535_, "p", &_inner_error_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp534_ = _tmp536_;
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 3992 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp537_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp534_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp534_) : NULL);
#line 267 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		pn3 = _tmp537_;
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp538_ = pn3;
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp538_, "id", "newp1", &_inner_error_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 268 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4051 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp539_ = pn3;
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp539_, "class", "black", &_inner_error_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 269 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4106 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp540_ = p;
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp541_ = pn3;
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp542_ = pn2;
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp543_ = gxml_dom_node_replace_child ((GXmlDomNode*) _tmp540_, (GXmlDomNode*) _tmp541_, (GXmlDomNode*) _tmp542_, &_inner_error_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp544_ = _tmp543_;
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp544_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 270 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4169 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp545_ = p;
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp546_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp545_);
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp547_ = _tmp546_;
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp548_ = _tmp547_;
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp549_ = gxml_dom_html_collection_get_length (_tmp548_);
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp550_ = _tmp549_;
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp550_ == 8, "p.children.length == 8");
#line 271 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp548_);
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp551_ = p;
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp552_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp551_);
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp553_ = _tmp552_;
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp554_ = _tmp553_;
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp555_ = gee_list_get ((GeeList*) _tmp554_, 7);
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp556_ = (GXmlDomElement*) _tmp555_;
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp556_, GXML_TYPE_DOM_ELEMENT), "p.children[7] is DomElement");
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp556_);
#line 272 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp554_);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp557_ = p;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp558_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp557_);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp559_ = _tmp558_;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp560_ = _tmp559_;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp561_ = gee_list_get ((GeeList*) _tmp560_, 7);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp562_ = (GXmlDomElement*) _tmp561_;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp563_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp562_);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp564_ = _tmp563_;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp565_ = _tmp564_;
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp565_, "p") == 0, "p.children[7].node_name == \"p\"");
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp565_);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp562_);
#line 273 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp560_);
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp566_ = p;
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp567_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp566_);
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp568_ = _tmp567_;
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp569_ = _tmp568_;
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp570_ = gee_list_get ((GeeList*) _tmp569_, 7);
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp571_ = (GXmlDomElement*) _tmp570_;
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp572_ = gxml_dom_element_get_attribute (_tmp571_, "id");
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp573_ = _tmp572_;
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp573_, "newp1") == 0, "p.children[7].get_attribute (\"id\") == \"newp1\"");
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp573_);
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp571_);
#line 274 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp569_);
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp574_ = p;
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp575_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp574_);
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp576_ = _tmp575_;
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp577_ = _tmp576_;
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp578_ = gee_list_get ((GeeList*) _tmp577_, 7);
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp579_ = (GXmlDomElement*) _tmp578_;
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp580_ = gxml_dom_element_get_attribute (_tmp579_, "class");
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp581_ = _tmp580_;
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp581_, "black") == 0, "p.children[7].get_attribute (\"class\") == \"black\"");
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp581_);
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp579_);
#line 275 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp577_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp583_ = doc;
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp584_ = gxml_dom_document_create_element (_tmp583_, "p", &_inner_error_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp582_ = _tmp584_;
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4334 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp585_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp582_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp582_) : NULL);
#line 276 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		pn4 = _tmp585_;
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp586_ = pn4;
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp586_, "id", "newp2", &_inner_error_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp582_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 277 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4397 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp587_ = pn4;
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp587_, "class", "black", &_inner_error_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp582_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 278 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4456 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp588_ = p;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp589_ = pn4;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp590_ = p;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp591_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp590_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp592_ = _tmp591_;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp593_ = _tmp592_;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp594_ = gee_list_get ((GeeList*) _tmp593_, 0);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp595_ = (GXmlDomNode*) _tmp594_;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp596_ = gxml_dom_node_replace_child ((GXmlDomNode*) _tmp588_, (GXmlDomNode*) _tmp589_, _tmp595_, &_inner_error_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp597_ = _tmp596_;
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp597_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp595_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp593_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp582_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 279 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4537 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp598_ = p;
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp599_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp598_);
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp600_ = _tmp599_;
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp601_ = _tmp600_;
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp602_ = gxml_dom_html_collection_get_length (_tmp601_);
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp603_ = _tmp602_;
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp603_ == 8, "p.children.length == 8");
#line 280 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp601_);
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp604_ = p;
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp605_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp604_);
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp606_ = _tmp605_;
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp607_ = _tmp606_;
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp608_ = gee_list_get ((GeeList*) _tmp607_, 0);
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp609_ = (GXmlDomElement*) _tmp608_;
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp609_, GXML_TYPE_DOM_ELEMENT), "p.children[0] is DomElement");
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp609_);
#line 281 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp607_);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp610_ = p;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp611_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp610_);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp612_ = _tmp611_;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp613_ = _tmp612_;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp614_ = gee_list_get ((GeeList*) _tmp613_, 0);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp615_ = (GXmlDomElement*) _tmp614_;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp616_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp615_);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp617_ = _tmp616_;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp618_ = _tmp617_;
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp618_, "p") == 0, "p.children[0].node_name == \"p\"");
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp618_);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp615_);
#line 282 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp613_);
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp619_ = p;
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp620_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp619_);
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp621_ = _tmp620_;
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp622_ = _tmp621_;
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp623_ = gee_list_get ((GeeList*) _tmp622_, 0);
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp624_ = (GXmlDomElement*) _tmp623_;
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp625_ = gxml_dom_element_get_attribute (_tmp624_, "id");
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp626_ = _tmp625_;
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp626_, "newp2") == 0, "p.children[0].get_attribute (\"id\") == \"newp2\"");
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp626_);
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp624_);
#line 283 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp622_);
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp627_ = p;
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp628_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp627_);
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp629_ = _tmp628_;
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp630_ = _tmp629_;
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp631_ = gee_list_get ((GeeList*) _tmp630_, 0);
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp632_ = (GXmlDomElement*) _tmp631_;
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp633_ = gxml_dom_element_get_attribute (_tmp632_, "class");
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp634_ = _tmp633_;
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp634_, "black") == 0, "p.children[0].get_attribute (\"class\") == \"black\"");
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp634_);
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp632_);
#line 284 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp630_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp635_ = p;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp636_ = p;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp637_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp636_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp638_ = _tmp637_;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp639_ = _tmp638_;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp640_ = gee_list_get ((GeeList*) _tmp639_, 0);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp641_ = (GXmlDomElement*) _tmp640_;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp642_ = gxml_dom_node_remove_child ((GXmlDomNode*) _tmp635_, (GXmlDomNode*) _tmp641_, &_inner_error_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp643_ = _tmp642_;
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp643_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp641_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp639_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn4);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp582_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn3);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp534_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn2);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp496_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ppn);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cp0);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (p);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pn);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp436_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng2);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ng);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (b);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e2);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e1);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e0);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn2);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp180_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (cn);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp159_);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (e);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 285 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 4724 "DomGDocumentTest.c"
			goto __catch200_g_error;
		}
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp644_ = p;
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp645_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp644_);
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp646_ = _tmp645_;
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp647_ = _tmp646_;
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp648_ = gxml_dom_html_collection_get_length (_tmp647_);
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp649_ = _tmp648_;
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp649_ == 7, "p.children.length == 7");
#line 286 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp647_);
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp650_ = p;
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp651_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp650_);
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp652_ = _tmp651_;
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp653_ = _tmp652_;
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp654_ = gee_list_get ((GeeList*) _tmp653_, 0);
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp655_ = (GXmlDomElement*) _tmp654_;
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp655_, GXML_TYPE_DOM_ELEMENT), "p.children[0] is DomElement");
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp655_);
#line 287 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp653_);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp656_ = p;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp657_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp656_);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp658_ = _tmp657_;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp659_ = _tmp658_;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp660_ = gee_list_get ((GeeList*) _tmp659_, 0);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp661_ = (GXmlDomElement*) _tmp660_;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp662_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp661_);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp663_ = _tmp662_;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp664_ = _tmp663_;
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp664_, "p") == 0, "p.children[0].node_name == \"p\"");
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp664_);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp661_);
#line 288 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp659_);
#line 289 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp665_ = p;
#line 289 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp666_ = gxml_dom_element_has_attribute (_tmp665_, "id");
#line 289 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (!_tmp666_, "!p.has_attribute (\"id\")");
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp667_ = p;
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp668_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp667_);
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp669_ = _tmp668_;
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp670_ = _tmp669_;
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp671_ = gee_list_get ((GeeList*) _tmp670_, 0);
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp672_ = (GXmlDomElement*) _tmp671_;
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp673_ = gxml_dom_element_get_attribute (_tmp672_, "class");
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp674_ = _tmp673_;
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp674_, "black") == 0, "p.children[0].get_attribute (\"class\") == \"black\"");
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp674_);
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp672_);
#line 290 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp670_);
#line 292 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp675_ = ng2;
#line 292 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp675_, GXML_TYPE_DOM_ELEMENT), "ng2 is DomElement");
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp676_ = ng2;
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp677_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp676_);
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp678_ = _tmp677_;
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp679_ = _tmp678_;
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp679_, "OtherNode") == 0, "ng2.node_name == \"OtherNode\"");
#line 293 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp679_);
#line 294 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp680_ = ng2;
#line 294 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp681_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp680_, NULL);
#line 294 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp682_ = _tmp681_;
#line 294 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp682_, "http://live.gnome.org/GXml") == 0, "ng2.lookup_namespace_uri (null) == \"http://live.gnome.org/GXml\"");
#line 294 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp682_);
#line 295 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp683_ = ng2;
#line 295 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp684_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp683_, "http://live.gnome.org/GXml");
#line 295 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp685_ = _tmp684_;
#line 295 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp685_ == NULL, "ng2.lookup_prefix (\"http://live.gnome.org/GXml\") == null");
#line 295 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp685_);
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp686_ = ng2;
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp687_ = gxml_dom_element_get_tag_name (_tmp686_);
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp688_ = _tmp687_;
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp689_ = _tmp688_;
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp689_, "OtherNode") == 0, "ng2.tag_name == \"OtherNode\"");
#line 296 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp689_);
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp690_ = doc;
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp691_ = gxml_dom_document_get_document_element (_tmp690_);
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp692_ = _tmp691_;
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp693_ = _tmp692_;
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp694_ = gxml_dom_element_get_elements_by_tag_name (_tmp693_, "p");
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp695_ = _tmp694_;
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp693_);
#line 301 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		l = _tmp695_;
#line 302 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (l != NULL, "l != null");
#line 303 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (l, GXML_TYPE_DOM_HTML_COLLECTION), "l is DomHTMLCollection");
#line 304 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp696_ = gxml_dom_html_collection_get_length (l);
#line 304 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp697_ = _tmp696_;
#line 304 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp697_ == 5, "l.length == 5");
#line 305 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp698_ = gee_list_get ((GeeList*) l, 0);
#line 305 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp699_ = (GXmlDomElement*) _tmp698_;
#line 305 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp699_, GXML_TYPE_DOM_ELEMENT), "l[0] is DomElement");
#line 305 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp699_);
#line 306 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp700_ = gee_list_get ((GeeList*) l, 1);
#line 306 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp701_ = (GXmlDomElement*) _tmp700_;
#line 306 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp701_, GXML_TYPE_DOM_ELEMENT), "l[1] is DomElement");
#line 306 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp701_);
#line 307 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp702_ = gee_list_get ((GeeList*) l, 1);
#line 307 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp703_ = (GXmlDomElement*) _tmp702_;
#line 307 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp703_, GXML_TYPE_DOM_ELEMENT), "l[1] is DomElement");
#line 307 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp703_);
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp704_ = gee_list_get ((GeeList*) l, 0);
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp705_ = (GXmlDomElement*) _tmp704_;
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp706_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp705_);
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp707_ = _tmp706_;
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp708_ = _tmp707_;
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp708_, "p") == 0, "l[0].node_name == \"p\"");
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp708_);
#line 308 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp705_);
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp709_ = gee_list_get ((GeeList*) l, 1);
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp710_ = (GXmlDomElement*) _tmp709_;
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp711_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp710_);
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp712_ = _tmp711_;
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp713_ = _tmp712_;
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp713_, "p") == 0, "l[1].node_name == \"p\"");
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp713_);
#line 309 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp710_);
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp714_ = gee_list_get ((GeeList*) l, 2);
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp715_ = (GXmlDomElement*) _tmp714_;
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp716_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp715_);
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp717_ = _tmp716_;
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp718_ = _tmp717_;
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp718_, "p") == 0, "l[2].node_name == \"p\"");
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp718_);
#line 310 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp715_);
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp719_ = doc;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp720_ = gxml_dom_document_get_document_element (_tmp719_);
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp721_ = _tmp720_;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp722_ = _tmp721_;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp723_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp722_);
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp724_ = _tmp723_;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp725_ = _tmp724_;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp726_ = gxml_dom_html_collection_get_length (_tmp725_);
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp727_ = _tmp726_;
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp727_ == 1, "doc.document_element.children.length == 1");
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp725_);
#line 311 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp722_);
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp728_ = doc;
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp729_ = gxml_dom_document_get_document_element (_tmp728_);
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp730_ = _tmp729_;
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp731_ = _tmp730_;
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp732_ = gxml_dom_element_get_elements_by_tag_name (_tmp731_, "OtherNode");
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp733_ = _tmp732_;
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp731_);
#line 312 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lnst = _tmp733_;
#line 313 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp734_ = gxml_dom_html_collection_get_length (lnst);
#line 313 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp735_ = _tmp734_;
#line 313 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp735_ == 1, "lnst.length == 1");
#line 314 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp736_ = gxml_dom_html_collection_item (lnst, 0);
#line 314 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		nnst = _tmp736_;
#line 315 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp737_ = gxml_dom_element_get_namespace_uri (nnst);
#line 315 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp738_ = _tmp737_;
#line 315 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp739_ = _tmp738_;
#line 315 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp739_, "http://live.gnome.org/GXml") == 0, "nnst.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 315 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp739_);
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp740_ = doc;
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp741_ = gxml_dom_document_get_document_element (_tmp740_);
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp742_ = _tmp741_;
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp743_ = _tmp742_;
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp744_ = gxml_dom_element_get_elements_by_tag_name_ns (_tmp743_, "http://live.gnome.org/GXml", "OtherNode");
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp745_ = _tmp744_;
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp743_);
#line 316 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lns = _tmp745_;
#line 317 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (lns != NULL, "lns != null");
#line 318 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (lns, GXML_TYPE_DOM_HTML_COLLECTION), "lns is DomHTMLCollection");
#line 322 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp746_ = gxml_dom_html_collection_get_length (lns);
#line 322 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp747_ = _tmp746_;
#line 322 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp747_ == 1, "lns.length == 1");
#line 323 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp748_ = gxml_dom_html_collection_item (lns, 0);
#line 323 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp749_ = _tmp748_;
#line 323 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp749_, GXML_TYPE_DOM_ELEMENT), "lns.item (0) is DomElement");
#line 323 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp749_);
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp750_ = gxml_dom_html_collection_item (lns, 0);
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp751_ = _tmp750_;
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp752_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp751_);
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp753_ = _tmp752_;
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp754_ = _tmp753_;
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp754_, "OtherNode") == 0, "lns.item (0).node_name == \"OtherNode\"");
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp754_);
#line 324 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp751_);
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp755_ = doc;
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp756_ = gxml_dom_document_get_document_element (_tmp755_);
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp757_ = _tmp756_;
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp758_ = _tmp757_;
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp759_ = gxml_dom_element_get_elements_by_class_name (_tmp758_, "black");
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp760_ = _tmp759_;
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp758_);
#line 325 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lcl = _tmp760_;
#line 326 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (lcl != NULL, "lcl != null");
#line 327 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (lcl, GXML_TYPE_DOM_HTML_COLLECTION), "lcl is DomHTMLCollection");
#line 328 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp761_ = gxml_dom_html_collection_get_length (lcl);
#line 328 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp762_ = _tmp761_;
#line 328 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp762_ == 3, "lcl.length == 3");
#line 329 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp763_ = gxml_dom_html_collection_item (lcl, 0);
#line 329 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp764_ = _tmp763_;
#line 329 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp764_, GXML_TYPE_DOM_ELEMENT), "lcl.item (0) is DomElement");
#line 329 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp764_);
#line 330 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp765_ = gxml_dom_html_collection_item (lcl, 1);
#line 330 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp766_ = _tmp765_;
#line 330 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp766_, GXML_TYPE_DOM_ELEMENT), "lcl.item (1) is DomElement");
#line 330 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp766_);
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp767_ = gxml_dom_html_collection_item (lcl, 0);
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp768_ = _tmp767_;
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp769_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp768_);
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp770_ = _tmp769_;
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp771_ = _tmp770_;
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp771_, "p") == 0, "lcl.item (0).node_name == \"p\"");
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp771_);
#line 331 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp768_);
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp772_ = gxml_dom_html_collection_item (lcl, 1);
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp773_ = _tmp772_;
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp774_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp773_);
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp775_ = _tmp774_;
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp776_ = _tmp775_;
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp776_, "p") == 0, "lcl.item (1).node_name == \"p\"");
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp776_);
#line 332 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp773_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lcl);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lns);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (nnst);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lnst);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (l);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (pn4);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp582_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (pn3);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp534_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (pn2);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp496_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ppn);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (cp0);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (p);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (pn);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp436_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ng2);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ng);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (b);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (e2);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (e1);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (e0);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (cn2);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (cn);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (e);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 5207 "DomGDocumentTest.c"
	}
	goto __finally200;
	__catch200_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp777_ = NULL;
		gchar* _tmp778_ = NULL;
		gchar* _tmp779_ = NULL;
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 334 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp777_ = e->message;
#line 334 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp778_ = g_strconcat ("Error: ", _tmp777_, NULL);
#line 334 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp779_ = _tmp778_;
#line 334 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:334: %s", _tmp779_);
#line 334 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp779_);
#line 335 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 5234 "DomGDocumentTest.c"
	}
	__finally200:
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 168 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 5245 "DomGDocumentTest.c"
	}
}


static void ___lambda195__gtest_func (void) {
#line 167 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda195_ ();
#line 5253 "DomGDocumentTest.c"
}


static void __lambda196_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomDocument* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomHTMLCollection* _tmp8_ = NULL;
		GXmlDomHTMLCollection* _tmp9_ = NULL;
		GXmlDomHTMLCollection* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		GXmlDomElement* n1 = NULL;
		GXmlDomDocument* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		GXmlDomDocument* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		GXmlDomNode* _tmp21_ = NULL;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomHTMLCollection* _tmp26_ = NULL;
		GXmlDomHTMLCollection* _tmp27_ = NULL;
		GXmlDomHTMLCollection* _tmp28_ = NULL;
		gpointer _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
		GeeList* _tmp40_ = NULL;
		GeeList* _tmp41_ = NULL;
		GeeList* _tmp42_ = NULL;
		gint _tmp43_ = 0;
		gint _tmp44_ = 0;
		GXmlDomElement* _tmp45_ = NULL;
		GeeList* _tmp46_ = NULL;
		GeeList* _tmp47_ = NULL;
		GeeList* _tmp48_ = NULL;
		gpointer _tmp49_ = NULL;
		GXmlNamespace* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GeeList* _tmp55_ = NULL;
		GeeList* _tmp56_ = NULL;
		GeeList* _tmp57_ = NULL;
		gpointer _tmp58_ = NULL;
		GXmlNamespace* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		GXmlDomElement* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		GXmlDomElement* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		gchar* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		GXmlDomElement* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		GXmlDomElement* _tmp75_ = NULL;
		gchar* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		GXmlDomElement* _tmp79_ = NULL;
		gchar* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		GXmlDomElement* _tmp83_ = NULL;
		GXmlDomTokenList* _tmp84_ = NULL;
		GXmlDomTokenList* _tmp85_ = NULL;
		GXmlDomTokenList* _tmp86_ = NULL;
		GXmlDomElement* _tmp87_ = NULL;
		GXmlDomTokenList* _tmp88_ = NULL;
		GXmlDomTokenList* _tmp89_ = NULL;
		GXmlDomTokenList* _tmp90_ = NULL;
		gint _tmp91_ = 0;
		gint _tmp92_ = 0;
		GXmlDomElement* _tmp93_ = NULL;
		GXmlDomTokenList* _tmp94_ = NULL;
		GXmlDomTokenList* _tmp95_ = NULL;
		GXmlDomTokenList* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		GXmlDomTokenList* _tmp100_ = NULL;
		GXmlDomTokenList* _tmp101_ = NULL;
		GXmlDomTokenList* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		GXmlDomElement* _tmp105_ = NULL;
		GXmlDomNamedNodeMap* _tmp106_ = NULL;
		GXmlDomNamedNodeMap* _tmp107_ = NULL;
		GXmlDomNamedNodeMap* _tmp108_ = NULL;
		GXmlDomElement* _tmp109_ = NULL;
		GXmlDomNamedNodeMap* _tmp110_ = NULL;
		GXmlDomNamedNodeMap* _tmp111_ = NULL;
		GXmlDomNamedNodeMap* _tmp112_ = NULL;
		gint _tmp113_ = 0;
		gint _tmp114_ = 0;
		GXmlDomElement* _tmp115_ = NULL;
		GXmlDomNamedNodeMap* _tmp116_ = NULL;
		GXmlDomNamedNodeMap* _tmp117_ = NULL;
		GXmlDomNamedNodeMap* _tmp118_ = NULL;
		GXmlDomNode* _tmp119_ = NULL;
		GXmlDomNode* _tmp120_ = NULL;
		GXmlDomElement* _tmp121_ = NULL;
		GXmlDomNamedNodeMap* _tmp122_ = NULL;
		GXmlDomNamedNodeMap* _tmp123_ = NULL;
		GXmlDomNamedNodeMap* _tmp124_ = NULL;
		GXmlDomNode* _tmp125_ = NULL;
		GXmlDomNode* _tmp126_ = NULL;
		gchar* _tmp127_ = NULL;
		gchar* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		GXmlDomElement* _tmp130_ = NULL;
		GXmlDomNamedNodeMap* _tmp131_ = NULL;
		GXmlDomNamedNodeMap* _tmp132_ = NULL;
		GXmlDomNamedNodeMap* _tmp133_ = NULL;
		GXmlDomNode* _tmp134_ = NULL;
		GXmlDomNode* _tmp135_ = NULL;
		gchar* _tmp136_ = NULL;
		gchar* _tmp137_ = NULL;
		gchar* _tmp138_ = NULL;
		GXmlDomElement* _tmp139_ = NULL;
		gchar* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		GXmlDomElement* _tmp143_ = NULL;
		gchar* _tmp144_ = NULL;
		gchar* _tmp145_ = NULL;
		GXmlDomElement* _tmp146_ = NULL;
		gchar* _tmp147_ = NULL;
		gchar* _tmp148_ = NULL;
		GXmlDomElement* _tmp149_ = NULL;
		gchar* _tmp150_ = NULL;
		gchar* _tmp151_ = NULL;
		gchar* _tmp152_ = NULL;
		GXmlDomElement* _tmp153_ = NULL;
		GXmlDomElement* _tmp154_ = NULL;
		gchar* _tmp155_ = NULL;
		gchar* _tmp156_ = NULL;
		GXmlDomElement* _tmp157_ = NULL;
		gboolean _tmp158_ = FALSE;
		GXmlDomElement* n2 = NULL;
		GXmlDomDocument* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlDomDocument* _tmp161_ = NULL;
		GXmlDomElement* _tmp162_ = NULL;
		GXmlDomElement* _tmp163_ = NULL;
		GXmlDomElement* _tmp164_ = NULL;
		GXmlDomElement* _tmp165_ = NULL;
		GXmlDomNode* _tmp166_ = NULL;
		GXmlDomNode* _tmp167_ = NULL;
		GXmlDomDocument* _tmp168_ = NULL;
		GXmlDomElement* _tmp169_ = NULL;
		GXmlDomElement* _tmp170_ = NULL;
		GXmlDomElement* _tmp171_ = NULL;
		GXmlDomHTMLCollection* _tmp172_ = NULL;
		GXmlDomHTMLCollection* _tmp173_ = NULL;
		GXmlDomHTMLCollection* _tmp174_ = NULL;
		gint _tmp175_ = 0;
		gint _tmp176_ = 0;
		GXmlDomElement* _tmp177_ = NULL;
		GXmlDomNamedNodeMap* _tmp178_ = NULL;
		GXmlDomNamedNodeMap* _tmp179_ = NULL;
		GXmlDomNamedNodeMap* _tmp180_ = NULL;
		gint _tmp181_ = 0;
		gint _tmp182_ = 0;
		GXmlDomElement* _tmp183_ = NULL;
		GXmlDomElement* _tmp184_ = NULL;
		GXmlDomNamedNodeMap* _tmp185_ = NULL;
		GXmlDomNamedNodeMap* _tmp186_ = NULL;
		GXmlDomNamedNodeMap* _tmp187_ = NULL;
		gint _tmp188_ = 0;
		gint _tmp189_ = 0;
		GXmlDomElement* _tmp190_ = NULL;
		gboolean _tmp191_ = FALSE;
		GXmlDomElement* _tmp192_ = NULL;
		gboolean _tmp193_ = FALSE;
		GXmlDomElement* _tmp194_ = NULL;
		gchar* _tmp195_ = NULL;
		gchar* _tmp196_ = NULL;
		GXmlDomElement* _tmp197_ = NULL;
		gchar* _tmp198_ = NULL;
		gchar* _tmp199_ = NULL;
#line 343 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_HTMLDOC, 0, &_inner_error_);
#line 343 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 343 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5470 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 343 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 343 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 344 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 344 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT), "doc is DomDocument");
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = doc;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element (_tmp4_);
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp7_);
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == 1, "doc.document_element.children.size == 1");
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 345 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_create_element_ns (_tmp13_, "http://live.gnome.org/GXml", "gxml:code", &_inner_error_);
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n1 = _tmp14_;
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 346 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5517 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = doc;
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element (_tmp15_);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = n1;
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp18_, (GXmlDomNode*) _tmp19_, &_inner_error_);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 347 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5546 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = doc;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp25_);
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gee_list_get ((GeeList*) _tmp28_, 1);
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = (GXmlDomElement*) _tmp29_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp30_) : NULL;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp31_ == NULL) {
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp30_);
#line 5573 "DomGDocumentTest.c"
		}
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 348 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n = _tmp32_;
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = n;
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp33_);
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "code") == 0, "n.node_name == \"code\"");
#line 349 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp36_);
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = n;
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp37_, "id", "0y1", &_inner_error_);
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 350 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5609 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = n;
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp38_, "class", "login black", &_inner_error_);
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 351 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5626 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = n;
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp39_) : NULL);
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gee_collection_get_size ((GeeCollection*) _tmp42_);
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp44_ == 1, "(n as GXml.Node).namespaces.size == 1");
#line 352 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp42_);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = n;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp45_) : NULL);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = _tmp47_;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = gee_list_get (_tmp48_, 0);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = (GXmlNamespace*) _tmp49_;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = gxml_namespace_get_uri (_tmp50_);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://live.gnome.org/GXml") == 0, "(n as GXml.Node).namespaces[0].uri == \"http://live.gnome.org/GXml\"");
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 353 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp48_);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = n;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = gxml_node_get_namespaces (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp54_) : NULL);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = gee_list_get (_tmp57_, 0);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp59_ = (GXmlNamespace*) _tmp58_;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp60_ = gxml_namespace_get_prefix (_tmp59_);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp61_ = _tmp60_;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "gxml") == 0, "(n as GXml.Node).namespaces[0].prefix == \"gxml\"");
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp62_);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 354 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp63_ = n;
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp64_ = gxml_dom_element_get_namespace_uri (_tmp63_);
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp66_, "http://live.gnome.org/GXml") == 0, "n.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 355 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp66_);
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp67_ = n;
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp68_ = gxml_dom_element_get_prefix (_tmp67_);
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp70_, "gxml") == 0, "n.prefix == \"gxml\"");
#line 356 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp70_);
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp71_ = n;
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp72_ = gxml_dom_element_get_local_name (_tmp71_);
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp74_, "code") == 0, "n.local_name == \"code\"");
#line 357 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp74_);
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp75_ = n;
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp76_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp75_);
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp77_ = _tmp76_;
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp78_, "code") == 0, "n.node_name == \"code\"");
#line 358 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp78_);
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp79_ = n;
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp80_ = gxml_dom_element_get_id (_tmp79_);
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp82_, "0y1") == 0, "n.id == \"0y1\"");
#line 359 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp82_);
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp83_ = n;
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp84_ = gxml_dom_element_get_class_list (_tmp83_);
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp86_ != NULL, "n.class_list != null");
#line 360 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp86_);
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp87_ = n;
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp88_ = gxml_dom_element_get_class_list (_tmp87_);
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp91_ = gxml_dom_token_list_get_length (_tmp90_);
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp92_ == 2, "n.class_list.length == 2");
#line 361 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp90_);
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp93_ = n;
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp94_ = gxml_dom_element_get_class_list (_tmp93_);
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp97_ = gxml_dom_token_list_item (_tmp96_, 0);
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp98_, "login") == 0, "n.class_list.item (0) == \"login\"");
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp98_);
#line 362 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp99_ = n;
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp100_ = gxml_dom_element_get_class_list (_tmp99_);
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp103_ = gxml_dom_token_list_item (_tmp102_, 1);
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp104_ = _tmp103_;
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "black") == 0, "n.class_list.item (1) == \"black\"");
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp104_);
#line 363 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp102_);
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp105_ = n;
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp106_ = gxml_dom_element_get_attributes (_tmp105_);
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp108_ != NULL, "n.attributes != null");
#line 364 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp109_ = n;
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_element_get_attributes (_tmp109_);
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_named_node_map_get_length (_tmp112_);
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp114_ == 2, "n.attributes.length == 2");
#line 365 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp112_);
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp115_ = n;
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp116_ = gxml_dom_element_get_attributes (_tmp115_);
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp119_ = gxml_dom_named_node_map_get_named_item (_tmp118_, "id");
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp120_, GXML_TYPE_DOM_NODE), "n.attributes.get_named_item (\"id\") is DomNode");
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp120_);
#line 366 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp121_ = n;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp122_ = gxml_dom_element_get_attributes (_tmp121_);
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp124_ = _tmp123_;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_named_node_map_get_named_item (_tmp124_, "id");
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp127_ = gxml_dom_node_get_node_name (_tmp126_);
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp129_, "id") == 0, "n.attributes.get_named_item (\"id\").node_name == \"id\"");
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp129_);
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp126_);
#line 367 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp124_);
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp130_ = n;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_element_get_attributes (_tmp130_);
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp134_ = gxml_dom_named_node_map_get_named_item (_tmp133_, "id");
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp136_ = gxml_dom_node_get_node_value (_tmp135_);
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp138_, "0y1") == 0, "n.attributes.get_named_item (\"id\").node_value == \"0y1\"");
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp138_);
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp135_);
#line 368 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp133_);
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp139_ = n;
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp139_);
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp142_, "code") == 0, "n.node_name == \"code\"");
#line 369 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp142_);
#line 370 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp143_ = n;
#line 370 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp144_ = gxml_dom_node_lookup_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp143_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp143_) : NULL, "gxml");
#line 370 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp145_ = _tmp144_;
#line 370 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp145_, "http://live.gnome.org/GXml") == 0, "(n as DomNode).lookup_namespace_uri (\"gxml\") == \"http://live.gnome.org/GXml\"");
#line 370 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp145_);
#line 371 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp146_ = n;
#line 371 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp147_ = gxml_dom_node_lookup_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp146_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp146_) : NULL, "http://live.gnome.org/GXml");
#line 371 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp148_ = _tmp147_;
#line 371 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp148_, "gxml") == 0, "(n as DomNode).lookup_prefix (\"http://live.gnome.org/GXml\") == \"gxml\"");
#line 371 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp148_);
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp149_ = n;
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp150_ = gxml_dom_element_get_tag_name (_tmp149_);
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp152_, "gxml:code") == 0, "n.tag_name == \"gxml:code\"");
#line 372 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp152_);
#line 373 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp153_ = n;
#line 373 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_remove_attribute (_tmp153_, "id");
#line 374 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp154_ = n;
#line 374 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp155_ = gxml_dom_element_get_attribute (_tmp154_, "id");
#line 374 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 374 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp156_ == NULL, "n.get_attribute (\"id\") == null");
#line 374 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp156_);
#line 375 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp157_ = n;
#line 375 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp158_ = gxml_dom_element_has_attribute (_tmp157_, "id");
#line 375 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (!_tmp158_, "!n.has_attribute (\"id\")");
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp159_ = doc;
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp160_ = gxml_dom_document_create_element (_tmp159_, "p", &_inner_error_);
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n2 = _tmp160_;
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 376 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 5999 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp161_ = doc;
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp162_ = gxml_dom_document_get_document_element (_tmp161_);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp165_ = n2;
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp166_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp164_, (GXmlDomNode*) _tmp165_, &_inner_error_);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp167_ = _tmp166_;
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp167_);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp164_);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 377 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6032 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp168_ = doc;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp169_ = gxml_dom_document_get_document_element (_tmp168_);
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp170_ = _tmp169_;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp171_ = _tmp170_;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp172_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp171_);
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp175_ = gxml_dom_html_collection_get_length (_tmp174_);
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp176_ = _tmp175_;
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp176_ == 3, "doc.document_element.children.length == 3");
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp174_);
#line 378 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp171_);
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp177_ = n2;
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp178_ = gxml_dom_element_get_attributes (_tmp177_);
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp181_ = gxml_dom_named_node_map_get_length (_tmp180_);
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp182_ == 0, "n2.attributes.length == 0");
#line 382 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp183_ = n2;
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp183_, "http://devel.org/", "dev:nice", "good", &_inner_error_);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n1);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 386 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6091 "DomGDocumentTest.c"
			goto __catch201_g_error;
		}
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp184_ = n2;
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp185_ = gxml_dom_element_get_attributes (_tmp184_);
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp188_ = gxml_dom_named_node_map_get_length (_tmp187_);
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp189_ = _tmp188_;
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp189_ == 1, "n2.attributes.length == 1");
#line 387 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp187_);
#line 388 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp190_ = n2;
#line 388 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp191_ = gxml_dom_element_has_attribute_ns (_tmp190_, "http://devel.org/", "nice");
#line 388 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp191_, "n2.has_attribute_ns (\"http://devel.org/\",\"nice\")");
#line 389 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp192_ = n2;
#line 389 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp193_ = gxml_dom_element_has_attribute_ns (_tmp192_, "http://devel.org/", "dev:nice");
#line 389 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (!_tmp193_, "!n2.has_attribute_ns (\"http://devel.org/\",\"dev:nice\")");
#line 393 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp194_ = n2;
#line 393 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp195_ = gxml_dom_element_get_attribute_ns (_tmp194_, "http://devel.org/", "nice");
#line 393 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp196_ = _tmp195_;
#line 393 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp196_, "good") == 0, "n2.get_attribute_ns (\"http://devel.org/\",\"nice\") == \"good\"");
#line 393 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp196_);
#line 394 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp197_ = n2;
#line 394 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp198_ = gxml_dom_element_get_attribute_ns (_tmp197_, "http://devel.org/", "dev:nice");
#line 394 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 394 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp199_ == NULL, "n2.get_attribute_ns (\"http://devel.org/\",\"dev:nice\") == null");
#line 394 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp199_);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n2);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n1);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 6152 "DomGDocumentTest.c"
	}
	goto __finally201;
	__catch201_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp200_ = NULL;
		gchar* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 396 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp200_ = e->message;
#line 396 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp201_ = g_strconcat ("Error: ", _tmp200_, NULL);
#line 396 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp202_ = _tmp201_;
#line 396 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:396: %s", _tmp202_);
#line 396 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp202_);
#line 397 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 6179 "DomGDocumentTest.c"
	}
	__finally201:
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 339 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 6190 "DomGDocumentTest.c"
	}
}


static void ___lambda196__gtest_func (void) {
#line 338 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda196_ ();
#line 6198 "DomGDocumentTest.c"
}


static void __lambda197_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		GXmlDomDocument* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GXmlDomDocument* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		GXmlDomDocument* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		GXmlDomDocument* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		GXmlDomDocument* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		GXmlDomDocument* _tmp21_ = NULL;
		GXmlDomDocumentType* _tmp22_ = NULL;
		GXmlDomDocumentType* _tmp23_ = NULL;
		GXmlDomDocumentType* _tmp24_ = NULL;
		GXmlDomDocument* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomElement* _tmp27_ = NULL;
		GXmlDomElement* _tmp28_ = NULL;
		GXmlDomDocument* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomDocument* _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GXmlDomHTMLCollection* le = NULL;
		GXmlDomDocument* _tmp40_ = NULL;
		GXmlDomHTMLCollection* _tmp41_ = NULL;
		GXmlDomHTMLCollection* _tmp42_ = NULL;
		gint _tmp43_ = 0;
		gint _tmp44_ = 0;
		GXmlDomHTMLCollection* _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GXmlDomHTMLCollection* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		GXmlDomDocument* _tmp57_ = NULL;
		GXmlDomElement* _tmp58_ = NULL;
		GXmlDomElement* _tmp59_ = NULL;
		GXmlDomElement* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GXmlDomNode* _tmp62_ = NULL;
		GXmlDomNode* _tmp63_ = NULL;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomHTMLCollection* lens = NULL;
		GXmlDomDocument* _tmp66_ = NULL;
		GXmlDomHTMLCollection* _tmp67_ = NULL;
		GXmlDomHTMLCollection* _tmp68_ = NULL;
		gint _tmp69_ = 0;
		gint _tmp70_ = 0;
		GXmlDomHTMLCollection* _tmp71_ = NULL;
		GXmlDomElement* _tmp72_ = NULL;
		GXmlDomElement* _tmp73_ = NULL;
		GXmlDomHTMLCollection* _tmp74_ = NULL;
		GXmlDomElement* _tmp75_ = NULL;
		GXmlDomElement* _tmp76_ = NULL;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		gchar* _tmp79_ = NULL;
		GXmlDomHTMLCollection* lec = NULL;
		GXmlDomDocument* _tmp80_ = NULL;
		GXmlDomHTMLCollection* _tmp81_ = NULL;
		GXmlDomHTMLCollection* _tmp82_ = NULL;
		gint _tmp83_ = 0;
		gint _tmp84_ = 0;
		GXmlDomHTMLCollection* _tmp85_ = NULL;
		GXmlDomElement* _tmp86_ = NULL;
		GXmlDomElement* _tmp87_ = NULL;
		GXmlDomHTMLCollection* _tmp88_ = NULL;
		GXmlDomElement* _tmp89_ = NULL;
		GXmlDomElement* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		GXmlDomHTMLCollection* _tmp94_ = NULL;
		GXmlDomElement* _tmp95_ = NULL;
		GXmlDomElement* _tmp96_ = NULL;
		GXmlDomHTMLCollection* _tmp97_ = NULL;
		GXmlDomElement* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		gchar* _tmp100_ = NULL;
		gchar* _tmp101_ = NULL;
		gchar* _tmp102_ = NULL;
		GXmlDomElement* _tmp103_ = NULL;
		GXmlDomHTMLCollection* lec2 = NULL;
		GXmlDomDocument* _tmp104_ = NULL;
		GXmlDomHTMLCollection* _tmp105_ = NULL;
		GXmlDomHTMLCollection* _tmp106_ = NULL;
		gint _tmp107_ = 0;
		gint _tmp108_ = 0;
		GXmlDomHTMLCollection* _tmp109_ = NULL;
		GXmlDomElement* _tmp110_ = NULL;
		GXmlDomElement* _tmp111_ = NULL;
		GXmlDomHTMLCollection* lec3 = NULL;
		GXmlDomDocument* _tmp112_ = NULL;
		GXmlDomHTMLCollection* _tmp113_ = NULL;
		GXmlDomHTMLCollection* _tmp114_ = NULL;
		gint _tmp115_ = 0;
		gint _tmp116_ = 0;
		GXmlDomHTMLCollection* lec4 = NULL;
		GXmlDomDocument* _tmp117_ = NULL;
		GXmlDomHTMLCollection* _tmp118_ = NULL;
		GXmlDomHTMLCollection* _tmp119_ = NULL;
		gint _tmp120_ = 0;
		gint _tmp121_ = 0;
		GXmlDomHTMLCollection* lec5 = NULL;
		GXmlDomDocument* _tmp122_ = NULL;
		GXmlDomHTMLCollection* _tmp123_ = NULL;
		GXmlDomHTMLCollection* _tmp124_ = NULL;
		gint _tmp125_ = 0;
		gint _tmp126_ = 0;
		GXmlDomHTMLCollection* _tmp127_ = NULL;
		GXmlDomElement* _tmp128_ = NULL;
		GXmlDomElement* _tmp129_ = NULL;
		GXmlDomHTMLCollection* _tmp130_ = NULL;
		GXmlDomElement* _tmp131_ = NULL;
		GXmlDomElement* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		gchar* _tmp134_ = NULL;
		gchar* _tmp135_ = NULL;
		GXmlDomHTMLCollection* _tmp136_ = NULL;
		GXmlDomElement* _tmp137_ = NULL;
		GXmlDomElement* _tmp138_ = NULL;
		GXmlDomHTMLCollection* _tmp139_ = NULL;
		GXmlDomElement* _tmp140_ = NULL;
		GXmlDomElement* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		gchar* _tmp143_ = NULL;
		gchar* _tmp144_ = NULL;
		GXmlDomHTMLCollection* _tmp145_ = NULL;
		GXmlDomElement* _tmp146_ = NULL;
		GXmlDomElement* _tmp147_ = NULL;
		GXmlDomHTMLCollection* _tmp148_ = NULL;
		GXmlDomElement* _tmp149_ = NULL;
		GXmlDomElement* _tmp150_ = NULL;
		gchar* _tmp151_ = NULL;
		gchar* _tmp152_ = NULL;
		gchar* _tmp153_ = NULL;
		GXmlDomText* t = NULL;
		GXmlDomDocument* _tmp154_ = NULL;
		GXmlDomText* _tmp155_ = NULL;
		GXmlDomElement* _tmp156_ = NULL;
		GXmlDomText* _tmp157_ = NULL;
		GXmlDomNode* _tmp158_ = NULL;
		GXmlDomNode* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlDomNodeList* _tmp161_ = NULL;
		GXmlDomNodeList* _tmp162_ = NULL;
		GXmlDomNodeList* _tmp163_ = NULL;
		gpointer _tmp164_ = NULL;
		GXmlDomNode* _tmp165_ = NULL;
		GXmlDomElement* _tmp166_ = NULL;
		GXmlDomNodeList* _tmp167_ = NULL;
		GXmlDomNodeList* _tmp168_ = NULL;
		GXmlDomNodeList* _tmp169_ = NULL;
		gpointer _tmp170_ = NULL;
		GXmlDomNode* _tmp171_ = NULL;
		gchar* _tmp172_ = NULL;
		gchar* _tmp173_ = NULL;
		gchar* _tmp174_ = NULL;
		GXmlDomComment* comment = NULL;
		GXmlDomDocument* _tmp175_ = NULL;
		GXmlDomComment* _tmp176_ = NULL;
		GXmlDomDocument* _tmp177_ = NULL;
		GXmlDomElement* _tmp178_ = NULL;
		GXmlDomElement* _tmp179_ = NULL;
		GXmlDomElement* _tmp180_ = NULL;
		GXmlDomComment* _tmp181_ = NULL;
		GXmlDomNode* _tmp182_ = NULL;
		GXmlDomNode* _tmp183_ = NULL;
		GXmlDomDocument* _tmp184_ = NULL;
		GXmlDomElement* _tmp185_ = NULL;
		GXmlDomElement* _tmp186_ = NULL;
		GXmlDomElement* _tmp187_ = NULL;
		GXmlDomNode* _tmp188_ = NULL;
		GXmlDomNode* _tmp189_ = NULL;
		GXmlDomNode* _tmp190_ = NULL;
		GXmlDomDocument* _tmp191_ = NULL;
		GXmlDomElement* _tmp192_ = NULL;
		GXmlDomElement* _tmp193_ = NULL;
		GXmlDomElement* _tmp194_ = NULL;
		GXmlDomNode* _tmp195_ = NULL;
		GXmlDomNode* _tmp196_ = NULL;
		GXmlDomNode* _tmp197_ = NULL;
		gchar* _tmp198_ = NULL;
		gchar* _tmp199_ = NULL;
		gchar* _tmp200_ = NULL;
		GXmlDomProcessingInstruction* pi = NULL;
		GXmlDomDocument* _tmp201_ = NULL;
		GXmlDomProcessingInstruction* _tmp202_ = NULL;
		GXmlDomDocument* _tmp203_ = NULL;
		GXmlDomElement* _tmp204_ = NULL;
		GXmlDomElement* _tmp205_ = NULL;
		GXmlDomElement* _tmp206_ = NULL;
		GXmlDomProcessingInstruction* _tmp207_ = NULL;
		GXmlDomNode* _tmp208_ = NULL;
		GXmlDomNode* _tmp209_ = NULL;
		GXmlDomDocument* _tmp210_ = NULL;
		GXmlDomElement* _tmp211_ = NULL;
		GXmlDomElement* _tmp212_ = NULL;
		GXmlDomElement* _tmp213_ = NULL;
		GXmlDomNode* _tmp214_ = NULL;
		GXmlDomNode* _tmp215_ = NULL;
		GXmlDomNode* _tmp216_ = NULL;
#line 405 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error_);
#line 405 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 405 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6441 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 405 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 405 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 406 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = doc;
#line 406 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_url (_tmp3_);
#line 406 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 406 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "about:blank") == 0, "doc.url == \"about:blank\"");
#line 407 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = doc;
#line 407 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_uri (_tmp6_);
#line 407 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 407 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "about:blank") == 0, "doc.document_uri == \"about:blank\"");
#line 408 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = doc;
#line 408 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_origin (_tmp9_);
#line 408 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 408 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "") == 0, "doc.origin == \"\"");
#line 409 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = doc;
#line 409 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = gxml_dom_document_get_compat_mode (_tmp12_);
#line 409 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 409 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "") == 0, "doc.compat_mode == \"\"");
#line 410 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = doc;
#line 410 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_character_set (_tmp15_);
#line 410 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 410 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp17_, "utf-8") == 0, "doc.character_set == \"utf-8\"");
#line 411 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = doc;
#line 411 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_content_type (_tmp18_);
#line 411 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 411 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "application/xml") == 0, "doc.content_type == \"application/xml\"");
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = doc;
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = gxml_dom_document_get_doctype (_tmp21_);
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp24_ == NULL, "doc.doctype == null");
#line 412 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = doc;
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (_tmp25_);
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp28_ != NULL, "doc.document_element != null");
#line 413 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = doc;
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, GXML_TYPE_DOM_ELEMENT), "doc.document_element is DomElement");
#line 414 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = doc;
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element (_tmp33_);
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp36_);
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "root") == 0, "doc.document_element.node_name == \"root\"");
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 415 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 416 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = doc;
#line 416 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = gxml_dom_document_get_elements_by_tag_name (_tmp40_, "code");
#line 416 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		le = _tmp41_;
#line 417 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = le;
#line 417 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_html_collection_get_length (_tmp42_);
#line 417 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 417 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp44_ == 2, "le.length == 2");
#line 418 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = le;
#line 418 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = gxml_dom_html_collection_item (_tmp45_, 0);
#line 418 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 418 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, GXML_TYPE_DOM_ELEMENT), "le.item (0) is DomElement");
#line 418 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = le;
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = gxml_dom_html_collection_item (_tmp48_, 0);
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp50_);
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = _tmp52_;
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "code") == 0, "le.item (0).node_name == \"code\"");
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp53_);
#line 419 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = doc;
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = gxml_dom_document_create_element_ns (_tmp54_, "http://git.gnome.org/browse/gxml", "git:MyNode", &_inner_error_);
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n = _tmp55_;
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 420 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6608 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = doc;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = gxml_dom_document_get_document_element (_tmp57_);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp61_ = n;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp62_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp60_, (GXmlDomNode*) _tmp61_, &_inner_error_);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp60_);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = _tmp63_;
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6639 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp64_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp56_) : NULL);
#line 421 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n2 = _tmp64_;
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp65_ = n2;
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp65_, "class", "node", &_inner_error_);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 422 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6664 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 423 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp66_ = doc;
#line 423 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp67_ = gxml_dom_document_get_elements_by_tag_name_ns (_tmp66_, "http://git.gnome.org/browse/gxml", "MyNode");
#line 423 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lens = _tmp67_;
#line 424 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp68_ = lens;
#line 424 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp69_ = gxml_dom_html_collection_get_length (_tmp68_);
#line 424 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 424 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp70_ == 1, "lens.length == 1");
#line 425 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp71_ = lens;
#line 425 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp72_ = gxml_dom_html_collection_item (_tmp71_, 0);
#line 425 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 425 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp73_, GXML_TYPE_DOM_ELEMENT), "lens.item (0) is DomElement");
#line 425 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp73_);
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp74_ = lens;
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp75_ = gxml_dom_html_collection_item (_tmp74_, 0);
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp76_);
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp79_, "MyNode") == 0, "lens.item (0).node_name == \"MyNode\"");
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp79_);
#line 426 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp76_);
#line 430 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp80_ = doc;
#line 430 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp81_ = gxml_dom_document_get_elements_by_class_name (_tmp80_, "node");
#line 430 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lec = _tmp81_;
#line 431 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp82_ = lec;
#line 431 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp83_ = gxml_dom_html_collection_get_length (_tmp82_);
#line 431 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 431 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp84_ == 4, "lec.length == 4");
#line 432 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp85_ = lec;
#line 432 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp86_ = gxml_dom_html_collection_item (_tmp85_, 0);
#line 432 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 432 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp87_, GXML_TYPE_DOM_ELEMENT), "lec.item (0) is DomElement");
#line 432 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp87_);
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp88_ = lec;
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp89_ = gxml_dom_html_collection_item (_tmp88_, 0);
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp91_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp90_);
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "MyNode") == 0, "lec.item (0).node_name == \"MyNode\"");
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp93_);
#line 433 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp90_);
#line 434 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp94_ = lec;
#line 434 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp95_ = gxml_dom_html_collection_item (_tmp94_, 1);
#line 434 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 434 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp96_, GXML_TYPE_DOM_ELEMENT), "lec.item (1) is DomElement");
#line 434 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp97_ = lec;
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp98_ = gxml_dom_html_collection_item (_tmp97_, 1);
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp100_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp99_);
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp102_, "page") == 0, "lec.item (1).node_name == \"page\"");
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp102_);
#line 435 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp103_ = n;
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp103_, "class", "node parent", &_inner_error_);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 436 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6801 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 437 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp104_ = doc;
#line 437 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp105_ = gxml_dom_document_get_elements_by_class_name (_tmp104_, "parent");
#line 437 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lec2 = _tmp105_;
#line 438 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp106_ = lec2;
#line 438 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_html_collection_get_length (_tmp106_);
#line 438 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 438 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp108_ == 4, "lec2.length == 4");
#line 439 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp109_ = lec2;
#line 439 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_html_collection_item (_tmp109_, 0);
#line 439 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 439 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp111_, GXML_TYPE_DOM_ELEMENT), "lec2.item (0) is DomElement");
#line 439 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp111_);
#line 440 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp112_ = doc;
#line 440 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_document_get_elements_by_class_name (_tmp112_, "parent code");
#line 440 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lec3 = _tmp113_;
#line 441 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp114_ = lec3;
#line 441 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp115_ = gxml_dom_html_collection_get_length (_tmp114_);
#line 441 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 441 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp116_ == 0, "lec3.length == 0");
#line 442 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp117_ = doc;
#line 442 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp118_ = gxml_dom_document_get_elements_by_class_name (_tmp117_, "code parent");
#line 442 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lec4 = _tmp118_;
#line 443 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp119_ = lec4;
#line 443 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp120_ = gxml_dom_html_collection_get_length (_tmp119_);
#line 443 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 443 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp121_ == 0, "lec4.length == 0");
#line 444 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp122_ = doc;
#line 444 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp123_ = gxml_dom_document_get_elements_by_class_name (_tmp122_, "node parent");
#line 444 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		lec5 = _tmp123_;
#line 449 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp124_ = lec5;
#line 449 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_html_collection_get_length (_tmp124_);
#line 449 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 449 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp126_ == 3, "lec5.length == 3");
#line 450 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp127_ = lec5;
#line 450 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp128_ = gxml_dom_html_collection_item (_tmp127_, 0);
#line 450 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 450 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp129_, GXML_TYPE_DOM_ELEMENT), "lec5.item (0) is DomElement");
#line 450 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp129_);
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp130_ = lec5;
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_html_collection_item (_tmp130_, 0);
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp133_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp132_);
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp135_ = _tmp134_;
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp135_, "MyNode") == 0, "lec5.item (0).node_name == \"MyNode\"");
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp135_);
#line 451 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp132_);
#line 452 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp136_ = lec5;
#line 452 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp137_ = gxml_dom_html_collection_item (_tmp136_, 1);
#line 452 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp138_ = _tmp137_;
#line 452 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp138_, GXML_TYPE_DOM_ELEMENT), "lec5.item (1) is DomElement");
#line 452 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp138_);
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp139_ = lec5;
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp140_ = gxml_dom_html_collection_item (_tmp139_, 1);
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp142_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp141_);
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp144_ = _tmp143_;
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp144_, "page") == 0, "lec5.item (1).node_name == \"page\"");
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp144_);
#line 453 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp141_);
#line 454 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp145_ = lec5;
#line 454 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp146_ = gxml_dom_html_collection_item (_tmp145_, 2);
#line 454 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 454 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp147_, GXML_TYPE_DOM_ELEMENT), "lec5.item (2) is DomElement");
#line 454 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp147_);
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp148_ = lec5;
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp149_ = gxml_dom_html_collection_item (_tmp148_, 2);
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp151_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp150_);
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp153_, "code") == 0, "lec5.item (2).node_name == \"code\"");
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp153_);
#line 455 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp150_);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp154_ = doc;
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp155_ = gxml_dom_document_create_text_node (_tmp154_, "TEXT", &_inner_error_);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		t = _tmp155_;
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 456 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 6986 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp156_ = n;
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp157_ = t;
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp158_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp156_, (GXmlDomNode*) _tmp157_, &_inner_error_);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp159_);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 457 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7027 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp160_ = n;
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp161_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp160_);
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp162_ = _tmp161_;
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp163_ = _tmp162_;
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp164_ = gee_list_get ((GeeList*) _tmp163_, 0);
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp165_ = (GXmlDomNode*) _tmp164_;
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp165_, GXML_TYPE_DOM_TEXT), "n.child_nodes[0] is DomText");
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp165_);
#line 458 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp163_);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp166_ = n;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp167_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp166_);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp168_ = _tmp167_;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp170_ = gee_list_get ((GeeList*) _tmp169_, 0);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp171_ = (GXmlDomNode*) _tmp170_;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp172_ = gxml_dom_node_get_node_value (_tmp171_);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp173_ = _tmp172_;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "TEXT") == 0, "n.child_nodes[0].node_value == \"TEXT\"");
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp174_);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp171_);
#line 459 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp169_);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp175_ = doc;
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp176_ = gxml_dom_document_create_comment (_tmp175_, "COMMENT", &_inner_error_);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		comment = _tmp176_;
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 460 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7108 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp177_ = doc;
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp178_ = gxml_dom_document_get_document_element (_tmp177_);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp181_ = comment;
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp182_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp180_, (GXmlDomNode*) _tmp181_, &_inner_error_);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp183_ = _tmp182_;
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp183_);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 461 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7159 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp184_ = doc;
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp185_ = gxml_dom_document_get_document_element (_tmp184_);
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp186_ = _tmp185_;
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp188_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp187_);
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp189_ = _tmp188_;
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp190_ = _tmp189_;
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp190_, GXML_TYPE_DOM_COMMENT), "doc.document_element.last_child is DomComment");
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 462 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp187_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp191_ = doc;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp192_ = gxml_dom_document_get_document_element (_tmp191_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp194_ = _tmp193_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp195_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp194_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp196_ = _tmp195_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp198_ = gxml_dom_node_get_node_value (_tmp197_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp199_ = _tmp198_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp200_ = _tmp199_;
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp200_, "COMMENT") == 0, "doc.document_element.last_child.node_value == \"COMMENT\"");
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp200_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp197_);
#line 463 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp194_);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp201_ = doc;
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp202_ = gxml_dom_document_create_processing_instruction (_tmp201_, "git", "commit", &_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		pi = _tmp202_;
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 464 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7246 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp203_ = doc;
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp204_ = gxml_dom_document_get_document_element (_tmp203_);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp205_ = _tmp204_;
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp206_ = _tmp205_;
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp207_ = pi;
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp208_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp206_, (GXmlDomNode*) _tmp207_, &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp209_ = _tmp208_;
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp209_);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp206_);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (pi);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (comment);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec5);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec4);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec3);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec2);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lec);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (lens);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n2);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp56_);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (le);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 465 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7299 "DomGDocumentTest.c"
			goto __catch202_g_error;
		}
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp210_ = doc;
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp211_ = gxml_dom_document_get_document_element (_tmp210_);
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp212_ = _tmp211_;
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp213_ = _tmp212_;
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp214_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp213_);
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp215_ = _tmp214_;
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp216_ = _tmp215_;
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp216_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION), "doc.document_element.last_child is DomProcessingInstruction");
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp216_);
#line 469 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp213_);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (pi);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (comment);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lec5);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lec4);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lec3);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lec2);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lec);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (lens);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n2);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (le);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7352 "DomGDocumentTest.c"
	}
	goto __finally202;
	__catch202_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp217_ = NULL;
		gchar* _tmp218_ = NULL;
		gchar* _tmp219_ = NULL;
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 471 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp217_ = e->message;
#line 471 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp218_ = g_strconcat ("Error: ", _tmp217_, NULL);
#line 471 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp219_ = _tmp218_;
#line 471 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:471: %s", _tmp219_);
#line 471 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp219_);
#line 472 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7379 "DomGDocumentTest.c"
	}
	__finally202:
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 401 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 7390 "DomGDocumentTest.c"
	}
}


static void ___lambda197__gtest_func (void) {
#line 400 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda197_ ();
#line 7398 "DomGDocumentTest.c"
}


static void __lambda198_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GXmlDomDocument* doc2 = NULL;
		GXmlDomDocument* _tmp5_ = NULL;
		GXmlDomDocument* _tmp6_ = NULL;
		GXmlDomDocument* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomNode* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		GXmlDomDocument* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomNode* _tmp17_ = NULL;
		GXmlDomNode* _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		GXmlDomDocument* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomNode* _tmp24_ = NULL;
		GXmlDomNode* _tmp25_ = NULL;
		GXmlDomNode* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GXmlDomDocument* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
#line 480 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error_);
#line 480 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 480 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7455 "DomGDocumentTest.c"
			goto __catch203_g_error;
		}
#line 480 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 480 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error_);
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7472 "DomGDocumentTest.c"
			goto __catch203_g_error;
		}
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp3_) : NULL);
#line 481 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc2 = _tmp5_;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = doc;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = doc2;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_document_import_node (_tmp6_, (GXmlDomNode*) _tmp10_, FALSE, &_inner_error_);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc2);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp3_);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 482 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7507 "DomGDocumentTest.c"
			goto __catch203_g_error;
		}
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = doc;
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gxml_dom_document_get_document_element (_tmp13_);
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp16_);
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.last_child is DomElement");
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 486 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp16_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = doc;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = gxml_dom_document_get_document_element (_tmp20_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp23_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name (_tmp26_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "Sentences") == 0, "doc.document_element.last_child.node_name == \"Sentences\"");
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 487 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = doc;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_document_get_document_element (_tmp30_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp33_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes (_tmp36_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp41_ == 0, "doc.document_element.last_child.child_nodes.length == 0");
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 488 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc2);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7598 "DomGDocumentTest.c"
	}
	goto __finally203;
	__catch203_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 491 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = e->message;
#line 491 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = g_strconcat ("Error: ", _tmp42_, NULL);
#line 491 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 491 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:491: %s", _tmp44_);
#line 491 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 492 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7625 "DomGDocumentTest.c"
	}
	__finally203:
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 476 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 7636 "DomGDocumentTest.c"
	}
}


static void ___lambda198__gtest_func (void) {
#line 475 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda198_ ();
#line 7644 "DomGDocumentTest.c"
}


static void __lambda199_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGDocument* _tmp0_ = NULL;
		GXmlGDocument* _tmp1_ = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlGDocument* _tmp3_ = NULL;
		GXmlGDocument* _tmp4_ = NULL;
		GXmlDomDocument* doc2 = NULL;
		GXmlDomDocument* _tmp5_ = NULL;
		GXmlDomDocument* _tmp6_ = NULL;
		GXmlDomDocument* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomHTMLCollection* _tmp11_ = NULL;
		GXmlDomHTMLCollection* _tmp12_ = NULL;
		GXmlDomHTMLCollection* _tmp13_ = NULL;
		gpointer _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomNode* _tmp16_ = NULL;
		GXmlDomNode* _tmp17_ = NULL;
		GXmlDomDocument* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomHTMLCollection* _tmp22_ = NULL;
		GXmlDomHTMLCollection* _tmp23_ = NULL;
		GXmlDomHTMLCollection* _tmp24_ = NULL;
		gpointer _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GXmlDomDocument* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		GXmlDomDocument* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
		GXmlDomElement* _tmp40_ = NULL;
		GXmlDomNode* _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
#line 500 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_XMLDOC, 0, &_inner_error_);
#line 500 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 500 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 7706 "DomGDocumentTest.c"
			goto __catch204_g_error;
		}
#line 500 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 500 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc = _tmp2_;
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = gxml_gdocument_new_from_string (DOM_GDOCUMENT_TEST_STRDOC, 0, &_inner_error_);
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7723 "DomGDocumentTest.c"
			goto __catch204_g_error;
		}
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp3_) : NULL);
#line 501 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		doc2 = _tmp5_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = doc2;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = doc;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp10_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = gee_list_last ((GeeList*) _tmp13_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = (GXmlDomElement*) _tmp14_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = gxml_dom_document_adopt_node (_tmp6_, (GXmlDomNode*) _tmp15_, &_inner_error_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc2);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp3_);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (doc);
#line 502 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 7772 "DomGDocumentTest.c"
			goto __catch204_g_error;
		}
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = doc;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (_tmp18_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) _tmp21_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = gee_list_last ((GeeList*) _tmp24_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = (GXmlDomElement*) _tmp25_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp26_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "project") == 0, "doc.document_element.children.last ().node_name == \"project\"");
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp26_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp24_);
#line 507 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = doc2;
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = gxml_dom_document_get_document_element (_tmp30_);
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp33_ = _tmp32_;
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp34_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp33_);
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_ELEMENT), "doc2.document_element.last_child is DomElement");
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 508 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = doc2;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_document_get_document_element (_tmp37_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = gxml_dom_node_get_last_child ((GXmlDomNode*) _tmp40_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = gxml_dom_node_get_node_name (_tmp43_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "Author") == 0, "doc2.document_element.last_child.node_name == \"Author\"");
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 509 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc2);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (doc);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 7865 "DomGDocumentTest.c"
	}
	goto __finally204;
	__catch204_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 512 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = e->message;
#line 512 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = g_strconcat ("Error: ", _tmp47_, NULL);
#line 512 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 512 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:512: %s", _tmp49_);
#line 512 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp49_);
#line 513 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 7892 "DomGDocumentTest.c"
	}
	__finally204:
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 496 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 7903 "DomGDocumentTest.c"
	}
}


static void ___lambda199__gtest_func (void) {
#line 495 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda199_ ();
#line 7911 "DomGDocumentTest.c"
}


static void __lambda200_ (void) {
}


static void ___lambda200__gtest_func (void) {
#line 516 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda200_ ();
#line 7922 "DomGDocumentTest.c"
}


static void __lambda201_ (void) {
}


static void ___lambda201__gtest_func (void) {
#line 519 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda201_ ();
#line 7933 "DomGDocumentTest.c"
}


static void __lambda202_ (void) {
}


static void ___lambda202__gtest_func (void) {
#line 522 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda202_ ();
#line 7944 "DomGDocumentTest.c"
}


static void __lambda203_ (void) {
}


static void ___lambda203__gtest_func (void) {
#line 525 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda203_ ();
#line 7955 "DomGDocumentTest.c"
}


static void __lambda204_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGDocument* _tmp0_ = NULL;
		GXmlDomDocument* _tmp1_ = NULL;
		GXmlDomText* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomText* _tmp4_ = NULL;
		GXmlDomCharacterData* t = NULL;
		GXmlDomCharacterData* _tmp5_ = NULL;
		GXmlDomCharacterData* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GXmlDomCharacterData* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		gchar* _tmp15_ = NULL;
		GXmlDomCharacterData* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlDomCharacterData* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		GXmlDomCharacterData* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		GXmlDomCharacterData* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		GXmlDomCharacterData* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		GXmlDomCharacterData* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GXmlDomCharacterData* _tmp36_ = NULL;
		GXmlDomCharacterData* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		GXmlDomCharacterData* _tmp41_ = NULL;
		GXmlDomCharacterData* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		GXmlDomCharacterData* _tmp46_ = NULL;
		GXmlDomCharacterData* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		GXmlDomCharacterData* _tmp51_ = NULL;
		GXmlDomCharacterData* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		GXmlDomCharacterData* _tmp56_ = NULL;
		GXmlDomCharacterData* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		GXmlDomCharacterData* _tmp61_ = NULL;
		GXmlDomCharacterData* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		GXmlDomElement* n = NULL;
		GXmlDomDocument* _tmp66_ = NULL;
		GXmlDomElement* _tmp67_ = NULL;
		GXmlDomDocument* _tmp68_ = NULL;
		GXmlDomElement* _tmp69_ = NULL;
		GXmlDomNode* _tmp70_ = NULL;
		GXmlDomNode* _tmp71_ = NULL;
		GXmlDomElement* _tmp72_ = NULL;
		GXmlDomCharacterData* _tmp73_ = NULL;
		GXmlDomNode* _tmp74_ = NULL;
		GXmlDomNode* _tmp75_ = NULL;
		GXmlDomCharacterData* _tmp76_ = NULL;
		GXmlDomNode* _tmp77_ = NULL;
		GXmlDomNode* _tmp78_ = NULL;
		GXmlDomNode* _tmp79_ = NULL;
		GXmlDomNodeList* _tmp80_ = NULL;
		GXmlDomNodeList* _tmp81_ = NULL;
		GXmlDomNodeList* _tmp82_ = NULL;
		gint _tmp83_ = 0;
		gint _tmp84_ = 0;
		GXmlDomCharacterData* _tmp85_ = NULL;
		GXmlDomNode* _tmp86_ = NULL;
		GXmlDomNode* _tmp87_ = NULL;
		GXmlDomNode* _tmp88_ = NULL;
		GXmlDomNodeList* _tmp89_ = NULL;
		GXmlDomNodeList* _tmp90_ = NULL;
		GXmlDomNodeList* _tmp91_ = NULL;
		gint _tmp92_ = 0;
		gint _tmp93_ = 0;
		GXmlDomElement* ntst = NULL;
		GXmlDomDocument* _tmp94_ = NULL;
		GXmlDomElement* _tmp95_ = NULL;
		GXmlDomElement* _tmp96_ = NULL;
		GXmlDomElement* _tmp97_ = NULL;
		GXmlDomNode* _tmp98_ = NULL;
		GXmlDomNode* _tmp99_ = NULL;
		GXmlDomText* ct1 = NULL;
		GXmlDomDocument* _tmp100_ = NULL;
		GXmlDomText* _tmp101_ = NULL;
		GXmlDomElement* _tmp102_ = NULL;
		GXmlDomText* _tmp103_ = NULL;
		GXmlDomNode* _tmp104_ = NULL;
		GXmlDomNode* _tmp105_ = NULL;
		GXmlDomElement* _tmp106_ = NULL;
		GXmlDomNodeList* _tmp107_ = NULL;
		GXmlDomNodeList* _tmp108_ = NULL;
		GXmlDomNodeList* _tmp109_ = NULL;
		gint _tmp110_ = 0;
		gint _tmp111_ = 0;
		GXmlDomText* ct2 = NULL;
		GXmlDomDocument* _tmp112_ = NULL;
		GXmlDomText* _tmp113_ = NULL;
		GXmlDomElement* _tmp114_ = NULL;
		GXmlDomText* _tmp115_ = NULL;
		GXmlDomNode* _tmp116_ = NULL;
		GXmlDomNode* _tmp117_ = NULL;
		GXmlDomElement* _tmp118_ = NULL;
		GXmlDomNodeList* _tmp119_ = NULL;
		GXmlDomNodeList* _tmp120_ = NULL;
		GXmlDomNodeList* _tmp121_ = NULL;
		GXmlDomNode* _tmp122_ = NULL;
		GXmlDomNode* _tmp123_ = NULL;
		GXmlDomElement* _tmp124_ = NULL;
		GXmlDomNodeList* _tmp125_ = NULL;
		GXmlDomNodeList* _tmp126_ = NULL;
		GXmlDomNodeList* _tmp127_ = NULL;
		GXmlDomNode* _tmp128_ = NULL;
		GXmlDomText* _tmp129_ = NULL;
		GXmlDomText* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
		gchar* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		GXmlDomElement* _tmp134_ = NULL;
		GXmlDomNodeList* _tmp135_ = NULL;
		GXmlDomNodeList* _tmp136_ = NULL;
		GXmlDomNodeList* _tmp137_ = NULL;
		GXmlDomNode* _tmp138_ = NULL;
		GXmlDomText* _tmp139_ = NULL;
		GXmlDomText* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		gchar* _tmp143_ = NULL;
#line 530 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp0_ = gxml_gdocument_new ();
#line 530 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp1_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL;
#line 530 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp1_ == NULL) {
#line 530 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 8117 "DomGDocumentTest.c"
		}
#line 530 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		d = _tmp1_;
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp3_ = d;
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp4_ = gxml_dom_document_create_text_node (_tmp3_, "TEXT", &_inner_error_);
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp2_ = _tmp4_;
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8131 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_DOM_CHARACTER_DATA) ? ((GXmlDomCharacterData*) _tmp2_) : NULL);
#line 531 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		t = _tmp5_;
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp6_ = t;
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp7_ = gxml_dom_character_data_get_data (_tmp6_);
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "TEXT") == 0, "t.data == \"TEXT\"");
#line 532 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp10_ = t;
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp11_ = gxml_dom_character_data_get_length (_tmp10_);
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp13_ = strlen ("TEXT");
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 533 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp12_ == _tmp14_, "t.length == \"TEXT\".length");
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp16_ = t;
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp17_ = gxml_dom_character_data_substring_data (_tmp16_, 0, 2, &_inner_error_);
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp15_ = _tmp17_;
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8176 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 534 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "TE") == 0, "t.substring_data (0,2) == \"TE\"");
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp19_ = t;
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp20_ = gxml_dom_character_data_substring_data (_tmp19_, 0, 3, &_inner_error_);
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp18_ = _tmp20_;
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8197 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 535 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "TEX") == 0, "t.substring_data (0,3) == \"TEX\"");
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp22_ = t;
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp23_ = gxml_dom_character_data_substring_data (_tmp22_, 1, 3, &_inner_error_);
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp21_ = _tmp23_;
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8220 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 536 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp21_, "EXT") == 0, "t.substring_data (1,3) == \"EXT\"");
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp25_ = t;
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp26_ = gxml_dom_character_data_substring_data (_tmp25_, 1, 4, &_inner_error_);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp24_ = _tmp26_;
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8245 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 537 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "EXT") == 0, "t.substring_data (1,4) == \"EXT\"");
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp28_ = t;
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp29_ = gxml_dom_character_data_substring_data (_tmp28_, 1, 5, &_inner_error_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp27_ = _tmp29_;
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8272 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 538 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "EXT") == 0, "t.substring_data (1,5) == \"EXT\"");
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp31_ = t;
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp32_ = gxml_dom_character_data_substring_data (_tmp31_, 2, 0, &_inner_error_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp30_ = _tmp32_;
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8301 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 539 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "") == 0, "t.substring_data (2,0) == \"\"");
#line 8306 "DomGDocumentTest.c"
		{
			GXmlDomCharacterData* _tmp33_ = NULL;
			gchar* _tmp34_ = NULL;
			gchar* _tmp35_ = NULL;
#line 541 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp33_ = t;
#line 541 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp34_ = gxml_dom_character_data_substring_data (_tmp33_, 5, 1, &_inner_error_);
#line 541 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_tmp35_ = _tmp34_;
#line 541 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp35_);
#line 541 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8321 "DomGDocumentTest.c"
				goto __catch206_g_error;
			}
#line 542 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			g_assert_not_reached ();
#line 8326 "DomGDocumentTest.c"
		}
		goto __finally206;
		__catch206_g_error:
		{
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			g_clear_error (&_inner_error_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_inner_error_ = NULL;
#line 8335 "DomGDocumentTest.c"
		}
		__finally206:
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 540 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8358 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 545 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp36_ = t;
#line 545 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_append_data (_tmp36_, " HI");
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp37_ = t;
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp38_ = gxml_dom_character_data_get_data (_tmp37_);
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp40_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 546 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp40_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp41_ = t;
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_replace_data (_tmp41_, 0, 4, "", &_inner_error_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 547 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8401 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp42_ = t;
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp43_ = gxml_dom_character_data_get_data (_tmp42_);
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp45_, " HI") == 0, "t.data == \" HI\"");
#line 548 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp46_ = t;
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_insert_data (_tmp46_, 0, "TEXT", &_inner_error_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 549 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8440 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp47_ = t;
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp48_ = gxml_dom_character_data_get_data (_tmp47_);
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 550 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp50_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp51_ = t;
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_delete_data (_tmp51_, 0, 4, &_inner_error_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 551 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8479 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp52_ = t;
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp53_ = gxml_dom_character_data_get_data (_tmp52_);
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp55_, " HI") == 0, "t.data == \" HI\"");
#line 552 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp55_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp56_ = t;
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_insert_data (_tmp56_, 0, "TEXT", &_inner_error_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 553 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8518 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp57_ = t;
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp58_ = gxml_dom_character_data_get_data (_tmp57_);
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp60_ = _tmp59_;
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp60_, "TEXT HI") == 0, "t.data == \"TEXT HI\"");
#line 554 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp60_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp61_ = t;
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		gxml_dom_character_data_replace_data (_tmp61_, 0, 4, "text", &_inner_error_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 555 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8557 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp62_ = t;
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp63_ = gxml_dom_character_data_get_data (_tmp62_);
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "text HI") == 0, "t.data == \"text HI\"");
#line 556 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp65_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp66_ = d;
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp67_ = gxml_dom_document_create_element (_tmp66_, "node", &_inner_error_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		n = _tmp67_;
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 557 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8598 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp68_ = d;
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp69_ = n;
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp70_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp68_, (GXmlDomNode*) _tmp69_, &_inner_error_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 558 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8633 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp72_ = n;
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp73_ = t;
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp74_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp72_, (GXmlDomNode*) _tmp73_, &_inner_error_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp75_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 559 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8668 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp76_ = t;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp77_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp76_);
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp80_ = gxml_dom_node_get_child_nodes (_tmp79_);
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp83_ = gxml_dom_node_list_get_length (_tmp82_);
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp84_ == 1, "t.parent_node.child_nodes.length == 1");
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 560 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp85_ = t;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp86_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp85_);
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp89_ = gxml_dom_node_get_child_nodes (_tmp88_);
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp90_ = _tmp89_;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp92_ = gxml_dom_node_list_get_length (_tmp91_);
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp93_ == 1, "t.parent_node.child_nodes.length == 1");
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp91_);
#line 561 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp88_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp94_ = d;
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp95_ = gxml_dom_document_create_element (_tmp94_, "child", &_inner_error_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ntst = _tmp95_;
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 562 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8747 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp96_ = n;
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp97_ = ntst;
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp98_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp96_, (GXmlDomNode*) _tmp97_, &_inner_error_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp99_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 563 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8784 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp100_ = d;
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp101_ = gxml_dom_document_create_text_node (_tmp100_, "TEXT1", &_inner_error_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ct1 = _tmp101_;
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 564 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8817 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp102_ = ntst;
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp103_ = ct1;
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp104_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp102_, (GXmlDomNode*) _tmp103_, &_inner_error_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 565 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8856 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp106_ = ntst;
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp107_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp106_);
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp109_ = _tmp108_;
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp110_ = gxml_dom_node_list_get_length (_tmp109_);
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (_tmp111_ == 1, "ntst.child_nodes.length == 1");
#line 566 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp109_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp112_ = d;
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp113_ = gxml_dom_document_create_text_node (_tmp112_, "TEXT2", &_inner_error_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		ct2 = _tmp113_;
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 567 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8907 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp114_ = ntst;
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp115_ = ct2;
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp116_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp114_, (GXmlDomNode*) _tmp115_, &_inner_error_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp117_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ct2);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ct1);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (ntst);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (n);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp30_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp27_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp24_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp21_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_free0 (_tmp15_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (t);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp2_);
#line 568 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (d);
#line 8948 "DomGDocumentTest.c"
			goto __catch205_g_error;
		}
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp118_ = ntst;
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp119_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp118_);
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp122_ = gxml_dom_node_list_item (_tmp121_, 0);
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp123_, GXML_TYPE_DOM_TEXT), "ntst.child_nodes.item (0) is DomText");
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 576 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp121_);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp124_ = ntst;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp125_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp124_);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp127_ = _tmp126_;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp128_ = gxml_dom_node_list_item (_tmp127_, 0);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp129_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp128_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp128_) : NULL;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp129_ == NULL) {
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp128_);
#line 8985 "DomGDocumentTest.c"
		}
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp131_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) _tmp130_);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp133_, "TEXT1TEXT2") == 0, "(ntst.child_nodes.item (0) as DomText).data == \"TEXT1TEXT2\"");
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp133_);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp130_);
#line 577 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp127_);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp134_ = ntst;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp134_);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp138_ = gxml_dom_node_list_item (_tmp137_, 0);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp139_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp138_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp138_) : NULL;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		if (_tmp139_ == NULL) {
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
			_g_object_unref0 (_tmp138_);
#line 9019 "DomGDocumentTest.c"
		}
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp141_ = gxml_dom_text_get_whole_text (_tmp140_);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp143_, "TEXT1TEXT2") == 0, "(ntst.child_nodes.item(0) as DomText).whole_text == \"TEXT1TEXT2\"");
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp143_);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp140_);
#line 579 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ct2);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ct1);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (ntst);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (n);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp27_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp15_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (t);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (_tmp2_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_object_unref0 (d);
#line 9063 "DomGDocumentTest.c"
	}
	goto __finally205;
	__catch205_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp144_ = NULL;
		gchar* _tmp145_ = NULL;
		gchar* _tmp146_ = NULL;
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		e = _inner_error_;
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_inner_error_ = NULL;
#line 581 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp144_ = e->message;
#line 581 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp145_ = g_strconcat ("Error: ", _tmp144_, NULL);
#line 581 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 581 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_message ("DomGDocumentTest.vala:581: %s", _tmp146_);
#line 581 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_free0 (_tmp146_);
#line 582 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_assert_not_reached ();
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		_g_error_free0 (e);
#line 9090 "DomGDocumentTest.c"
	}
	__finally205:
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 529 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
		return;
#line 9101 "DomGDocumentTest.c"
	}
}


static void ___lambda204__gtest_func (void) {
#line 528 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	__lambda204_ ();
#line 9109 "DomGDocumentTest.c"
}


void dom_gdocument_test_add_tests (void) {
#line 69 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/children", ___lambda191__gtest_func);
#line 89 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/child_nodes", ___lambda192__gtest_func);
#line 112 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/element_collections", ___lambda193__gtest_func);
#line 139 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/element/element_collections", ___lambda194__gtest_func);
#line 167 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/node", ___lambda195__gtest_func);
#line 338 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/element/api", ___lambda196__gtest_func);
#line 400 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/api", ___lambda197__gtest_func);
#line 475 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/import", ___lambda198__gtest_func);
#line 495 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/adopt", ___lambda199__gtest_func);
#line 516 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/event", ___lambda200__gtest_func);
#line 519 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/range", ___lambda201__gtest_func);
#line 522 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/iterator", ___lambda202__gtest_func);
#line 525 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/document/walker", ___lambda203__gtest_func);
#line 528 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	g_test_add_func ("/gxml/dom/character", ___lambda204__gtest_func);
#line 9142 "DomGDocumentTest.c"
}


DomGDocumentTest* dom_gdocument_test_construct (GType object_type) {
	DomGDocumentTest* self = NULL;
#line 25 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	self = (DomGDocumentTest*) gxml_test_construct (object_type);
#line 25 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	return self;
#line 9152 "DomGDocumentTest.c"
}


DomGDocumentTest* dom_gdocument_test_new (void) {
#line 25 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	return dom_gdocument_test_construct (TYPE_DOM_GDOCUMENT_TEST);
#line 9159 "DomGDocumentTest.c"
}


static void dom_gdocument_test_class_init (DomGDocumentTestClass * klass) {
#line 25 "/home/despinosa/Proyectos/gxml/test/DomGDocumentTest.vala"
	dom_gdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 9166 "DomGDocumentTest.c"
}


static void dom_gdocument_test_instance_init (DomGDocumentTest * self) {
}


GType dom_gdocument_test_get_type (void) {
	static volatile gsize dom_gdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&dom_gdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (DomGDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) dom_gdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (DomGDocumentTest), 0, (GInstanceInitFunc) dom_gdocument_test_instance_init, NULL };
		GType dom_gdocument_test_type_id;
		dom_gdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "DomGDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&dom_gdocument_test_type_id__volatile, dom_gdocument_test_type_id);
	}
	return dom_gdocument_test_type_id__volatile;
}



