/* GomSerializationTest.c generated by valac 0.34.13, the Vala compiler
 * generated from GomSerializationTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_THREE_KEYS (three_keys_get_type ())
#define THREE_KEYS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THREE_KEYS, ThreeKeys))
#define THREE_KEYS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THREE_KEYS, ThreeKeysClass))
#define IS_THREE_KEYS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THREE_KEYS))
#define IS_THREE_KEYS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THREE_KEYS))
#define THREE_KEYS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THREE_KEYS, ThreeKeysClass))

typedef struct _ThreeKeys ThreeKeys;
typedef struct _ThreeKeysClass ThreeKeysClass;
typedef struct _ThreeKeysPrivate ThreeKeysPrivate;

#define THREE_KEY_TYPE_MAP (three_key_map_get_type ())
#define THREE_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), THREE_KEY_TYPE_MAP, ThreeKeyMap))
#define THREE_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), THREE_KEY_TYPE_MAP, ThreeKeyMapClass))
#define THREE_KEY_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THREE_KEY_TYPE_MAP))
#define THREE_KEY_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THREE_KEY_TYPE_MAP))
#define THREE_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), THREE_KEY_TYPE_MAP, ThreeKeyMapClass))

typedef struct _ThreeKeyMap ThreeKeyMap;
typedef struct _ThreeKeyMapClass ThreeKeyMapClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_THREE_KEY (three_key_get_type ())
#define THREE_KEY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THREE_KEY, ThreeKey))
#define THREE_KEY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THREE_KEY, ThreeKeyClass))
#define IS_THREE_KEY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THREE_KEY))
#define IS_THREE_KEY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THREE_KEY))
#define THREE_KEY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THREE_KEY, ThreeKeyClass))

typedef struct _ThreeKey ThreeKey;
typedef struct _ThreeKeyClass ThreeKeyClass;
typedef struct _ThreeKeyPrivate ThreeKeyPrivate;
typedef struct _ThreeKeyMapPrivate ThreeKeyMapPrivate;

#define TYPE_OPERATIONS (operations_get_type ())
#define OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATIONS, Operations))
#define OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATIONS, OperationsClass))
#define IS_OPERATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATIONS))
#define IS_OPERATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATIONS))
#define OPERATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATIONS, OperationsClass))

typedef struct _Operations Operations;
typedef struct _OperationsClass OperationsClass;
typedef struct _OperationsPrivate OperationsPrivate;

#define OPERATION_TYPE_MAP (operation_map_get_type ())
#define OPERATION_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), OPERATION_TYPE_MAP, OperationMap))
#define OPERATION_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), OPERATION_TYPE_MAP, OperationMapClass))
#define OPERATION_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), OPERATION_TYPE_MAP))
#define OPERATION_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), OPERATION_TYPE_MAP))
#define OPERATION_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), OPERATION_TYPE_MAP, OperationMapClass))

typedef struct _OperationMap OperationMap;
typedef struct _OperationMapClass OperationMapClass;

#define TYPE_OPERATION (operation_get_type ())
#define OPERATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OPERATION, Operation))
#define OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OPERATION, OperationClass))
#define IS_OPERATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OPERATION))
#define IS_OPERATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OPERATION))
#define OPERATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OPERATION, OperationClass))

typedef struct _Operation Operation;
typedef struct _OperationClass OperationClass;
typedef struct _OperationPrivate OperationPrivate;
typedef struct _OperationMapPrivate OperationMapPrivate;

#define TYPE_GOM_NAME (gom_name_get_type ())
#define GOM_NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_NAME, GomName))
#define GOM_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_NAME, GomNameClass))
#define IS_GOM_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_NAME))
#define IS_GOM_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_NAME))
#define GOM_NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_NAME, GomNameClass))

typedef struct _GomName GomName;
typedef struct _GomNameClass GomNameClass;
typedef struct _GomNamePrivate GomNamePrivate;

#define TYPE_GOM_EMAIL (gom_email_get_type ())
#define GOM_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_EMAIL, GomEmail))
#define GOM_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_EMAIL, GomEmailClass))
#define IS_GOM_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_EMAIL))
#define IS_GOM_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_EMAIL))
#define GOM_EMAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_EMAIL, GomEmailClass))

typedef struct _GomEmail GomEmail;
typedef struct _GomEmailClass GomEmailClass;
typedef struct _GomEmailPrivate GomEmailPrivate;

#define TYPE_GOM_AUTHOR (gom_author_get_type ())
#define GOM_AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_AUTHOR, GomAuthor))
#define GOM_AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_AUTHOR, GomAuthorClass))
#define IS_GOM_AUTHOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_AUTHOR))
#define IS_GOM_AUTHOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_AUTHOR))
#define GOM_AUTHOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_AUTHOR, GomAuthorClass))

typedef struct _GomAuthor GomAuthor;
typedef struct _GomAuthorClass GomAuthorClass;
typedef struct _GomAuthorPrivate GomAuthorPrivate;

#define TYPE_NAME (name_get_type ())
#define NAME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME, Name))
#define NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME, NameClass))
#define IS_NAME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME))
#define IS_NAME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME))
#define NAME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME, NameClass))

typedef struct _Name Name;
typedef struct _NameClass NameClass;

#define TYPE_EMAIL (email_get_type ())
#define EMAIL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_EMAIL, Email))
#define EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_EMAIL, EmailClass))
#define IS_EMAIL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_EMAIL))
#define IS_EMAIL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_EMAIL))
#define EMAIL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_EMAIL, EmailClass))

typedef struct _Email Email;
typedef struct _EmailClass EmailClass;

#define GOM_AUTHOR_TYPE_ARRAY (gom_author_array_get_type ())
#define GOM_AUTHOR_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArray))
#define GOM_AUTHOR_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArrayClass))
#define GOM_AUTHOR_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_AUTHOR_TYPE_ARRAY))
#define GOM_AUTHOR_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_AUTHOR_TYPE_ARRAY))
#define GOM_AUTHOR_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_AUTHOR_TYPE_ARRAY, GomAuthorArrayClass))

typedef struct _GomAuthorArray GomAuthorArray;
typedef struct _GomAuthorArrayClass GomAuthorArrayClass;
typedef struct _GomAuthorArrayPrivate GomAuthorArrayPrivate;

#define TYPE_GOM_AUTHORS (gom_authors_get_type ())
#define GOM_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_AUTHORS, GomAuthors))
#define GOM_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_AUTHORS, GomAuthorsClass))
#define IS_GOM_AUTHORS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_AUTHORS))
#define IS_GOM_AUTHORS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_AUTHORS))
#define GOM_AUTHORS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_AUTHORS, GomAuthorsClass))

typedef struct _GomAuthors GomAuthors;
typedef struct _GomAuthorsClass GomAuthorsClass;
typedef struct _GomAuthorsPrivate GomAuthorsPrivate;

#define TYPE_GOM_INVENTORY (gom_inventory_get_type ())
#define GOM_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_INVENTORY, GomInventory))
#define GOM_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_INVENTORY, GomInventoryClass))
#define IS_GOM_INVENTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_INVENTORY))
#define IS_GOM_INVENTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_INVENTORY))
#define GOM_INVENTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_INVENTORY, GomInventoryClass))

typedef struct _GomInventory GomInventory;
typedef struct _GomInventoryClass GomInventoryClass;
typedef struct _GomInventoryPrivate GomInventoryPrivate;

#define GOM_INVENTORY_TYPE_DUAL_KEY_MAP (gom_inventory_dual_key_map_get_type ())
#define GOM_INVENTORY_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMap))
#define GOM_INVENTORY_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMapClass))
#define GOM_INVENTORY_IS_DUAL_KEY_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP))
#define GOM_INVENTORY_IS_DUAL_KEY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_INVENTORY_TYPE_DUAL_KEY_MAP))
#define GOM_INVENTORY_DUAL_KEY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMapClass))

typedef struct _GomInventoryDualKeyMap GomInventoryDualKeyMap;
typedef struct _GomInventoryDualKeyMapClass GomInventoryDualKeyMapClass;
typedef struct _GomInventoryDualKeyMapPrivate GomInventoryDualKeyMapPrivate;

#define TYPE_GOM_CATEGORY (gom_category_get_type ())
#define GOM_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_CATEGORY, GomCategory))
#define GOM_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_CATEGORY, GomCategoryClass))
#define IS_GOM_CATEGORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_CATEGORY))
#define IS_GOM_CATEGORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_CATEGORY))
#define GOM_CATEGORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_CATEGORY, GomCategoryClass))

typedef struct _GomCategory GomCategory;
typedef struct _GomCategoryClass GomCategoryClass;
typedef struct _GomCategoryPrivate GomCategoryPrivate;

#define GOM_CATEGORY_TYPE_MAP (gom_category_map_get_type ())
#define GOM_CATEGORY_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_CATEGORY_TYPE_MAP, GomCategoryMap))
#define GOM_CATEGORY_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_CATEGORY_TYPE_MAP, GomCategoryMapClass))
#define GOM_CATEGORY_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_CATEGORY_TYPE_MAP))
#define GOM_CATEGORY_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_CATEGORY_TYPE_MAP))
#define GOM_CATEGORY_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_CATEGORY_TYPE_MAP, GomCategoryMapClass))

typedef struct _GomCategoryMap GomCategoryMap;
typedef struct _GomCategoryMapClass GomCategoryMapClass;
typedef struct _GomCategoryMapPrivate GomCategoryMapPrivate;

#define TYPE_GOM_RESUME (gom_resume_get_type ())
#define GOM_RESUME(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_RESUME, GomResume))
#define GOM_RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_RESUME, GomResumeClass))
#define IS_GOM_RESUME(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_RESUME))
#define IS_GOM_RESUME_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_RESUME))
#define GOM_RESUME_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_RESUME, GomResumeClass))

typedef struct _GomResume GomResume;
typedef struct _GomResumeClass GomResumeClass;
typedef struct _GomResumePrivate GomResumePrivate;

#define GOM_RESUME_TYPE_MAP (gom_resume_map_get_type ())
#define GOM_RESUME_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_RESUME_TYPE_MAP, GomResumeMap))
#define GOM_RESUME_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_RESUME_TYPE_MAP, GomResumeMapClass))
#define GOM_RESUME_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_RESUME_TYPE_MAP))
#define GOM_RESUME_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_RESUME_TYPE_MAP))
#define GOM_RESUME_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_RESUME_TYPE_MAP, GomResumeMapClass))

typedef struct _GomResumeMap GomResumeMap;
typedef struct _GomResumeMapClass GomResumeMapClass;
typedef struct _GomResumeMapPrivate GomResumeMapPrivate;

#define TYPE_GOM_BOOK (gom_book_get_type ())
#define GOM_BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BOOK, GomBook))
#define GOM_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BOOK, GomBookClass))
#define IS_GOM_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BOOK))
#define IS_GOM_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BOOK))
#define GOM_BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BOOK, GomBookClass))

typedef struct _GomBook GomBook;
typedef struct _GomBookClass GomBookClass;
typedef struct _GomBookPrivate GomBookPrivate;

#define GOM_BOOK_TYPE_ARRAY (gom_book_array_get_type ())
#define GOM_BOOK_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_BOOK_TYPE_ARRAY, GomBookArray))
#define GOM_BOOK_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_BOOK_TYPE_ARRAY, GomBookArrayClass))
#define GOM_BOOK_IS_ARRAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_BOOK_TYPE_ARRAY))
#define GOM_BOOK_IS_ARRAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_BOOK_TYPE_ARRAY))
#define GOM_BOOK_ARRAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_BOOK_TYPE_ARRAY, GomBookArrayClass))

typedef struct _GomBookArray GomBookArray;
typedef struct _GomBookArrayClass GomBookArrayClass;
typedef struct _GomBookArrayPrivate GomBookArrayPrivate;

#define TYPE_GOM_BOOK_STORE (gom_book_store_get_type ())
#define GOM_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BOOK_STORE, GomBookStore))
#define GOM_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BOOK_STORE, GomBookStoreClass))
#define IS_GOM_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BOOK_STORE))
#define IS_GOM_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BOOK_STORE))
#define GOM_BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BOOK_STORE, GomBookStoreClass))

typedef struct _GomBookStore GomBookStore;
typedef struct _GomBookStoreClass GomBookStoreClass;
typedef struct _GomBookStorePrivate GomBookStorePrivate;

#define TYPE_GOM_BASIC_TYPES (gom_basic_types_get_type ())
#define GOM_BASIC_TYPES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_BASIC_TYPES, GomBasicTypes))
#define GOM_BASIC_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_BASIC_TYPES, GomBasicTypesClass))
#define IS_GOM_BASIC_TYPES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_BASIC_TYPES))
#define IS_GOM_BASIC_TYPES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_BASIC_TYPES))
#define GOM_BASIC_TYPES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_BASIC_TYPES, GomBasicTypesClass))

typedef struct _GomBasicTypes GomBasicTypes;
typedef struct _GomBasicTypesClass GomBasicTypesClass;
typedef struct _GomBasicTypesPrivate GomBasicTypesPrivate;

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_SERIALIZATION_TEST (gom_serialization_test_get_type ())
#define GOM_SERIALIZATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTest))
#define GOM_SERIALIZATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTestClass))
#define IS_GOM_SERIALIZATION_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_SERIALIZATION_TEST))
#define IS_GOM_SERIALIZATION_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_SERIALIZATION_TEST))
#define GOM_SERIALIZATION_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_SERIALIZATION_TEST, GomSerializationTestClass))

typedef struct _GomSerializationTest GomSerializationTest;
typedef struct _GomSerializationTestClass GomSerializationTestClass;
typedef struct _GomSerializationTestPrivate GomSerializationTestPrivate;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK (gom_serialization_test_book_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook))
#define GOM_SERIALIZATION_TEST_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBookClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK))
#define GOM_SERIALIZATION_TEST_IS_BOOK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK))
#define GOM_SERIALIZATION_TEST_BOOK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBookClass))

typedef struct _GomSerializationTestBook GomSerializationTestBook;
typedef struct _GomSerializationTestBookClass GomSerializationTestBookClass;

#define GOM_SERIALIZATION_TEST_TYPE_COMPUTER (gom_serialization_test_computer_get_type ())
#define GOM_SERIALIZATION_TEST_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer))
#define GOM_SERIALIZATION_TEST_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputerClass))
#define GOM_SERIALIZATION_TEST_IS_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER))
#define GOM_SERIALIZATION_TEST_IS_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_COMPUTER))
#define GOM_SERIALIZATION_TEST_COMPUTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputerClass))

typedef struct _GomSerializationTestComputer GomSerializationTestComputer;
typedef struct _GomSerializationTestComputerClass GomSerializationTestComputerClass;

#define GOM_SERIALIZATION_TEST_TYPE_TAXES (gom_serialization_test_taxes_get_type ())
#define GOM_SERIALIZATION_TEST_TAXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes))
#define GOM_SERIALIZATION_TEST_TAXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxesClass))
#define GOM_SERIALIZATION_TEST_IS_TAXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES))
#define GOM_SERIALIZATION_TEST_IS_TAXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_TAXES))
#define GOM_SERIALIZATION_TEST_TAXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxesClass))

typedef struct _GomSerializationTestTaxes GomSerializationTestTaxes;
typedef struct _GomSerializationTestTaxesClass GomSerializationTestTaxesClass;

#define GOM_SERIALIZATION_TEST_TAXES_TYPE_MONTH (gom_serialization_test_taxes_month_get_type ())
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND (gom_serialization_test_book_stand_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStandClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STAND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STAND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStandClass))

typedef struct _GomSerializationTestBookStand GomSerializationTestBookStand;
typedef struct _GomSerializationTestBookStandClass GomSerializationTestBookStandClass;

#define GOM_SERIALIZATION_TEST_TYPE_REGISTERS (gom_serialization_test_registers_get_type ())
#define GOM_SERIALIZATION_TEST_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegisters))
#define GOM_SERIALIZATION_TEST_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_REGISTERS))
#define GOM_SERIALIZATION_TEST_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegistersClass))

typedef struct _GomSerializationTestRegisters GomSerializationTestRegisters;
typedef struct _GomSerializationTestRegistersClass GomSerializationTestRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER (gom_serialization_test_book_register_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister))
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegisterClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_REGISTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER))
#define GOM_SERIALIZATION_TEST_IS_BOOK_REGISTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER))
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegisterClass))

typedef struct _GomSerializationTestBookRegister GomSerializationTestBookRegister;
typedef struct _GomSerializationTestBookRegisterClass GomSerializationTestBookRegisterClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION (gom_serialization_test_book_stand_dimension_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimensionClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimensionClass))

typedef struct _GomSerializationTestBookStandDimension GomSerializationTestBookStandDimension;
typedef struct _GomSerializationTestBookStandDimensionClass GomSerializationTestBookStandDimensionClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y (gom_serialization_test_book_stand_dimension_y_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionY))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionYClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Y(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Y_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionYClass))

typedef struct _GomSerializationTestBookStandDimensionY GomSerializationTestBookStandDimensionY;
typedef struct _GomSerializationTestBookStandDimensionYClass GomSerializationTestBookStandDimensionYClass;

#define GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z (gom_serialization_test_book_stand_dimension_z_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZ))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZClass))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Z(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_IS_DIMENSION_Z_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z))
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZClass))

typedef struct _GomSerializationTestBookStandDimensionZ GomSerializationTestBookStandDimensionZ;
typedef struct _GomSerializationTestBookStandDimensionZClass GomSerializationTestBookStandDimensionZClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE (gom_serialization_test_book_store_get_type ())
#define GOM_SERIALIZATION_TEST_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore))
#define GOM_SERIALIZATION_TEST_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStoreClass))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE))
#define GOM_SERIALIZATION_TEST_IS_BOOK_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE))
#define GOM_SERIALIZATION_TEST_BOOK_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStoreClass))

typedef struct _GomSerializationTestBookStore GomSerializationTestBookStore;
typedef struct _GomSerializationTestBookStoreClass GomSerializationTestBookStoreClass;

#define GOM_SERIALIZATION_TEST_TYPE_BOOKS (gom_serialization_test_books_get_type ())
#define GOM_SERIALIZATION_TEST_BOOKS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooks))
#define GOM_SERIALIZATION_TEST_BOOKS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooksClass))
#define GOM_SERIALIZATION_TEST_IS_BOOKS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS))
#define GOM_SERIALIZATION_TEST_IS_BOOKS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_BOOKS))
#define GOM_SERIALIZATION_TEST_BOOKS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooksClass))

typedef struct _GomSerializationTestBooks GomSerializationTestBooks;
typedef struct _GomSerializationTestBooksClass GomSerializationTestBooksClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS (gom_serialization_test_hash_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegisters))
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegistersClass))

typedef struct _GomSerializationTestHashRegisters GomSerializationTestHashRegisters;
typedef struct _GomSerializationTestHashRegistersClass GomSerializationTestHashRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS (gom_serialization_test_hash_pair_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegisters))
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_PAIR_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_PAIR_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegistersClass))

typedef struct _GomSerializationTestHashPairRegisters GomSerializationTestHashPairRegisters;
typedef struct _GomSerializationTestHashPairRegistersClass GomSerializationTestHashPairRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS (gom_serialization_test_hash_three_registers_get_type ())
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegisters))
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegistersClass))
#define GOM_SERIALIZATION_TEST_IS_HASH_THREE_REGISTERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS))
#define GOM_SERIALIZATION_TEST_IS_HASH_THREE_REGISTERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS))
#define GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegistersClass))

typedef struct _GomSerializationTestHashThreeRegisters GomSerializationTestHashThreeRegisters;
typedef struct _GomSerializationTestHashThreeRegistersClass GomSerializationTestHashThreeRegistersClass;

#define GOM_SERIALIZATION_TEST_TYPE_MOTOR (gom_serialization_test_motor_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor))
#define GOM_SERIALIZATION_TEST_MOTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotorClass))
#define GOM_SERIALIZATION_TEST_IS_MOTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR))
#define GOM_SERIALIZATION_TEST_IS_MOTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_TYPE_MOTOR))
#define GOM_SERIALIZATION_TEST_MOTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotorClass))

typedef struct _GomSerializationTestMotor GomSerializationTestMotor;
typedef struct _GomSerializationTestMotorClass GomSerializationTestMotorClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON (gom_serialization_test_motor_on_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_ON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOn))
#define GOM_SERIALIZATION_TEST_MOTOR_ON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOnClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_ON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_ON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON))
#define GOM_SERIALIZATION_TEST_MOTOR_ON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, GomSerializationTestMotorOnClass))

typedef struct _GomSerializationTestMotorOn GomSerializationTestMotorOn;
typedef struct _GomSerializationTestMotorOnClass GomSerializationTestMotorOnClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE (gom_serialization_test_motor_torque_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorque))
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorqueClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TORQUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TORQUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE))
#define GOM_SERIALIZATION_TEST_MOTOR_TORQUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, GomSerializationTestMotorTorqueClass))

typedef struct _GomSerializationTestMotorTorque GomSerializationTestMotorTorque;
typedef struct _GomSerializationTestMotorTorqueClass GomSerializationTestMotorTorqueClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED (gom_serialization_test_motor_speed_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeed))
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeedClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_SPEED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_SPEED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED))
#define GOM_SERIALIZATION_TEST_MOTOR_SPEED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, GomSerializationTestMotorSpeedClass))

typedef struct _GomSerializationTestMotorSpeed GomSerializationTestMotorSpeed;
typedef struct _GomSerializationTestMotorSpeedClass GomSerializationTestMotorSpeedClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE (gom_serialization_test_motor_tension_type_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionType))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionTypeClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionTypeClass))

typedef struct _GomSerializationTestMotorTensionType GomSerializationTestMotorTensionType;
typedef struct _GomSerializationTestMotorTensionTypeClass GomSerializationTestMotorTensionTypeClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION (gom_serialization_test_motor_tension_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTension))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTensionClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_TENSION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION))
#define GOM_SERIALIZATION_TEST_MOTOR_TENSION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, GomSerializationTestMotorTensionClass))

typedef struct _GomSerializationTestMotorTension GomSerializationTestMotorTension;
typedef struct _GomSerializationTestMotorTensionClass GomSerializationTestMotorTensionClass;

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE_ENUM (gom_serialization_test_motor_tension_type_enum_get_type ())

#define GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL (gom_serialization_test_motor_model_get_type ())
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModel))
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModelClass))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL))
#define GOM_SERIALIZATION_TEST_MOTOR_IS_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL))
#define GOM_SERIALIZATION_TEST_MOTOR_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModelClass))

typedef struct _GomSerializationTestMotorModel GomSerializationTestMotorModel;
typedef struct _GomSerializationTestMotorModelClass GomSerializationTestMotorModelClass;
#define __g_list_free__g_free0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_free0_ (var), NULL)))
typedef struct _GomSerializationTestBookPrivate GomSerializationTestBookPrivate;
typedef struct _GomSerializationTestComputerPrivate GomSerializationTestComputerPrivate;
typedef struct _GomSerializationTestTaxesPrivate GomSerializationTestTaxesPrivate;
typedef struct _GomSerializationTestBookRegisterPrivate GomSerializationTestBookRegisterPrivate;
typedef struct _GomSerializationTestBookStandPrivate GomSerializationTestBookStandPrivate;
typedef struct _GomSerializationTestBookStandDimensionPrivate GomSerializationTestBookStandDimensionPrivate;
typedef struct _GomSerializationTestBookStandDimensionYPrivate GomSerializationTestBookStandDimensionYPrivate;
typedef struct _GomSerializationTestBookStandDimensionZPrivate GomSerializationTestBookStandDimensionZPrivate;
typedef struct _GomSerializationTestRegistersPrivate GomSerializationTestRegistersPrivate;
typedef struct _GomSerializationTestHashRegistersPrivate GomSerializationTestHashRegistersPrivate;
typedef struct _GomSerializationTestHashPairRegistersPrivate GomSerializationTestHashPairRegistersPrivate;
typedef struct _GomSerializationTestHashThreeRegistersPrivate GomSerializationTestHashThreeRegistersPrivate;
typedef struct _GomSerializationTestBooksPrivate GomSerializationTestBooksPrivate;
typedef struct _GomSerializationTestBookStorePrivate GomSerializationTestBookStorePrivate;
typedef struct _GomSerializationTestMotorPrivate GomSerializationTestMotorPrivate;
typedef struct _GomSerializationTestMotorOnPrivate GomSerializationTestMotorOnPrivate;
typedef struct _GomSerializationTestMotorTorquePrivate GomSerializationTestMotorTorquePrivate;
typedef struct _GomSerializationTestMotorSpeedPrivate GomSerializationTestMotorSpeedPrivate;
typedef struct _GomSerializationTestMotorTensionTypePrivate GomSerializationTestMotorTensionTypePrivate;
typedef struct _GomSerializationTestMotorTensionPrivate GomSerializationTestMotorTensionPrivate;
typedef struct _GomSerializationTestMotorModelPrivate GomSerializationTestMotorModelPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _ThreeKeys {
	GXmlGomElement parent_instance;
	ThreeKeysPrivate * priv;
};

struct _ThreeKeysClass {
	GXmlGomElementClass parent_class;
};

struct _ThreeKeysPrivate {
	ThreeKeyMap* _map;
};

struct _ThreeKey {
	GXmlGomElement parent_instance;
	ThreeKeyPrivate * priv;
};

struct _ThreeKeyClass {
	GXmlGomElementClass parent_class;
};

struct _ThreeKeyPrivate {
	gchar* _id;
	gchar* _code;
	gchar* _name;
};

struct _ThreeKeyMap {
	GXmlGomHashThreeMap parent_instance;
	ThreeKeyMapPrivate * priv;
};

struct _ThreeKeyMapClass {
	GXmlGomHashThreeMapClass parent_class;
};

struct _Operations {
	GXmlGomElement parent_instance;
	OperationsPrivate * priv;
};

struct _OperationsClass {
	GXmlGomElementClass parent_class;
};

struct _OperationsPrivate {
	OperationMap* _map;
};

struct _Operation {
	GXmlGomElement parent_instance;
	OperationPrivate * priv;
};

struct _OperationClass {
	GXmlGomElementClass parent_class;
};

struct _OperationPrivate {
	gchar* _id;
	gchar* _code;
};

struct _OperationMap {
	GXmlGomHashPairedMap parent_instance;
	OperationMapPrivate * priv;
};

struct _OperationMapClass {
	GXmlGomHashPairedMapClass parent_class;
};

struct _GomName {
	GXmlGomElement parent_instance;
	GomNamePrivate * priv;
};

struct _GomNameClass {
	GXmlGomElementClass parent_class;
};

struct _GomEmail {
	GXmlGomElement parent_instance;
	GomEmailPrivate * priv;
};

struct _GomEmailClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthor {
	GXmlGomElement parent_instance;
	GomAuthorPrivate * priv;
};

struct _GomAuthorClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthorPrivate {
	Name* _name;
	Email* _email;
};

struct _GomAuthorArray {
	GXmlGomArrayList parent_instance;
	GomAuthorArrayPrivate * priv;
};

struct _GomAuthorArrayClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomAuthors {
	GXmlGomElement parent_instance;
	GomAuthorsPrivate * priv;
};

struct _GomAuthorsClass {
	GXmlGomElementClass parent_class;
};

struct _GomAuthorsPrivate {
	gchar* _number;
	GomAuthorArray* _array;
};

struct _GomInventory {
	GXmlGomElement parent_instance;
	GomInventoryPrivate * priv;
};

struct _GomInventoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomInventoryPrivate {
	gint _number;
	gint _row;
	gchar* _inventory;
};

struct _GomInventoryDualKeyMap {
	GXmlGomHashMap parent_instance;
	GomInventoryDualKeyMapPrivate * priv;
};

struct _GomInventoryDualKeyMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomCategory {
	GXmlGomElement parent_instance;
	GomCategoryPrivate * priv;
};

struct _GomCategoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomCategoryPrivate {
	gchar* _name;
};

struct _GomCategoryMap {
	GXmlGomHashMap parent_instance;
	GomCategoryMapPrivate * priv;
};

struct _GomCategoryMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomResume {
	GXmlGomElement parent_instance;
	GomResumePrivate * priv;
};

struct _GomResumeClass {
	GXmlGomElementClass parent_class;
};

struct _GomResumePrivate {
	gchar* _chapter;
	gchar* _text;
};

struct _GomResumeMap {
	GXmlGomHashMap parent_instance;
	GomResumeMapPrivate * priv;
};

struct _GomResumeMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomBook {
	GXmlGomElement parent_instance;
	GomBookPrivate * priv;
};

struct _GomBookClass {
	GXmlGomElementClass parent_class;
};

struct _GomBookPrivate {
	gchar* _year;
	gchar* _isbn;
	GomName* _name;
	GomAuthors* _authors;
	GomInventoryDualKeyMap* _inventory_registers;
	GomCategoryMap* _categories;
	GomResumeMap* _resumes;
};

struct _GomBookArray {
	GXmlGomArrayList parent_instance;
	GomBookArrayPrivate * priv;
};

struct _GomBookArrayClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomBookStore {
	GXmlGomElement parent_instance;
	GomBookStorePrivate * priv;
};

struct _GomBookStoreClass {
	GXmlGomElementClass parent_class;
};

struct _GomBookStorePrivate {
	gchar* _name;
	GomBookArray* _books;
};

struct _GomBasicTypes {
	GXmlGomElement parent_instance;
	GomBasicTypesPrivate * priv;
};

struct _GomBasicTypesClass {
	GXmlGomElementClass parent_class;
};

struct _GomBasicTypesPrivate {
	gchar* _text;
	gint _integer;
	gdouble _real_double;
	gfloat _real_float;
	guint _unsigned_integer;
	gboolean _boolean;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomSerializationTest {
	GXmlTest parent_instance;
	GomSerializationTestPrivate * priv;
};

struct _GomSerializationTestClass {
	GXmlTestClass parent_class;
};

typedef enum  {
	GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY
} GomSerializationTestTaxesMonth;

typedef enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC
} GomSerializationTestMotorTensionTypeEnum;

struct _GomSerializationTestBook {
	GXmlGomElement parent_instance;
	GomSerializationTestBookPrivate * priv;
};

struct _GomSerializationTestBookClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookPrivate {
	gchar* _name;
};

struct _GomSerializationTestComputer {
	GXmlGomElement parent_instance;
	GomSerializationTestComputerPrivate * priv;
};

struct _GomSerializationTestComputerClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestComputerPrivate {
	gchar* _model;
	gchar* _ignore;
};

struct _GomSerializationTestTaxes {
	GXmlGomElement parent_instance;
	GomSerializationTestTaxesPrivate * priv;
};

struct _GomSerializationTestTaxesClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestTaxesPrivate {
	gdouble _month_rate;
	gboolean _tax_free;
	GomSerializationTestTaxesMonth _month;
	GXmlGomDate* _pay_date;
	GXmlGomDateTime* _timestamp;
};

struct _GomSerializationTestBookRegister {
	GXmlGomElement parent_instance;
	GomSerializationTestBookRegisterPrivate * priv;
};

struct _GomSerializationTestBookRegisterClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookRegisterPrivate {
	GomSerializationTestBook* _book;
	gint _year;
	gchar* _cover;
};

struct _GomSerializationTestBookStand {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStandPrivate * priv;
};

struct _GomSerializationTestBookStandClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStandPrivate {
	GomSerializationTestHashRegisters* _hashmap_registers;
	GomSerializationTestHashPairRegisters* _hashpair_registers;
	GomSerializationTestHashThreeRegisters* _hashthree_registers;
	gchar* _classification;
	GomSerializationTestBookStandDimension* _dimension_x;
	GomSerializationTestBookStandDimensionY* _dimension_y;
	GomSerializationTestBookStandDimensionZ* _dimension_z;
	GomSerializationTestRegisters* _registers;
	GomSerializationTestBooks* _books;
};

struct _GomSerializationTestBookStandDimension {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStandDimensionPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStandDimensionPrivate {
	gdouble _length;
	gchar* _dtype;
};

struct _GomSerializationTestBookStandDimensionY {
	GomSerializationTestBookStandDimension parent_instance;
	GomSerializationTestBookStandDimensionYPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionYClass {
	GomSerializationTestBookStandDimensionClass parent_class;
};

struct _GomSerializationTestBookStandDimensionZ {
	GomSerializationTestBookStandDimension parent_instance;
	GomSerializationTestBookStandDimensionZPrivate * priv;
};

struct _GomSerializationTestBookStandDimensionZClass {
	GomSerializationTestBookStandDimensionClass parent_class;
};

struct _GomSerializationTestRegisters {
	GXmlGomArrayList parent_instance;
	GomSerializationTestRegistersPrivate * priv;
};

struct _GomSerializationTestRegistersClass {
	GXmlGomArrayListClass parent_class;
};

struct _GomSerializationTestHashRegisters {
	GXmlGomHashMap parent_instance;
	GomSerializationTestHashRegistersPrivate * priv;
};

struct _GomSerializationTestHashRegistersClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomSerializationTestHashPairRegisters {
	GXmlGomHashPairedMap parent_instance;
	GomSerializationTestHashPairRegistersPrivate * priv;
};

struct _GomSerializationTestHashPairRegistersClass {
	GXmlGomHashPairedMapClass parent_class;
};

struct _GomSerializationTestHashThreeRegisters {
	GXmlGomHashThreeMap parent_instance;
	GomSerializationTestHashThreeRegistersPrivate * priv;
};

struct _GomSerializationTestHashThreeRegistersClass {
	GXmlGomHashThreeMapClass parent_class;
};

struct _GomSerializationTestBooks {
	GXmlGomHashMap parent_instance;
	GomSerializationTestBooksPrivate * priv;
};

struct _GomSerializationTestBooksClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomSerializationTestBookStore {
	GXmlGomElement parent_instance;
	GomSerializationTestBookStorePrivate * priv;
};

struct _GomSerializationTestBookStoreClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestBookStorePrivate {
	gchar* _name;
	GomSerializationTestBooks* _books;
};

struct _GomSerializationTestMotor {
	GXmlGomElement parent_instance;
	GomSerializationTestMotorPrivate * priv;
};

struct _GomSerializationTestMotorClass {
	GXmlGomElementClass parent_class;
};

struct _GomSerializationTestMotorPrivate {
	GomSerializationTestMotorOn* _is_on;
	GomSerializationTestMotorTorque* _torque;
	GomSerializationTestMotorSpeed* _speed;
	GomSerializationTestMotorTensionType* _tension_type;
	GomSerializationTestMotorTension* _tension;
	GomSerializationTestMotorModel* _model;
};

struct _GomSerializationTestMotorOn {
	GXmlGomBoolean parent_instance;
	GomSerializationTestMotorOnPrivate * priv;
};

struct _GomSerializationTestMotorOnClass {
	GXmlGomBooleanClass parent_class;
};

struct _GomSerializationTestMotorTorque {
	GXmlGomDouble parent_instance;
	GomSerializationTestMotorTorquePrivate * priv;
};

struct _GomSerializationTestMotorTorqueClass {
	GXmlGomDoubleClass parent_class;
};

struct _GomSerializationTestMotorSpeed {
	GXmlGomFloat parent_instance;
	GomSerializationTestMotorSpeedPrivate * priv;
};

struct _GomSerializationTestMotorSpeedClass {
	GXmlGomFloatClass parent_class;
};

struct _GomSerializationTestMotorTensionType {
	GXmlGomEnum parent_instance;
	GomSerializationTestMotorTensionTypePrivate * priv;
};

struct _GomSerializationTestMotorTensionTypeClass {
	GXmlGomEnumClass parent_class;
};

struct _GomSerializationTestMotorTension {
	GXmlGomInt parent_instance;
	GomSerializationTestMotorTensionPrivate * priv;
};

struct _GomSerializationTestMotorTensionClass {
	GXmlGomIntClass parent_class;
};

struct _GomSerializationTestMotorModel {
	GXmlGomArrayString parent_instance;
	GomSerializationTestMotorModelPrivate * priv;
};

struct _GomSerializationTestMotorModelClass {
	GXmlGomArrayStringClass parent_class;
};


static gpointer three_keys_parent_class = NULL;
static gpointer three_key_parent_class = NULL;
static gpointer three_key_map_parent_class = NULL;
static GXmlMappeableElementThreeKeyIface* three_key_gxml_mappeable_element_three_key_parent_iface = NULL;
static gpointer operations_parent_class = NULL;
static gpointer operation_parent_class = NULL;
static gpointer operation_map_parent_class = NULL;
static GXmlMappeableElementPairKeyIface* operation_gxml_mappeable_element_pair_key_parent_iface = NULL;
static gpointer gom_name_parent_class = NULL;
static gpointer gom_email_parent_class = NULL;
static gpointer gom_author_parent_class = NULL;
static gpointer gom_author_array_parent_class = NULL;
static gpointer gom_authors_parent_class = NULL;
static gpointer gom_inventory_parent_class = NULL;
static gpointer gom_inventory_dual_key_map_parent_class = NULL;
static gpointer gom_category_parent_class = NULL;
static gpointer gom_category_map_parent_class = NULL;
static gpointer gom_resume_parent_class = NULL;
static gpointer gom_resume_map_parent_class = NULL;
static gpointer gom_book_parent_class = NULL;
static gpointer gom_book_array_parent_class = NULL;
static gpointer gom_book_store_parent_class = NULL;
static gpointer gom_basic_types_parent_class = NULL;
static gpointer gom_serialization_test_parent_class = NULL;
static gpointer gom_serialization_test_book_parent_class = NULL;
static gpointer gom_serialization_test_computer_parent_class = NULL;
static gpointer gom_serialization_test_taxes_parent_class = NULL;
static gpointer gom_serialization_test_book_register_parent_class = NULL;
static GXmlMappeableElementIface* gom_serialization_test_book_register_gxml_mappeable_element_parent_iface = NULL;
static GXmlMappeableElementPairKeyIface* gom_serialization_test_book_register_gxml_mappeable_element_pair_key_parent_iface = NULL;
static GXmlMappeableElementThreeKeyIface* gom_serialization_test_book_register_gxml_mappeable_element_three_key_parent_iface = NULL;
static gpointer gom_serialization_test_book_stand_parent_class = NULL;
static gpointer gom_serialization_test_book_stand_dimension_parent_class = NULL;
static gpointer gom_serialization_test_book_stand_dimension_y_parent_class = NULL;
static gpointer gom_serialization_test_book_stand_dimension_z_parent_class = NULL;
static gpointer gom_serialization_test_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_pair_registers_parent_class = NULL;
static gpointer gom_serialization_test_hash_three_registers_parent_class = NULL;
static gpointer gom_serialization_test_books_parent_class = NULL;
static gpointer gom_serialization_test_book_store_parent_class = NULL;
static gpointer gom_serialization_test_motor_parent_class = NULL;
static gpointer gom_serialization_test_motor_on_parent_class = NULL;
static gpointer gom_serialization_test_motor_torque_parent_class = NULL;
static gpointer gom_serialization_test_motor_speed_parent_class = NULL;
static gpointer gom_serialization_test_motor_tension_type_parent_class = NULL;
static gpointer gom_serialization_test_motor_tension_parent_class = NULL;
static gpointer gom_serialization_test_motor_model_parent_class = NULL;

GType three_keys_get_type (void) G_GNUC_CONST;
GType three_key_map_get_type (void) G_GNUC_CONST;
#define THREE_KEYS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_THREE_KEYS, ThreeKeysPrivate))
enum  {
	THREE_KEYS_0_PROPERTY,
	THREE_KEYS_MAP_PROPERTY
};
ThreeKeys* three_keys_new (void);
ThreeKeys* three_keys_construct (GType object_type);
ThreeKeyMap* three_keys_get_map (ThreeKeys* self);
void three_keys_set_map (ThreeKeys* self, ThreeKeyMap* value);
static GObject * three_keys_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void three_keys_finalize (GObject* obj);
static void _vala_three_keys_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_three_keys_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType three_key_get_type (void) G_GNUC_CONST;
#define THREE_KEY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_THREE_KEY, ThreeKeyPrivate))
enum  {
	THREE_KEY_0_PROPERTY,
	THREE_KEY_ID_PROPERTY,
	THREE_KEY_CODE_PROPERTY,
	THREE_KEY_NAME_PROPERTY
};
static gchar* three_key_real_get_map_pkey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_id (ThreeKey* self);
static gchar* three_key_real_get_map_skey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_code (ThreeKey* self);
static gchar* three_key_real_get_map_tkey (GXmlMappeableElementThreeKey* base);
const gchar* three_key_get_name (ThreeKey* self);
ThreeKey* three_key_new (void);
ThreeKey* three_key_construct (GType object_type);
void three_key_set_id (ThreeKey* self, const gchar* value);
void three_key_set_code (ThreeKey* self, const gchar* value);
void three_key_set_name (ThreeKey* self, const gchar* value);
static GObject * three_key_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	THREE_KEY_MAP_0_PROPERTY
};
ThreeKeyMap* three_key_map_new (void);
ThreeKeyMap* three_key_map_construct (GType object_type);
static GObject * three_key_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void three_key_finalize (GObject* obj);
static void _vala_three_key_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_three_key_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType operations_get_type (void) G_GNUC_CONST;
GType operation_map_get_type (void) G_GNUC_CONST;
#define OPERATIONS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_OPERATIONS, OperationsPrivate))
enum  {
	OPERATIONS_0_PROPERTY,
	OPERATIONS_MAP_PROPERTY
};
Operations* operations_new (void);
Operations* operations_construct (GType object_type);
OperationMap* operations_get_map (Operations* self);
void operations_set_map (Operations* self, OperationMap* value);
static GObject * operations_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void operations_finalize (GObject* obj);
static void _vala_operations_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_operations_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType operation_get_type (void) G_GNUC_CONST;
#define OPERATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_OPERATION, OperationPrivate))
enum  {
	OPERATION_0_PROPERTY,
	OPERATION_ID_PROPERTY,
	OPERATION_CODE_PROPERTY
};
static gchar* operation_real_get_map_primary_key (GXmlMappeableElementPairKey* base);
const gchar* operation_get_id (Operation* self);
static gchar* operation_real_get_map_secondary_key (GXmlMappeableElementPairKey* base);
const gchar* operation_get_code (Operation* self);
Operation* operation_new (void);
Operation* operation_construct (GType object_type);
void operation_set_id (Operation* self, const gchar* value);
void operation_set_code (Operation* self, const gchar* value);
static GObject * operation_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	OPERATION_MAP_0_PROPERTY
};
OperationMap* operation_map_new (void);
OperationMap* operation_map_construct (GType object_type);
static GObject * operation_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void operation_finalize (GObject* obj);
static void _vala_operation_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_operation_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_name_get_type (void) G_GNUC_CONST;
enum  {
	GOM_NAME_0_PROPERTY
};
GomName* gom_name_new (void);
GomName* gom_name_construct (GType object_type);
static GObject * gom_name_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_email_get_type (void) G_GNUC_CONST;
enum  {
	GOM_EMAIL_0_PROPERTY
};
GomEmail* gom_email_new (void);
GomEmail* gom_email_construct (GType object_type);
static GObject * gom_email_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_author_get_type (void) G_GNUC_CONST;
GType name_get_type (void) G_GNUC_CONST;
GType email_get_type (void) G_GNUC_CONST;
#define GOM_AUTHOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_AUTHOR, GomAuthorPrivate))
enum  {
	GOM_AUTHOR_0_PROPERTY,
	GOM_AUTHOR_NAME_PROPERTY,
	GOM_AUTHOR_EMAIL_PROPERTY
};
GomAuthor* gom_author_new (void);
GomAuthor* gom_author_construct (GType object_type);
Name* gom_author_get_name (GomAuthor* self);
void gom_author_set_name (GomAuthor* self, Name* value);
Email* gom_author_get_email (GomAuthor* self);
void gom_author_set_email (GomAuthor* self, Email* value);
static GObject * gom_author_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_author_array_get_type (void) G_GNUC_CONST;
enum  {
	GOM_AUTHOR_ARRAY_0_PROPERTY
};
GomAuthorArray* gom_author_array_new (void);
GomAuthorArray* gom_author_array_construct (GType object_type);
static GObject * gom_author_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_author_finalize (GObject* obj);
static void _vala_gom_author_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_author_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_authors_get_type (void) G_GNUC_CONST;
#define GOM_AUTHORS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_AUTHORS, GomAuthorsPrivate))
enum  {
	GOM_AUTHORS_0_PROPERTY,
	GOM_AUTHORS_NUMBER_PROPERTY,
	GOM_AUTHORS_ARRAY_PROPERTY
};
GomAuthors* gom_authors_new (void);
GomAuthors* gom_authors_construct (GType object_type);
const gchar* gom_authors_get_number (GomAuthors* self);
void gom_authors_set_number (GomAuthors* self, const gchar* value);
GomAuthorArray* gom_authors_get_array (GomAuthors* self);
void gom_authors_set_array (GomAuthors* self, GomAuthorArray* value);
static GObject * gom_authors_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_authors_finalize (GObject* obj);
static void _vala_gom_authors_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_authors_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_inventory_get_type (void) G_GNUC_CONST;
#define GOM_INVENTORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_INVENTORY, GomInventoryPrivate))
enum  {
	GOM_INVENTORY_0_PROPERTY,
	GOM_INVENTORY_NUMBER_PROPERTY,
	GOM_INVENTORY_ROW_PROPERTY,
	GOM_INVENTORY_INVENTORY_PROPERTY
};
GomInventory* gom_inventory_new (void);
GomInventory* gom_inventory_construct (GType object_type);
gint gom_inventory_get_number (GomInventory* self);
void gom_inventory_set_number (GomInventory* self, gint value);
gint gom_inventory_get_row (GomInventory* self);
void gom_inventory_set_row (GomInventory* self, gint value);
const gchar* gom_inventory_get_inventory (GomInventory* self);
void gom_inventory_set_inventory (GomInventory* self, const gchar* value);
static GObject * gom_inventory_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_inventory_dual_key_map_get_type (void) G_GNUC_CONST;
enum  {
	GOM_INVENTORY_DUAL_KEY_MAP_0_PROPERTY
};
GomInventoryDualKeyMap* gom_inventory_dual_key_map_new (void);
GomInventoryDualKeyMap* gom_inventory_dual_key_map_construct (GType object_type);
static GObject * gom_inventory_dual_key_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_inventory_finalize (GObject* obj);
static void _vala_gom_inventory_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_inventory_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_category_get_type (void) G_GNUC_CONST;
#define GOM_CATEGORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_CATEGORY, GomCategoryPrivate))
enum  {
	GOM_CATEGORY_0_PROPERTY,
	GOM_CATEGORY_NAME_PROPERTY
};
GomCategory* gom_category_new (void);
GomCategory* gom_category_construct (GType object_type);
const gchar* gom_category_get_name (GomCategory* self);
void gom_category_set_name (GomCategory* self, const gchar* value);
static GObject * gom_category_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_category_map_get_type (void) G_GNUC_CONST;
enum  {
	GOM_CATEGORY_MAP_0_PROPERTY
};
GomCategoryMap* gom_category_map_new (void);
GomCategoryMap* gom_category_map_construct (GType object_type);
static GObject * gom_category_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_category_finalize (GObject* obj);
static void _vala_gom_category_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_category_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_resume_get_type (void) G_GNUC_CONST;
#define GOM_RESUME_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_RESUME, GomResumePrivate))
enum  {
	GOM_RESUME_0_PROPERTY,
	GOM_RESUME_CHAPTER_PROPERTY,
	GOM_RESUME_TEXT_PROPERTY
};
GomResume* gom_resume_new (void);
GomResume* gom_resume_construct (GType object_type);
const gchar* gom_resume_get_chapter (GomResume* self);
void gom_resume_set_chapter (GomResume* self, const gchar* value);
const gchar* gom_resume_get_text (GomResume* self);
void gom_resume_set_text (GomResume* self, const gchar* value);
static GObject * gom_resume_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_resume_map_get_type (void) G_GNUC_CONST;
enum  {
	GOM_RESUME_MAP_0_PROPERTY
};
GomResumeMap* gom_resume_map_new (void);
GomResumeMap* gom_resume_map_construct (GType object_type);
static GObject * gom_resume_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_resume_finalize (GObject* obj);
static void _vala_gom_resume_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_resume_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_book_get_type (void) G_GNUC_CONST;
#define GOM_BOOK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_BOOK, GomBookPrivate))
enum  {
	GOM_BOOK_0_PROPERTY,
	GOM_BOOK_YEAR_PROPERTY,
	GOM_BOOK_ISBN_PROPERTY,
	GOM_BOOK_NAME_PROPERTY,
	GOM_BOOK_AUTHORS_PROPERTY,
	GOM_BOOK_INVENTORY_REGISTERS_PROPERTY,
	GOM_BOOK_CATEGORIES_PROPERTY,
	GOM_BOOK_RESUMES_PROPERTY
};
GomBook* gom_book_new (void);
GomBook* gom_book_construct (GType object_type);
const gchar* gom_book_get_year (GomBook* self);
void gom_book_set_year (GomBook* self, const gchar* value);
const gchar* gom_book_get_isbn (GomBook* self);
void gom_book_set_isbn (GomBook* self, const gchar* value);
GomName* gom_book_get_name (GomBook* self);
void gom_book_set_name (GomBook* self, GomName* value);
GomAuthors* gom_book_get_authors (GomBook* self);
void gom_book_set_authors (GomBook* self, GomAuthors* value);
GomInventoryDualKeyMap* gom_book_get_inventory_registers (GomBook* self);
void gom_book_set_inventory_registers (GomBook* self, GomInventoryDualKeyMap* value);
GomCategoryMap* gom_book_get_categories (GomBook* self);
void gom_book_set_categories (GomBook* self, GomCategoryMap* value);
GomResumeMap* gom_book_get_resumes (GomBook* self);
void gom_book_set_resumes (GomBook* self, GomResumeMap* value);
static GObject * gom_book_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_book_array_get_type (void) G_GNUC_CONST;
enum  {
	GOM_BOOK_ARRAY_0_PROPERTY
};
GomBookArray* gom_book_array_new (void);
GomBookArray* gom_book_array_construct (GType object_type);
static GObject * gom_book_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_book_finalize (GObject* obj);
static void _vala_gom_book_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_book_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_book_store_get_type (void) G_GNUC_CONST;
#define GOM_BOOK_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_BOOK_STORE, GomBookStorePrivate))
enum  {
	GOM_BOOK_STORE_0_PROPERTY,
	GOM_BOOK_STORE_NAME_PROPERTY,
	GOM_BOOK_STORE_BOOKS_PROPERTY
};
GomBookStore* gom_book_store_new (void);
GomBookStore* gom_book_store_construct (GType object_type);
const gchar* gom_book_store_get_name (GomBookStore* self);
void gom_book_store_set_name (GomBookStore* self, const gchar* value);
GomBookArray* gom_book_store_get_books (GomBookStore* self);
void gom_book_store_set_books (GomBookStore* self, GomBookArray* value);
static GObject * gom_book_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_book_store_finalize (GObject* obj);
static void _vala_gom_book_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_book_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_basic_types_get_type (void) G_GNUC_CONST;
#define GOM_BASIC_TYPES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_GOM_BASIC_TYPES, GomBasicTypesPrivate))
enum  {
	GOM_BASIC_TYPES_0_PROPERTY,
	GOM_BASIC_TYPES_TEXT_PROPERTY,
	GOM_BASIC_TYPES_INTEGER_PROPERTY,
	GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY,
	GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY,
	GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY,
	GOM_BASIC_TYPES_BOOLEAN_PROPERTY
};
GomBasicTypes* gom_basic_types_new (void);
GomBasicTypes* gom_basic_types_construct (GType object_type);
const gchar* gom_basic_types_get_text (GomBasicTypes* self);
void gom_basic_types_set_text (GomBasicTypes* self, const gchar* value);
gint gom_basic_types_get_integer (GomBasicTypes* self);
void gom_basic_types_set_integer (GomBasicTypes* self, gint value);
gdouble gom_basic_types_get_real_double (GomBasicTypes* self);
void gom_basic_types_set_real_double (GomBasicTypes* self, gdouble value);
gfloat gom_basic_types_get_real_float (GomBasicTypes* self);
void gom_basic_types_set_real_float (GomBasicTypes* self, gfloat value);
guint gom_basic_types_get_unsigned_integer (GomBasicTypes* self);
void gom_basic_types_set_unsigned_integer (GomBasicTypes* self, guint value);
gboolean gom_basic_types_get_boolean (GomBasicTypes* self);
void gom_basic_types_set_boolean (GomBasicTypes* self, gboolean value);
static GObject * gom_basic_types_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_basic_types_finalize (GObject* obj);
static void _vala_gom_basic_types_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_basic_types_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_serialization_test_get_type (void) G_GNUC_CONST;
enum  {
	GOM_SERIALIZATION_TEST_0_PROPERTY
};
void gom_serialization_test_add_tests (void);
static void __lambda261_ (void);
GType gom_serialization_test_book_get_type (void) G_GNUC_CONST;
GomSerializationTestBook* gom_serialization_test_book_new (void);
GomSerializationTestBook* gom_serialization_test_book_construct (GType object_type);
void gom_serialization_test_book_set_name (GomSerializationTestBook* self, const gchar* value);
gchar* gom_serialization_test_book_to_string (GomSerializationTestBook* self);
static void ___lambda261__gtest_func (void);
static void __lambda262_ (void);
GType gom_serialization_test_computer_get_type (void) G_GNUC_CONST;
GomSerializationTestComputer* gom_serialization_test_computer_new (void);
GomSerializationTestComputer* gom_serialization_test_computer_construct (GType object_type);
gchar* gom_serialization_test_computer_to_string (GomSerializationTestComputer* self);
void gom_serialization_test_computer_set_model (GomSerializationTestComputer* self, const gchar* value);
void gom_serialization_test_computer_set_ignore (GomSerializationTestComputer* self, const gchar* value);
const gchar* gom_serialization_test_computer_get_model (GomSerializationTestComputer* self);
const gchar* gom_serialization_test_computer_get_ignore (GomSerializationTestComputer* self);
static void ___lambda262__gtest_func (void);
static void __lambda263_ (void);
GType gom_serialization_test_taxes_get_type (void) G_GNUC_CONST;
GomSerializationTestTaxes* gom_serialization_test_taxes_new (void);
GomSerializationTestTaxes* gom_serialization_test_taxes_construct (GType object_type);
gchar* gom_serialization_test_taxes_to_string (GomSerializationTestTaxes* self);
void gom_serialization_test_taxes_set_month_rate (GomSerializationTestTaxes* self, gdouble value);
gdouble gom_serialization_test_taxes_get_month_rate (GomSerializationTestTaxes* self);
GType gom_serialization_test_taxes_month_get_type (void) G_GNUC_CONST;
void gom_serialization_test_taxes_set_month (GomSerializationTestTaxes* self, GomSerializationTestTaxesMonth value);
GomSerializationTestTaxesMonth gom_serialization_test_taxes_get_month (GomSerializationTestTaxes* self);
void gom_serialization_test_taxes_set_tax_free (GomSerializationTestTaxes* self, gboolean value);
gboolean gom_serialization_test_taxes_get_tax_free (GomSerializationTestTaxes* self);
static void ___lambda263__gtest_func (void);
static void __lambda264_ (void);
void gom_serialization_test_taxes_set_pay_date (GomSerializationTestTaxes* self, GXmlGomDate* value);
GXmlGomDate* gom_serialization_test_taxes_get_pay_date (GomSerializationTestTaxes* self);
static void ___lambda264__gtest_func (void);
static void __lambda265_ (void);
static void ___lambda265__gtest_func (void);
static void __lambda266_ (void);
void gom_serialization_test_taxes_set_timestamp (GomSerializationTestTaxes* self, GXmlGomDateTime* value);
GXmlGomDateTime* gom_serialization_test_taxes_get_timestamp (GomSerializationTestTaxes* self);
static void ___lambda266__gtest_func (void);
static void __lambda267_ (void);
GType gom_serialization_test_book_stand_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStand* gom_serialization_test_book_stand_new (void);
GomSerializationTestBookStand* gom_serialization_test_book_stand_construct (GType object_type);
gchar* gom_serialization_test_book_stand_to_string (GomSerializationTestBookStand* self);
GType gom_serialization_test_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestRegisters* gom_serialization_test_book_stand_get_registers (GomSerializationTestBookStand* self);
GType gom_serialization_test_book_register_get_type (void) G_GNUC_CONST;
GomSerializationTestBookRegister* gom_serialization_test_book_register_new (void);
GomSerializationTestBookRegister* gom_serialization_test_book_register_construct (GType object_type);
void gom_serialization_test_book_register_set_year (GomSerializationTestBookRegister* self, gint value);
gint gom_serialization_test_book_register_get_year (GomSerializationTestBookRegister* self);
GType gom_serialization_test_book_stand_dimension_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_get_dimension_x (GomSerializationTestBookStand* self);
gdouble gom_serialization_test_book_stand_dimension_get_length (GomSerializationTestBookStandDimension* self);
GType gom_serialization_test_book_stand_dimension_y_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_get_dimension_y (GomSerializationTestBookStand* self);
GType gom_serialization_test_book_stand_dimension_z_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_get_dimension_z (GomSerializationTestBookStand* self);
static void ___lambda267__gtest_func (void);
static void __lambda268_ (void);
GType gom_serialization_test_book_store_get_type (void) G_GNUC_CONST;
GomSerializationTestBookStore* gom_serialization_test_book_store_new (void);
GomSerializationTestBookStore* gom_serialization_test_book_store_construct (GType object_type);
gchar* gom_serialization_test_book_store_to_string (GomSerializationTestBookStore* self);
GType gom_serialization_test_books_get_type (void) G_GNUC_CONST;
GomSerializationTestBooks* gom_serialization_test_book_store_get_books (GomSerializationTestBookStore* self);
GomSerializationTestBook* gom_serialization_test_book_new_document (GXmlDomDocument* doc);
GomSerializationTestBook* gom_serialization_test_book_construct_document (GType object_type, GXmlDomDocument* doc);
const gchar* gom_serialization_test_book_get_name (GomSerializationTestBook* self);
static void ___lambda268__gtest_func (void);
static void __lambda269_ (void);
GType gom_serialization_test_hash_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashRegisters* gom_serialization_test_book_stand_get_hashmap_registers (GomSerializationTestBookStand* self);
GomSerializationTestBook* gom_serialization_test_book_register_create_book (GomSerializationTestBookRegister* self, const gchar* name);
void gom_serialization_test_book_register_set_book (GomSerializationTestBookRegister* self, GomSerializationTestBook* value);
GomSerializationTestBook* gom_serialization_test_book_register_get_book (GomSerializationTestBookRegister* self);
static void ___lambda269__gtest_func (void);
static void __lambda270_ (void);
GType gom_serialization_test_hash_pair_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashPairRegisters* gom_serialization_test_book_stand_get_hashpair_registers (GomSerializationTestBookStand* self);
static void ___lambda270__gtest_func (void);
static void __lambda271_ (void);
GType gom_serialization_test_hash_three_registers_get_type (void) G_GNUC_CONST;
GomSerializationTestHashThreeRegisters* gom_serialization_test_book_stand_get_hashthree_registers (GomSerializationTestBookStand* self);
void gom_serialization_test_book_register_set_cover (GomSerializationTestBookRegister* self, const gchar* value);
const gchar* gom_serialization_test_book_register_get_cover (GomSerializationTestBookRegister* self);
static void ___lambda271__gtest_func (void);
static void __lambda272_ (void);
GType gom_serialization_test_motor_get_type (void) G_GNUC_CONST;
GomSerializationTestMotor* gom_serialization_test_motor_new (void);
GomSerializationTestMotor* gom_serialization_test_motor_construct (GType object_type);
gchar* gom_serialization_test_motor_to_string (GomSerializationTestMotor* self);
GomSerializationTestMotorOn* gom_serialization_test_motor_on_new (void);
GomSerializationTestMotorOn* gom_serialization_test_motor_on_construct (GType object_type);
GType gom_serialization_test_motor_on_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_is_on (GomSerializationTestMotor* self, GomSerializationTestMotorOn* value);
GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_new (void);
GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_construct (GType object_type);
GType gom_serialization_test_motor_torque_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_torque (GomSerializationTestMotor* self, GomSerializationTestMotorTorque* value);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_new (void);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_construct (GType object_type);
GType gom_serialization_test_motor_speed_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_speed (GomSerializationTestMotor* self, GomSerializationTestMotorSpeed* value);
GomSerializationTestMotorSpeed* gom_serialization_test_motor_get_speed (GomSerializationTestMotor* self);
GType gom_serialization_test_motor_tension_type_get_type (void) G_GNUC_CONST;
GomSerializationTestMotorTensionType* gom_serialization_test_motor_get_tension_type (GomSerializationTestMotor* self);
GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_new (void);
GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_construct (GType object_type);
void gom_serialization_test_motor_set_tension_type (GomSerializationTestMotor* self, GomSerializationTestMotorTensionType* value);
GomSerializationTestMotorTension* gom_serialization_test_motor_tension_new (void);
GomSerializationTestMotorTension* gom_serialization_test_motor_tension_construct (GType object_type);
GType gom_serialization_test_motor_tension_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_tension (GomSerializationTestMotor* self, GomSerializationTestMotorTension* value);
GomSerializationTestMotorOn* gom_serialization_test_motor_get_is_on (GomSerializationTestMotor* self);
GomSerializationTestMotorTorque* gom_serialization_test_motor_get_torque (GomSerializationTestMotor* self);
GType gom_serialization_test_motor_tension_type_enum_get_type (void) G_GNUC_CONST;
GomSerializationTestMotorTension* gom_serialization_test_motor_get_tension (GomSerializationTestMotor* self);
GomSerializationTestMotorModel* gom_serialization_test_motor_model_new (void);
GomSerializationTestMotorModel* gom_serialization_test_motor_model_construct (GType object_type);
GType gom_serialization_test_motor_model_get_type (void) G_GNUC_CONST;
void gom_serialization_test_motor_set_model (GomSerializationTestMotor* self, GomSerializationTestMotorModel* value);
GomSerializationTestMotorModel* gom_serialization_test_motor_get_model (GomSerializationTestMotor* self);
static void ___lambda272__gtest_func (void);
static void __lambda273_ (void);
static void ___lambda273__gtest_func (void);
static void __lambda274_ (void);
static void ___lambda274__gtest_func (void);
static void __lambda275_ (void);
gchar* gom_serialization_test_book_register_to_string (GomSerializationTestBookRegister* self);
static void ___lambda275__gtest_func (void);
static void __lambda276_ (void);
static void ___lambda276__gtest_func (void);
static void __lambda277_ (void);
static void ___lambda277__gtest_func (void);
static void __lambda278_ (void);
GomSerializationTestBooks* gom_serialization_test_book_stand_get_books (GomSerializationTestBookStand* self);
static void ___lambda278__gtest_func (void);
static void __lambda279_ (void);
static void ___lambda279__gtest_func (void);
static void __lambda280_ (void);
static void _g_free0_ (gpointer var);
static void _g_list_free__g_free0_ (GList* self);
static void ___lambda280__gtest_func (void);
static void __lambda281_ (void);
static void ___lambda281__gtest_func (void);
static void __lambda282_ (void);
static void ___lambda282__gtest_func (void);
GomSerializationTest* gom_serialization_test_new (void);
GomSerializationTest* gom_serialization_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
#define GOM_SERIALIZATION_TEST_BOOK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBookPrivate))
enum  {
	GOM_SERIALIZATION_TEST_BOOK_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY
};
static GObject * gom_serialization_test_book_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_finalize (GObject* obj);
static void _vala_gom_serialization_test_book_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_book_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_SERIALIZATION_TEST_COMPUTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputerPrivate))
enum  {
	GOM_SERIALIZATION_TEST_COMPUTER_0_PROPERTY,
	GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY,
	GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY
};
static GObject * gom_serialization_test_computer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_computer_finalize (GObject* obj);
static void _vala_gom_serialization_test_computer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_computer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_SERIALIZATION_TEST_TAXES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxesPrivate))
enum  {
	GOM_SERIALIZATION_TEST_TAXES_0_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY,
	GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY
};
static GObject * gom_serialization_test_taxes_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_taxes_finalize (GObject* obj);
static void _vala_gom_serialization_test_taxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_taxes_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_SERIALIZATION_TEST_BOOK_REGISTER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegisterPrivate))
enum  {
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY
};
GomSerializationTestBookRegister* gom_serialization_test_book_register_new_document (GXmlDomDocument* doc);
GomSerializationTestBookRegister* gom_serialization_test_book_register_construct_document (GType object_type, GXmlDomDocument* doc);
static gchar* gom_serialization_test_book_register_real_get_map_key (GXmlMappeableElement* base);
static gchar* gom_serialization_test_book_register_real_get_map_primary_key (GXmlMappeableElementPairKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_secondary_key (GXmlMappeableElementPairKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_pkey (GXmlMappeableElementThreeKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_skey (GXmlMappeableElementThreeKey* base);
static gchar* gom_serialization_test_book_register_real_get_map_tkey (GXmlMappeableElementThreeKey* base);
static GObject * gom_serialization_test_book_register_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_register_finalize (GObject* obj);
static void _vala_gom_serialization_test_book_register_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_book_register_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_SERIALIZATION_TEST_BOOK_STAND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStandPrivate))
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY
};
const gchar* gom_serialization_test_book_stand_get_classification (GomSerializationTestBookStand* self);
void gom_serialization_test_book_stand_set_classification (GomSerializationTestBookStand* self, const gchar* value);
void gom_serialization_test_book_stand_set_dimension_x (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimension* value);
void gom_serialization_test_book_stand_set_dimension_y (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimensionY* value);
void gom_serialization_test_book_stand_set_dimension_z (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimensionZ* value);
void gom_serialization_test_book_stand_set_registers (GomSerializationTestBookStand* self, GomSerializationTestRegisters* value);
void gom_serialization_test_book_stand_set_hashmap_registers (GomSerializationTestBookStand* self, GomSerializationTestHashRegisters* value);
void gom_serialization_test_book_stand_set_hashpair_registers (GomSerializationTestBookStand* self, GomSerializationTestHashPairRegisters* value);
void gom_serialization_test_book_stand_set_hashthree_registers (GomSerializationTestBookStand* self, GomSerializationTestHashThreeRegisters* value);
void gom_serialization_test_book_stand_set_books (GomSerializationTestBookStand* self, GomSerializationTestBooks* value);
static GObject * gom_serialization_test_book_stand_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
#define GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimensionPrivate))
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY
};
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_new (void);
GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_construct (GType object_type);
void gom_serialization_test_book_stand_dimension_set_length (GomSerializationTestBookStandDimension* self, gdouble value);
const gchar* gom_serialization_test_book_stand_dimension_get_dtype (GomSerializationTestBookStandDimension* self);
void gom_serialization_test_book_stand_dimension_set_dtype (GomSerializationTestBookStandDimension* self, const gchar* value);
static GObject * gom_serialization_test_book_stand_dimension_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_stand_dimension_finalize (GObject* obj);
static void _vala_gom_serialization_test_book_stand_dimension_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_book_stand_dimension_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_0_PROPERTY
};
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_new (void);
GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_construct (GType object_type);
static GObject * gom_serialization_test_book_stand_dimension_y_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_0_PROPERTY
};
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_new (void);
GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_construct (GType object_type);
static GObject * gom_serialization_test_book_stand_dimension_z_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_stand_finalize (GObject* obj);
static void _vala_gom_serialization_test_book_stand_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_book_stand_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
enum  {
	GOM_SERIALIZATION_TEST_REGISTERS_0_PROPERTY
};
GomSerializationTestRegisters* gom_serialization_test_registers_new (void);
GomSerializationTestRegisters* gom_serialization_test_registers_construct (GType object_type);
static GObject * gom_serialization_test_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_HASH_REGISTERS_0_PROPERTY
};
GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_new (void);
GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_HASH_PAIR_REGISTERS_0_PROPERTY
};
GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_new (void);
GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_pair_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_HASH_THREE_REGISTERS_0_PROPERTY
};
GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_new (void);
GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_construct (GType object_type);
static GObject * gom_serialization_test_hash_three_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_BOOKS_0_PROPERTY
};
GomSerializationTestBooks* gom_serialization_test_books_new (void);
GomSerializationTestBooks* gom_serialization_test_books_construct (GType object_type);
static GObject * gom_serialization_test_books_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
#define GOM_SERIALIZATION_TEST_BOOK_STORE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStorePrivate))
enum  {
	GOM_SERIALIZATION_TEST_BOOK_STORE_0_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY,
	GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY
};
const gchar* gom_serialization_test_book_store_get_name (GomSerializationTestBookStore* self);
void gom_serialization_test_book_store_set_name (GomSerializationTestBookStore* self, const gchar* value);
void gom_serialization_test_book_store_set_books (GomSerializationTestBookStore* self, GomSerializationTestBooks* value);
static GObject * gom_serialization_test_book_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_book_store_finalize (GObject* obj);
static void _vala_gom_serialization_test_book_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_book_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_SERIALIZATION_TEST_MOTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotorPrivate))
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_0_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY,
	GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY
};
static GObject * gom_serialization_test_motor_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_ON_0_PROPERTY
};
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TORQUE_0_PROPERTY
};
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_SPEED_0_PROPERTY
};
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_0_PROPERTY
};
static GObject * gom_serialization_test_motor_tension_type_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_TENSION_0_PROPERTY
};
enum  {
	GOM_SERIALIZATION_TEST_MOTOR_MODEL_0_PROPERTY
};
static GObject * gom_serialization_test_motor_model_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_serialization_test_motor_finalize (GObject* obj);
static void _vala_gom_serialization_test_motor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_serialization_test_motor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


ThreeKeys* three_keys_construct (GType object_type) {
	ThreeKeys * self = NULL;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKeys*) gxml_gom_element_construct (object_type);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 1788 "GomSerializationTest.c"
}


ThreeKeys* three_keys_new (void) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return three_keys_construct (TYPE_THREE_KEYS);
#line 1795 "GomSerializationTest.c"
}


ThreeKeyMap* three_keys_get_map (ThreeKeys* self) {
	ThreeKeyMap* result;
	ThreeKeyMap* _tmp0_ = NULL;
	ThreeKeyMap* _tmp1_ = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 31 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "map");
#line 1811 "GomSerializationTest.c"
	}
#line 32 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = self->priv->_map;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 1819 "GomSerializationTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1826 "GomSerializationTest.c"
}


void three_keys_set_map (ThreeKeys* self, ThreeKeyMap* value) {
	ThreeKeyMap* _tmp0_ = NULL;
	ThreeKeyMap* _tmp5_ = NULL;
	ThreeKeyMap* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 35 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 35 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ != NULL) {
#line 1841 "GomSerializationTest.c"
		{
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "map", &_inner_error_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1847 "GomSerializationTest.c"
				goto __catch279_g_error;
			}
		}
		goto __finally279;
		__catch279_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_ = NULL;
			const gchar* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			e = _inner_error_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_inner_error_ = NULL;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp1_ = e;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp2_ = _tmp1_->message;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp4_ = _tmp3_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_warning ("GomSerializationTest.vala:37: %s", _tmp4_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp4_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_error_free0 (e);
#line 1877 "GomSerializationTest.c"
		}
		__finally279:
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_clear_error (&_inner_error_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			return;
#line 1888 "GomSerializationTest.c"
		}
	}
#line 38 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = value;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_map = _tmp6_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "map");
#line 1901 "GomSerializationTest.c"
}


static GObject * three_keys_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKeys * self;
	GError * _inner_error_ = NULL;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_keys_parent_class);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEYS, ThreeKeys);
#line 1916 "GomSerializationTest.c"
	{
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "ThreeKeys");
#line 1920 "GomSerializationTest.c"
	}
	goto __finally280;
	__catch280_g_error:
	{
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1931 "GomSerializationTest.c"
	}
	__finally280:
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1940 "GomSerializationTest.c"
	}
#line 41 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 1944 "GomSerializationTest.c"
}


static void three_keys_class_init (ThreeKeysClass * klass) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	three_keys_parent_class = g_type_class_peek_parent (klass);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (ThreeKeysPrivate));
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_three_keys_get_property;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_three_keys_set_property;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_keys_constructor;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = three_keys_finalize;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEYS_MAP_PROPERTY, g_param_spec_object ("map", "map", "map", THREE_KEY_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 1963 "GomSerializationTest.c"
}


static void three_keys_instance_init (ThreeKeys * self) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = THREE_KEYS_GET_PRIVATE (self);
#line 1970 "GomSerializationTest.c"
}


static void three_keys_finalize (GObject* obj) {
	ThreeKeys * self;
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEYS, ThreeKeys);
#line 27 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (three_keys_parent_class)->finalize (obj);
#line 1982 "GomSerializationTest.c"
}


GType three_keys_get_type (void) {
	static volatile gsize three_keys_type_id__volatile = 0;
	if (g_once_init_enter (&three_keys_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeysClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_keys_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKeys), 0, (GInstanceInitFunc) three_keys_instance_init, NULL };
		GType three_keys_type_id;
		three_keys_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ThreeKeys", &g_define_type_info, 0);
		g_once_init_leave (&three_keys_type_id__volatile, three_keys_type_id);
	}
	return three_keys_type_id__volatile;
}


static void _vala_three_keys_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ThreeKeys * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEYS, ThreeKeys);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEYS_MAP_PROPERTY:
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, three_keys_get_map (self));
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2009 "GomSerializationTest.c"
		default:
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2015 "GomSerializationTest.c"
	}
}


static void _vala_three_keys_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ThreeKeys * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEYS, ThreeKeys);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEYS_MAP_PROPERTY:
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_keys_set_map (self, g_value_get_object (value));
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2031 "GomSerializationTest.c"
		default:
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2037 "GomSerializationTest.c"
	}
}


static gchar* three_key_real_get_map_pkey (GXmlMappeableElementThreeKey* base) {
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 51 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 51 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 51 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 51 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 51 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2057 "GomSerializationTest.c"
}


static gchar* three_key_real_get_map_skey (GXmlMappeableElementThreeKey* base) {
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2076 "GomSerializationTest.c"
}


static gchar* three_key_real_get_map_tkey (GXmlMappeableElementThreeKey* base) {
	ThreeKey * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKey*) base;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2095 "GomSerializationTest.c"
}


ThreeKey* three_key_construct (GType object_type) {
	ThreeKey * self = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKey*) gxml_gom_element_construct (object_type);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 2105 "GomSerializationTest.c"
}


ThreeKey* three_key_new (void) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return three_key_construct (TYPE_THREE_KEY);
#line 2112 "GomSerializationTest.c"
}


const gchar* three_key_get_id (ThreeKey* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2127 "GomSerializationTest.c"
}


void three_key_set_id (ThreeKey* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_id = _tmp1_;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "id");
#line 2146 "GomSerializationTest.c"
}


const gchar* three_key_get_code (ThreeKey* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2161 "GomSerializationTest.c"
}


void three_key_set_code (ThreeKey* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_code = _tmp1_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "code");
#line 2180 "GomSerializationTest.c"
}


const gchar* three_key_get_name (ThreeKey* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2195 "GomSerializationTest.c"
}


void three_key_set_name (ThreeKey* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 2214 "GomSerializationTest.c"
}


static GObject * three_key_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKey * self;
	GError * _inner_error_ = NULL;
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_key_parent_class);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEY, ThreeKey);
#line 2229 "GomSerializationTest.c"
	{
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "ThreeKey");
#line 2233 "GomSerializationTest.c"
	}
	goto __finally281;
	__catch281_g_error:
	{
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 2244 "GomSerializationTest.c"
	}
	__finally281:
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 2253 "GomSerializationTest.c"
	}
#line 50 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 2257 "GomSerializationTest.c"
}


ThreeKeyMap* three_key_map_construct (GType object_type) {
	ThreeKeyMap * self = NULL;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (ThreeKeyMap*) gxml_gom_hash_three_map_construct (object_type);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 2267 "GomSerializationTest.c"
}


ThreeKeyMap* three_key_map_new (void) {
#line 54 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return three_key_map_construct (THREE_KEY_TYPE_MAP);
#line 2274 "GomSerializationTest.c"
}


static GObject * three_key_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	ThreeKeyMap * self;
	GError * _inner_error_ = NULL;
#line 55 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (three_key_map_parent_class);
#line 55 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 55 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, THREE_KEY_TYPE_MAP, ThreeKeyMap);
#line 2289 "GomSerializationTest.c"
	{
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, TYPE_THREE_KEY, &_inner_error_);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2295 "GomSerializationTest.c"
			goto __catch282_g_error;
		}
	}
	goto __finally282;
	__catch282_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = e;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = _tmp0_->message;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:57: %s", _tmp3_);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 2325 "GomSerializationTest.c"
	}
	__finally282:
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 2334 "GomSerializationTest.c"
	}
#line 55 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 2338 "GomSerializationTest.c"
}


static void three_key_map_class_init (ThreeKeyMapClass * klass) {
#line 54 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	three_key_map_parent_class = g_type_class_peek_parent (klass);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_key_map_constructor;
#line 2347 "GomSerializationTest.c"
}


static void three_key_map_instance_init (ThreeKeyMap * self) {
}


GType three_key_map_get_type (void) {
	static volatile gsize three_key_map_type_id__volatile = 0;
	if (g_once_init_enter (&three_key_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeyMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_key_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKeyMap), 0, (GInstanceInitFunc) three_key_map_instance_init, NULL };
		GType three_key_map_type_id;
		three_key_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_THREE_MAP, "ThreeKeyMap", &g_define_type_info, 0);
		g_once_init_leave (&three_key_map_type_id__volatile, three_key_map_type_id);
	}
	return three_key_map_type_id__volatile;
}


static void three_key_class_init (ThreeKeyClass * klass) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	three_key_parent_class = g_type_class_peek_parent (klass);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (ThreeKeyPrivate));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_three_key_get_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_three_key_set_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = three_key_constructor;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = three_key_finalize;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_ID_PROPERTY, g_param_spec_string ("id", "::ID", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_CODE_PROPERTY, g_param_spec_string ("code", "::Code", "code", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), THREE_KEY_NAME_PROPERTY, g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2386 "GomSerializationTest.c"
}


static void three_key_gxml_mappeable_element_three_key_interface_init (GXmlMappeableElementThreeKeyIface * iface) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	three_key_gxml_mappeable_element_three_key_parent_iface = g_type_interface_peek_parent (iface);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_pkey = (gchar* (*)(GXmlMappeableElementThreeKey*)) three_key_real_get_map_pkey;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_skey = (gchar* (*)(GXmlMappeableElementThreeKey*)) three_key_real_get_map_skey;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_tkey = (gchar* (*)(GXmlMappeableElementThreeKey*)) three_key_real_get_map_tkey;
#line 2399 "GomSerializationTest.c"
}


static void three_key_instance_init (ThreeKey * self) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = THREE_KEY_GET_PRIVATE (self);
#line 2406 "GomSerializationTest.c"
}


static void three_key_finalize (GObject* obj) {
	ThreeKey * self;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_THREE_KEY, ThreeKey);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (three_key_parent_class)->finalize (obj);
#line 2422 "GomSerializationTest.c"
}


GType three_key_get_type (void) {
	static volatile gsize three_key_type_id__volatile = 0;
	if (g_once_init_enter (&three_key_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (ThreeKeyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) three_key_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ThreeKey), 0, (GInstanceInitFunc) three_key_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_three_key_info = { (GInterfaceInitFunc) three_key_gxml_mappeable_element_three_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType three_key_type_id;
		three_key_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "ThreeKey", &g_define_type_info, 0);
		g_type_add_interface_static (three_key_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_THREE_KEY, &gxml_mappeable_element_three_key_info);
		g_once_init_leave (&three_key_type_id__volatile, three_key_type_id);
	}
	return three_key_type_id__volatile;
}


static void _vala_three_key_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ThreeKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEY, ThreeKey);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_ID_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_id (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_CODE_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_code (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_NAME_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, three_key_get_name (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2463 "GomSerializationTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2469 "GomSerializationTest.c"
	}
}


static void _vala_three_key_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ThreeKey * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_THREE_KEY, ThreeKey);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_ID_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_id (self, g_value_get_string (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_CODE_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_code (self, g_value_get_string (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case THREE_KEY_NAME_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_name (self, g_value_get_string (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2497 "GomSerializationTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2503 "GomSerializationTest.c"
	}
}


Operations* operations_construct (GType object_type) {
	Operations * self = NULL;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (Operations*) gxml_gom_element_construct (object_type);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 2514 "GomSerializationTest.c"
}


Operations* operations_new (void) {
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return operations_construct (TYPE_OPERATIONS);
#line 2521 "GomSerializationTest.c"
}


OperationMap* operations_get_map (Operations* self) {
	OperationMap* result;
	OperationMap* _tmp0_ = NULL;
	OperationMap* _tmp1_ = NULL;
#line 64 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 65 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 66 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "map");
#line 2537 "GomSerializationTest.c"
	}
#line 67 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = self->priv->_map;
#line 67 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2545 "GomSerializationTest.c"
}


void operations_set_map (Operations* self, OperationMap* value) {
	OperationMap* _tmp0_ = NULL;
	OperationMap* _tmp5_ = NULL;
	OperationMap* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_map;
#line 70 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ != NULL) {
#line 2560 "GomSerializationTest.c"
		{
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "map", &_inner_error_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2566 "GomSerializationTest.c"
				goto __catch283_g_error;
			}
		}
		goto __finally283;
		__catch283_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_ = NULL;
			const gchar* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			e = _inner_error_;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_inner_error_ = NULL;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp1_ = e;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp2_ = _tmp1_->message;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp4_ = _tmp3_;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_warning ("GomSerializationTest.vala:72: %s", _tmp4_);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp4_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_error_free0 (e);
#line 2596 "GomSerializationTest.c"
		}
		__finally283:
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_clear_error (&_inner_error_);
#line 71 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			return;
#line 2607 "GomSerializationTest.c"
		}
	}
#line 73 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = value;
#line 73 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 73 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 73 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_map = _tmp6_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "map");
#line 2620 "GomSerializationTest.c"
}


static GObject * operations_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	Operations * self;
	GError * _inner_error_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operations_parent_class);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATIONS, Operations);
#line 2635 "GomSerializationTest.c"
	{
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Operations");
#line 2639 "GomSerializationTest.c"
	}
	goto __finally284;
	__catch284_g_error:
	{
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 2650 "GomSerializationTest.c"
	}
	__finally284:
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 2659 "GomSerializationTest.c"
	}
#line 76 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 2663 "GomSerializationTest.c"
}


static void operations_class_init (OperationsClass * klass) {
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	operations_parent_class = g_type_class_peek_parent (klass);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (OperationsPrivate));
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_operations_get_property;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_operations_set_property;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operations_constructor;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = operations_finalize;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATIONS_MAP_PROPERTY, g_param_spec_object ("map", "map", "map", OPERATION_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 2682 "GomSerializationTest.c"
}


static void operations_instance_init (Operations * self) {
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = OPERATIONS_GET_PRIVATE (self);
#line 2689 "GomSerializationTest.c"
}


static void operations_finalize (GObject* obj) {
	Operations * self;
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATIONS, Operations);
#line 62 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_map);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (operations_parent_class)->finalize (obj);
#line 2701 "GomSerializationTest.c"
}


GType operations_get_type (void) {
	static volatile gsize operations_type_id__volatile = 0;
	if (g_once_init_enter (&operations_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operations_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Operations), 0, (GInstanceInitFunc) operations_instance_init, NULL };
		GType operations_type_id;
		operations_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "Operations", &g_define_type_info, 0);
		g_once_init_leave (&operations_type_id__volatile, operations_type_id);
	}
	return operations_type_id__volatile;
}


static void _vala_operations_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	Operations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATIONS, Operations);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATIONS_MAP_PROPERTY:
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, operations_get_map (self));
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2728 "GomSerializationTest.c"
		default:
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2734 "GomSerializationTest.c"
	}
}


static void _vala_operations_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	Operations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATIONS, Operations);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATIONS_MAP_PROPERTY:
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operations_set_map (self, g_value_get_object (value));
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2750 "GomSerializationTest.c"
		default:
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 61 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 2756 "GomSerializationTest.c"
	}
}


static gchar* operation_real_get_map_primary_key (GXmlMappeableElementPairKey* base) {
	Operation * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 84 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (Operation*) base;
#line 84 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 84 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 84 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 84 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2776 "GomSerializationTest.c"
}


static gchar* operation_real_get_map_secondary_key (GXmlMappeableElementPairKey* base) {
	Operation * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (Operation*) base;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2795 "GomSerializationTest.c"
}


Operation* operation_construct (GType object_type) {
	Operation * self = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (Operation*) gxml_gom_element_construct (object_type);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 2805 "GomSerializationTest.c"
}


Operation* operation_new (void) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return operation_construct (TYPE_OPERATION);
#line 2812 "GomSerializationTest.c"
}


const gchar* operation_get_id (Operation* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_id;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2827 "GomSerializationTest.c"
}


void operation_set_id (Operation* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_id = _tmp1_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "id");
#line 2846 "GomSerializationTest.c"
}


const gchar* operation_get_code (Operation* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_code;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 2861 "GomSerializationTest.c"
}


void operation_set_code (Operation* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_code = _tmp1_;
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "code");
#line 2880 "GomSerializationTest.c"
}


static GObject * operation_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	Operation * self;
	GError * _inner_error_ = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operation_parent_class);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION, Operation);
#line 2895 "GomSerializationTest.c"
	{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Operation");
#line 2899 "GomSerializationTest.c"
	}
	goto __finally285;
	__catch285_g_error:
	{
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 2910 "GomSerializationTest.c"
	}
	__finally285:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 2919 "GomSerializationTest.c"
	}
#line 83 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 2923 "GomSerializationTest.c"
}


OperationMap* operation_map_construct (GType object_type) {
	OperationMap * self = NULL;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (OperationMap*) gxml_gom_hash_paired_map_construct (object_type);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 2933 "GomSerializationTest.c"
}


OperationMap* operation_map_new (void) {
#line 86 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return operation_map_construct (OPERATION_TYPE_MAP);
#line 2940 "GomSerializationTest.c"
}


static GObject * operation_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	OperationMap * self;
	GError * _inner_error_ = NULL;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (operation_map_parent_class);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, OPERATION_TYPE_MAP, OperationMap);
#line 2955 "GomSerializationTest.c"
	{
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, TYPE_OPERATION, &_inner_error_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2961 "GomSerializationTest.c"
			goto __catch286_g_error;
		}
	}
	goto __finally286;
	__catch286_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = e;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = _tmp0_->message;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:89: %s", _tmp3_);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 2991 "GomSerializationTest.c"
	}
	__finally286:
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3000 "GomSerializationTest.c"
	}
#line 87 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3004 "GomSerializationTest.c"
}


static void operation_map_class_init (OperationMapClass * klass) {
#line 86 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	operation_map_parent_class = g_type_class_peek_parent (klass);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operation_map_constructor;
#line 3013 "GomSerializationTest.c"
}


static void operation_map_instance_init (OperationMap * self) {
}


GType operation_map_get_type (void) {
	static volatile gsize operation_map_type_id__volatile = 0;
	if (g_once_init_enter (&operation_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operation_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (OperationMap), 0, (GInstanceInitFunc) operation_map_instance_init, NULL };
		GType operation_map_type_id;
		operation_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_PAIRED_MAP, "OperationMap", &g_define_type_info, 0);
		g_once_init_leave (&operation_map_type_id__volatile, operation_map_type_id);
	}
	return operation_map_type_id__volatile;
}


static void operation_class_init (OperationClass * klass) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	operation_parent_class = g_type_class_peek_parent (klass);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (OperationPrivate));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_operation_get_property;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_operation_set_property;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = operation_constructor;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = operation_finalize;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATION_ID_PROPERTY, g_param_spec_string ("id", "::ID", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), OPERATION_CODE_PROPERTY, g_param_spec_string ("code", "::Code", "code", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3050 "GomSerializationTest.c"
}


static void operation_gxml_mappeable_element_pair_key_interface_init (GXmlMappeableElementPairKeyIface * iface) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	operation_gxml_mappeable_element_pair_key_parent_iface = g_type_interface_peek_parent (iface);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_primary_key = (gchar* (*)(GXmlMappeableElementPairKey*)) operation_real_get_map_primary_key;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_secondary_key = (gchar* (*)(GXmlMappeableElementPairKey*)) operation_real_get_map_secondary_key;
#line 3061 "GomSerializationTest.c"
}


static void operation_instance_init (Operation * self) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = OPERATION_GET_PRIVATE (self);
#line 3068 "GomSerializationTest.c"
}


static void operation_finalize (GObject* obj) {
	Operation * self;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_OPERATION, Operation);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_id);
#line 82 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_code);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (operation_parent_class)->finalize (obj);
#line 3082 "GomSerializationTest.c"
}


GType operation_get_type (void) {
	static volatile gsize operation_type_id__volatile = 0;
	if (g_once_init_enter (&operation_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (OperationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) operation_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (Operation), 0, (GInstanceInitFunc) operation_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_pair_key_info = { (GInterfaceInitFunc) operation_gxml_mappeable_element_pair_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType operation_type_id;
		operation_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "Operation", &g_define_type_info, 0);
		g_type_add_interface_static (operation_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_PAIR_KEY, &gxml_mappeable_element_pair_key_info);
		g_once_init_leave (&operation_type_id__volatile, operation_type_id);
	}
	return operation_type_id__volatile;
}


static void _vala_operation_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	Operation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATION, Operation);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATION_ID_PROPERTY:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, operation_get_id (self));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATION_CODE_PROPERTY:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, operation_get_code (self));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3117 "GomSerializationTest.c"
		default:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3123 "GomSerializationTest.c"
	}
}


static void _vala_operation_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	Operation * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_OPERATION, Operation);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATION_ID_PROPERTY:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_id (self, g_value_get_string (value));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case OPERATION_CODE_PROPERTY:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_code (self, g_value_get_string (value));
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3145 "GomSerializationTest.c"
		default:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3151 "GomSerializationTest.c"
	}
}


GomName* gom_name_construct (GType object_type) {
	GomName * self = NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomName*) gxml_gom_element_construct (object_type);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3162 "GomSerializationTest.c"
}


GomName* gom_name_new (void) {
#line 93 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_name_construct (TYPE_GOM_NAME);
#line 3169 "GomSerializationTest.c"
}


static GObject * gom_name_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomName * self;
	GError * _inner_error_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_name_parent_class);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_NAME, GomName);
#line 3184 "GomSerializationTest.c"
	{
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Name");
#line 3188 "GomSerializationTest.c"
	}
	goto __finally287;
	__catch287_g_error:
	{
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3199 "GomSerializationTest.c"
	}
	__finally287:
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3208 "GomSerializationTest.c"
	}
#line 95 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3212 "GomSerializationTest.c"
}


static void gom_name_class_init (GomNameClass * klass) {
#line 93 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_name_parent_class = g_type_class_peek_parent (klass);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_name_constructor;
#line 3221 "GomSerializationTest.c"
}


static void gom_name_instance_init (GomName * self) {
}


GType gom_name_get_type (void) {
	static volatile gsize gom_name_type_id__volatile = 0;
	if (g_once_init_enter (&gom_name_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomNameClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_name_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomName), 0, (GInstanceInitFunc) gom_name_instance_init, NULL };
		GType gom_name_type_id;
		gom_name_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomName", &g_define_type_info, 0);
		g_once_init_leave (&gom_name_type_id__volatile, gom_name_type_id);
	}
	return gom_name_type_id__volatile;
}


GomEmail* gom_email_construct (GType object_type) {
	GomEmail * self = NULL;
#line 98 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomEmail*) gxml_gom_element_construct (object_type);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3247 "GomSerializationTest.c"
}


GomEmail* gom_email_new (void) {
#line 98 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_email_construct (TYPE_GOM_EMAIL);
#line 3254 "GomSerializationTest.c"
}


static GObject * gom_email_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomEmail * self;
	GError * _inner_error_ = NULL;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_email_parent_class);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_EMAIL, GomEmail);
#line 3269 "GomSerializationTest.c"
	{
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Email");
#line 3273 "GomSerializationTest.c"
	}
	goto __finally288;
	__catch288_g_error:
	{
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3284 "GomSerializationTest.c"
	}
	__finally288:
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3293 "GomSerializationTest.c"
	}
#line 100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3297 "GomSerializationTest.c"
}


static void gom_email_class_init (GomEmailClass * klass) {
#line 98 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_email_parent_class = g_type_class_peek_parent (klass);
#line 98 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_email_constructor;
#line 3306 "GomSerializationTest.c"
}


static void gom_email_instance_init (GomEmail * self) {
}


GType gom_email_get_type (void) {
	static volatile gsize gom_email_type_id__volatile = 0;
	if (g_once_init_enter (&gom_email_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomEmailClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_email_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomEmail), 0, (GInstanceInitFunc) gom_email_instance_init, NULL };
		GType gom_email_type_id;
		gom_email_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomEmail", &g_define_type_info, 0);
		g_once_init_leave (&gom_email_type_id__volatile, gom_email_type_id);
	}
	return gom_email_type_id__volatile;
}


GomAuthor* gom_author_construct (GType object_type) {
	GomAuthor * self = NULL;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomAuthor*) gxml_gom_element_construct (object_type);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3332 "GomSerializationTest.c"
}


GomAuthor* gom_author_new (void) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_author_construct (TYPE_GOM_AUTHOR);
#line 3339 "GomSerializationTest.c"
}


Name* gom_author_get_name (GomAuthor* self) {
	Name* result;
	Name* _tmp0_ = NULL;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3354 "GomSerializationTest.c"
}


void gom_author_set_name (GomAuthor* self, Name* value) {
	Name* _tmp0_ = NULL;
	Name* _tmp1_ = NULL;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 3373 "GomSerializationTest.c"
}


Email* gom_author_get_email (GomAuthor* self) {
	Email* result;
	Email* _tmp0_ = NULL;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_email;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3388 "GomSerializationTest.c"
}


void gom_author_set_email (GomAuthor* self, Email* value) {
	Email* _tmp0_ = NULL;
	Email* _tmp1_ = NULL;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_email);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_email = _tmp1_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "email");
#line 3407 "GomSerializationTest.c"
}


static GObject * gom_author_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthor * self;
	GError * _inner_error_ = NULL;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_author_parent_class);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHOR, GomAuthor);
#line 3422 "GomSerializationTest.c"
	{
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Author");
#line 3426 "GomSerializationTest.c"
	}
	goto __finally289;
	__catch289_g_error:
	{
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3437 "GomSerializationTest.c"
	}
	__finally289:
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3446 "GomSerializationTest.c"
	}
#line 107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3450 "GomSerializationTest.c"
}


GomAuthorArray* gom_author_array_construct (GType object_type) {
	GomAuthorArray * self = NULL;
#line 108 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomAuthorArray*) gxml_gom_array_list_construct (object_type);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3460 "GomSerializationTest.c"
}


GomAuthorArray* gom_author_array_new (void) {
#line 108 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_author_array_construct (GOM_AUTHOR_TYPE_ARRAY);
#line 3467 "GomSerializationTest.c"
}


static GObject * gom_author_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthorArray * self;
	GError * _inner_error_ = NULL;
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_author_array_parent_class);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_AUTHOR_TYPE_ARRAY, GomAuthorArray);
#line 3482 "GomSerializationTest.c"
	{
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, TYPE_GOM_AUTHOR, &_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3488 "GomSerializationTest.c"
			goto __catch290_g_error;
		}
	}
	goto __finally290;
	__catch290_g_error:
	{
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3501 "GomSerializationTest.c"
	}
	__finally290:
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3510 "GomSerializationTest.c"
	}
#line 109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3514 "GomSerializationTest.c"
}


static void gom_author_array_class_init (GomAuthorArrayClass * klass) {
#line 108 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_author_array_parent_class = g_type_class_peek_parent (klass);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_author_array_constructor;
#line 3523 "GomSerializationTest.c"
}


static void gom_author_array_instance_init (GomAuthorArray * self) {
}


GType gom_author_array_get_type (void) {
	static volatile gsize gom_author_array_type_id__volatile = 0;
	if (g_once_init_enter (&gom_author_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_author_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthorArray), 0, (GInstanceInitFunc) gom_author_array_instance_init, NULL };
		GType gom_author_array_type_id;
		gom_author_array_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomAuthorArray", &g_define_type_info, 0);
		g_once_init_leave (&gom_author_array_type_id__volatile, gom_author_array_type_id);
	}
	return gom_author_array_type_id__volatile;
}


static void gom_author_class_init (GomAuthorClass * klass) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_author_parent_class = g_type_class_peek_parent (klass);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomAuthorPrivate));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_author_get_property;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_author_set_property;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_author_constructor;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_author_finalize;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHOR_NAME_PROPERTY, g_param_spec_object ("name", "name", "name", TYPE_NAME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHOR_EMAIL_PROPERTY, g_param_spec_object ("email", "email", "email", TYPE_EMAIL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3560 "GomSerializationTest.c"
}


static void gom_author_instance_init (GomAuthor * self) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_AUTHOR_GET_PRIVATE (self);
#line 3567 "GomSerializationTest.c"
}


static void gom_author_finalize (GObject* obj) {
	GomAuthor * self;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHOR, GomAuthor);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_email);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_author_parent_class)->finalize (obj);
#line 3581 "GomSerializationTest.c"
}


GType gom_author_get_type (void) {
	static volatile gsize gom_author_type_id__volatile = 0;
	if (g_once_init_enter (&gom_author_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_author_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthor), 0, (GInstanceInitFunc) gom_author_instance_init, NULL };
		GType gom_author_type_id;
		gom_author_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomAuthor", &g_define_type_info, 0);
		g_once_init_leave (&gom_author_type_id__volatile, gom_author_type_id);
	}
	return gom_author_type_id__volatile;
}


static void _vala_gom_author_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomAuthor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHOR, GomAuthor);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHOR_NAME_PROPERTY:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_author_get_name (self));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHOR_EMAIL_PROPERTY:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_author_get_email (self));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3614 "GomSerializationTest.c"
		default:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3620 "GomSerializationTest.c"
	}
}


static void _vala_gom_author_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomAuthor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHOR, GomAuthor);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHOR_NAME_PROPERTY:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_author_set_name (self, g_value_get_object (value));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHOR_EMAIL_PROPERTY:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_author_set_email (self, g_value_get_object (value));
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3642 "GomSerializationTest.c"
		default:
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3648 "GomSerializationTest.c"
	}
}


GomAuthors* gom_authors_construct (GType object_type) {
	GomAuthors * self = NULL;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomAuthors*) gxml_gom_element_construct (object_type);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3659 "GomSerializationTest.c"
}


GomAuthors* gom_authors_new (void) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_authors_construct (TYPE_GOM_AUTHORS);
#line 3666 "GomSerializationTest.c"
}


const gchar* gom_authors_get_number (GomAuthors* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_number;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3681 "GomSerializationTest.c"
}


void gom_authors_set_number (GomAuthors* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_number);
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_number = _tmp1_;
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "number");
#line 3700 "GomSerializationTest.c"
}


GomAuthorArray* gom_authors_get_array (GomAuthors* self) {
	GomAuthorArray* result;
	GomAuthorArray* _tmp0_ = NULL;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_array;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3715 "GomSerializationTest.c"
}


void gom_authors_set_array (GomAuthors* self, GomAuthorArray* value) {
	GomAuthorArray* _tmp0_ = NULL;
	GomAuthorArray* _tmp1_ = NULL;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_array);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_array = _tmp1_;
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "array");
#line 3734 "GomSerializationTest.c"
}


static GObject * gom_authors_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomAuthors * self;
	GError * _inner_error_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_authors_parent_class);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHORS, GomAuthors);
#line 3749 "GomSerializationTest.c"
	{
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Authors");
#line 3753 "GomSerializationTest.c"
	}
	goto __finally291;
	__catch291_g_error:
	{
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 3764 "GomSerializationTest.c"
	}
	__finally291:
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 3773 "GomSerializationTest.c"
	}
#line 117 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 3777 "GomSerializationTest.c"
}


static void gom_authors_class_init (GomAuthorsClass * klass) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_authors_parent_class = g_type_class_peek_parent (klass);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomAuthorsPrivate));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_authors_get_property;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_authors_set_property;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_authors_constructor;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_authors_finalize;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHORS_NUMBER_PROPERTY, g_param_spec_string ("number", "number", "number", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_AUTHORS_ARRAY_PROPERTY, g_param_spec_object ("array", "array", "array", GOM_AUTHOR_TYPE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 3798 "GomSerializationTest.c"
}


static void gom_authors_instance_init (GomAuthors * self) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_AUTHORS_GET_PRIVATE (self);
#line 3805 "GomSerializationTest.c"
}


static void gom_authors_finalize (GObject* obj) {
	GomAuthors * self;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_AUTHORS, GomAuthors);
#line 116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_number);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_array);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_authors_parent_class)->finalize (obj);
#line 3819 "GomSerializationTest.c"
}


GType gom_authors_get_type (void) {
	static volatile gsize gom_authors_type_id__volatile = 0;
	if (g_once_init_enter (&gom_authors_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomAuthorsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_authors_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomAuthors), 0, (GInstanceInitFunc) gom_authors_instance_init, NULL };
		GType gom_authors_type_id;
		gom_authors_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomAuthors", &g_define_type_info, 0);
		g_once_init_leave (&gom_authors_type_id__volatile, gom_authors_type_id);
	}
	return gom_authors_type_id__volatile;
}


static void _vala_gom_authors_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomAuthors * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHORS, GomAuthors);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHORS_NUMBER_PROPERTY:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_authors_get_number (self));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHORS_ARRAY_PROPERTY:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_authors_get_array (self));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3852 "GomSerializationTest.c"
		default:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3858 "GomSerializationTest.c"
	}
}


static void _vala_gom_authors_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomAuthors * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_AUTHORS, GomAuthors);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHORS_NUMBER_PROPERTY:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_authors_set_number (self, g_value_get_string (value));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_AUTHORS_ARRAY_PROPERTY:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_authors_set_array (self, g_value_get_object (value));
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3880 "GomSerializationTest.c"
		default:
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 3886 "GomSerializationTest.c"
	}
}


GomInventory* gom_inventory_construct (GType object_type) {
	GomInventory * self = NULL;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomInventory*) gxml_gom_element_construct (object_type);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 3897 "GomSerializationTest.c"
}


GomInventory* gom_inventory_new (void) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_inventory_construct (TYPE_GOM_INVENTORY);
#line 3904 "GomSerializationTest.c"
}


gint gom_inventory_get_number (GomInventory* self) {
	gint result;
	gint _tmp0_ = 0;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_number;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3919 "GomSerializationTest.c"
}


void gom_inventory_set_number (GomInventory* self, gint value) {
	gint _tmp0_ = 0;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_number = _tmp0_;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "number");
#line 3933 "GomSerializationTest.c"
}


gint gom_inventory_get_row (GomInventory* self) {
	gint result;
	gint _tmp0_ = 0;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_row;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3948 "GomSerializationTest.c"
}


void gom_inventory_set_row (GomInventory* self, gint value) {
	gint _tmp0_ = 0;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_row = _tmp0_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "row");
#line 3962 "GomSerializationTest.c"
}


const gchar* gom_inventory_get_inventory (GomInventory* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_inventory;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 3977 "GomSerializationTest.c"
}


void gom_inventory_set_inventory (GomInventory* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_inventory);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_inventory = _tmp1_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "inventory");
#line 3996 "GomSerializationTest.c"
}


static GObject * gom_inventory_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomInventory * self;
	GError * _inner_error_ = NULL;
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_inventory_parent_class);
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_INVENTORY, GomInventory);
#line 4011 "GomSerializationTest.c"
	{
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Inventory");
#line 4015 "GomSerializationTest.c"
	}
	goto __finally292;
	__catch292_g_error:
	{
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4026 "GomSerializationTest.c"
	}
	__finally292:
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4035 "GomSerializationTest.c"
	}
#line 129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4039 "GomSerializationTest.c"
}


GomInventoryDualKeyMap* gom_inventory_dual_key_map_construct (GType object_type) {
	GomInventoryDualKeyMap * self = NULL;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomInventoryDualKeyMap*) gxml_gom_hash_map_construct (object_type);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4049 "GomSerializationTest.c"
}


GomInventoryDualKeyMap* gom_inventory_dual_key_map_new (void) {
#line 131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_inventory_dual_key_map_construct (GOM_INVENTORY_TYPE_DUAL_KEY_MAP);
#line 4056 "GomSerializationTest.c"
}


static GObject * gom_inventory_dual_key_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomInventoryDualKeyMap * self;
	GError * _inner_error_ = NULL;
#line 132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_inventory_dual_key_map_parent_class);
#line 132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_INVENTORY_TYPE_DUAL_KEY_MAP, GomInventoryDualKeyMap);
#line 4071 "GomSerializationTest.c"
	{
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_INVENTORY, "number", &_inner_error_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4077 "GomSerializationTest.c"
			goto __catch293_g_error;
		}
	}
	goto __finally293;
	__catch293_g_error:
	{
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4090 "GomSerializationTest.c"
	}
	__finally293:
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4099 "GomSerializationTest.c"
	}
#line 132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4103 "GomSerializationTest.c"
}


static void gom_inventory_dual_key_map_class_init (GomInventoryDualKeyMapClass * klass) {
#line 131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_inventory_dual_key_map_parent_class = g_type_class_peek_parent (klass);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_inventory_dual_key_map_constructor;
#line 4112 "GomSerializationTest.c"
}


static void gom_inventory_dual_key_map_instance_init (GomInventoryDualKeyMap * self) {
}


GType gom_inventory_dual_key_map_get_type (void) {
	static volatile gsize gom_inventory_dual_key_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_inventory_dual_key_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomInventoryDualKeyMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_inventory_dual_key_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomInventoryDualKeyMap), 0, (GInstanceInitFunc) gom_inventory_dual_key_map_instance_init, NULL };
		GType gom_inventory_dual_key_map_type_id;
		gom_inventory_dual_key_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomInventoryDualKeyMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_inventory_dual_key_map_type_id__volatile, gom_inventory_dual_key_map_type_id);
	}
	return gom_inventory_dual_key_map_type_id__volatile;
}


static void gom_inventory_class_init (GomInventoryClass * klass) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_inventory_parent_class = g_type_class_peek_parent (klass);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomInventoryPrivate));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_inventory_get_property;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_inventory_set_property;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_inventory_constructor;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_inventory_finalize;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_NUMBER_PROPERTY, g_param_spec_int ("number", "::Number", "number", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_ROW_PROPERTY, g_param_spec_int ("row", "::Row", "row", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_INVENTORY_INVENTORY_PROPERTY, g_param_spec_string ("inventory", "::Inventory", "inventory", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4151 "GomSerializationTest.c"
}


static void gom_inventory_instance_init (GomInventory * self) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_INVENTORY_GET_PRIVATE (self);
#line 4158 "GomSerializationTest.c"
}


static void gom_inventory_finalize (GObject* obj) {
	GomInventory * self;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_INVENTORY, GomInventory);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_inventory);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_inventory_parent_class)->finalize (obj);
#line 4170 "GomSerializationTest.c"
}


GType gom_inventory_get_type (void) {
	static volatile gsize gom_inventory_type_id__volatile = 0;
	if (g_once_init_enter (&gom_inventory_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomInventoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_inventory_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomInventory), 0, (GInstanceInitFunc) gom_inventory_instance_init, NULL };
		GType gom_inventory_type_id;
		gom_inventory_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomInventory", &g_define_type_info, 0);
		g_once_init_leave (&gom_inventory_type_id__volatile, gom_inventory_type_id);
	}
	return gom_inventory_type_id__volatile;
}


static void _vala_gom_inventory_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomInventory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_INVENTORY, GomInventory);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_NUMBER_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_int (value, gom_inventory_get_number (self));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_ROW_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_int (value, gom_inventory_get_row (self));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_INVENTORY_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_inventory_get_inventory (self));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4209 "GomSerializationTest.c"
		default:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4215 "GomSerializationTest.c"
	}
}


static void _vala_gom_inventory_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomInventory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_INVENTORY, GomInventory);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_NUMBER_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_inventory_set_number (self, g_value_get_int (value));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_ROW_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_inventory_set_row (self, g_value_get_int (value));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_INVENTORY_INVENTORY_PROPERTY:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_inventory_set_inventory (self, g_value_get_string (value));
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4243 "GomSerializationTest.c"
		default:
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4249 "GomSerializationTest.c"
	}
}


GomCategory* gom_category_construct (GType object_type) {
	GomCategory * self = NULL;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomCategory*) gxml_gom_element_construct (object_type);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4260 "GomSerializationTest.c"
}


GomCategory* gom_category_new (void) {
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_category_construct (TYPE_GOM_CATEGORY);
#line 4267 "GomSerializationTest.c"
}


const gchar* gom_category_get_name (GomCategory* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4282 "GomSerializationTest.c"
}


void gom_category_set_name (GomCategory* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 4301 "GomSerializationTest.c"
}


static GObject * gom_category_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomCategory * self;
	GError * _inner_error_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_category_parent_class);
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_CATEGORY, GomCategory);
#line 4316 "GomSerializationTest.c"
	{
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Category");
#line 4320 "GomSerializationTest.c"
	}
	goto __finally294;
	__catch294_g_error:
	{
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4331 "GomSerializationTest.c"
	}
	__finally294:
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4340 "GomSerializationTest.c"
	}
#line 143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4344 "GomSerializationTest.c"
}


GomCategoryMap* gom_category_map_construct (GType object_type) {
	GomCategoryMap * self = NULL;
#line 144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomCategoryMap*) gxml_gom_hash_map_construct (object_type);
#line 144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4354 "GomSerializationTest.c"
}


GomCategoryMap* gom_category_map_new (void) {
#line 144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_category_map_construct (GOM_CATEGORY_TYPE_MAP);
#line 4361 "GomSerializationTest.c"
}


static GObject * gom_category_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomCategoryMap * self;
	GError * _inner_error_ = NULL;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_category_map_parent_class);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_CATEGORY_TYPE_MAP, GomCategoryMap);
#line 4376 "GomSerializationTest.c"
	{
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_CATEGORY, "name", &_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4382 "GomSerializationTest.c"
			goto __catch295_g_error;
		}
	}
	goto __finally295;
	__catch295_g_error:
	{
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4395 "GomSerializationTest.c"
	}
	__finally295:
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4404 "GomSerializationTest.c"
	}
#line 145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4408 "GomSerializationTest.c"
}


static void gom_category_map_class_init (GomCategoryMapClass * klass) {
#line 144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_category_map_parent_class = g_type_class_peek_parent (klass);
#line 144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_category_map_constructor;
#line 4417 "GomSerializationTest.c"
}


static void gom_category_map_instance_init (GomCategoryMap * self) {
}


GType gom_category_map_get_type (void) {
	static volatile gsize gom_category_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_category_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomCategoryMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_category_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomCategoryMap), 0, (GInstanceInitFunc) gom_category_map_instance_init, NULL };
		GType gom_category_map_type_id;
		gom_category_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomCategoryMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_category_map_type_id__volatile, gom_category_map_type_id);
	}
	return gom_category_map_type_id__volatile;
}


static void gom_category_class_init (GomCategoryClass * klass) {
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_category_parent_class = g_type_class_peek_parent (klass);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomCategoryPrivate));
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_category_get_property;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_category_set_property;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_category_constructor;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_category_finalize;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_CATEGORY_NAME_PROPERTY, g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4452 "GomSerializationTest.c"
}


static void gom_category_instance_init (GomCategory * self) {
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_CATEGORY_GET_PRIVATE (self);
#line 4459 "GomSerializationTest.c"
}


static void gom_category_finalize (GObject* obj) {
	GomCategory * self;
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_CATEGORY, GomCategory);
#line 142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_category_parent_class)->finalize (obj);
#line 4471 "GomSerializationTest.c"
}


GType gom_category_get_type (void) {
	static volatile gsize gom_category_type_id__volatile = 0;
	if (g_once_init_enter (&gom_category_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomCategoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_category_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomCategory), 0, (GInstanceInitFunc) gom_category_instance_init, NULL };
		GType gom_category_type_id;
		gom_category_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomCategory", &g_define_type_info, 0);
		g_once_init_leave (&gom_category_type_id__volatile, gom_category_type_id);
	}
	return gom_category_type_id__volatile;
}


static void _vala_gom_category_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomCategory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_CATEGORY, GomCategory);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_CATEGORY_NAME_PROPERTY:
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_category_get_name (self));
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4498 "GomSerializationTest.c"
		default:
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4504 "GomSerializationTest.c"
	}
}


static void _vala_gom_category_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomCategory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_CATEGORY, GomCategory);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_CATEGORY_NAME_PROPERTY:
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_category_set_name (self, g_value_get_string (value));
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4520 "GomSerializationTest.c"
		default:
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4526 "GomSerializationTest.c"
	}
}


GomResume* gom_resume_construct (GType object_type) {
	GomResume * self = NULL;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomResume*) gxml_gom_element_construct (object_type);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4537 "GomSerializationTest.c"
}


GomResume* gom_resume_new (void) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_resume_construct (TYPE_GOM_RESUME);
#line 4544 "GomSerializationTest.c"
}


const gchar* gom_resume_get_chapter (GomResume* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_chapter;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4559 "GomSerializationTest.c"
}


void gom_resume_set_chapter (GomResume* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_chapter);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_chapter = _tmp1_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "chapter");
#line 4578 "GomSerializationTest.c"
}


const gchar* gom_resume_get_text (GomResume* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_text;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4593 "GomSerializationTest.c"
}


void gom_resume_set_text (GomResume* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_text = _tmp1_;
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "text");
#line 4612 "GomSerializationTest.c"
}


static GObject * gom_resume_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomResume * self;
	GError * _inner_error_ = NULL;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_resume_parent_class);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_RESUME, GomResume);
#line 4627 "GomSerializationTest.c"
	{
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Resume");
#line 4631 "GomSerializationTest.c"
	}
	goto __finally296;
	__catch296_g_error:
	{
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4642 "GomSerializationTest.c"
	}
	__finally296:
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4651 "GomSerializationTest.c"
	}
#line 159 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4655 "GomSerializationTest.c"
}


GomResumeMap* gom_resume_map_construct (GType object_type) {
	GomResumeMap * self = NULL;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomResumeMap*) gxml_gom_hash_map_construct (object_type);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4665 "GomSerializationTest.c"
}


GomResumeMap* gom_resume_map_new (void) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_resume_map_construct (GOM_RESUME_TYPE_MAP);
#line 4672 "GomSerializationTest.c"
}


static GObject * gom_resume_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomResumeMap * self;
	GError * _inner_error_ = NULL;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_resume_map_parent_class);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 161 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_RESUME_TYPE_MAP, GomResumeMap);
#line 4687 "GomSerializationTest.c"
	{
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, TYPE_GOM_RESUME, "chapter", &_inner_error_);
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4693 "GomSerializationTest.c"
			goto __catch297_g_error;
		}
	}
	goto __finally297;
	__catch297_g_error:
	{
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 4706 "GomSerializationTest.c"
	}
	__finally297:
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 4715 "GomSerializationTest.c"
	}
#line 161 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 4719 "GomSerializationTest.c"
}


static void gom_resume_map_class_init (GomResumeMapClass * klass) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_resume_map_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_resume_map_constructor;
#line 4728 "GomSerializationTest.c"
}


static void gom_resume_map_instance_init (GomResumeMap * self) {
}


GType gom_resume_map_get_type (void) {
	static volatile gsize gom_resume_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_resume_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomResumeMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_resume_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomResumeMap), 0, (GInstanceInitFunc) gom_resume_map_instance_init, NULL };
		GType gom_resume_map_type_id;
		gom_resume_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomResumeMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_resume_map_type_id__volatile, gom_resume_map_type_id);
	}
	return gom_resume_map_type_id__volatile;
}


static void gom_resume_class_init (GomResumeClass * klass) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_resume_parent_class = g_type_class_peek_parent (klass);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomResumePrivate));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_resume_get_property;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_resume_set_property;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_resume_constructor;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_resume_finalize;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_RESUME_CHAPTER_PROPERTY, g_param_spec_string ("chapter", "::Chapter", "chapter", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_RESUME_TEXT_PROPERTY, g_param_spec_string ("text", "::Text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 4765 "GomSerializationTest.c"
}


static void gom_resume_instance_init (GomResume * self) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_RESUME_GET_PRIVATE (self);
#line 4772 "GomSerializationTest.c"
}


static void gom_resume_finalize (GObject* obj) {
	GomResume * self;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_RESUME, GomResume);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_chapter);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_resume_parent_class)->finalize (obj);
#line 4786 "GomSerializationTest.c"
}


GType gom_resume_get_type (void) {
	static volatile gsize gom_resume_type_id__volatile = 0;
	if (g_once_init_enter (&gom_resume_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomResumeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_resume_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomResume), 0, (GInstanceInitFunc) gom_resume_instance_init, NULL };
		GType gom_resume_type_id;
		gom_resume_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomResume", &g_define_type_info, 0);
		g_once_init_leave (&gom_resume_type_id__volatile, gom_resume_type_id);
	}
	return gom_resume_type_id__volatile;
}


static void _vala_gom_resume_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomResume * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_RESUME, GomResume);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_RESUME_CHAPTER_PROPERTY:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_resume_get_chapter (self));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_RESUME_TEXT_PROPERTY:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_resume_get_text (self));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4819 "GomSerializationTest.c"
		default:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4825 "GomSerializationTest.c"
	}
}


static void _vala_gom_resume_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomResume * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_RESUME, GomResume);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_RESUME_CHAPTER_PROPERTY:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_resume_set_chapter (self, g_value_get_string (value));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_RESUME_TEXT_PROPERTY:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_resume_set_text (self, g_value_get_string (value));
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4847 "GomSerializationTest.c"
		default:
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 4853 "GomSerializationTest.c"
	}
}


GomBook* gom_book_construct (GType object_type) {
	GomBook * self = NULL;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomBook*) gxml_gom_element_construct (object_type);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 4864 "GomSerializationTest.c"
}


GomBook* gom_book_new (void) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_book_construct (TYPE_GOM_BOOK);
#line 4871 "GomSerializationTest.c"
}


const gchar* gom_book_get_year (GomBook* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_year;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4886 "GomSerializationTest.c"
}


void gom_book_set_year (GomBook* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_year);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_year = _tmp1_;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "year");
#line 4905 "GomSerializationTest.c"
}


const gchar* gom_book_get_isbn (GomBook* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_isbn;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4920 "GomSerializationTest.c"
}


void gom_book_set_isbn (GomBook* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_isbn);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_isbn = _tmp1_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "isbn");
#line 4939 "GomSerializationTest.c"
}


GomName* gom_book_get_name (GomBook* self) {
	GomName* result;
	GomName* _tmp0_ = NULL;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4954 "GomSerializationTest.c"
}


void gom_book_set_name (GomBook* self, GomName* value) {
	GomName* _tmp0_ = NULL;
	GomName* _tmp1_ = NULL;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 4973 "GomSerializationTest.c"
}


GomAuthors* gom_book_get_authors (GomBook* self) {
	GomAuthors* result;
	GomAuthors* _tmp0_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_authors;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 4988 "GomSerializationTest.c"
}


void gom_book_set_authors (GomBook* self, GomAuthors* value) {
	GomAuthors* _tmp0_ = NULL;
	GomAuthors* _tmp1_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_authors);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_authors = _tmp1_;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "authors");
#line 5007 "GomSerializationTest.c"
}


GomInventoryDualKeyMap* gom_book_get_inventory_registers (GomBook* self) {
	GomInventoryDualKeyMap* result;
	GomInventoryDualKeyMap* _tmp0_ = NULL;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_inventory_registers;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5022 "GomSerializationTest.c"
}


void gom_book_set_inventory_registers (GomBook* self, GomInventoryDualKeyMap* value) {
	GomInventoryDualKeyMap* _tmp0_ = NULL;
	GomInventoryDualKeyMap* _tmp1_ = NULL;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_inventory_registers);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_inventory_registers = _tmp1_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "inventory-registers");
#line 5041 "GomSerializationTest.c"
}


GomCategoryMap* gom_book_get_categories (GomBook* self) {
	GomCategoryMap* result;
	GomCategoryMap* _tmp0_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_categories;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5056 "GomSerializationTest.c"
}


void gom_book_set_categories (GomBook* self, GomCategoryMap* value) {
	GomCategoryMap* _tmp0_ = NULL;
	GomCategoryMap* _tmp1_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_categories);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_categories = _tmp1_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "categories");
#line 5075 "GomSerializationTest.c"
}


GomResumeMap* gom_book_get_resumes (GomBook* self) {
	GomResumeMap* result;
	GomResumeMap* _tmp0_ = NULL;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_resumes;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5090 "GomSerializationTest.c"
}


void gom_book_set_resumes (GomBook* self, GomResumeMap* value) {
	GomResumeMap* _tmp0_ = NULL;
	GomResumeMap* _tmp1_ = NULL;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_resumes);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_resumes = _tmp1_;
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "resumes");
#line 5109 "GomSerializationTest.c"
}


static GObject * gom_book_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomBook * self;
	GError * _inner_error_ = NULL;
#line 179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_parent_class);
#line 179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK, GomBook);
#line 5124 "GomSerializationTest.c"
	{
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Book");
#line 5128 "GomSerializationTest.c"
	}
	goto __finally298;
	__catch298_g_error:
	{
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5139 "GomSerializationTest.c"
	}
	__finally298:
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 5148 "GomSerializationTest.c"
	}
#line 179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 5152 "GomSerializationTest.c"
}


GomBookArray* gom_book_array_construct (GType object_type) {
	GomBookArray * self = NULL;
#line 182 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomBookArray*) gxml_gom_array_list_construct (object_type);
#line 182 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 5162 "GomSerializationTest.c"
}


GomBookArray* gom_book_array_new (void) {
#line 182 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_book_array_construct (GOM_BOOK_TYPE_ARRAY);
#line 5169 "GomSerializationTest.c"
}


static GObject * gom_book_array_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomBookArray * self;
	GError * _inner_error_ = NULL;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_array_parent_class);
#line 183 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 183 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_BOOK_TYPE_ARRAY, GomBookArray);
#line 5184 "GomSerializationTest.c"
	{
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, TYPE_GOM_BOOK, &_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5190 "GomSerializationTest.c"
			goto __catch299_g_error;
		}
	}
	goto __finally299;
	__catch299_g_error:
	{
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5203 "GomSerializationTest.c"
	}
	__finally299:
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 5212 "GomSerializationTest.c"
	}
#line 183 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 5216 "GomSerializationTest.c"
}


static void gom_book_array_class_init (GomBookArrayClass * klass) {
#line 182 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_book_array_parent_class = g_type_class_peek_parent (klass);
#line 182 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_array_constructor;
#line 5225 "GomSerializationTest.c"
}


static void gom_book_array_instance_init (GomBookArray * self) {
}


GType gom_book_array_get_type (void) {
	static volatile gsize gom_book_array_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_array_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookArrayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_array_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBookArray), 0, (GInstanceInitFunc) gom_book_array_instance_init, NULL };
		GType gom_book_array_type_id;
		gom_book_array_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomBookArray", &g_define_type_info, 0);
		g_once_init_leave (&gom_book_array_type_id__volatile, gom_book_array_type_id);
	}
	return gom_book_array_type_id__volatile;
}


static void gom_book_class_init (GomBookClass * klass) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_book_parent_class = g_type_class_peek_parent (klass);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomBookPrivate));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_book_get_property;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_book_set_property;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_constructor;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_book_finalize;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_YEAR_PROPERTY, g_param_spec_string ("year", "::Year", "year", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_ISBN_PROPERTY, g_param_spec_string ("isbn", "::ISBN", "isbn", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_NAME_PROPERTY, g_param_spec_object ("name", "name", "name", TYPE_GOM_NAME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_AUTHORS_PROPERTY, g_param_spec_object ("authors", "authors", "authors", TYPE_GOM_AUTHORS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_INVENTORY_REGISTERS_PROPERTY, g_param_spec_object ("inventory-registers", "inventory-registers", "inventory-registers", GOM_INVENTORY_TYPE_DUAL_KEY_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_CATEGORIES_PROPERTY, g_param_spec_object ("categories", "categories", "categories", GOM_CATEGORY_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_RESUMES_PROPERTY, g_param_spec_object ("resumes", "resumes", "resumes", GOM_RESUME_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5272 "GomSerializationTest.c"
}


static void gom_book_instance_init (GomBook * self) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_BOOK_GET_PRIVATE (self);
#line 5279 "GomSerializationTest.c"
}


static void gom_book_finalize (GObject* obj) {
	GomBook * self;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK, GomBook);
#line 171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_year);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_isbn);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_name);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_authors);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_inventory_registers);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_categories);
#line 178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_resumes);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_book_parent_class)->finalize (obj);
#line 5303 "GomSerializationTest.c"
}


GType gom_book_get_type (void) {
	static volatile gsize gom_book_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBook), 0, (GInstanceInitFunc) gom_book_instance_init, NULL };
		GType gom_book_type_id;
		gom_book_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBook", &g_define_type_info, 0);
		g_once_init_leave (&gom_book_type_id__volatile, gom_book_type_id);
	}
	return gom_book_type_id__volatile;
}


static void _vala_gom_book_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK, GomBook);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_YEAR_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_book_get_year (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_ISBN_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_book_get_isbn (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_NAME_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_name (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_AUTHORS_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_authors (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_INVENTORY_REGISTERS_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_inventory_registers (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_CATEGORIES_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_categories (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_RESUMES_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_get_resumes (self));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5366 "GomSerializationTest.c"
		default:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5372 "GomSerializationTest.c"
	}
}


static void _vala_gom_book_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK, GomBook);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_YEAR_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_year (self, g_value_get_string (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_ISBN_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_isbn (self, g_value_get_string (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_NAME_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_name (self, g_value_get_object (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_AUTHORS_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_authors (self, g_value_get_object (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_INVENTORY_REGISTERS_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_inventory_registers (self, g_value_get_object (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_CATEGORIES_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_categories (self, g_value_get_object (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_RESUMES_PROPERTY:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_set_resumes (self, g_value_get_object (value));
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5424 "GomSerializationTest.c"
		default:
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 168 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5430 "GomSerializationTest.c"
	}
}


GomBookStore* gom_book_store_construct (GType object_type) {
	GomBookStore * self = NULL;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomBookStore*) gxml_gom_element_construct (object_type);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 5441 "GomSerializationTest.c"
}


GomBookStore* gom_book_store_new (void) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_book_store_construct (TYPE_GOM_BOOK_STORE);
#line 5448 "GomSerializationTest.c"
}


const gchar* gom_book_store_get_name (GomBookStore* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5463 "GomSerializationTest.c"
}


void gom_book_store_set_name (GomBookStore* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 5482 "GomSerializationTest.c"
}


GomBookArray* gom_book_store_get_books (GomBookStore* self) {
	GomBookArray* result;
	GomBookArray* _tmp0_ = NULL;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5497 "GomSerializationTest.c"
}


void gom_book_store_set_books (GomBookStore* self, GomBookArray* value) {
	GomBookArray* _tmp0_ = NULL;
	GomBookArray* _tmp1_ = NULL;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_books = _tmp1_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "books");
#line 5516 "GomSerializationTest.c"
}


static GObject * gom_book_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomBookStore * self;
	GError * _inner_error_ = NULL;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_book_store_parent_class);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 5531 "GomSerializationTest.c"
	{
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStore");
#line 5535 "GomSerializationTest.c"
	}
	goto __finally300;
	__catch300_g_error:
	{
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5546 "GomSerializationTest.c"
	}
	__finally300:
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 5555 "GomSerializationTest.c"
	}
#line 195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 5559 "GomSerializationTest.c"
}


static void gom_book_store_class_init (GomBookStoreClass * klass) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_book_store_parent_class = g_type_class_peek_parent (klass);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomBookStorePrivate));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_book_store_get_property;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_book_store_set_property;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_book_store_constructor;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_book_store_finalize;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_STORE_NAME_PROPERTY, g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BOOK_STORE_BOOKS_PROPERTY, g_param_spec_object ("books", "books", "books", GOM_BOOK_TYPE_ARRAY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5580 "GomSerializationTest.c"
}


static void gom_book_store_instance_init (GomBookStore * self) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_BOOK_STORE_GET_PRIVATE (self);
#line 5587 "GomSerializationTest.c"
}


static void gom_book_store_finalize (GObject* obj) {
	GomBookStore * self;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_book_store_parent_class)->finalize (obj);
#line 5601 "GomSerializationTest.c"
}


GType gom_book_store_get_type (void) {
	static volatile gsize gom_book_store_type_id__volatile = 0;
	if (g_once_init_enter (&gom_book_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBookStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_book_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBookStore), 0, (GInstanceInitFunc) gom_book_store_instance_init, NULL };
		GType gom_book_store_type_id;
		gom_book_store_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBookStore", &g_define_type_info, 0);
		g_once_init_leave (&gom_book_store_type_id__volatile, gom_book_store_type_id);
	}
	return gom_book_store_type_id__volatile;
}


static void _vala_gom_book_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_STORE_NAME_PROPERTY:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_book_store_get_name (self));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_STORE_BOOKS_PROPERTY:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_book_store_get_books (self));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5634 "GomSerializationTest.c"
		default:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5640 "GomSerializationTest.c"
	}
}


static void _vala_gom_book_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BOOK_STORE, GomBookStore);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_STORE_NAME_PROPERTY:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_store_set_name (self, g_value_get_string (value));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BOOK_STORE_BOOKS_PROPERTY:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_book_store_set_books (self, g_value_get_object (value));
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5662 "GomSerializationTest.c"
		default:
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 5668 "GomSerializationTest.c"
	}
}


GomBasicTypes* gom_basic_types_construct (GType object_type) {
	GomBasicTypes * self = NULL;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomBasicTypes*) gxml_gom_element_construct (object_type);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 5679 "GomSerializationTest.c"
}


GomBasicTypes* gom_basic_types_new (void) {
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_basic_types_construct (TYPE_GOM_BASIC_TYPES);
#line 5686 "GomSerializationTest.c"
}


const gchar* gom_basic_types_get_text (GomBasicTypes* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_text;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5701 "GomSerializationTest.c"
}


void gom_basic_types_set_text (GomBasicTypes* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_text = _tmp1_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "text");
#line 5720 "GomSerializationTest.c"
}


gint gom_basic_types_get_integer (GomBasicTypes* self) {
	gint result;
	gint _tmp0_ = 0;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_integer;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5735 "GomSerializationTest.c"
}


void gom_basic_types_set_integer (GomBasicTypes* self, gint value) {
	gint _tmp0_ = 0;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_integer = _tmp0_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "integer");
#line 5749 "GomSerializationTest.c"
}


gdouble gom_basic_types_get_real_double (GomBasicTypes* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_real_double;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5764 "GomSerializationTest.c"
}


void gom_basic_types_set_real_double (GomBasicTypes* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_real_double = _tmp0_;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "real-double");
#line 5778 "GomSerializationTest.c"
}


gfloat gom_basic_types_get_real_float (GomBasicTypes* self) {
	gfloat result;
	gfloat _tmp0_ = 0.0F;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0F);
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_real_float;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5793 "GomSerializationTest.c"
}


void gom_basic_types_set_real_float (GomBasicTypes* self, gfloat value) {
	gfloat _tmp0_ = 0.0F;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_real_float = _tmp0_;
#line 208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "real-float");
#line 5807 "GomSerializationTest.c"
}


guint gom_basic_types_get_unsigned_integer (GomBasicTypes* self) {
	guint result;
	guint _tmp0_ = 0U;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0U);
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_unsigned_integer;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5822 "GomSerializationTest.c"
}


void gom_basic_types_set_unsigned_integer (GomBasicTypes* self, guint value) {
	guint _tmp0_ = 0U;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_unsigned_integer = _tmp0_;
#line 210 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "unsigned-integer");
#line 5836 "GomSerializationTest.c"
}


gboolean gom_basic_types_get_boolean (GomBasicTypes* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_boolean;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 5851 "GomSerializationTest.c"
}


void gom_basic_types_set_boolean (GomBasicTypes* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_boolean = _tmp0_;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "boolean");
#line 5865 "GomSerializationTest.c"
}


static GObject * gom_basic_types_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomBasicTypes * self;
	GError * _inner_error_ = NULL;
#line 213 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_basic_types_parent_class);
#line 213 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 213 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 5880 "GomSerializationTest.c"
	{
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "GomBasicTypes");
#line 5884 "GomSerializationTest.c"
	}
	goto __finally301;
	__catch301_g_error:
	{
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 5895 "GomSerializationTest.c"
	}
	__finally301:
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 214 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 5904 "GomSerializationTest.c"
	}
#line 213 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 5908 "GomSerializationTest.c"
}


static void gom_basic_types_class_init (GomBasicTypesClass * klass) {
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_basic_types_parent_class = g_type_class_peek_parent (klass);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomBasicTypesPrivate));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_basic_types_get_property;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_basic_types_set_property;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_basic_types_constructor;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_basic_types_finalize;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_TEXT_PROPERTY, g_param_spec_string ("text", "::text", "text", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_INTEGER_PROPERTY, g_param_spec_int ("integer", "::integer", "integer", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY, g_param_spec_double ("real-double", "::realDouble", "real-double", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY, g_param_spec_float ("real-float", "::realFloat", "real-float", -G_MAXFLOAT, G_MAXFLOAT, 0.0F, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY, g_param_spec_uint ("unsigned-integer", "::unsignedInteger", "unsigned-integer", 0, G_MAXUINT, 0U, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_BASIC_TYPES_BOOLEAN_PROPERTY, g_param_spec_boolean ("boolean", "::Boolean", "boolean", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5937 "GomSerializationTest.c"
}


static void gom_basic_types_instance_init (GomBasicTypes * self) {
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_BASIC_TYPES_GET_PRIVATE (self);
#line 5944 "GomSerializationTest.c"
}


static void gom_basic_types_finalize (GObject* obj) {
	GomBasicTypes * self;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_text);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_basic_types_parent_class)->finalize (obj);
#line 5956 "GomSerializationTest.c"
}


GType gom_basic_types_get_type (void) {
	static volatile gsize gom_basic_types_type_id__volatile = 0;
	if (g_once_init_enter (&gom_basic_types_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomBasicTypesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_basic_types_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomBasicTypes), 0, (GInstanceInitFunc) gom_basic_types_instance_init, NULL };
		GType gom_basic_types_type_id;
		gom_basic_types_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomBasicTypes", &g_define_type_info, 0);
		g_once_init_leave (&gom_basic_types_type_id__volatile, gom_basic_types_type_id);
	}
	return gom_basic_types_type_id__volatile;
}


static void _vala_gom_basic_types_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomBasicTypes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_TEXT_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_basic_types_get_text (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_INTEGER_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_int (value, gom_basic_types_get_integer (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_double (value, gom_basic_types_get_real_double (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_float (value, gom_basic_types_get_real_float (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_uint (value, gom_basic_types_get_unsigned_integer (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_BOOLEAN_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_boolean (value, gom_basic_types_get_boolean (self));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 6013 "GomSerializationTest.c"
		default:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 6019 "GomSerializationTest.c"
	}
}


static void _vala_gom_basic_types_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomBasicTypes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_GOM_BASIC_TYPES, GomBasicTypes);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_TEXT_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_text (self, g_value_get_string (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_INTEGER_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_integer (self, g_value_get_int (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_DOUBLE_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_real_double (self, g_value_get_double (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_REAL_FLOAT_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_real_float (self, g_value_get_float (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_UNSIGNED_INTEGER_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_unsigned_integer (self, g_value_get_uint (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_BASIC_TYPES_BOOLEAN_PROPERTY:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_boolean (self, g_value_get_boolean (value));
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 6065 "GomSerializationTest.c"
		default:
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 6071 "GomSerializationTest.c"
	}
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 6092 "GomSerializationTest.c"
}


static void __lambda261_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlXParser* _tmp1_ = NULL;
		gchar* s = NULL;
		gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 521 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 521 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp0_;
#line 522 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gxml_xparser_new ((GXmlDomNode*) b);
#line 522 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		parser = _tmp1_;
#line 523 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp2_;
#line 523 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 523 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 6129 "GomSerializationTest.c"
			goto __catch302_g_error;
		}
#line 524 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = s;
#line 524 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 525 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = s;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = string_contains (_tmp4_, "<Book/>");
#line 525 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp5_, "\"<Book/>\" in s");
#line 526 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (b, "My Book");
#line 527 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = gxml_dom_element_get_attribute ((GXmlDomElement*) b, "name");
#line 527 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 527 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "My Book") == 0, "b.get_attribute (\"name\") == \"My Book\"");
#line 527 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 528 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_to_string (b);
#line 528 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 528 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp8_;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 6164 "GomSerializationTest.c"
	}
	goto __finally302;
	__catch302_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 533 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = e->message;
#line 533 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = g_strconcat ("Error: ", _tmp9_, NULL);
#line 533 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 533 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:533: %s", _tmp11_);
#line 533 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp11_);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 6191 "GomSerializationTest.c"
	}
	__finally302:
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 6202 "GomSerializationTest.c"
	}
}


static void ___lambda261__gtest_func (void) {
#line 519 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda261_ ();
#line 6210 "GomSerializationTest.c"
}


static void __lambda262_ (void) {
	GomSerializationTestComputer* c = NULL;
	GomSerializationTestComputer* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
#line 538 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_computer_new ();
#line 538 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	c = _tmp0_;
#line 539 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_computer_to_string (c);
#line 539 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = s;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 541 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = s;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = string_contains (_tmp3_, "<Computer/>");
#line 541 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp4_, "\"<Computer/>\" in s");
#line 542 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_computer_set_model (c, "T3456-E");
#line 543 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_computer_set_ignore (c, "Nothing");
#line 544 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = gom_serialization_test_computer_get_model (c);
#line 544 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 544 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp6_, "T3456-E") == 0, "c.model == \"T3456-E\"");
#line 545 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = gxml_dom_element_get_attribute ((GXmlDomElement*) c, "model");
#line 545 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = _tmp7_;
#line 545 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp8_, "T3456-E") == 0, "c.get_attribute (\"model\") == \"T3456-E\"");
#line 545 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp8_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = gom_serialization_test_computer_get_ignore (c);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp10_, "Nothing") == 0, "c.ignore == \"Nothing\"");
#line 547 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = gxml_dom_element_get_attribute ((GXmlDomElement*) c, "ignore");
#line 547 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 547 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp12_ == NULL, "c.get_attribute (\"ignore\") == null");
#line 547 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp12_);
#line 548 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = gom_serialization_test_computer_to_string (c);
#line 548 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 548 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp13_;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (c);
#line 6291 "GomSerializationTest.c"
}


static void ___lambda262__gtest_func (void) {
#line 537 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda262_ ();
#line 6298 "GomSerializationTest.c"
}


static void __lambda263_ (void) {
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	const gchar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	const gchar* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	gdouble _tmp11_ = 0.0;
	gdouble _tmp12_ = 0.0;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gboolean _tmp15_ = FALSE;
	gchar* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gboolean _tmp18_ = FALSE;
	GomSerializationTestTaxesMonth _tmp19_ = 0;
	GomSerializationTestTaxesMonth _tmp20_ = 0;
	gchar* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gboolean _tmp23_ = FALSE;
	gboolean _tmp24_ = FALSE;
	gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	const gchar* _tmp28_ = NULL;
	gboolean _tmp29_ = FALSE;
	const gchar* _tmp30_ = NULL;
	gboolean _tmp31_ = FALSE;
	const gchar* _tmp32_ = NULL;
	gboolean _tmp33_ = FALSE;
	const gchar* _tmp34_ = NULL;
	gboolean _tmp35_ = FALSE;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 554 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	t = _tmp0_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = s;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 560 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = s;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = string_contains (_tmp3_, "<Taxes ");
#line 560 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp4_, "\"<Taxes \" in s");
#line 561 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = s;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = string_contains (_tmp5_, "monthRate=\"0\"");
#line 561 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp6_, "\"monthRate=\\\"0\\\"\" in s");
#line 562 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = s;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = string_contains (_tmp7_, "Month=\"january\"");
#line 562 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp8_, "\"Month=\\\"january\\\"\" in s");
#line 563 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = s;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = string_contains (_tmp9_, "TaxFree=\"false\"");
#line 563 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp10_, "\"TaxFree=\\\"false\\\"\" in s");
#line 564 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_set_month_rate (t, 16.5);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_taxes_get_month_rate (t);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = g_strdup_printf ("%.2f", _tmp12_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp14_ = _tmp13_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp15_ = string_contains (_tmp14_, "16.5");
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp15_, "\"16.5\" in \"%.2f\".printf (t.month_rate)");
#line 565 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp14_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp16_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "monthrate");
#line 566 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp17_ = _tmp16_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp18_ = string_contains (_tmp17_, "16.5");
#line 566 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp18_, "\"16.5\" in t.get_attribute (\"monthrate\")");
#line 566 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp17_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_set_month (t, GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp19_ = gom_serialization_test_taxes_get_month (t);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp20_ == GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY, "t.month == Taxes.Month.FEBRUARY");
#line 569 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp21_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "month");
#line 569 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp22_ = _tmp21_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp22_, "february") == 0, "t.get_attribute (\"month\") == \"february\"");
#line 569 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp22_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_set_tax_free (t, TRUE);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp23_ = gom_serialization_test_taxes_get_tax_free (t);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp24_ = _tmp23_;
#line 571 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp24_ == TRUE, "t.tax_free == true");
#line 572 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp25_ = gxml_dom_element_get_attribute ((GXmlDomElement*) t, "taxfree");
#line 572 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp26_, "true") == 0, "t.get_attribute (\"taxfree\") == \"true\"");
#line 572 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp26_);
#line 573 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp27_ = gom_serialization_test_taxes_to_string (t);
#line 573 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 573 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp27_;
#line 574 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp28_ = s;
#line 574 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp29_ = string_contains (_tmp28_, "<Taxes ");
#line 574 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp29_, "\"<Taxes \" in s");
#line 575 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp30_ = s;
#line 575 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp31_ = string_contains (_tmp30_, "monthRate=\"16.5\"");
#line 575 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp31_, "\"monthRate=\\\"16.5\\\"\" in s");
#line 576 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp32_ = s;
#line 576 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp33_ = string_contains (_tmp32_, "Month=\"february\"");
#line 576 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp33_, "\"Month=\\\"february\\\"\" in s");
#line 577 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp34_ = s;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp35_ = string_contains (_tmp34_, "TaxFree=\"true\"");
#line 577 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp35_, "\"TaxFree=\\\"true\\\"\" in s");
#line 553 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 6469 "GomSerializationTest.c"
}


static void ___lambda263__gtest_func (void) {
#line 553 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda263_ ();
#line 6476 "GomSerializationTest.c"
}


static void __lambda264_ (void) {
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	const gchar* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	const gchar* _tmp7_ = NULL;
	gboolean _tmp8_ = FALSE;
	const gchar* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GXmlGomDate* _tmp11_ = NULL;
	GXmlGomDate* _tmp12_ = NULL;
	GDate d = {0};
	gboolean _tmp13_ = FALSE;
	GXmlGomDate* _tmp14_ = NULL;
	GXmlGomDate* _tmp15_ = NULL;
	GXmlGomDate* _tmp16_ = NULL;
	GXmlGomDate* _tmp17_ = NULL;
	GDate _tmp18_ = {0};
	GXmlGomDate* _tmp19_ = NULL;
	GXmlGomDate* _tmp20_ = NULL;
	GDate _tmp21_ = {0};
	gboolean _tmp22_ = FALSE;
	GXmlGomDate* _tmp23_ = NULL;
	GXmlGomDate* _tmp24_ = NULL;
	gchar* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	GXmlGomDate* _tmp28_ = NULL;
	GXmlGomDate* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	gchar* _tmp32_ = NULL;
	GXmlGomDate* _tmp33_ = NULL;
	GXmlGomDate* _tmp34_ = NULL;
	GXmlGomDate* _tmp35_ = NULL;
	GXmlGomDate* _tmp36_ = NULL;
	GDate _tmp37_ = {0};
	gboolean _tmp38_ = FALSE;
	GXmlGomDate* _tmp39_ = NULL;
	GXmlGomDate* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	GXmlGomDate* _tmp44_ = NULL;
	GXmlGomDate* _tmp45_ = NULL;
	gchar* _tmp46_ = NULL;
	gchar* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	GXmlGomDate* _tmp49_ = NULL;
	GXmlGomDate* _tmp50_ = NULL;
	GXmlGomDate* _tmp51_ = NULL;
	GXmlGomDate* _tmp52_ = NULL;
	GDate _tmp53_ = {0};
	gboolean _tmp54_ = FALSE;
	GXmlGomDate* _tmp55_ = NULL;
	GXmlGomDate* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	gchar* _tmp59_ = NULL;
	GXmlGomDate* _tmp60_ = NULL;
	GXmlGomDate* _tmp61_ = NULL;
	gchar* _tmp62_ = NULL;
	gchar* _tmp63_ = NULL;
	gchar* _tmp64_ = NULL;
	gchar* _tmp65_ = NULL;
	const gchar* _tmp66_ = NULL;
	const gchar* _tmp67_ = NULL;
	gboolean _tmp68_ = FALSE;
	GXmlGomDate* gd = NULL;
	GXmlGomDate* _tmp69_ = NULL;
	GDate _tmp70_ = {0};
	gboolean _tmp71_ = FALSE;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	gchar* _tmp74_ = NULL;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 583 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	t = _tmp0_;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = s;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 589 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = s;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = string_contains (_tmp3_, "<Taxes ");
#line 589 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp4_, "\"<Taxes \" in s");
#line 590 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = s;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = string_contains (_tmp5_, "monthRate=\"0\"");
#line 590 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp6_, "\"monthRate=\\\"0\\\"\" in s");
#line 591 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = s;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = string_contains (_tmp7_, "Month=\"january\"");
#line 591 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp8_, "\"Month=\\\"january\\\"\" in s");
#line 592 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = s;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = string_contains (_tmp9_, "TaxFree=\"false\"");
#line 592 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp10_, "\"TaxFree=\\\"false\\\"\" in s");
#line 593 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = gxml_gom_date_new ();
#line 593 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_set_pay_date (t, _tmp12_);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp12_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	memset (&d, 0, sizeof (GDate));
#line 595 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_date_set_dmy (&d, (GDateDay) 1, (gint) ((GDateMonth) 2), (GDateYear) 2017);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = g_date_valid (&d);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp13_, "d.valid ()");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp14_ = gom_serialization_test_taxes_get_pay_date (t);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp15_ = _tmp14_;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp15_ != NULL, "t.pay_date != null");
#line 598 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp16_ = gom_serialization_test_taxes_get_pay_date (t);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp17_ = _tmp16_;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp18_ = d;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_set_date (_tmp17_, &_tmp18_);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp19_ = gom_serialization_test_taxes_get_pay_date (t);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 599 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp20_, &_tmp21_);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp22_ = g_date_valid (&_tmp21_);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp22_, "t.pay_date.get_date ().valid ()");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp23_ = gom_serialization_test_taxes_get_pay_date (t);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp24_ = _tmp23_;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp25_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp24_);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp27_ = _tmp26_;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp27_ != NULL, "t.pay_date.value != null");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp27_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp28_ = gom_serialization_test_taxes_get_pay_date (t);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp29_ = _tmp28_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp30_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp29_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp31_ = _tmp30_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp32_ = _tmp31_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp32_, "2017-02-01") == 0, "t.pay_date.value == \"2017-02-01\"");
#line 601 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp32_);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp33_ = gom_serialization_test_taxes_get_pay_date (t);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp34_ = _tmp33_;
#line 602 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp34_, "2023-3-10");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp35_ = gom_serialization_test_taxes_get_pay_date (t);
#line 603 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp36_ = _tmp35_;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp36_, &_tmp37_);
#line 603 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp38_ = g_date_valid (&_tmp37_);
#line 603 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp38_, "t.pay_date.get_date ().valid ()");
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp39_ = gom_serialization_test_taxes_get_pay_date (t);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp40_ = _tmp39_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp41_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp40_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp42_ = _tmp41_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp43_ = _tmp42_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp43_ != NULL, "t.pay_date.value != null");
#line 604 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp43_);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp44_ = gom_serialization_test_taxes_get_pay_date (t);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp45_ = _tmp44_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp46_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp45_);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp47_ = _tmp46_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp48_ = _tmp47_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp48_, "2023-03-10") == 0, "t.pay_date.value == \"2023-03-10\"");
#line 605 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp48_);
#line 606 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp49_ = gom_serialization_test_taxes_get_pay_date (t);
#line 606 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp50_ = _tmp49_;
#line 606 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp50_, "2075-3-17");
#line 607 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp51_ = gom_serialization_test_taxes_get_pay_date (t);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp52_ = _tmp51_;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_get_date (_tmp52_, &_tmp53_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp54_ = g_date_valid (&_tmp53_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp54_, "t.pay_date.get_date ().valid ()");
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp55_ = gom_serialization_test_taxes_get_pay_date (t);
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp56_ = _tmp55_;
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp57_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp56_);
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp58_ = _tmp57_;
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp59_ = _tmp58_;
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp59_ != NULL, "t.pay_date.value != null");
#line 608 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp59_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp60_ = gom_serialization_test_taxes_get_pay_date (t);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp61_ = _tmp60_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp62_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp61_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp63_ = _tmp62_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp64_ = _tmp63_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp64_, "2075-03-17") == 0, "t.pay_date.value == \"2075-03-17\"");
#line 609 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp64_);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp65_ = gom_serialization_test_taxes_to_string (t);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp65_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp66_ = s;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp66_ != NULL, "s != null");
#line 612 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp67_ = s;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp68_ = string_contains (_tmp67_, "PayDate=\"2075-03-17\"");
#line 612 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp68_, "\"PayDate=\\\"2075-03-17\\\"\" in s");
#line 613 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp69_ = gxml_gom_date_new ();
#line 613 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gd = _tmp69_;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) gd, "2076-03-17");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_get_date (gd, &_tmp70_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp71_ = g_date_valid (&_tmp70_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp71_, "gd.get_date ().valid ()");
#line 616 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp72_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) gd);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp73_ = _tmp72_;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp74_ = _tmp73_;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp74_, "2076-03-17") == 0, "gd.value == \"2076-03-17\"");
#line 616 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp74_);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (gd);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 6796 "GomSerializationTest.c"
}


static void ___lambda264__gtest_func (void) {
#line 582 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda264_ ();
#line 6803 "GomSerializationTest.c"
}


static void __lambda265_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestTaxes* t = NULL;
		GomSerializationTestTaxes* _tmp0_ = NULL;
		gchar* s = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		gboolean _tmp5_ = FALSE;
		gboolean _tmp6_ = FALSE;
		gboolean _tmp7_ = FALSE;
		GXmlGomDate* _tmp8_ = NULL;
		GXmlGomDate* _tmp9_ = NULL;
		GXmlGomDate* _tmp10_ = NULL;
		GXmlGomDate* _tmp11_ = NULL;
		GDate _tmp12_ = {0};
		gboolean _tmp13_ = FALSE;
		GXmlGomDate* _tmp14_ = NULL;
		GXmlGomDate* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlGomDate* _tmp19_ = NULL;
		GXmlGomDate* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_taxes_new ();
#line 620 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		t = _tmp0_;
#line 621 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) t, "<Taxes PayDate=\"2050-12-09\"/>", &_inner_error_);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 621 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (t);
#line 6846 "GomSerializationTest.c"
			goto __catch303_g_error;
		}
#line 622 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp1_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (s != NULL, "s != null");
#line 625 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_strconcat ("DOC:", s, NULL);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:625: %s", _tmp3_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp3_);
#line 627 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = string_contains (s, "<Taxes ");
#line 627 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp4_, "\"<Taxes \" in s");
#line 628 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = string_contains (s, "monthRate=\"0\"");
#line 628 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp5_, "\"monthRate=\\\"0\\\"\" in s");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = string_contains (s, "Month=\"january\"");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp6_, "\"Month=\\\"january\\\"\" in s");
#line 630 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = string_contains (s, "TaxFree=\"false\"");
#line 630 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp7_, "\"TaxFree=\\\"false\\\"\" in s");
#line 631 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_taxes_get_pay_date (t);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp9_ != NULL, "t.pay_date != null");
#line 632 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_taxes_get_pay_date (t);
#line 632 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 632 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_date_get_date (_tmp11_, &_tmp12_);
#line 632 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = g_date_valid (&_tmp12_);
#line 632 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp13_, "t.pay_date.get_date ().valid ()");
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_taxes_get_pay_date (t);
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp15_);
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = _tmp17_;
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp18_ != NULL, "t.pay_date.value != null");
#line 633 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp18_);
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = gom_serialization_test_taxes_get_pay_date (t);
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp20_);
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "2050-12-09") == 0, "t.pay_date.value == \"2050-12-09\"");
#line 634 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp23_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (t);
#line 6927 "GomSerializationTest.c"
	}
	goto __finally303;
	__catch303_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = e->message;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = g_strconcat ("Error: ", _tmp24_, NULL);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:636: %s", _tmp26_);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp26_);
#line 637 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 6954 "GomSerializationTest.c"
	}
	__finally303:
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 6965 "GomSerializationTest.c"
	}
}


static void ___lambda265__gtest_func (void) {
#line 618 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda265_ ();
#line 6973 "GomSerializationTest.c"
}


static void __lambda266_ (void) {
	GomSerializationTestTaxes* t = NULL;
	GomSerializationTestTaxes* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	GXmlGomDateTime* _tmp6_ = NULL;
	GXmlGomDateTime* _tmp7_ = NULL;
	GDateTime* d = NULL;
	GDateTime* _tmp8_ = NULL;
	GXmlGomDateTime* _tmp9_ = NULL;
	GXmlGomDateTime* _tmp10_ = NULL;
	GXmlGomDateTime* _tmp11_ = NULL;
	GXmlGomDateTime* _tmp12_ = NULL;
	GXmlGomDateTime* _tmp13_ = NULL;
	GXmlGomDateTime* _tmp14_ = NULL;
	GXmlGomDateTime* _tmp15_ = NULL;
	GXmlGomDateTime* _tmp16_ = NULL;
	gchar* _tmp17_ = NULL;
	gchar* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	GXmlGomDateTime* _tmp20_ = NULL;
	GXmlGomDateTime* _tmp21_ = NULL;
	gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	GXmlGomDateTime* _tmp25_ = NULL;
	GXmlGomDateTime* _tmp26_ = NULL;
	GXmlGomDateTime* _tmp27_ = NULL;
	GXmlGomDateTime* _tmp28_ = NULL;
	gchar* _tmp29_ = NULL;
	gchar* _tmp30_ = NULL;
	gchar* _tmp31_ = NULL;
	GXmlGomDateTime* _tmp32_ = NULL;
	GXmlGomDateTime* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	gchar* s2 = NULL;
	gchar* _tmp37_ = NULL;
	gboolean _tmp38_ = FALSE;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_taxes_new ();
#line 641 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	t = _tmp0_;
#line 642 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_taxes_to_string (t);
#line 642 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (s != NULL, "s != null");
#line 647 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = string_contains (s, "<Taxes ");
#line 647 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp2_, "\"<Taxes \" in s");
#line 648 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = string_contains (s, "monthRate=\"0\"");
#line 648 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp3_, "\"monthRate=\\\"0\\\"\" in s");
#line 649 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = string_contains (s, "Month=\"january\"");
#line 649 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp4_, "\"Month=\\\"january\\\"\" in s");
#line 650 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = string_contains (s, "TaxFree=\"false\"");
#line 650 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp5_, "\"TaxFree=\\\"false\\\"\" in s");
#line 651 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = gxml_gom_date_time_new ();
#line 651 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = _tmp6_;
#line 651 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_set_timestamp (t, _tmp7_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp7_);
#line 652 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = g_date_time_new_local (2017, 2, 10, 14, 14, 20.345);
#line 652 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	d = _tmp8_;
#line 658 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = gom_serialization_test_taxes_get_timestamp (t);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = _tmp9_;
#line 658 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp10_ != NULL, "t.timestamp != null");
#line 659 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_taxes_get_timestamp (t);
#line 659 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 659 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_date_time_set_datetime (_tmp12_, d);
#line 660 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = gom_serialization_test_taxes_get_timestamp (t);
#line 660 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp14_ = _tmp13_;
#line 660 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp14_ != NULL, "t.timestamp != null");
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp15_ = gom_serialization_test_taxes_get_timestamp (t);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp16_ = _tmp15_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp17_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp16_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp18_ = _tmp17_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp19_ = _tmp18_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp19_ != NULL, "t.timestamp.value != null");
#line 661 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp19_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp20_ = gom_serialization_test_taxes_get_timestamp (t);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp21_ = _tmp20_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp22_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp21_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp23_ = _tmp22_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp24_ = _tmp23_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp24_, "2017-02-10T14:14:20") == 0, "t.timestamp.value == \"2017-02-10T14:14:20\"");
#line 662 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp24_);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp25_ = gom_serialization_test_taxes_get_timestamp (t);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp26_, "2023-3-10T15:23:10.356");
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp27_ = gom_serialization_test_taxes_get_timestamp (t);
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp28_ = _tmp27_;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp29_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp28_);
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp30_ = _tmp29_;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp31_ = _tmp30_;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp31_ != NULL, "t.timestamp.value != null");
#line 664 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp31_);
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp32_ = gom_serialization_test_taxes_get_timestamp (t);
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp33_ = _tmp32_;
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp34_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp33_);
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp35_ = _tmp34_;
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp36_ = _tmp35_;
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp36_, "2023-03-10T15:23:10") == 0, "t.timestamp.value == \"2023-03-10T15:23:10\"");
#line 665 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp36_);
#line 666 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp37_ = gom_serialization_test_taxes_to_string (t);
#line 666 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s2 = _tmp37_;
#line 667 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (s2 != NULL, "s2 != null");
#line 671 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp38_ = string_contains (s2, "Timestamp=\"2023-03-10T15:23:10\"");
#line 671 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp38_, "\"Timestamp=\\\"2023-03-10T15:23:10\\\"\" in s2");
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s2);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_date_time_unref0 (d);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (t);
#line 7157 "GomSerializationTest.c"
}


static void ___lambda266__gtest_func (void) {
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda266_ ();
#line 7164 "GomSerializationTest.c"
}


static void __lambda267_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		GomSerializationTestBookStand* _tmp6_ = NULL;
		GXmlDomDocument* _tmp7_ = NULL;
		GXmlDomDocument* _tmp8_ = NULL;
		GomSerializationTestBookStand* _tmp9_ = NULL;
		GomSerializationTestRegisters* _tmp10_ = NULL;
		GomSerializationTestRegisters* _tmp11_ = NULL;
		GomSerializationTestBookStand* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		GomSerializationTestBookStand* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		GomSerializationTestBookRegister* br2 = NULL;
		GomSerializationTestBookStand* _tmp24_ = NULL;
		GomSerializationTestRegisters* _tmp25_ = NULL;
		GomSerializationTestRegisters* _tmp26_ = NULL;
		GXmlGomElement* _tmp27_ = NULL;
		GomSerializationTestBookRegister* _tmp28_ = NULL;
		GomSerializationTestBookRegister* _tmp29_ = NULL;
		GomSerializationTestBookStand* _tmp30_ = NULL;
		GomSerializationTestRegisters* _tmp31_ = NULL;
		GomSerializationTestRegisters* _tmp32_ = NULL;
		GomSerializationTestBookRegister* _tmp33_ = NULL;
		GomSerializationTestBookStand* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		gboolean _tmp38_ = FALSE;
		GomSerializationTestBookRegister* br3 = NULL;
		GomSerializationTestBookStand* _tmp39_ = NULL;
		GomSerializationTestRegisters* _tmp40_ = NULL;
		GomSerializationTestRegisters* _tmp41_ = NULL;
		GXmlGomElement* _tmp42_ = NULL;
		GomSerializationTestBookRegister* _tmp43_ = NULL;
		GomSerializationTestBookStand* _tmp44_ = NULL;
		GomSerializationTestRegisters* _tmp45_ = NULL;
		GomSerializationTestRegisters* _tmp46_ = NULL;
		GomSerializationTestBookRegister* _tmp47_ = NULL;
		GomSerializationTestBookRegister* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GomSerializationTestBookStand* _tmp50_ = NULL;
		GXmlDomDocument* _tmp51_ = NULL;
		GXmlDomDocument* _tmp52_ = NULL;
		GXmlDomElement* _tmp53_ = NULL;
		GomSerializationTestBookStand* _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		GomSerializationTestBookRegister* br4 = NULL;
		GomSerializationTestBookStand* _tmp57_ = NULL;
		GomSerializationTestRegisters* _tmp58_ = NULL;
		GomSerializationTestRegisters* _tmp59_ = NULL;
		GXmlGomElement* _tmp60_ = NULL;
		GomSerializationTestBookRegister* _tmp61_ = NULL;
		GomSerializationTestBookStand* _tmp62_ = NULL;
		GomSerializationTestRegisters* _tmp63_ = NULL;
		GomSerializationTestRegisters* _tmp64_ = NULL;
		GomSerializationTestBookRegister* _tmp65_ = NULL;
		GomSerializationTestBookRegister* _tmp66_ = NULL;
		GomSerializationTestBookStand* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		const gchar* _tmp69_ = NULL;
		const gchar* _tmp70_ = NULL;
		gboolean _tmp71_ = FALSE;
		GXmlDomElement* _tmp72_ = NULL;
		GomSerializationTestBookStand* _tmp73_ = NULL;
		GomSerializationTestRegisters* _tmp74_ = NULL;
		GomSerializationTestRegisters* _tmp75_ = NULL;
		GXmlDomElement* _tmp76_ = NULL;
		gint _tmp77_ = 0;
		gint _tmp78_ = 0;
		GXmlDomElement* _tmp79_ = NULL;
		GomSerializationTestBookStand* _tmp80_ = NULL;
		GomSerializationTestRegisters* _tmp81_ = NULL;
		GomSerializationTestRegisters* _tmp82_ = NULL;
		GXmlDomElement* _tmp83_ = NULL;
		gint _tmp84_ = 0;
		gint _tmp85_ = 0;
		GXmlDomElement* _tmp86_ = NULL;
		GomSerializationTestBookStand* _tmp87_ = NULL;
		GomSerializationTestRegisters* _tmp88_ = NULL;
		GomSerializationTestRegisters* _tmp89_ = NULL;
		GXmlDomElement* _tmp90_ = NULL;
		gint _tmp91_ = 0;
		gint _tmp92_ = 0;
		GomSerializationTestBookStand* _tmp93_ = NULL;
		gboolean _tmp94_ = FALSE;
		GomSerializationTestBookStand* _tmp95_ = NULL;
		GomSerializationTestBookStandDimension* _tmp96_ = NULL;
		GomSerializationTestBookStandDimension* _tmp97_ = NULL;
		GomSerializationTestBookStand* _tmp98_ = NULL;
		GomSerializationTestBookStandDimension* _tmp99_ = NULL;
		GomSerializationTestBookStandDimension* _tmp100_ = NULL;
		gdouble _tmp101_ = 0.0;
		gdouble _tmp102_ = 0.0;
		GomSerializationTestBookStand* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		const gchar* _tmp105_ = NULL;
		const gchar* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		gchar* _tmp108_ = NULL;
		const gchar* _tmp109_ = NULL;
		gboolean _tmp110_ = FALSE;
		GomSerializationTestBookStand* _tmp111_ = NULL;
		gboolean _tmp112_ = FALSE;
		GomSerializationTestBookStand* _tmp113_ = NULL;
		GomSerializationTestBookStandDimensionY* _tmp114_ = NULL;
		GomSerializationTestBookStandDimensionY* _tmp115_ = NULL;
		GomSerializationTestBookStand* _tmp116_ = NULL;
		GomSerializationTestBookStandDimensionY* _tmp117_ = NULL;
		GomSerializationTestBookStandDimensionY* _tmp118_ = NULL;
		gdouble _tmp119_ = 0.0;
		gdouble _tmp120_ = 0.0;
		GomSerializationTestBookStand* _tmp121_ = NULL;
		gchar* _tmp122_ = NULL;
		const gchar* _tmp123_ = NULL;
		const gchar* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
		gchar* _tmp126_ = NULL;
		const gchar* _tmp127_ = NULL;
		gboolean _tmp128_ = FALSE;
		GomSerializationTestBookStand* _tmp129_ = NULL;
		gboolean _tmp130_ = FALSE;
		GomSerializationTestBookStand* _tmp131_ = NULL;
		GomSerializationTestBookStandDimensionZ* _tmp132_ = NULL;
		GomSerializationTestBookStandDimensionZ* _tmp133_ = NULL;
		GomSerializationTestBookStand* _tmp134_ = NULL;
		GomSerializationTestBookStandDimensionZ* _tmp135_ = NULL;
		GomSerializationTestBookStandDimensionZ* _tmp136_ = NULL;
		gdouble _tmp137_ = 0.0;
		gdouble _tmp138_ = 0.0;
		GomSerializationTestBookStand* _tmp139_ = NULL;
		gchar* _tmp140_ = NULL;
		const gchar* _tmp141_ = NULL;
		const gchar* _tmp142_ = NULL;
		gchar* _tmp143_ = NULL;
		gchar* _tmp144_ = NULL;
		const gchar* _tmp145_ = NULL;
		gboolean _tmp146_ = FALSE;
#line 675 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 675 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = bs;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp2_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = s;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 681 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = s;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = string_contains (_tmp4_, "<BookStand Classification=\"Science\"/>");
#line 681 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp5_, "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 682 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = bs;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp6_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp8_ != NULL, "bs.owner_document != null");
#line 683 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = bs;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_stand_get_registers (_tmp9_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp11_ == NULL, "bs.registers == null");
#line 684 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = bs;
#line 684 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp12_, "registers");
#line 684 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp13_, "bs.set_instance_property (\"registers\")");
#line 685 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = bs;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gom_serialization_test_book_stand_to_string (_tmp14_);
#line 685 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 685 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp15_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = s;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp16_ != NULL, "s != null");
#line 690 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = s;
#line 690 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = string_contains (_tmp17_, "<BookStand Classification=\"Science\"/>");
#line 690 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp18_, "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 7378 "GomSerializationTest.c"
		{
			GomSerializationTestBookRegister* br = NULL;
			GomSerializationTestBookRegister* _tmp19_ = NULL;
			GomSerializationTestBookStand* _tmp20_ = NULL;
			GomSerializationTestRegisters* _tmp21_ = NULL;
			GomSerializationTestRegisters* _tmp22_ = NULL;
			GomSerializationTestBookRegister* _tmp23_ = NULL;
#line 692 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp19_ = gom_serialization_test_book_register_new ();
#line 692 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			br = _tmp19_;
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp20_ = bs;
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp21_ = gom_serialization_test_book_stand_get_registers (_tmp20_);
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp22_ = _tmp21_;
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp23_ = br;
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			gxml_gom_collection_append ((GXmlGomCollection*) _tmp22_, (GXmlDomElement*) _tmp23_, &_inner_error_);
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 693 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				_g_object_unref0 (br);
#line 7404 "GomSerializationTest.c"
				goto __catch305_g_error;
			}
#line 694 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_assert_not_reached ();
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 7411 "GomSerializationTest.c"
		}
		goto __finally305;
		__catch305_g_error:
		{
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_clear_error (&_inner_error_);
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_inner_error_ = NULL;
#line 7420 "GomSerializationTest.c"
		}
		__finally305:
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 691 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7429 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = bs;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = gom_serialization_test_book_stand_get_registers (_tmp24_);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp26_);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp27_) : NULL;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp28_ == NULL) {
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp27_);
#line 7446 "GomSerializationTest.c"
		}
#line 696 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br2 = _tmp28_;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = br2;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp29_, 2016);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = bs;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = gom_serialization_test_book_stand_get_registers (_tmp30_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = _tmp31_;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = br2;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp32_, (GXmlDomElement*) _tmp33_, &_inner_error_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7472 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 699 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = bs;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = gom_serialization_test_book_stand_to_string (_tmp34_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp35_;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = s;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp36_ != NULL, "s != null");
#line 704 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = s;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = string_contains (_tmp37_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/></B" \
"ookStand>");
#line 704 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp38_, "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/></BookStand>\" in s");
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = bs;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_stand_get_registers (_tmp39_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp41_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp42_) : NULL;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp43_ == NULL) {
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp42_);
#line 7507 "GomSerializationTest.c"
		}
#line 705 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br3 = _tmp43_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = bs;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gom_serialization_test_book_stand_get_registers (_tmp44_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = br3;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp46_, (GXmlDomElement*) _tmp47_, &_inner_error_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7531 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 707 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = br3;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp48_, 2010);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = bs;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp50_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = _tmp51_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = gxml_dom_document_create_element (_tmp52_, "Test", &_inner_error_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp53_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7558 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = bs;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp54_, (GXmlDomNode*) _tmp49_, &_inner_error_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = _tmp55_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp56_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp49_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7581 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = bs;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = gom_serialization_test_book_stand_get_registers (_tmp57_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp59_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp60_) : NULL;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp61_ == NULL) {
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp60_);
#line 7598 "GomSerializationTest.c"
		}
#line 709 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br4 = _tmp61_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = bs;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = gom_serialization_test_book_stand_get_registers (_tmp62_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = _tmp63_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = br4;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp64_, (GXmlDomElement*) _tmp65_, &_inner_error_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp49_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7626 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 711 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = br4;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp66_, 2000);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = bs;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = gom_serialization_test_book_stand_to_string (_tmp67_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp68_;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = s;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp69_ != NULL, "s != null");
#line 717 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = s;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = string_contains (_tmp70_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/></BookSt" \
"and>");
#line 717 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp71_, "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/></BookStand>\" in s");
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = bs;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = gom_serialization_test_book_stand_get_registers (_tmp73_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = _tmp74_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp75_, 0, &_inner_error_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = _tmp76_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp49_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7675 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp72_) : NULL);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp78_ == 2016, "(bs.registers.get_item (0) as BookRegister).year == 2016");
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = bs;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = gom_serialization_test_book_stand_get_registers (_tmp80_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = _tmp81_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp82_, 1, &_inner_error_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = _tmp83_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp72_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp49_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7710 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp79_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp79_) : NULL);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = _tmp84_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp85_ == 2010, "(bs.registers.get_item (1) as BookRegister).year == 2010");
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = bs;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = gom_serialization_test_book_stand_get_registers (_tmp87_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = _tmp88_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp89_, 2, &_inner_error_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = _tmp90_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp79_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp72_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br4);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp49_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br3);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br2);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 7747 "GomSerializationTest.c"
			goto __catch304_g_error;
		}
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp86_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp86_) : NULL);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = _tmp91_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp92_ == 2000, "(bs.registers.get_item (2) as BookRegister).year == 2000");
#line 721 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = bs;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp93_, "Dimension-X");
#line 721 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp94_, "bs.set_instance_property(\"Dimension-X\")");
#line 722 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = bs;
#line 722 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = gom_serialization_test_book_stand_get_dimension_x (_tmp95_);
#line 722 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = _tmp96_;
#line 722 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp97_ != NULL, "bs.dimension_x != null");
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = bs;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = gom_serialization_test_book_stand_get_dimension_x (_tmp98_);
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp100_ = _tmp99_;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp101_ = gom_serialization_test_book_stand_dimension_get_length (_tmp100_);
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = _tmp101_;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp102_ == 1.0, "bs.dimension_x.length == 1.0");
#line 724 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = bs;
#line 724 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = gom_serialization_test_book_stand_to_string (_tmp103_);
#line 724 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 724 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp104_;
#line 725 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp105_ = s;
#line 725 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp105_ != NULL, "s != null");
#line 727 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp106_ = s;
#line 727 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp107_ = g_strconcat ("DOC:", _tmp106_, NULL);
#line 727 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp108_ = _tmp107_;
#line 727 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:727: %s", _tmp108_);
#line 727 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp108_);
#line 729 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp109_ = s;
#line 729 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp110_ = string_contains (_tmp109_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/></BookStand>");
#line 729 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp110_, "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/></BookStand>\" in s");
#line 730 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp111_ = bs;
#line 730 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp112_ = gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp111_, "DimensionY");
#line 730 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp112_, "bs.set_instance_property(\"DimensionY\")");
#line 731 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp113_ = bs;
#line 731 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp114_ = gom_serialization_test_book_stand_get_dimension_y (_tmp113_);
#line 731 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp115_ = _tmp114_;
#line 731 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp115_ != NULL, "bs.dimension_y != null");
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp116_ = bs;
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp117_ = gom_serialization_test_book_stand_get_dimension_y (_tmp116_);
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp118_ = _tmp117_;
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp119_ = gom_serialization_test_book_stand_dimension_get_length ((GomSerializationTestBookStandDimension*) _tmp118_);
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp120_ = _tmp119_;
#line 732 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp120_ == 1.0, "bs.dimension_y.length == 1.0");
#line 733 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp121_ = bs;
#line 733 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp122_ = gom_serialization_test_book_stand_to_string (_tmp121_);
#line 733 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 733 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp122_;
#line 734 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp123_ = s;
#line 734 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp123_ != NULL, "s != null");
#line 736 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp124_ = s;
#line 736 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp125_ = g_strconcat ("DOC:", _tmp124_, NULL);
#line 736 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp126_ = _tmp125_;
#line 736 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:736: %s", _tmp126_);
#line 736 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp126_);
#line 738 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp127_ = s;
#line 738 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp128_ = string_contains (_tmp127_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/><Dimension Length=\"1\" Type=\"y\"/></Book" \
"Stand>");
#line 738 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp128_, "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/><Dimension Length=\\\"1\\\" Type=\\\"y\\\"/></BookStand>\" in s");
#line 739 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp129_ = bs;
#line 739 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp130_ = gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp129_, "::DimensionZ");
#line 739 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp130_, "bs.set_instance_property(\"::DimensionZ\")");
#line 740 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp131_ = bs;
#line 740 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp132_ = gom_serialization_test_book_stand_get_dimension_z (_tmp131_);
#line 740 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp133_ = _tmp132_;
#line 740 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp133_ != NULL, "bs.dimension_z != null");
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp134_ = bs;
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp135_ = gom_serialization_test_book_stand_get_dimension_z (_tmp134_);
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp136_ = _tmp135_;
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp137_ = gom_serialization_test_book_stand_dimension_get_length ((GomSerializationTestBookStandDimension*) _tmp136_);
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp138_ = _tmp137_;
#line 741 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp138_ == 1.0, "bs.dimension_z.length == 1.0");
#line 742 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp139_ = bs;
#line 742 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp140_ = gom_serialization_test_book_stand_to_string (_tmp139_);
#line 742 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 742 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp140_;
#line 743 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp141_ = s;
#line 743 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp141_ != NULL, "s != null");
#line 745 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp142_ = s;
#line 745 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp143_ = g_strconcat ("DOC:", _tmp142_, NULL);
#line 745 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp144_ = _tmp143_;
#line 745 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:745: %s", _tmp144_);
#line 745 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp144_);
#line 747 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp145_ = s;
#line 747 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp146_ = string_contains (_tmp145_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/><Dimensi" \
"on Length=\"1\" Type=\"x\"/><Dimension Length=\"1\" Type=\"y\"/><Dimen" \
"sion Length=\"1\" Type=\"z\"/></BookStand>");
#line 747 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp146_, "\"<BookStand Classification=\\\"Science\\\"><BookRegister Year=\\\"2016\\\"/><BookRegister Year=\\\"2010\\\"/><Test/><BookRegister Year=\\\"2000\\\"/><Dimension Length=\\\"1\\\" Type=\\\"x\\\"/><Dimension Length=\\\"1\\\" Type=\\\"y\\\"/><Dimension Length=\\\"1\\\" Type=\\\"z\\\"/></BookStand>\" in s");
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp86_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp79_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp72_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br4);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp49_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br3);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br2);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 7936 "GomSerializationTest.c"
	}
	goto __finally304;
	__catch304_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp147_ = NULL;
		gchar* _tmp148_ = NULL;
		gchar* _tmp149_ = NULL;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 749 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp147_ = e->message;
#line 749 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp148_ = g_strconcat ("Error: ", _tmp147_, NULL);
#line 749 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp149_ = _tmp148_;
#line 749 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:749: %s", _tmp149_);
#line 749 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp149_);
#line 750 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 7963 "GomSerializationTest.c"
	}
	__finally304:
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 7974 "GomSerializationTest.c"
	}
}


static void ___lambda267__gtest_func (void) {
#line 673 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda267_ ();
#line 7982 "GomSerializationTest.c"
}


static void __lambda268_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStore* bs = NULL;
		GomSerializationTestBookStore* _tmp0_ = NULL;
		gchar* s = NULL;
		GomSerializationTestBookStore* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gboolean _tmp5_ = FALSE;
		GomSerializationTestBookStore* _tmp6_ = NULL;
		GomSerializationTestBooks* _tmp7_ = NULL;
		GomSerializationTestBooks* _tmp8_ = NULL;
		GomSerializationTestBookStore* _tmp9_ = NULL;
		GomSerializationTestBookStore* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gboolean _tmp14_ = FALSE;
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp15_ = NULL;
		GomSerializationTestBookStore* _tmp20_ = NULL;
		GXmlDomDocument* _tmp21_ = NULL;
		GXmlDomDocument* _tmp22_ = NULL;
		GomSerializationTestBook* _tmp23_ = NULL;
		GomSerializationTestBook* _tmp24_ = NULL;
		GomSerializationTestBookStore* _tmp25_ = NULL;
		GomSerializationTestBooks* _tmp26_ = NULL;
		GomSerializationTestBooks* _tmp27_ = NULL;
		GomSerializationTestBook* _tmp28_ = NULL;
		GomSerializationTestBookStore* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		gboolean _tmp33_ = FALSE;
		GomSerializationTestBook* b2 = NULL;
		GomSerializationTestBookStore* _tmp34_ = NULL;
		GXmlDomDocument* _tmp35_ = NULL;
		GXmlDomDocument* _tmp36_ = NULL;
		GomSerializationTestBook* _tmp37_ = NULL;
		GomSerializationTestBook* _tmp38_ = NULL;
		GomSerializationTestBookStore* _tmp39_ = NULL;
		GomSerializationTestBooks* _tmp40_ = NULL;
		GomSerializationTestBooks* _tmp41_ = NULL;
		GomSerializationTestBook* _tmp42_ = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		GomSerializationTestBookStore* _tmp44_ = NULL;
		GXmlDomDocument* _tmp45_ = NULL;
		GXmlDomDocument* _tmp46_ = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GomSerializationTestBookStore* _tmp48_ = NULL;
		GXmlDomNode* _tmp49_ = NULL;
		GXmlDomNode* _tmp50_ = NULL;
		GomSerializationTestBook* b3 = NULL;
		GomSerializationTestBookStore* _tmp51_ = NULL;
		GXmlDomDocument* _tmp52_ = NULL;
		GXmlDomDocument* _tmp53_ = NULL;
		GomSerializationTestBook* _tmp54_ = NULL;
		GomSerializationTestBook* _tmp55_ = NULL;
		GomSerializationTestBookStore* _tmp56_ = NULL;
		GomSerializationTestBooks* _tmp57_ = NULL;
		GomSerializationTestBooks* _tmp58_ = NULL;
		GomSerializationTestBook* _tmp59_ = NULL;
		GomSerializationTestBookStore* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		const gchar* _tmp62_ = NULL;
		const gchar* _tmp63_ = NULL;
		gboolean _tmp64_ = FALSE;
		GomSerializationTestBookStore* _tmp65_ = NULL;
		GomSerializationTestBooks* _tmp66_ = NULL;
		GomSerializationTestBooks* _tmp67_ = NULL;
		GXmlDomElement* _tmp68_ = NULL;
		GXmlDomElement* _tmp69_ = NULL;
		GomSerializationTestBookStore* _tmp70_ = NULL;
		GomSerializationTestBooks* _tmp71_ = NULL;
		GomSerializationTestBooks* _tmp72_ = NULL;
		GXmlDomElement* _tmp73_ = NULL;
		GXmlDomElement* _tmp74_ = NULL;
		GomSerializationTestBookStore* _tmp75_ = NULL;
		GomSerializationTestBooks* _tmp76_ = NULL;
		GomSerializationTestBooks* _tmp77_ = NULL;
		GXmlDomElement* _tmp78_ = NULL;
		GXmlDomElement* _tmp79_ = NULL;
		GomSerializationTestBookStore* _tmp80_ = NULL;
		GomSerializationTestBooks* _tmp81_ = NULL;
		GomSerializationTestBooks* _tmp82_ = NULL;
		GXmlDomElement* _tmp83_ = NULL;
		GomSerializationTestBook* _tmp84_ = NULL;
		GomSerializationTestBook* _tmp85_ = NULL;
		const gchar* _tmp86_ = NULL;
		const gchar* _tmp87_ = NULL;
		GomSerializationTestBookStore* _tmp88_ = NULL;
		GomSerializationTestBooks* _tmp89_ = NULL;
		GomSerializationTestBooks* _tmp90_ = NULL;
		GXmlDomElement* _tmp91_ = NULL;
		GomSerializationTestBook* _tmp92_ = NULL;
		GomSerializationTestBook* _tmp93_ = NULL;
		const gchar* _tmp94_ = NULL;
		const gchar* _tmp95_ = NULL;
		GomSerializationTestBookStore* _tmp96_ = NULL;
		GomSerializationTestBooks* _tmp97_ = NULL;
		GomSerializationTestBooks* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		GomSerializationTestBook* _tmp100_ = NULL;
		GomSerializationTestBook* _tmp101_ = NULL;
		const gchar* _tmp102_ = NULL;
		const gchar* _tmp103_ = NULL;
#line 755 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_store_new ();
#line 755 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 756 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = bs;
#line 756 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_store_to_string (_tmp1_);
#line 756 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp2_;
#line 757 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = s;
#line 757 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "s != null");
#line 761 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = s;
#line 761 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = string_contains (_tmp4_, "<BookStore/>");
#line 761 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp5_, "\"<BookStore/>\" in s");
#line 762 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = bs;
#line 762 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_store_get_books (_tmp6_);
#line 762 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 762 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp8_ == NULL, "bs.books == null");
#line 763 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = bs;
#line 763 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) _tmp9_, "books");
#line 764 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = bs;
#line 764 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = gom_serialization_test_book_store_to_string (_tmp10_);
#line 764 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 764 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp11_;
#line 765 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = s;
#line 765 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp12_ != NULL, "s != null");
#line 769 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = s;
#line 769 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = string_contains (_tmp13_, "<BookStore/>");
#line 769 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp14_, "\"<BookStore/>\" in s");
#line 770 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gom_serialization_test_book_new ();
#line 770 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp15_;
#line 8148 "GomSerializationTest.c"
		{
			GomSerializationTestBookStore* _tmp16_ = NULL;
			GomSerializationTestBooks* _tmp17_ = NULL;
			GomSerializationTestBooks* _tmp18_ = NULL;
			GomSerializationTestBook* _tmp19_ = NULL;
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp16_ = bs;
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp17_ = gom_serialization_test_book_store_get_books (_tmp16_);
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp18_ = _tmp17_;
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp19_ = b;
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			gxml_gom_collection_append ((GXmlGomCollection*) _tmp18_, (GXmlDomElement*) _tmp19_, &_inner_error_);
#line 772 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8166 "GomSerializationTest.c"
				goto __catch307_g_error;
			}
#line 773 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_assert_not_reached ();
#line 8171 "GomSerializationTest.c"
		}
		goto __finally307;
		__catch307_g_error:
		{
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_clear_error (&_inner_error_);
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_inner_error_ = NULL;
#line 8180 "GomSerializationTest.c"
		}
		__finally307:
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 771 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8191 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = bs;
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp20_);
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = gom_serialization_test_book_new_document (_tmp22_);
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 775 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp23_;
#line 776 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = b;
#line 776 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp24_, "Title1");
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = bs;
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gom_serialization_test_book_store_get_books (_tmp25_);
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = b;
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp27_, (GXmlDomElement*) _tmp28_, &_inner_error_);
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 777 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8228 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 778 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = bs;
#line 778 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_book_store_to_string (_tmp29_);
#line 778 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 778 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp30_;
#line 779 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = s;
#line 779 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp31_ != NULL, "s != null");
#line 783 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = s;
#line 783 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = string_contains (_tmp32_, "<BookStore><Book Name=\"Title1\"/></BookStore>");
#line 783 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp33_, "\"<BookStore><Book Name=\\\"Title1\\\"/></BookStore>\" in s");
#line 784 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = bs;
#line 784 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp34_);
#line 784 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = _tmp35_;
#line 784 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = gom_serialization_test_book_new_document (_tmp36_);
#line 784 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b2 = _tmp37_;
#line 785 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = b2;
#line 785 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp38_, "Title2");
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = bs;
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_store_get_books (_tmp39_);
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = b2;
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp41_, (GXmlDomElement*) _tmp42_, &_inner_error_);
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 786 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8283 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = bs;
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp44_);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = gxml_dom_document_create_element (_tmp46_, "Test", &_inner_error_);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = _tmp47_;
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8306 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = bs;
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp48_, (GXmlDomNode*) _tmp43_, &_inner_error_);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = _tmp49_;
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp50_);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp43_);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 787 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8329 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 788 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = bs;
#line 788 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp51_);
#line 788 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = _tmp52_;
#line 788 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = gom_serialization_test_book_new_document (_tmp53_);
#line 788 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b3 = _tmp54_;
#line 789 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = b3;
#line 789 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp55_, "Title3");
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = bs;
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = gom_serialization_test_book_store_get_books (_tmp56_);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = b3;
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp58_, (GXmlDomElement*) _tmp59_, &_inner_error_);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b3);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp43_);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b2);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 790 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8370 "GomSerializationTest.c"
			goto __catch306_g_error;
		}
#line 791 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = bs;
#line 791 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = gom_serialization_test_book_store_to_string (_tmp60_);
#line 791 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 791 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp61_;
#line 792 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = s;
#line 792 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp62_ != NULL, "s != null");
#line 796 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = s;
#line 796 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = string_contains (_tmp63_, "<BookStore><Book Name=\"Title1\"/><Book Name=\"Title2\"/><Test/><Book " \
"Name=\"Title3\"/></BookStore>");
#line 796 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp64_, "\"<BookStore><Book Name=\\\"Title1\\\"/><Book Name=\\\"Title2\\\"/><Test/><Book Name=\\\"Title3\\\"/></BookStore>\" in s");
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = bs;
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = gom_serialization_test_book_store_get_books (_tmp65_);
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = _tmp66_;
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp67_, "Title1");
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = _tmp68_;
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp69_ != NULL, "bs.books.get(\"Title1\") != null");
#line 797 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp69_);
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = bs;
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = gom_serialization_test_book_store_get_books (_tmp70_);
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = _tmp71_;
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp72_, "Title2");
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = _tmp73_;
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp74_ != NULL, "bs.books.get(\"Title2\") != null");
#line 798 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp74_);
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = bs;
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = gom_serialization_test_book_store_get_books (_tmp75_);
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = _tmp76_;
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp77_, "Title3");
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = _tmp78_;
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp79_ != NULL, "bs.books.get(\"Title3\") != null");
#line 799 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp79_);
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = bs;
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = gom_serialization_test_book_store_get_books (_tmp80_);
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = _tmp81_;
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp82_, "Title1");
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp83_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp83_) : NULL;
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp84_ == NULL) {
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp83_);
#line 8447 "GomSerializationTest.c"
		}
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = _tmp84_;
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = gom_serialization_test_book_get_name (_tmp85_);
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = _tmp86_;
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "Title1") == 0, "(bs.books.get(\"Title1\") as Book).name == \"Title1\"");
#line 800 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp85_);
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = bs;
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = gom_serialization_test_book_store_get_books (_tmp88_);
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = _tmp89_;
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp90_, "Title2");
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp91_) : NULL;
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp92_ == NULL) {
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp91_);
#line 8473 "GomSerializationTest.c"
		}
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = _tmp92_;
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = gom_serialization_test_book_get_name (_tmp93_);
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = _tmp94_;
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp95_, "Title2") == 0, "(bs.books.get(\"Title2\") as Book).name == \"Title2\"");
#line 801 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp93_);
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = bs;
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = gom_serialization_test_book_store_get_books (_tmp96_);
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = _tmp97_;
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp98_, "Title3");
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp100_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp99_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp99_) : NULL;
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp100_ == NULL) {
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp99_);
#line 8499 "GomSerializationTest.c"
		}
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp101_ = _tmp100_;
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = gom_serialization_test_book_get_name (_tmp101_);
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = _tmp102_;
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp103_, "Title3") == 0, "(bs.books.get(\"Title3\") as Book).name == \"Title3\"");
#line 802 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp101_);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b3);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp43_);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b2);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 8523 "GomSerializationTest.c"
	}
	goto __finally306;
	__catch306_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp104_ = NULL;
		gchar* _tmp105_ = NULL;
		gchar* _tmp106_ = NULL;
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 804 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = e->message;
#line 804 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp105_ = g_strconcat ("Error: ", _tmp104_, NULL);
#line 804 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp106_ = _tmp105_;
#line 804 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:804: %s", _tmp106_);
#line 804 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp106_);
#line 805 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 8550 "GomSerializationTest.c"
	}
	__finally306:
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 754 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 8561 "GomSerializationTest.c"
	}
}


static void ___lambda268__gtest_func (void) {
#line 753 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda268_ ();
#line 8569 "GomSerializationTest.c"
}


static void __lambda269_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		GomSerializationTestBookStand* _tmp1_ = NULL;
		GomSerializationTestHashRegisters* _tmp2_ = NULL;
		GomSerializationTestHashRegisters* _tmp3_ = NULL;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestBookStand* _tmp4_ = NULL;
		GomSerializationTestHashRegisters* _tmp5_ = NULL;
		GomSerializationTestHashRegisters* _tmp6_ = NULL;
		GXmlGomElement* _tmp7_ = NULL;
		GomSerializationTestBookRegister* _tmp8_ = NULL;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBookRegister* _tmp9_ = NULL;
		GomSerializationTestBook* _tmp10_ = NULL;
		GomSerializationTestBookRegister* _tmp11_ = NULL;
		GomSerializationTestBook* _tmp12_ = NULL;
		GomSerializationTestBookRegister* _tmp13_ = NULL;
		GomSerializationTestBookStand* _tmp14_ = NULL;
		GomSerializationTestHashRegisters* _tmp15_ = NULL;
		GomSerializationTestHashRegisters* _tmp16_ = NULL;
		GomSerializationTestBookRegister* _tmp17_ = NULL;
		GomSerializationTestBookStand* _tmp18_ = NULL;
		GomSerializationTestHashRegisters* _tmp19_ = NULL;
		GomSerializationTestHashRegisters* _tmp20_ = NULL;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
		GomSerializationTestBookStand* _tmp23_ = NULL;
		GomSerializationTestHashRegisters* _tmp24_ = NULL;
		GomSerializationTestHashRegisters* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestBookStand* _tmp27_ = NULL;
		GomSerializationTestHashRegisters* _tmp28_ = NULL;
		GomSerializationTestHashRegisters* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GomSerializationTestBookRegister* _tmp31_ = NULL;
		GomSerializationTestBookRegister* _tmp32_ = NULL;
		GomSerializationTestBookRegister* _tmp33_ = NULL;
		gint _tmp34_ = 0;
		gint _tmp35_ = 0;
		GomSerializationTestBookRegister* _tmp36_ = NULL;
		GomSerializationTestBook* _tmp37_ = NULL;
		GomSerializationTestBook* _tmp38_ = NULL;
		GomSerializationTestBookRegister* _tmp39_ = NULL;
		GomSerializationTestBook* _tmp40_ = NULL;
		GomSerializationTestBook* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		const gchar* _tmp43_ = NULL;
		GomSerializationTestBookRegister* _tmp44_ = NULL;
		GXmlDomNodeList* _tmp45_ = NULL;
		GXmlDomNodeList* _tmp46_ = NULL;
		GXmlDomNodeList* _tmp47_ = NULL;
		gint _tmp48_ = 0;
		gint _tmp49_ = 0;
		GomSerializationTestBook* book2 = NULL;
		GomSerializationTestBookRegister* _tmp50_ = NULL;
		GomSerializationTestBook* _tmp51_ = NULL;
		GomSerializationTestBookRegister* _tmp52_ = NULL;
		GomSerializationTestBook* _tmp53_ = NULL;
		GXmlDomNode* _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
		GomSerializationTestBookRegister* _tmp56_ = NULL;
		GXmlDomNodeList* _tmp57_ = NULL;
		GXmlDomNodeList* _tmp58_ = NULL;
		GXmlDomNodeList* _tmp59_ = NULL;
		gint _tmp60_ = 0;
		gint _tmp61_ = 0;
		GomSerializationTestBookRegister* _tmp62_ = NULL;
		GomSerializationTestBook* _tmp63_ = NULL;
		GomSerializationTestBookRegister* _tmp64_ = NULL;
		GXmlDomNodeList* _tmp65_ = NULL;
		GXmlDomNodeList* _tmp66_ = NULL;
		GXmlDomNodeList* _tmp67_ = NULL;
		gint _tmp68_ = 0;
		gint _tmp69_ = 0;
#line 810 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 810 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 811 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = bs;
#line 811 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp1_);
#line 811 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 811 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "bs.hashmap_registers != null");
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = bs;
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp4_);
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp6_);
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp7_) : NULL;
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp8_ == NULL) {
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp7_);
#line 8677 "GomSerializationTest.c"
		}
#line 812 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br = _tmp8_;
#line 813 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = br;
#line 813 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_register_create_book (_tmp9_, "Book1");
#line 813 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		book = _tmp10_;
#line 814 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = br;
#line 814 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = book;
#line 814 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (_tmp11_, _tmp12_);
#line 815 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = br;
#line 815 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (_tmp13_, 2017);
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = bs;
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp14_);
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = br;
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp16_, (GXmlDomElement*) _tmp17_, &_inner_error_);
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 816 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8715 "GomSerializationTest.c"
			goto __catch308_g_error;
		}
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = bs;
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp18_);
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp20_);
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 817 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp22_ == 1, "bs.hashmap_registers.length == 1");
#line 818 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = bs;
#line 818 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp23_);
#line 818 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 818 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gxml_gom_hash_map_has_key ((GXmlGomHashMap*) _tmp25_, "2017-Book1");
#line 818 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp26_, "bs.hashmap_registers.has_key (\"2017-Book1\")");
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = bs;
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_stand_get_hashmap_registers (_tmp27_);
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp29_, "2017-Book1");
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp30_) : NULL;
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp31_ == NULL) {
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp30_);
#line 8754 "GomSerializationTest.c"
		}
#line 819 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b1 = _tmp31_;
#line 820 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = b1;
#line 820 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp32_ != NULL, "b1 != null");
#line 821 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = b1;
#line 821 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = gom_serialization_test_book_register_get_year (_tmp33_);
#line 821 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 821 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp35_ == 2017, "b1.year == 2017");
#line 822 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = b1;
#line 822 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = gom_serialization_test_book_register_get_book (_tmp36_);
#line 822 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 822 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp38_ != NULL, "b1.book != null");
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = b1;
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_register_get_book (_tmp39_);
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = gom_serialization_test_book_get_name (_tmp41_);
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 823 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = b1;
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp44_);
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = _tmp46_;
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = gxml_dom_node_list_get_length (_tmp47_);
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp49_ == 1, "b1.child_nodes.length == 1");
#line 824 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp47_);
#line 825 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = b1;
#line 825 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = gom_serialization_test_book_register_create_book (_tmp50_, "Book2");
#line 825 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		book2 = _tmp51_;
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = b1;
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = book2;
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp52_, (GXmlDomNode*) _tmp53_, &_inner_error_);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = _tmp54_;
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp55_);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (book2);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b1);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 826 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 8834 "GomSerializationTest.c"
			goto __catch308_g_error;
		}
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = b1;
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp56_);
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = gxml_dom_node_list_get_length (_tmp59_);
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = _tmp60_;
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp61_ == 2, "b1.child_nodes.length == 2");
#line 827 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp59_);
#line 828 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = b1;
#line 828 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = book2;
#line 828 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (_tmp62_, _tmp63_);
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = b1;
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp64_);
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = _tmp65_;
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = _tmp66_;
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = gxml_dom_node_list_get_length (_tmp67_);
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = _tmp68_;
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp69_ == 1, "b1.child_nodes.length == 1");
#line 829 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp67_);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (book2);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 8885 "GomSerializationTest.c"
	}
	goto __finally308;
	__catch308_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 831 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = e->message;
#line 831 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = g_strconcat ("Error: ", _tmp70_, NULL);
#line 831 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = _tmp71_;
#line 831 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:831: %s", _tmp72_);
#line 831 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp72_);
#line 832 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 8912 "GomSerializationTest.c"
	}
	__finally308:
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 809 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 8923 "GomSerializationTest.c"
	}
}


static void ___lambda269__gtest_func (void) {
#line 808 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda269_ ();
#line 8931 "GomSerializationTest.c"
}


static void __lambda270_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp1_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp2_ = NULL;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestHashPairRegisters* _tmp3_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp4_ = NULL;
		GXmlGomElement* _tmp5_ = NULL;
		GomSerializationTestBookRegister* _tmp6_ = NULL;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBook* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp10_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp11_ = NULL;
		gint _tmp12_ = 0;
		gint _tmp13_ = 0;
		GomSerializationTestHashPairRegisters* _tmp14_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp15_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp16_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp17_ = NULL;
		gint _tmp18_ = 0;
		gint _tmp19_ = 0;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestHashPairRegisters* _tmp20_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GomSerializationTestBookRegister* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		GomSerializationTestBook* _tmp26_ = NULL;
		GomSerializationTestBook* _tmp27_ = NULL;
		GomSerializationTestBook* _tmp28_ = NULL;
		GomSerializationTestBook* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
#line 837 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 837 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 838 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 838 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 838 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp2_ != NULL, "bs.hashpair_registers != null");
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp4_);
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp5_) : NULL;
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp6_ == NULL) {
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp5_);
#line 8996 "GomSerializationTest.c"
		}
#line 839 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br = _tmp6_;
#line 840 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_register_create_book (br, "Book1");
#line 840 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		book = _tmp7_;
#line 841 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_get_name (book);
#line 841 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 841 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Book1") == 0, "book.name == \"Book1\"");
#line 842 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (br, book);
#line 843 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (br, 2017);
#line 844 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 844 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 844 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp11_);
#line 844 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 844 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp13_ == 0, "bs.hashpair_registers.length == 0");
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp15_, (GXmlDomElement*) br, &_inner_error_);
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 845 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9038 "GomSerializationTest.c"
			goto __catch309_g_error;
		}
#line 846 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 846 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 846 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp17_);
#line 846 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 846 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp19_ == 1, "bs.hashpair_registers.length == 1");
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = gom_serialization_test_book_stand_get_hashpair_registers (bs);
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp21_, "2017", "Book1");
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp22_) : NULL;
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp23_ == NULL) {
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp22_);
#line 9063 "GomSerializationTest.c"
		}
#line 847 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b1 = _tmp23_;
#line 848 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (b1 != NULL, "b1 != null");
#line 849 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_register_get_year (b1);
#line 849 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 849 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp25_ == 2017, "b1.year == 2017");
#line 850 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gom_serialization_test_book_register_get_book (b1);
#line 850 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 850 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp27_ != NULL, "b1.book != null");
#line 851 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_register_get_book (b1);
#line 851 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 851 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_book_get_name (_tmp29_);
#line 851 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 851 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 9099 "GomSerializationTest.c"
	}
	goto __finally309;
	__catch309_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 853 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = e->message;
#line 853 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = g_strconcat ("Error: ", _tmp32_, NULL);
#line 853 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 853 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:853: %s", _tmp34_);
#line 853 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp34_);
#line 854 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 9126 "GomSerializationTest.c"
	}
	__finally309:
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 836 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 9137 "GomSerializationTest.c"
	}
}


static void ___lambda270__gtest_func (void) {
#line 835 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda270_ ();
#line 9145 "GomSerializationTest.c"
}


static void __lambda271_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp1_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp2_ = NULL;
		GomSerializationTestBookRegister* br = NULL;
		GomSerializationTestHashThreeRegisters* _tmp3_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp4_ = NULL;
		GXmlGomElement* _tmp5_ = NULL;
		GomSerializationTestBookRegister* _tmp6_ = NULL;
		GomSerializationTestBook* book = NULL;
		GomSerializationTestBook* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp18_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp19_ = NULL;
		gint _tmp20_ = 0;
		gint _tmp21_ = 0;
		GomSerializationTestHashThreeRegisters* _tmp22_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp23_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp24_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		GomSerializationTestBookRegister* b1 = NULL;
		GomSerializationTestHashThreeRegisters* _tmp28_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GomSerializationTestBookRegister* _tmp31_ = NULL;
		gint _tmp32_ = 0;
		gint _tmp33_ = 0;
		GomSerializationTestBook* _tmp34_ = NULL;
		GomSerializationTestBook* _tmp35_ = NULL;
		GomSerializationTestBook* _tmp36_ = NULL;
		GomSerializationTestBook* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		const gchar* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
#line 859 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 859 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 860 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 860 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 860 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp2_ != NULL, "bs.hashthree_registers != null");
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp4_);
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp5_) : NULL;
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp6_ == NULL) {
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp5_);
#line 9220 "GomSerializationTest.c"
		}
#line 861 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		br = _tmp6_;
#line 862 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_register_create_book (br, "Book1");
#line 862 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		book = _tmp7_;
#line 863 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gom_serialization_test_book_get_name (book);
#line 863 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 863 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Book1") == 0, "book.name == \"Book1\"");
#line 864 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (br, book);
#line 865 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (br, 2017);
#line 866 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_cover (br, "SYSTEMS");
#line 867 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gxml_mappeable_element_three_key_get_map_pkey ((GXmlMappeableElementThreeKey*) br);
#line 867 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 867 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "2017") == 0, "br.get_map_pkey () == \"2017\"");
#line 867 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp11_);
#line 868 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = gxml_mappeable_element_three_key_get_map_skey ((GXmlMappeableElementThreeKey*) br);
#line 868 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 868 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "Book1") == 0, "br.get_map_skey () == \"Book1\"");
#line 868 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp13_);
#line 869 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_register_get_cover (br);
#line 869 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 869 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp15_, "SYSTEMS") == 0, "br.cover == \"SYSTEMS\"");
#line 870 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gxml_mappeable_element_three_key_get_map_tkey ((GXmlMappeableElementThreeKey*) br);
#line 870 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 870 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp17_, "SYSTEMS") == 0, "br.get_map_tkey () == \"SYSTEMS\"");
#line 870 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp17_);
#line 871 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 871 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 871 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp19_);
#line 871 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 871 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp21_ == 0, "bs.hashthree_registers.length == 0");
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp23_, (GXmlDomElement*) br, &_inner_error_);
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (book);
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (br);
#line 872 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 9294 "GomSerializationTest.c"
			goto __catch310_g_error;
		}
#line 873 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 873 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 873 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp25_);
#line 873 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 873 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp27_ == 1, "bs.hashthree_registers.length == 1");
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = gom_serialization_test_book_stand_get_hashthree_registers (bs);
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp29_, "2017", "Book1", "SYSTEMS");
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp30_) : NULL;
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp31_ == NULL) {
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp30_);
#line 9319 "GomSerializationTest.c"
		}
#line 874 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b1 = _tmp31_;
#line 875 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (b1 != NULL, "b1 != null");
#line 876 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = gom_serialization_test_book_register_get_year (b1);
#line 876 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 876 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp33_ == 2017, "b1.year == 2017");
#line 877 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = gom_serialization_test_book_register_get_book (b1);
#line 877 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 877 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp35_ != NULL, "b1.book != null");
#line 878 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = gom_serialization_test_book_register_get_book (b1);
#line 878 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 878 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = gom_serialization_test_book_get_name (_tmp37_);
#line 878 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = _tmp38_;
#line 878 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "Book1") == 0, "b1.book.name == \"Book1\"");
#line 879 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_book_register_get_cover (b1);
#line 879 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 879 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "SYSTEMS") == 0, "b1.cover == \"SYSTEMS\"");
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b1);
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (book);
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (br);
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 9361 "GomSerializationTest.c"
	}
	goto __finally310;
	__catch310_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 881 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = e->message;
#line 881 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = g_strconcat ("Error: ", _tmp42_, NULL);
#line 881 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 881 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:881: %s", _tmp44_);
#line 881 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp44_);
#line 882 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 9388 "GomSerializationTest.c"
	}
	__finally310:
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 858 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 9399 "GomSerializationTest.c"
	}
}


static void ___lambda271__gtest_func (void) {
#line 857 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda271_ ();
#line 9407 "GomSerializationTest.c"
}


static void __lambda272_ (void) {
	GomSerializationTestMotor* m = NULL;
	GomSerializationTestMotor* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GomSerializationTestMotorOn* _tmp5_ = NULL;
	GomSerializationTestMotorOn* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	GomSerializationTestMotorTorque* _tmp11_ = NULL;
	GomSerializationTestMotorTorque* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	const gchar* _tmp15_ = NULL;
	gboolean _tmp16_ = FALSE;
	GomSerializationTestMotorSpeed* _tmp17_ = NULL;
	GomSerializationTestMotorSpeed* _tmp18_ = NULL;
	GomSerializationTestMotorSpeed* _tmp19_ = NULL;
	GomSerializationTestMotorSpeed* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	const gchar* _tmp23_ = NULL;
	gboolean _tmp24_ = FALSE;
	GomSerializationTestMotorSpeed* _tmp25_ = NULL;
	GomSerializationTestMotorSpeed* _tmp26_ = NULL;
	GomSerializationTestMotorSpeed* _tmp27_ = NULL;
	GomSerializationTestMotorSpeed* _tmp28_ = NULL;
	GomSerializationTestMotorSpeed* _tmp29_ = NULL;
	GomSerializationTestMotorSpeed* _tmp30_ = NULL;
	gdouble _tmp31_ = 0.0;
	GomSerializationTestMotorSpeed* _tmp32_ = NULL;
	GomSerializationTestMotorSpeed* _tmp33_ = NULL;
	gchar* _tmp34_ = NULL;
	gchar* _tmp35_ = NULL;
	gchar* _tmp36_ = NULL;
	GomSerializationTestMotorSpeed* _tmp37_ = NULL;
	GomSerializationTestMotorSpeed* _tmp38_ = NULL;
	gchar* _tmp39_ = NULL;
	gchar* _tmp40_ = NULL;
	gchar* _tmp41_ = NULL;
	gchar* _tmp42_ = NULL;
	gchar* _tmp43_ = NULL;
	GomSerializationTestMotorTensionType* _tmp44_ = NULL;
	GomSerializationTestMotorTensionType* _tmp45_ = NULL;
	GomSerializationTestMotorTensionType* _tmp46_ = NULL;
	GomSerializationTestMotorTensionType* _tmp47_ = NULL;
	gchar* _tmp48_ = NULL;
	const gchar* _tmp49_ = NULL;
	const gchar* _tmp50_ = NULL;
	gboolean _tmp51_ = FALSE;
	GomSerializationTestMotorTensionType* _tmp52_ = NULL;
	GomSerializationTestMotorTensionType* _tmp53_ = NULL;
	GomSerializationTestMotorTensionType* _tmp54_ = NULL;
	GomSerializationTestMotorTensionType* _tmp55_ = NULL;
	gchar* _tmp56_ = NULL;
	gchar* _tmp57_ = NULL;
	gchar* _tmp58_ = NULL;
	GomSerializationTestMotorTension* _tmp59_ = NULL;
	GomSerializationTestMotorTension* _tmp60_ = NULL;
	gchar* _tmp61_ = NULL;
	const gchar* _tmp62_ = NULL;
	const gchar* _tmp63_ = NULL;
	gboolean _tmp64_ = FALSE;
	GomSerializationTestMotorOn* _tmp65_ = NULL;
	GomSerializationTestMotorOn* _tmp66_ = NULL;
	GomSerializationTestMotorTorque* _tmp67_ = NULL;
	GomSerializationTestMotorTorque* _tmp68_ = NULL;
	GomSerializationTestMotorSpeed* _tmp69_ = NULL;
	GomSerializationTestMotorSpeed* _tmp70_ = NULL;
	GomSerializationTestMotorTensionType* _tmp71_ = NULL;
	GomSerializationTestMotorTensionType* _tmp72_ = NULL;
	GomSerializationTestMotorTension* _tmp73_ = NULL;
	GomSerializationTestMotorTension* _tmp74_ = NULL;
	gchar* _tmp75_ = NULL;
	const gchar* _tmp76_ = NULL;
	const gchar* _tmp77_ = NULL;
	gboolean _tmp78_ = FALSE;
	GomSerializationTestMotorModel* _tmp79_ = NULL;
	GomSerializationTestMotorModel* _tmp80_ = NULL;
	GomSerializationTestMotorModel* _tmp81_ = NULL;
	GomSerializationTestMotorModel* _tmp82_ = NULL;
	GomSerializationTestMotorModel* _tmp83_ = NULL;
	GomSerializationTestMotorModel* _tmp84_ = NULL;
	gchar* _tmp85_ = NULL;
	gchar* _tmp86_ = NULL;
	gchar* _tmp87_ = NULL;
	GomSerializationTestMotorModel* _tmp88_ = NULL;
	GomSerializationTestMotorModel* _tmp89_ = NULL;
	gchar* _tmp90_ = NULL;
	gchar* _tmp91_ = NULL;
	gchar* _tmp92_ = NULL;
	GomSerializationTestMotorModel* _tmp93_ = NULL;
	GomSerializationTestMotorModel* _tmp94_ = NULL;
	GomSerializationTestMotorModel* _tmp95_ = NULL;
	GomSerializationTestMotorModel* _tmp96_ = NULL;
	gchar* _tmp97_ = NULL;
	gchar* _tmp98_ = NULL;
	gchar* _tmp99_ = NULL;
	gchar* _tmp100_ = NULL;
	const gchar* _tmp101_ = NULL;
	const gchar* _tmp102_ = NULL;
	gboolean _tmp103_ = FALSE;
	GomSerializationTestMotorModel* _tmp104_ = NULL;
	GomSerializationTestMotorModel* _tmp105_ = NULL;
	gboolean _tmp106_ = FALSE;
	GomSerializationTestMotorModel* _tmp107_ = NULL;
	GomSerializationTestMotorModel* _tmp108_ = NULL;
	gboolean _tmp109_ = FALSE;
	GomSerializationTestMotorModel* _tmp110_ = NULL;
	GomSerializationTestMotorModel* _tmp111_ = NULL;
	GomSerializationTestMotorModel* _tmp112_ = NULL;
	GomSerializationTestMotorModel* _tmp113_ = NULL;
	gboolean _tmp114_ = FALSE;
#line 886 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_motor_new ();
#line 886 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	m = _tmp0_;
#line 887 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = gom_serialization_test_motor_to_string (m);
#line 887 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 888 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = s;
#line 888 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp2_ != NULL, "s != null");
#line 892 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = s;
#line 892 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = string_contains (_tmp3_, "<Motor/>");
#line 892 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp4_, "\"<Motor/>\" in s");
#line 893 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = gom_serialization_test_motor_on_new ();
#line 893 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 893 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_is_on (m, _tmp6_);
#line 893 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp6_);
#line 894 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = gom_serialization_test_motor_to_string (m);
#line 894 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 894 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp7_;
#line 895 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = s;
#line 895 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp8_ != NULL, "s != null");
#line 899 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = s;
#line 899 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = string_contains (_tmp9_, "<Motor On=\"false\"/>");
#line 899 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp10_, "\"<Motor On=\\\"false\\\"/>\" in s");
#line 900 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = gom_serialization_test_motor_torque_new ();
#line 900 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = _tmp11_;
#line 900 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_torque (m, _tmp12_);
#line 900 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp12_);
#line 901 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = gom_serialization_test_motor_to_string (m);
#line 901 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 901 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp13_;
#line 902 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp14_ = s;
#line 902 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp14_ != NULL, "s != null");
#line 906 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp15_ = s;
#line 906 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp16_ = string_contains (_tmp15_, "<Motor On=\"false\" Torque=\"0.0000\"/>");
#line 906 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp16_, "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\"/>\" in s");
#line 907 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp17_ = gom_serialization_test_motor_speed_new ();
#line 907 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp18_ = _tmp17_;
#line 907 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_speed (m, _tmp18_);
#line 907 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp18_);
#line 908 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp19_ = gom_serialization_test_motor_get_speed (m);
#line 908 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp20_ = _tmp19_;
#line 908 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_double_set_double ((GXmlGomDouble*) _tmp20_, 1.0);
#line 909 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp21_ = gom_serialization_test_motor_to_string (m);
#line 909 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 909 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp21_;
#line 910 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp22_ = s;
#line 910 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp22_ != NULL, "s != null");
#line 914 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp23_ = s;
#line 914 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp24_ = string_contains (_tmp23_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\"/>");
#line 914 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp24_, "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\"/>\" in s");
#line 915 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp25_ = gom_serialization_test_motor_get_speed (m);
#line 915 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp26_ = _tmp25_;
#line 915 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp26_ != NULL, "m.speed != null");
#line 916 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (m, GXML_TYPE_GOM_OBJECT), "m is GomObject");
#line 917 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp27_ = gom_serialization_test_motor_get_speed (m);
#line 917 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp28_ = _tmp27_;
#line 917 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_GOM_PROPERTY), "m.speed is GomProperty");
#line 918 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp29_ = gom_serialization_test_motor_get_speed (m);
#line 918 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp30_ = _tmp29_;
#line 918 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp31_ = gxml_gom_double_get_double ((GXmlGomDouble*) _tmp30_);
#line 918 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp31_ == 1.0, "m.speed.get_double () == 1.0");
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp32_ = gom_serialization_test_motor_get_speed (m);
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp33_ = _tmp32_;
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp34_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp33_);
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp35_ = _tmp34_;
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp36_ = _tmp35_;
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp36_ != NULL, "m.speed.value != null");
#line 919 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp36_);
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp37_ = gom_serialization_test_motor_get_speed (m);
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp38_ = _tmp37_;
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp39_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp38_);
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp40_ = _tmp39_;
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp41_ = _tmp40_;
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp41_, "1.0000") == 0, "m.speed.value == \"1.0000\"");
#line 920 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp41_);
#line 924 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp42_ = gxml_dom_element_get_attribute ((GXmlDomElement*) m, "speed");
#line 924 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp43_ = _tmp42_;
#line 924 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp43_ != NULL, "m.get_attribute (\"speed\") != null");
#line 924 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp43_);
#line 925 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp44_ = gom_serialization_test_motor_get_tension_type (m);
#line 925 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp45_ = _tmp44_;
#line 925 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp45_ == NULL, "m.tension_type == null");
#line 926 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp46_ = gom_serialization_test_motor_tension_type_new ();
#line 926 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp47_ = _tmp46_;
#line 926 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_tension_type (m, _tmp47_);
#line 926 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp47_);
#line 927 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp48_ = gom_serialization_test_motor_to_string (m);
#line 927 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 927 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp48_;
#line 928 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp49_ = s;
#line 928 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp49_ != NULL, "s != null");
#line 932 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp50_ = s;
#line 932 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp51_ = string_contains (_tmp50_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\" TensionType=\"a" \
"c\"/>");
#line 932 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp51_, "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\" TensionType=\\\"ac\\\"/>\" in s");
#line 933 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp52_ = gom_serialization_test_motor_get_tension_type (m);
#line 933 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp53_ = _tmp52_;
#line 933 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp53_ != NULL, "m.tension_type != null");
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp54_ = gom_serialization_test_motor_get_tension_type (m);
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp55_ = _tmp54_;
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp56_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp55_);
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp57_ = _tmp56_;
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp58_ = _tmp57_;
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp58_, "ac") == 0, "m.tension_type.value == \"ac\"");
#line 934 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp58_);
#line 935 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp59_ = gom_serialization_test_motor_tension_new ();
#line 935 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp60_ = _tmp59_;
#line 935 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_tension (m, _tmp60_);
#line 935 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp60_);
#line 936 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp61_ = gom_serialization_test_motor_to_string (m);
#line 936 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 936 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp61_;
#line 937 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp62_ = s;
#line 937 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp62_ != NULL, "s != null");
#line 941 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp63_ = s;
#line 941 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp64_ = string_contains (_tmp63_, "<Motor On=\"false\" Torque=\"0.0000\" Speed=\"1.0000\" TensionType=\"a" \
"c\" Tension=\"0\"/>");
#line 941 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp64_, "\"<Motor On=\\\"false\\\" Torque=\\\"0.0000\\\" Speed=\\\"1.0000\\\" TensionType=\\\"ac\\\" Tension=\\\"0\\\"/>\" in s");
#line 942 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp65_ = gom_serialization_test_motor_get_is_on (m);
#line 942 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp66_ = _tmp65_;
#line 942 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_boolean_set_boolean ((GXmlGomBoolean*) _tmp66_, TRUE);
#line 943 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp67_ = gom_serialization_test_motor_get_torque (m);
#line 943 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp68_ = _tmp67_;
#line 943 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_double_set_double ((GXmlGomDouble*) _tmp68_, 3.1416);
#line 944 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp69_ = gom_serialization_test_motor_get_speed (m);
#line 944 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp70_ = _tmp69_;
#line 944 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_float_set_float ((GXmlGomFloat*) _tmp70_, (gfloat) 3600.1011);
#line 945 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp71_ = gom_serialization_test_motor_get_tension_type (m);
#line 945 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp72_ = _tmp71_;
#line 945 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_enum_set_enum ((GXmlGomEnum*) _tmp72_, (gint) GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC);
#line 946 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp73_ = gom_serialization_test_motor_get_tension (m);
#line 946 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp74_ = _tmp73_;
#line 946 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_int_set_integer ((GXmlGomInt*) _tmp74_, 125);
#line 947 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp75_ = gom_serialization_test_motor_to_string (m);
#line 947 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 947 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp75_;
#line 948 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp76_ = s;
#line 948 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp76_ != NULL, "s != null");
#line 952 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp77_ = s;
#line 952 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp78_ = string_contains (_tmp77_, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\"/>");
#line 952 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp78_, "\"<Motor On=\\\"true\\\" Torque=\\\"3.1416\\\" Speed=\\\"3600.1011\\\" TensionType=\\\"dc\\\" Tension=\\\"125\\\"/>\" in s");
#line 953 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp79_ = gom_serialization_test_motor_model_new ();
#line 953 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp80_ = _tmp79_;
#line 953 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_set_model (m, _tmp80_);
#line 953 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (_tmp80_);
#line 954 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp81_ = gom_serialization_test_motor_get_model (m);
#line 954 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp82_ = _tmp81_;
#line 954 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp82_ != NULL, "m.model != null");
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp83_ = gom_serialization_test_motor_get_model (m);
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp84_ = _tmp83_;
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp85_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp84_);
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp86_ = _tmp85_;
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp87_ = _tmp86_;
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp87_ != NULL, "m.model.value != null");
#line 955 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp87_);
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp88_ = gom_serialization_test_motor_get_model (m);
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp89_ = _tmp88_;
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp90_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp89_);
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp91_ = _tmp90_;
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp92_ = _tmp91_;
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp92_, "") == 0, "m.model.value == \"\"");
#line 956 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp92_);
#line 957 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp93_ = gom_serialization_test_motor_get_model (m);
#line 957 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp94_ = _tmp93_;
#line 957 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp94_, "Model3");
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp95_ = gom_serialization_test_motor_get_model (m);
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp96_ = _tmp95_;
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp97_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp96_);
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp98_ = _tmp97_;
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp99_ = _tmp98_;
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (g_strcmp0 (_tmp99_, "Model3") == 0, "m.model.value == \"Model3\"");
#line 958 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp99_);
#line 959 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp100_ = gom_serialization_test_motor_to_string (m);
#line 959 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 959 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp100_;
#line 960 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp101_ = s;
#line 960 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp101_ != NULL, "s != null");
#line 964 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp102_ = s;
#line 964 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp103_ = string_contains (_tmp102_, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\" Model=\"Model3\"/>");
#line 964 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp103_, "\"<Motor On=\\\"true\\\" Torque=\\\"3.1416\\\" Speed=\\\"3600.1011\\\" TensionType=\\\"dc\\\" Tension=\\\"125\\\" Model=\\\"Model3\\\"/>\" in s");
#line 965 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp104_ = gom_serialization_test_motor_get_model (m);
#line 965 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp105_ = _tmp104_;
#line 965 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp106_ = gxml_gom_array_string_is_valid_value ((GXmlGomArrayString*) _tmp105_);
#line 965 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (!_tmp106_, "!m.model.is_valid_value ()");
#line 966 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp107_ = gom_serialization_test_motor_get_model (m);
#line 966 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp108_ = _tmp107_;
#line 966 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp109_ = gxml_gom_array_string_search ((GXmlGomArrayString*) _tmp108_, "MODEL1");
#line 966 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp109_, "m.model.search (\"MODEL1\")");
#line 967 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp110_ = gom_serialization_test_motor_get_model (m);
#line 967 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp111_ = _tmp110_;
#line 967 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_property_set_value ((GXmlGomBaseProperty*) _tmp111_, "MODEL1");
#line 968 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp112_ = gom_serialization_test_motor_get_model (m);
#line 968 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp113_ = _tmp112_;
#line 968 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp114_ = gxml_gom_array_string_is_valid_value ((GXmlGomArrayString*) _tmp113_);
#line 968 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_vala_assert (_tmp114_, "m.model.is_valid_value ()");
#line 885 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (s);
#line 885 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (m);
#line 9915 "GomSerializationTest.c"
}


static void ___lambda272__gtest_func (void) {
#line 885 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda272_ ();
#line 9922 "GomSerializationTest.c"
}


static void __lambda273_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_ = NULL;
		GXmlXParser* parser = NULL;
		GomSerializationTestBook* _tmp1_ = NULL;
		GXmlXParser* _tmp2_ = NULL;
		GXmlXParser* _tmp3_ = NULL;
		gchar* s = NULL;
		GXmlXParser* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		GomSerializationTestBook* _tmp7_ = NULL;
		GomSerializationTestBook* _tmp8_ = NULL;
		GXmlDomNodeList* _tmp9_ = NULL;
		GXmlDomNodeList* _tmp10_ = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		GomSerializationTestBook* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GomSerializationTestBook* _tmp18_ = NULL;
		GXmlDomNamedNodeMap* _tmp19_ = NULL;
		GXmlDomNamedNodeMap* _tmp20_ = NULL;
		GXmlDomNamedNodeMap* _tmp21_ = NULL;
		GomSerializationTestBook* _tmp22_ = NULL;
		GXmlDomNamedNodeMap* _tmp23_ = NULL;
		GXmlDomNamedNodeMap* _tmp24_ = NULL;
		GXmlDomNamedNodeMap* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		GomSerializationTestBook* _tmp28_ = NULL;
		const gchar* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		GXmlXParser* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		GomSerializationTestBook* _tmp38_ = NULL;
		GomSerializationTestBook* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		GomSerializationTestBook* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		const gchar* _tmp44_ = NULL;
		gboolean _tmp45_ = FALSE;
#line 972 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 972 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp0_;
#line 973 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = b;
#line 973 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gxml_xparser_new ((GXmlDomNode*) _tmp1_);
#line 973 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		parser = _tmp2_;
#line 974 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = parser;
#line 974 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) _tmp3_, "<book name=\"Loco\"/>", NULL, &_inner_error_);
#line 974 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 974 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 974 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 9998 "GomSerializationTest.c"
			goto __catch311_g_error;
		}
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = parser;
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = gxml_parser_write_string ((GXmlParser*) _tmp4_, &_inner_error_);
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp5_;
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 975 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10013 "GomSerializationTest.c"
			goto __catch311_g_error;
		}
#line 976 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = s;
#line 976 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp6_ != NULL, "s != null");
#line 980 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = b;
#line 980 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp7_ != NULL, "b != null");
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = b;
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp8_);
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = _tmp9_;
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp11_ != NULL, "b.child_nodes != null");
#line 981 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp11_);
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = b;
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gee_collection_get_size ((GeeCollection*) _tmp15_);
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp17_ == 0, "b.child_nodes.size == 0");
#line 982 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp15_);
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = b;
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp18_);
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp21_ != NULL, "b.attributes != null");
#line 983 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp21_);
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = b;
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp22_);
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = _tmp23_;
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gee_map_get_size ((GeeMap*) _tmp25_);
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp27_ == 0, "b.attributes.size == 0");
#line 984 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp25_);
#line 985 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = b;
#line 985 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = gom_serialization_test_book_get_name (_tmp28_);
#line 985 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = _tmp29_;
#line 985 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp30_ != NULL, "b.name != null");
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = parser;
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = gxml_parser_write_string ((GXmlParser*) _tmp32_, &_inner_error_);
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = _tmp33_;
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10102 "GomSerializationTest.c"
			goto __catch311_g_error;
		}
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = _tmp31_;
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = NULL;
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 989 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp34_;
#line 990 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = s;
#line 990 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp35_ != NULL, "s != null");
#line 991 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = s;
#line 991 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = string_contains (_tmp36_, "<Book Name=\"Loco\"/>");
#line 991 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp37_, "\"<Book Name=\\\"Loco\\\"/>\" in s");
#line 995 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = b;
#line 995 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (_tmp38_, "My Book");
#line 996 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = b;
#line 996 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp39_, "name");
#line 996 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 996 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "My Book") == 0, "b.get_attribute (\"name\") == \"My Book\"");
#line 996 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp41_);
#line 997 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = b;
#line 997 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = gom_serialization_test_book_to_string (_tmp42_);
#line 997 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 997 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp43_;
#line 998 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = s;
#line 998 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = string_contains (_tmp44_, "<Book Name=\"My Book\"/>");
#line 998 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp45_, "\"<Book Name=\\\"My Book\\\"/>\" in s");
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp31_);
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 10159 "GomSerializationTest.c"
	}
	goto __finally311;
	__catch311_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1000 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = e->message;
#line 1000 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = g_strconcat ("Error: ", _tmp46_, NULL);
#line 1000 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 1000 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1000: %s", _tmp48_);
#line 1000 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp48_);
#line 1001 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10186 "GomSerializationTest.c"
	}
	__finally311:
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 971 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 10197 "GomSerializationTest.c"
	}
}


static void ___lambda273__gtest_func (void) {
#line 970 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda273_ ();
#line 10205 "GomSerializationTest.c"
}


static void __lambda274_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBook* b = NULL;
		GomSerializationTestBook* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		GXmlDomNodeList* _tmp3_ = NULL;
		GXmlDomNodeList* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		gint _tmp6_ = 0;
		gint _tmp7_ = 0;
		GXmlDomDocument* _tmp8_ = NULL;
		GXmlDomDocument* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomDocument* _tmp13_ = NULL;
		GXmlDomDocument* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
#line 1006 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_new ();
#line 1006 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp0_;
#line 1007 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) b, "<chair name=\"Tall\"/>", &_inner_error_);
#line 1007 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1007 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10244 "GomSerializationTest.c"
			goto __catch312_g_error;
		}
#line 1012 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_get_name (b);
#line 1012 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp1_;
#line 1012 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp2_ == NULL, "b.name == null");
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) b);
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = _tmp4_;
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = gee_collection_get_size ((GeeCollection*) _tmp5_);
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp7_ == 0, "b.child_nodes.size == 0");
#line 1013 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp5_);
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) b);
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element (_tmp9_);
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp12_ != NULL, "b.owner_document.document_element != null");
#line 1014 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp12_);
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) b);
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gxml_dom_document_get_document_element (_tmp14_);
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp17_);
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Book") == 0, "b.owner_document.document_element.node_name == \"Book\"");
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp20_);
#line 1015 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp17_);
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 10305 "GomSerializationTest.c"
	}
	goto __finally312;
	__catch312_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1017 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = e->message;
#line 1017 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = g_strconcat ("Error: ", _tmp21_, NULL);
#line 1017 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1017 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1017: %s", _tmp23_);
#line 1017 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp23_);
#line 1018 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10332 "GomSerializationTest.c"
	}
	__finally312:
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1005 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 10343 "GomSerializationTest.c"
	}
}


static void ___lambda274__gtest_func (void) {
#line 1004 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda274_ ();
#line 10351 "GomSerializationTest.c"
}


static void __lambda275_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookRegister* b = NULL;
		GomSerializationTestBookRegister* _tmp0_ = NULL;
		gchar* s = NULL;
		gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
#line 1023 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_register_new ();
#line 1023 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		b = _tmp0_;
#line 1024 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_book_register_to_string (b);
#line 1024 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp1_;
#line 1028 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = s;
#line 1028 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = string_contains (_tmp2_, "<BookRegister Year=\"0\"/>");
#line 1028 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_, "\"<BookRegister Year=\\\"0\\\"/>\" in s");
#line 1029 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) b, "<bookRegister><Book/></bookRegister>", &_inner_error_);
#line 1029 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1029 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1029 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (b);
#line 10392 "GomSerializationTest.c"
			goto __catch313_g_error;
		}
#line 1030 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = gom_serialization_test_book_register_to_string (b);
#line 1030 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1030 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 1032 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = s;
#line 1032 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("doc:", _tmp5_, NULL);
#line 1032 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 1032 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1032: %s", _tmp7_);
#line 1032 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 1034 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = s;
#line 1034 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = string_contains (_tmp8_, "<BookRegister Year=\"0\"><Book/></BookRegister>");
#line 1034 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp9_, "\"<BookRegister Year=\\\"0\\\"><Book/></BookRegister>\" in s");
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (b);
#line 10421 "GomSerializationTest.c"
	}
	goto __finally313;
	__catch313_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1036 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = e->message;
#line 1036 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = g_strconcat ("Error: ", _tmp10_, NULL);
#line 1036 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1036 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1036: %s", _tmp12_);
#line 1036 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp12_);
#line 1037 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10448 "GomSerializationTest.c"
	}
	__finally313:
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1022 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 10459 "GomSerializationTest.c"
	}
}


static void ___lambda275__gtest_func (void) {
#line 1021 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda275_ ();
#line 10467 "GomSerializationTest.c"
}


static void __lambda276_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestMotor* m = NULL;
		GomSerializationTestMotor* _tmp0_ = NULL;
		gchar* s = NULL;
		gchar* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
		gboolean _tmp3_ = FALSE;
		GXmlXParser* parser = NULL;
		GXmlXParser* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		const gchar* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		const gchar* _tmp10_ = NULL;
		gboolean _tmp11_ = FALSE;
		const gchar* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
		const gchar* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		const gchar* _tmp16_ = NULL;
		gboolean _tmp17_ = FALSE;
		const gchar* _tmp18_ = NULL;
		gboolean _tmp19_ = FALSE;
		GomSerializationTestMotorOn* _tmp20_ = NULL;
		GomSerializationTestMotorOn* _tmp21_ = NULL;
		GomSerializationTestMotorOn* _tmp22_ = NULL;
		GomSerializationTestMotorOn* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		GomSerializationTestMotorTorque* _tmp25_ = NULL;
		GomSerializationTestMotorTorque* _tmp26_ = NULL;
		GomSerializationTestMotorTorque* _tmp27_ = NULL;
		GomSerializationTestMotorTorque* _tmp28_ = NULL;
		gdouble _tmp29_ = 0.0;
		GomSerializationTestMotorSpeed* _tmp30_ = NULL;
		GomSerializationTestMotorSpeed* _tmp31_ = NULL;
		GomSerializationTestMotorSpeed* _tmp32_ = NULL;
		GomSerializationTestMotorSpeed* _tmp33_ = NULL;
		gdouble _tmp34_ = 0.0;
		GomSerializationTestMotorTension* _tmp35_ = NULL;
		GomSerializationTestMotorTension* _tmp36_ = NULL;
		GomSerializationTestMotorTension* _tmp37_ = NULL;
		GomSerializationTestMotorTension* _tmp38_ = NULL;
		gint _tmp39_ = 0;
		GomSerializationTestMotorTensionType* _tmp40_ = NULL;
		GomSerializationTestMotorTensionType* _tmp41_ = NULL;
		GomSerializationTestMotorTensionType* _tmp42_ = NULL;
		GomSerializationTestMotorTensionType* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
#line 1042 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_motor_new ();
#line 1042 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		m = _tmp0_;
#line 1043 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = gom_serialization_test_motor_to_string (m);
#line 1043 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp1_;
#line 1047 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = s;
#line 1047 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = string_contains (_tmp2_, "<Motor/>");
#line 1047 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_, "\"<Motor/>\" in s");
#line 1048 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = gxml_xparser_new ((GXmlDomNode*) m);
#line 1048 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		parser = _tmp4_;
#line 1049 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) parser, "<Motor On=\"true\" Torque=\"3.1416\" Speed=\"3600.1011\" TensionType=\"" \
"dc\" Tension=\"125\"/>", NULL, &_inner_error_);
#line 1049 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1049 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1049 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1049 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (m);
#line 10552 "GomSerializationTest.c"
			goto __catch314_g_error;
		}
#line 1050 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = gom_serialization_test_motor_to_string (m);
#line 1050 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1050 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp5_;
#line 1054 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = s;
#line 1054 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = string_contains (_tmp6_, "<Motor ");
#line 1054 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp7_, "\"<Motor \" in s");
#line 1055 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = s;
#line 1055 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = string_contains (_tmp8_, "On=\"true\"");
#line 1055 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp9_, "\"On=\\\"true\\\"\" in s");
#line 1056 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = s;
#line 1056 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = string_contains (_tmp10_, "Torque=\"3.1416\"");
#line 1056 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp11_, "\"Torque=\\\"3.1416\\\"\" in s");
#line 1057 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = s;
#line 1057 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = string_contains (_tmp12_, "Speed=\"3600.1011\"");
#line 1057 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp13_, "\"Speed=\\\"3600.1011\\\"\" in s");
#line 1058 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = s;
#line 1058 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = string_contains (_tmp14_, "TensionType=\"dc\"");
#line 1058 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp15_, "\"TensionType=\\\"dc\\\"\" in s");
#line 1059 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = s;
#line 1059 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = string_contains (_tmp16_, "Tension=\"125\"");
#line 1059 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp17_, "\"Tension=\\\"125\\\"\" in s");
#line 1060 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = s;
#line 1060 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = string_contains (_tmp18_, "/>");
#line 1060 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp19_, "\"/>\" in s");
#line 1061 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = gom_serialization_test_motor_get_is_on (m);
#line 1061 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = _tmp20_;
#line 1061 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp21_ != NULL, "m.is_on != null");
#line 1062 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = gom_serialization_test_motor_get_is_on (m);
#line 1062 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1062 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gxml_gom_boolean_get_boolean ((GXmlGomBoolean*) _tmp23_);
#line 1062 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp24_ == TRUE, "m.is_on.get_boolean() == true");
#line 1063 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = gom_serialization_test_motor_get_torque (m);
#line 1063 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1063 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp26_ != NULL, "m.torque != null");
#line 1064 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = gom_serialization_test_motor_get_torque (m);
#line 1064 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1064 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = gxml_gom_double_get_double ((GXmlGomDouble*) _tmp28_);
#line 1064 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp29_ == 3.1416, "m.torque.get_double () == 3.1416");
#line 1065 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gom_serialization_test_motor_get_speed (m);
#line 1065 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 1065 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp31_ != NULL, "m.speed != null");
#line 1066 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = gom_serialization_test_motor_get_speed (m);
#line 1066 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = _tmp32_;
#line 1066 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = gxml_gom_double_get_double ((GXmlGomDouble*) _tmp33_);
#line 1066 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp34_ == 3600.1011, "m.speed.get_double () == 3600.1011");
#line 1067 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = gom_serialization_test_motor_get_tension (m);
#line 1067 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = _tmp35_;
#line 1067 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp36_ != NULL, "m.tension != null");
#line 1068 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = gom_serialization_test_motor_get_tension (m);
#line 1068 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1068 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = gxml_gom_int_get_integer ((GXmlGomInt*) _tmp38_);
#line 1068 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp39_ == 125, "m.tension.get_integer () == 125");
#line 1069 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gom_serialization_test_motor_get_tension_type (m);
#line 1069 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 1069 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp41_ != NULL, "m.tension_type != null");
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = gom_serialization_test_motor_get_tension_type (m);
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = gxml_gom_base_property_get_value ((GXmlGomBaseProperty*) _tmp43_);
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "dc") == 0, "m.tension_type.value == \"dc\"");
#line 1070 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp46_);
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (m);
#line 10685 "GomSerializationTest.c"
	}
	goto __finally314;
	__catch314_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1072 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = e->message;
#line 1072 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = g_strconcat ("Error: ", _tmp47_, NULL);
#line 1072 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1072 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1072: %s", _tmp49_);
#line 1072 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp49_);
#line 1073 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 10712 "GomSerializationTest.c"
	}
	__finally314:
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1041 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 10723 "GomSerializationTest.c"
	}
}


static void ___lambda276__gtest_func (void) {
#line 1040 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda276_ ();
#line 10731 "GomSerializationTest.c"
}


static void __lambda277_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		GXmlXParser* parser = NULL;
		GomSerializationTestBookStand* _tmp5_ = NULL;
		GXmlXParser* _tmp6_ = NULL;
		GXmlXParser* _tmp7_ = NULL;
		GomSerializationTestBookStand* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GomSerializationTestBookStand* _tmp10_ = NULL;
		GomSerializationTestRegisters* _tmp11_ = NULL;
		GomSerializationTestRegisters* _tmp12_ = NULL;
		GomSerializationTestBookStand* _tmp13_ = NULL;
		GomSerializationTestRegisters* _tmp14_ = NULL;
		GomSerializationTestRegisters* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GomSerializationTestBookStand* _tmp18_ = NULL;
		GomSerializationTestRegisters* _tmp19_ = NULL;
		GomSerializationTestRegisters* _tmp20_ = NULL;
		GQueue* _tmp21_ = NULL;
		GQueue* _tmp22_ = NULL;
		gconstpointer _tmp23_ = NULL;
		GomSerializationTestBookStand* _tmp24_ = NULL;
		GomSerializationTestRegisters* _tmp25_ = NULL;
		GomSerializationTestRegisters* _tmp26_ = NULL;
		GQueue* _tmp27_ = NULL;
		GQueue* _tmp28_ = NULL;
		gconstpointer _tmp29_ = NULL;
		GomSerializationTestBookStand* _tmp30_ = NULL;
		GomSerializationTestRegisters* _tmp31_ = NULL;
		GomSerializationTestRegisters* _tmp32_ = NULL;
		GQueue* _tmp33_ = NULL;
		GQueue* _tmp34_ = NULL;
		gconstpointer _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GomSerializationTestBookStand* _tmp37_ = NULL;
		GomSerializationTestRegisters* _tmp38_ = NULL;
		GomSerializationTestRegisters* _tmp39_ = NULL;
		GXmlDomElement* _tmp40_ = NULL;
		GXmlDomElement* _tmp41_ = NULL;
		GomSerializationTestBookStand* _tmp42_ = NULL;
		GomSerializationTestRegisters* _tmp43_ = NULL;
		GomSerializationTestRegisters* _tmp44_ = NULL;
		GXmlDomElement* _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GomSerializationTestBookStand* _tmp47_ = NULL;
		GomSerializationTestRegisters* _tmp48_ = NULL;
		GomSerializationTestRegisters* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomElement* _tmp51_ = NULL;
		GomSerializationTestBookStand* _tmp52_ = NULL;
		GomSerializationTestRegisters* _tmp53_ = NULL;
		GomSerializationTestRegisters* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomElement* _tmp56_ = NULL;
		GomSerializationTestBookStand* _tmp57_ = NULL;
		GomSerializationTestRegisters* _tmp58_ = NULL;
		GomSerializationTestRegisters* _tmp59_ = NULL;
		GXmlDomElement* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GomSerializationTestBookStand* _tmp62_ = NULL;
		GomSerializationTestRegisters* _tmp63_ = NULL;
		GomSerializationTestRegisters* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GomSerializationTestBookStand* _tmp67_ = NULL;
		GomSerializationTestRegisters* _tmp68_ = NULL;
		GomSerializationTestRegisters* _tmp69_ = NULL;
		GXmlDomElement* _tmp70_ = NULL;
		GXmlDomElement* _tmp71_ = NULL;
		GomSerializationTestBookStand* _tmp72_ = NULL;
		GomSerializationTestRegisters* _tmp73_ = NULL;
		GomSerializationTestRegisters* _tmp74_ = NULL;
		GXmlDomElement* _tmp75_ = NULL;
		GXmlDomElement* _tmp76_ = NULL;
		GomSerializationTestBookStand* _tmp77_ = NULL;
		GomSerializationTestRegisters* _tmp78_ = NULL;
		GomSerializationTestRegisters* _tmp79_ = NULL;
		GXmlDomElement* _tmp80_ = NULL;
		GXmlDomElement* _tmp81_ = NULL;
		GomSerializationTestBookStand* _tmp82_ = NULL;
		GomSerializationTestRegisters* _tmp83_ = NULL;
		GomSerializationTestRegisters* _tmp84_ = NULL;
		GXmlDomElement* _tmp85_ = NULL;
		gint _tmp86_ = 0;
		gint _tmp87_ = 0;
		GXmlDomElement* _tmp88_ = NULL;
		GomSerializationTestBookStand* _tmp89_ = NULL;
		GomSerializationTestRegisters* _tmp90_ = NULL;
		GomSerializationTestRegisters* _tmp91_ = NULL;
		GXmlDomElement* _tmp92_ = NULL;
		gint _tmp93_ = 0;
		gint _tmp94_ = 0;
		GXmlDomElement* _tmp95_ = NULL;
		GomSerializationTestBookStand* _tmp96_ = NULL;
		GomSerializationTestRegisters* _tmp97_ = NULL;
		GomSerializationTestRegisters* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		gint _tmp100_ = 0;
		gint _tmp101_ = 0;
#line 1078 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 1078 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 1079 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = bs;
#line 1079 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 1079 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp2_;
#line 1083 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = s;
#line 1083 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = string_contains (_tmp3_, "<BookStand Classification=\"Science\"/>");
#line 1083 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp4_, "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 1084 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = bs;
#line 1084 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = gxml_xparser_new ((GXmlDomNode*) _tmp5_);
#line 1084 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		parser = _tmp6_;
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = parser;
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_parser_read_string ((GXmlParser*) _tmp7_, "<BookStand Classification=\"Science\"><BookRegister Year=\"2016\"/><Bo" \
"okRegister Year=\"2010\"/><Test/><BookRegister Year=\"2000\"/></BookSt" \
"and>", NULL, &_inner_error_);
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1085 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 10877 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1086 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = bs;
#line 1086 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = gom_serialization_test_book_stand_to_string (_tmp8_);
#line 1086 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1086 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp9_;
#line 1091 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = bs;
#line 1091 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = gom_serialization_test_book_stand_get_registers (_tmp10_);
#line 1091 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1091 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp12_ != NULL, "bs.registers != null");
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = bs;
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = gom_serialization_test_book_stand_get_registers (_tmp13_);
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = _tmp14_;
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp15_);
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1092 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp17_ == 3, "bs.registers.length == 3");
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = bs;
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = gom_serialization_test_book_stand_get_registers (_tmp18_);
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp20_);
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = g_queue_peek_nth (_tmp22_, (guint) 0);
#line 1093 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp23_)) == 0, "bs.registers.nodes_index.peek_nth (0) == 0");
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = bs;
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = gom_serialization_test_book_stand_get_registers (_tmp24_);
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp26_);
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = g_queue_peek_nth (_tmp28_, (guint) 1);
#line 1094 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp29_)) == 1, "bs.registers.nodes_index.peek_nth (1) == 1");
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = bs;
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = gom_serialization_test_book_stand_get_registers (_tmp30_);
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = _tmp31_;
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp32_);
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = g_queue_peek_nth (_tmp34_, (guint) 2);
#line 1095 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp35_)) == 3, "bs.registers.nodes_index.peek_nth (2) == 3");
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = bs;
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = gom_serialization_test_book_stand_get_registers (_tmp37_);
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = _tmp38_;
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp39_, 0, &_inner_error_);
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = _tmp40_;
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 10968 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1096 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp36_ != NULL, "bs.registers.get_item (0) != null");
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = bs;
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = gom_serialization_test_book_stand_get_registers (_tmp42_);
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp44_, 0, &_inner_error_);
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp45_;
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 10993 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1097 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (0) is DomElement");
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = bs;
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = gom_serialization_test_book_stand_get_registers (_tmp47_);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp49_, 0, &_inner_error_);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp50_;
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11020 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1098 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp46_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (0) is BookRegister");
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = bs;
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = gom_serialization_test_book_stand_get_registers (_tmp52_);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp54_, 1, &_inner_error_);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = _tmp55_;
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11049 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1099 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp51_ != NULL, "bs.registers.get_item (1) != null");
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = bs;
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = gom_serialization_test_book_stand_get_registers (_tmp57_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp59_, 1, &_inner_error_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = _tmp60_;
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11080 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1100 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (1) is DomElement");
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = bs;
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = gom_serialization_test_book_stand_get_registers (_tmp62_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = _tmp63_;
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp64_, 1, &_inner_error_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = _tmp65_;
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11113 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1101 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (1) is BookRegister");
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = bs;
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = gom_serialization_test_book_stand_get_registers (_tmp67_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = _tmp68_;
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp69_, 2, &_inner_error_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = _tmp70_;
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11148 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1102 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp66_ != NULL, "bs.registers.get_item (2) != null");
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = bs;
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = gom_serialization_test_book_stand_get_registers (_tmp72_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = _tmp73_;
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp74_, 2, &_inner_error_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = _tmp75_;
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11185 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1103 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GXML_TYPE_DOM_ELEMENT), "bs.registers.get_item (2) is DomElement");
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = bs;
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = gom_serialization_test_book_stand_get_registers (_tmp77_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = _tmp78_;
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp79_, 2, &_inner_error_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = _tmp80_;
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11224 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1104 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp76_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER), "bs.registers.get_item (2) is BookRegister");
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = bs;
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = gom_serialization_test_book_stand_get_registers (_tmp82_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = _tmp83_;
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp84_, 0, &_inner_error_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = _tmp85_;
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11265 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp81_) : NULL);
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = _tmp86_;
#line 1105 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp87_ == 2016, "(bs.registers.get_item (0) as BookRegister).year == 2016");
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = bs;
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = gom_serialization_test_book_stand_get_registers (_tmp89_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = _tmp90_;
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp91_, 1, &_inner_error_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = _tmp92_;
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11312 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp88_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp88_) : NULL);
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 1106 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp94_ == 2010, "(bs.registers.get_item (1) as BookRegister).year == 2010");
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = bs;
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = gom_serialization_test_book_stand_get_registers (_tmp96_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = _tmp97_;
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp98_, 2, &_inner_error_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = _tmp99_;
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp88_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp41_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp36_);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (parser);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11361 "GomSerializationTest.c"
			goto __catch315_g_error;
		}
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp100_ = gom_serialization_test_book_register_get_year (G_TYPE_CHECK_INSTANCE_TYPE (_tmp95_, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER) ? ((GomSerializationTestBookRegister*) _tmp95_) : NULL);
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp101_ = _tmp100_;
#line 1107 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp101_ == 2000, "(bs.registers.get_item (2) as BookRegister).year == 2000");
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp95_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp88_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp81_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp76_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp71_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp66_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp61_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp56_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp51_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp46_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp41_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp36_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 11400 "GomSerializationTest.c"
	}
	goto __finally315;
	__catch315_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = e->message;
#line 1109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = g_strconcat ("Error: ", _tmp102_, NULL);
#line 1109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = _tmp103_;
#line 1109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1109: %s", _tmp104_);
#line 1109 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp104_);
#line 1110 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 11427 "GomSerializationTest.c"
	}
	__finally315:
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1077 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 11438 "GomSerializationTest.c"
	}
}


static void ___lambda277__gtest_func (void) {
#line 1076 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda277_ ();
#line 11446 "GomSerializationTest.c"
}


static void __lambda278_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomSerializationTestBookStand* bs = NULL;
		GomSerializationTestBookStand* _tmp0_ = NULL;
		gchar* s = NULL;
		GomSerializationTestBookStand* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gboolean _tmp4_ = FALSE;
		GomSerializationTestBookStand* _tmp5_ = NULL;
		GomSerializationTestBookStand* _tmp6_ = NULL;
		GomSerializationTestBooks* _tmp7_ = NULL;
		GomSerializationTestBooks* _tmp8_ = NULL;
		GomSerializationTestBookStand* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GomSerializationTestBookStand* _tmp14_ = NULL;
		GomSerializationTestBooks* _tmp15_ = NULL;
		GomSerializationTestBooks* _tmp16_ = NULL;
		gint _tmp17_ = 0;
		gint _tmp18_ = 0;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		GomSerializationTestBookStand* _tmp23_ = NULL;
		GomSerializationTestBooks* _tmp24_ = NULL;
		GomSerializationTestBooks* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		GomSerializationTestBookStand* _tmp28_ = NULL;
		GomSerializationTestBooks* _tmp29_ = NULL;
		GomSerializationTestBooks* _tmp30_ = NULL;
		GQueue* _tmp31_ = NULL;
		GQueue* _tmp32_ = NULL;
		gconstpointer _tmp33_ = NULL;
		GomSerializationTestBookStand* _tmp34_ = NULL;
		GomSerializationTestBooks* _tmp35_ = NULL;
		GomSerializationTestBooks* _tmp36_ = NULL;
		GQueue* _tmp37_ = NULL;
		GQueue* _tmp38_ = NULL;
		gconstpointer _tmp39_ = NULL;
		GomSerializationTestBookStand* _tmp40_ = NULL;
		GomSerializationTestBooks* _tmp41_ = NULL;
		GomSerializationTestBooks* _tmp42_ = NULL;
		GQueue* _tmp43_ = NULL;
		GQueue* _tmp44_ = NULL;
		gconstpointer _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GomSerializationTestBookStand* _tmp47_ = NULL;
		GomSerializationTestBooks* _tmp48_ = NULL;
		GomSerializationTestBooks* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomElement* _tmp51_ = NULL;
		GomSerializationTestBookStand* _tmp52_ = NULL;
		GomSerializationTestBooks* _tmp53_ = NULL;
		GomSerializationTestBooks* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomElement* _tmp56_ = NULL;
		GomSerializationTestBookStand* _tmp57_ = NULL;
		GomSerializationTestBooks* _tmp58_ = NULL;
		GomSerializationTestBooks* _tmp59_ = NULL;
		GXmlDomElement* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GomSerializationTestBookStand* _tmp62_ = NULL;
		GomSerializationTestBooks* _tmp63_ = NULL;
		GomSerializationTestBooks* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GomSerializationTestBookStand* _tmp67_ = NULL;
		GomSerializationTestBooks* _tmp68_ = NULL;
		GomSerializationTestBooks* _tmp69_ = NULL;
		GXmlDomElement* _tmp70_ = NULL;
		GXmlDomElement* _tmp71_ = NULL;
		GomSerializationTestBookStand* _tmp72_ = NULL;
		GomSerializationTestBooks* _tmp73_ = NULL;
		GomSerializationTestBooks* _tmp74_ = NULL;
		GXmlDomElement* _tmp75_ = NULL;
		GXmlDomElement* _tmp76_ = NULL;
		GomSerializationTestBookStand* _tmp77_ = NULL;
		GomSerializationTestBooks* _tmp78_ = NULL;
		GomSerializationTestBooks* _tmp79_ = NULL;
		GXmlDomElement* _tmp80_ = NULL;
		GXmlDomElement* _tmp81_ = NULL;
		GomSerializationTestBookStand* _tmp82_ = NULL;
		GomSerializationTestBooks* _tmp83_ = NULL;
		GomSerializationTestBooks* _tmp84_ = NULL;
		GXmlDomElement* _tmp85_ = NULL;
		GXmlDomElement* _tmp86_ = NULL;
		GomSerializationTestBookStand* _tmp87_ = NULL;
		GomSerializationTestBooks* _tmp88_ = NULL;
		GomSerializationTestBooks* _tmp89_ = NULL;
		GXmlDomElement* _tmp90_ = NULL;
		GXmlDomElement* _tmp91_ = NULL;
		GomSerializationTestBookStand* _tmp92_ = NULL;
		GomSerializationTestBooks* _tmp93_ = NULL;
		GomSerializationTestBooks* _tmp94_ = NULL;
		GXmlDomElement* _tmp95_ = NULL;
		const gchar* _tmp96_ = NULL;
		const gchar* _tmp97_ = NULL;
		GXmlDomElement* _tmp98_ = NULL;
		GomSerializationTestBookStand* _tmp99_ = NULL;
		GomSerializationTestBooks* _tmp100_ = NULL;
		GomSerializationTestBooks* _tmp101_ = NULL;
		GXmlDomElement* _tmp102_ = NULL;
		const gchar* _tmp103_ = NULL;
		const gchar* _tmp104_ = NULL;
		GXmlDomElement* _tmp105_ = NULL;
		GomSerializationTestBookStand* _tmp106_ = NULL;
		GomSerializationTestBooks* _tmp107_ = NULL;
		GomSerializationTestBooks* _tmp108_ = NULL;
		GXmlDomElement* _tmp109_ = NULL;
		const gchar* _tmp110_ = NULL;
		const gchar* _tmp111_ = NULL;
		GomSerializationTestBookStand* _tmp112_ = NULL;
		GomSerializationTestBooks* _tmp113_ = NULL;
		GomSerializationTestBooks* _tmp114_ = NULL;
		GXmlDomElement* _tmp115_ = NULL;
		GXmlDomElement* _tmp116_ = NULL;
		GomSerializationTestBookStand* _tmp117_ = NULL;
		GomSerializationTestBooks* _tmp118_ = NULL;
		GomSerializationTestBooks* _tmp119_ = NULL;
		GXmlDomElement* _tmp120_ = NULL;
		GXmlDomElement* _tmp121_ = NULL;
		GomSerializationTestBookStand* _tmp122_ = NULL;
		GomSerializationTestBooks* _tmp123_ = NULL;
		GomSerializationTestBooks* _tmp124_ = NULL;
		GXmlDomElement* _tmp125_ = NULL;
		GXmlDomElement* _tmp126_ = NULL;
		GomSerializationTestBookStand* _tmp127_ = NULL;
		GomSerializationTestBooks* _tmp128_ = NULL;
		GomSerializationTestBooks* _tmp129_ = NULL;
		GXmlDomElement* _tmp130_ = NULL;
		GXmlDomElement* _tmp131_ = NULL;
		GomSerializationTestBookStand* _tmp132_ = NULL;
		GomSerializationTestBooks* _tmp133_ = NULL;
		GomSerializationTestBooks* _tmp134_ = NULL;
		GXmlDomElement* _tmp135_ = NULL;
		GXmlDomElement* _tmp136_ = NULL;
		GomSerializationTestBookStand* _tmp137_ = NULL;
		GomSerializationTestBooks* _tmp138_ = NULL;
		GomSerializationTestBooks* _tmp139_ = NULL;
		GXmlDomElement* _tmp140_ = NULL;
		GXmlDomElement* _tmp141_ = NULL;
		GomSerializationTestBookStand* _tmp142_ = NULL;
		GomSerializationTestBooks* _tmp143_ = NULL;
		GomSerializationTestBooks* _tmp144_ = NULL;
		GXmlDomElement* _tmp145_ = NULL;
		GXmlDomElement* _tmp146_ = NULL;
		GomSerializationTestBookStand* _tmp147_ = NULL;
		GomSerializationTestBooks* _tmp148_ = NULL;
		GomSerializationTestBooks* _tmp149_ = NULL;
		GXmlDomElement* _tmp150_ = NULL;
		GXmlDomElement* _tmp151_ = NULL;
		GomSerializationTestBookStand* _tmp152_ = NULL;
		GomSerializationTestBooks* _tmp153_ = NULL;
		GomSerializationTestBooks* _tmp154_ = NULL;
		GXmlDomElement* _tmp155_ = NULL;
		GXmlDomElement* _tmp156_ = NULL;
		GomSerializationTestBookStand* _tmp157_ = NULL;
		GomSerializationTestBooks* _tmp158_ = NULL;
		GomSerializationTestBooks* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlDomElement* _tmp161_ = NULL;
#line 1115 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_serialization_test_book_stand_new ();
#line 1115 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp0_;
#line 1116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = bs;
#line 1116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = gom_serialization_test_book_stand_to_string (_tmp1_);
#line 1116 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp2_;
#line 1120 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = s;
#line 1120 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = string_contains (_tmp3_, "<BookStand Classification=\"Science\"/>");
#line 1120 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp4_, "\"<BookStand Classification=\\\"Science\\\"/>\" in s");
#line 1121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = bs;
#line 1121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp5_, "<bookStand Classification=\"Science\"><book name=\"Title1\"/><book nam" \
"e=\"Title2\"/><Test/><book name=\"Title3\"/></bookStand>", &_inner_error_);
#line 1121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1121 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11643 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1123 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = bs;
#line 1123 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gom_serialization_test_book_stand_get_books (_tmp6_);
#line 1123 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1123 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp8_ != NULL, "bs.books != null");
#line 1124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = bs;
#line 1124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = gom_serialization_test_book_stand_to_string (_tmp9_);
#line 1124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1124 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp10_;
#line 1125 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = s;
#line 1125 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = g_strconcat ("doc:", _tmp11_, NULL);
#line 1125 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = _tmp12_;
#line 1125 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1125: %s", _tmp13_);
#line 1125 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp13_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = bs;
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gom_serialization_test_book_stand_get_books (_tmp14_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = _tmp15_;
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp16_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = _tmp17_;
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = g_strdup_printf ("%i", _tmp18_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = g_strconcat ("Books: ", _tmp20_, NULL);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1126: %s", _tmp22_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp22_);
#line 1126 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp20_);
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = bs;
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gom_serialization_test_book_stand_get_books (_tmp23_);
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp25_);
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = _tmp26_;
#line 1127 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp27_ == 3, "bs.books.length == 3");
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = bs;
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = gom_serialization_test_book_stand_get_books (_tmp28_);
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = _tmp29_;
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp30_);
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = _tmp31_;
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = g_queue_peek_nth (_tmp32_, (guint) 0);
#line 1128 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp33_)) == 0, "bs.books.nodes_index.peek_nth (0) == 0");
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = bs;
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = gom_serialization_test_book_stand_get_books (_tmp34_);
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = _tmp35_;
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp36_);
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = g_queue_peek_nth (_tmp38_, (guint) 1);
#line 1129 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp39_)) == 1, "bs.books.nodes_index.peek_nth (1) == 1");
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = bs;
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = gom_serialization_test_book_stand_get_books (_tmp40_);
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = _tmp41_;
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = gxml_gom_collection_get_nodes_index ((GXmlGomCollection*) _tmp42_);
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = g_queue_peek_nth (_tmp44_, (guint) 2);
#line 1130 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (((gint) ((gintptr) _tmp45_)) == 3, "bs.books.nodes_index.peek_nth (2) == 3");
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = bs;
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = gom_serialization_test_book_stand_get_books (_tmp47_);
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp49_, 0, &_inner_error_);
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp50_;
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11766 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1131 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp46_ != NULL, "bs.books.get_item (0) != null");
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = bs;
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = gom_serialization_test_book_stand_get_books (_tmp52_);
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp54_, 0, &_inner_error_);
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = _tmp55_;
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11789 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1132 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (0) is DomElement");
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = bs;
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = gom_serialization_test_book_stand_get_books (_tmp57_);
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp59_, 0, &_inner_error_);
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = _tmp60_;
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11814 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1133 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (0) is Book");
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = bs;
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = gom_serialization_test_book_stand_get_books (_tmp62_);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = _tmp63_;
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp64_, 1, &_inner_error_);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = _tmp65_;
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11841 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1134 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp61_ != NULL, "bs.books.get_item (1) != null");
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = bs;
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = gom_serialization_test_book_stand_get_books (_tmp67_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = _tmp68_;
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp69_, 1, &_inner_error_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = _tmp70_;
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11870 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1135 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (1) is DomElement");
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = bs;
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = gom_serialization_test_book_stand_get_books (_tmp72_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = _tmp73_;
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp74_, 1, &_inner_error_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = _tmp75_;
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11901 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1136 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (1) is Book");
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = bs;
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = gom_serialization_test_book_stand_get_books (_tmp77_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = _tmp78_;
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp79_, 2, &_inner_error_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = _tmp80_;
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11934 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1137 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp76_ != NULL, "bs.books.get_item (2) != null");
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = bs;
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = gom_serialization_test_book_stand_get_books (_tmp82_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = _tmp83_;
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp84_, 2, &_inner_error_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = _tmp85_;
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 11969 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1138 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp81_, GXML_TYPE_DOM_ELEMENT), "bs.books.get_item (2) is DomElement");
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = bs;
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = gom_serialization_test_book_stand_get_books (_tmp87_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = _tmp88_;
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp89_, 2, &_inner_error_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = _tmp90_;
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12006 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1139 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp86_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get_item (2) is Book");
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = bs;
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = gom_serialization_test_book_stand_get_books (_tmp92_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp94_, 0, &_inner_error_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = _tmp95_;
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp86_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12045 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp91_) : NULL);
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = _tmp96_;
#line 1140 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp97_, "Title1") == 0, "(bs.books.get_item (0) as Book).name == \"Title1\"");
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = bs;
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp100_ = gom_serialization_test_book_stand_get_books (_tmp99_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp101_ = _tmp100_;
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp101_, 1, &_inner_error_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = _tmp102_;
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp91_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp86_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12090 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp98_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp98_) : NULL);
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = _tmp103_;
#line 1141 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp104_, "Title2") == 0, "(bs.books.get_item (1) as Book).name == \"Title2\"");
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp106_ = bs;
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp107_ = gom_serialization_test_book_stand_get_books (_tmp106_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp108_ = _tmp107_;
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp109_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp108_, 2, &_inner_error_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp105_ = _tmp109_;
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp98_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp91_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp86_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp81_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp71_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp66_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp61_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp56_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp46_);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (s);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 12137 "GomSerializationTest.c"
			goto __catch316_g_error;
		}
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp110_ = gom_serialization_test_book_get_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp105_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp105_) : NULL);
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp111_ = _tmp110_;
#line 1142 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp111_, "Title3") == 0, "(bs.books.get_item (2) as Book).name == \"Title3\"");
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp112_ = bs;
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp113_ = gom_serialization_test_book_stand_get_books (_tmp112_);
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp114_ = _tmp113_;
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp115_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp114_, "Title1");
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp116_ = _tmp115_;
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp116_ != NULL, "bs.books.get (\"Title1\") != null");
#line 1143 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp116_);
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp117_ = bs;
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp118_ = gom_serialization_test_book_stand_get_books (_tmp117_);
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp119_ = _tmp118_;
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp120_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp119_, "Title1");
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp121_ = _tmp120_;
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp121_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title1\") is DomElement");
#line 1144 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp121_);
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp122_ = bs;
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp123_ = gom_serialization_test_book_stand_get_books (_tmp122_);
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp124_ = _tmp123_;
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp125_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp124_, "Title1");
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp126_ = _tmp125_;
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp126_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title1\") is Book");
#line 1145 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp126_);
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp127_ = bs;
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp128_ = gom_serialization_test_book_stand_get_books (_tmp127_);
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp129_ = _tmp128_;
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp130_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp129_, "Title2");
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp131_ = _tmp130_;
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp131_ != NULL, "bs.books.get (\"Title2\") != null");
#line 1146 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp131_);
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp132_ = bs;
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp133_ = gom_serialization_test_book_stand_get_books (_tmp132_);
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp134_ = _tmp133_;
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp135_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp134_, "Title2");
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp136_ = _tmp135_;
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp136_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title2\") is DomElement");
#line 1147 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp136_);
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp137_ = bs;
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp138_ = gom_serialization_test_book_stand_get_books (_tmp137_);
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp139_ = _tmp138_;
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp140_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp139_, "Title2");
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp141_ = _tmp140_;
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp141_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title2\") is Book");
#line 1148 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp141_);
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp142_ = bs;
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp143_ = gom_serialization_test_book_stand_get_books (_tmp142_);
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp144_ = _tmp143_;
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp145_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp144_, "Title3");
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp146_ = _tmp145_;
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp146_ != NULL, "bs.books.get (\"Title3\") != null");
#line 1149 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp146_);
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp147_ = bs;
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp148_ = gom_serialization_test_book_stand_get_books (_tmp147_);
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp149_ = _tmp148_;
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp150_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp149_, "Title3");
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp151_ = _tmp150_;
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp151_, GXML_TYPE_DOM_ELEMENT), "bs.books.get (\"Title3\") is DomElement");
#line 1150 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp151_);
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp152_ = bs;
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp153_ = gom_serialization_test_book_stand_get_books (_tmp152_);
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp154_ = _tmp153_;
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp155_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp154_, "Title3");
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp156_ = _tmp155_;
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp156_, GOM_SERIALIZATION_TEST_TYPE_BOOK), "bs.books.get (\"Title3\") is Book");
#line 1151 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp156_);
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp157_ = bs;
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp158_ = gom_serialization_test_book_stand_get_books (_tmp157_);
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp159_ = _tmp158_;
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp160_ = gxml_gom_hash_map_get ((GXmlGomHashMap*) _tmp159_, "Title4");
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp161_ = _tmp160_;
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp161_ == NULL, "bs.books.get (\"Title4\") == null");
#line 1152 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp161_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp105_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp98_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp91_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp86_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp81_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp76_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp71_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp66_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp61_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp56_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp51_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp46_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 12314 "GomSerializationTest.c"
	}
	goto __finally316;
	__catch316_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp162_ = NULL;
		gchar* _tmp163_ = NULL;
		gchar* _tmp164_ = NULL;
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1154 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp162_ = e->message;
#line 1154 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp163_ = g_strconcat ("Error: ", _tmp162_, NULL);
#line 1154 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp164_ = _tmp163_;
#line 1154 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1154: %s", _tmp164_);
#line 1154 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp164_);
#line 1155 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 12341 "GomSerializationTest.c"
	}
	__finally316:
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1114 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 12352 "GomSerializationTest.c"
	}
}


static void ___lambda278__gtest_func (void) {
#line 1113 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda278_ ();
#line 12360 "GomSerializationTest.c"
}


static void __lambda279_ (void) {
	GError * _inner_error_ = NULL;
	{
		gdouble time = 0.0;
		GFile* f = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GomBookStore* bs = NULL;
		GomBookStore* _tmp3_ = NULL;
		GomBookStore* _tmp4_ = NULL;
		GomBookStore* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		GomBookStore* _tmp7_ = NULL;
		GomBookArray* _tmp8_ = NULL;
		GomBookArray* _tmp9_ = NULL;
		GomBookStore* _tmp10_ = NULL;
		GomBookArray* _tmp11_ = NULL;
		GomBookArray* _tmp12_ = NULL;
		GXmlGomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GomBookStore* _tmp15_ = NULL;
		GomBookArray* _tmp16_ = NULL;
		GomBookArray* _tmp17_ = NULL;
		GType _tmp18_ = 0UL;
		GType _tmp19_ = 0UL;
		gboolean _tmp20_ = FALSE;
		GomBookStore* _tmp21_ = NULL;
		GomBookArray* _tmp22_ = NULL;
		GomBookArray* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		GomBookStore* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		GomBookStore* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		GomBookStore* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		GomBookStore* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		gdouble _tmp39_ = 0.0;
		gdouble _tmp40_ = 0.0;
		gdouble _tmp41_ = 0.0;
		GFile* of = NULL;
		GFile* _tmp42_ = NULL;
		GomBookStore* _tmp43_ = NULL;
		GXmlDomDocument* _tmp44_ = NULL;
		GXmlDomDocument* _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GXmlDomElement* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		GomBookStore* _tmp54_ = NULL;
		GXmlDomNodeList* _tmp55_ = NULL;
		GXmlDomNodeList* _tmp56_ = NULL;
		GXmlDomNodeList* _tmp57_ = NULL;
		gint _tmp58_ = 0;
		gint _tmp59_ = 0;
		GXmlDomHTMLCollection* ns = NULL;
		GomBookStore* _tmp60_ = NULL;
		GXmlDomHTMLCollection* _tmp61_ = NULL;
		GXmlDomHTMLCollection* _tmp62_ = NULL;
		gint _tmp63_ = 0;
		gint _tmp64_ = 0;
		GomBookStore* _tmp65_ = NULL;
		GFile* _tmp66_ = NULL;
		gdouble _tmp67_ = 0.0;
		gdouble _tmp68_ = 0.0;
		gdouble _tmp69_ = 0.0;
		GFile* _tmp70_ = NULL;
		gboolean _tmp71_ = FALSE;
#line 1162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_DIR "/test-collection.xml");
#line 1162 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		f = _tmp0_;
#line 1163 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = f;
#line 1163 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 1163 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp2_, "f.query_exists ()");
#line 1164 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_test_timer_start ();
#line 1165 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gom_book_store_new ();
#line 1165 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bs = _tmp3_;
#line 1166 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = bs;
#line 1166 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp4_ != NULL, "bs != null");
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = bs;
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = f;
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_file ((GXmlGomElement*) _tmp5_, _tmp6_, NULL, &_inner_error_);
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1170 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 12476 "GomSerializationTest.c"
			goto __catch317_g_error;
		}
#line 1171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = bs;
#line 1171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = gom_book_store_get_books (_tmp7_);
#line 1171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp8_;
#line 1171 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp9_ != NULL, "bs.books != null");
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = bs;
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = gom_book_store_get_books (_tmp10_);
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = _tmp11_;
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = gxml_gom_collection_get_element ((GXmlGomCollection*) _tmp12_);
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = _tmp13_;
#line 1172 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp14_ != NULL, "bs.books.element != null");
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = bs;
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = gom_book_store_get_books (_tmp15_);
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = _tmp16_;
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = gxml_gom_collection_get_items_type ((GXmlGomCollection*) _tmp17_);
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = g_type_is_a (_tmp19_, TYPE_GOM_BOOK);
#line 1173 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp20_, "bs.books.items_type.is_a (typeof(GomBook))");
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = bs;
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = gom_book_store_get_books (_tmp21_);
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gxml_gom_collection_get_items_name ((GXmlGomCollection*) _tmp23_);
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1174 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp25_, "Book") == 0, "bs.books.items_name == \"Book\"");
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = bs;
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = gxml_dom_element_get_local_name ((GXmlDomElement*) _tmp26_);
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp29_, "BookStore") == 0, "bs.local_name == \"BookStore\"");
#line 1175 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp29_);
#line 1176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = bs;
#line 1176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp30_, "name");
#line 1176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = _tmp31_;
#line 1176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp32_ != NULL, "bs.get_attribute (\"name\") != null");
#line 1176 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp32_);
#line 1177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = bs;
#line 1177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = gom_book_store_get_name (_tmp33_);
#line 1177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1177 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp35_ != NULL, "bs.name != null");
#line 1178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = bs;
#line 1178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = gom_book_store_get_name (_tmp36_);
#line 1178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1178 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "The Great Book") == 0, "bs.name == \"The Great Book\"");
#line 1179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = g_test_timer_elapsed ();
#line 1179 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		time = _tmp39_;
#line 1180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = time;
#line 1180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = time;
#line 1180 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_test_minimized_result (_tmp40_, "deserialize/performance: %g seconds", _tmp41_);
#line 1184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = g_file_new_for_path (TEST_SAVE_DIR "/test-large-new.xml");
#line 1184 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		of = _tmp42_;
#line 1185 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_test_timer_start ();
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = bs;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp43_);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = _tmp44_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = gxml_dom_document_get_document_element (_tmp45_);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = _tmp46_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = _tmp47_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp48_);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = _tmp49_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = _tmp50_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = g_utf8_strdown (_tmp51_, (gssize) -1);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = _tmp52_;
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "bookstore") == 0, "bs.owner_document.document_element.node_name.down () == \"bookstore\"");
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp53_);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp51_);
#line 1190 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp48_);
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = bs;
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp54_);
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = _tmp55_;
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = _tmp56_;
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = gxml_dom_node_list_get_length (_tmp57_);
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp59_ == 7, "bs.child_nodes.length == 7");
#line 1194 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp57_);
#line 1195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = bs;
#line 1195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = gxml_dom_element_get_elements_by_tag_name ((GXmlDomElement*) _tmp60_, "Book");
#line 1195 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		ns = _tmp61_;
#line 1200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = ns;
#line 1200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = gxml_dom_html_collection_get_length (_tmp62_);
#line 1200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = _tmp63_;
#line 1200 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp64_ == 3, "ns.length == 3");
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = bs;
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = of;
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_write_file ((GXmlGomElement*) _tmp65_, _tmp66_, &_inner_error_);
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ns);
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (of);
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1205 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 12655 "GomSerializationTest.c"
			goto __catch317_g_error;
		}
#line 1206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = g_test_timer_elapsed ();
#line 1206 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		time = _tmp67_;
#line 1207 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = time;
#line 1207 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = time;
#line 1207 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_test_minimized_result (_tmp68_, "Serialize/performance: %g seconds", _tmp69_);
#line 1208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = of;
#line 1208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = g_file_query_exists (_tmp70_, NULL);
#line 1208 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp71_, "of.query_exists ()");
#line 12674 "GomSerializationTest.c"
		{
			GFile* _tmp72_ = NULL;
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_tmp72_ = of;
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_file_delete (_tmp72_, NULL, &_inner_error_);
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12683 "GomSerializationTest.c"
				goto __catch318_g_error;
			}
		}
		goto __finally318;
		__catch318_g_error:
		{
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_clear_error (&_inner_error_);
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_inner_error_ = NULL;
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			g_assert_not_reached ();
#line 12696 "GomSerializationTest.c"
		}
		__finally318:
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ns);
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (of);
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bs);
#line 1209 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (f);
#line 12709 "GomSerializationTest.c"
			goto __catch317_g_error;
		}
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (ns);
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (of);
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bs);
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (f);
#line 12720 "GomSerializationTest.c"
	}
	goto __finally317;
	__catch317_g_error:
	{
		GError* e = NULL;
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1215 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 12734 "GomSerializationTest.c"
	}
	__finally317:
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1160 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 12745 "GomSerializationTest.c"
	}
}


static void ___lambda279__gtest_func (void) {
#line 1158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda279_ ();
#line 12753 "GomSerializationTest.c"
}


static void _g_free0_ (gpointer var) {
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	var = (g_free (var), NULL);
#line 12760 "GomSerializationTest.c"
}


static void _g_list_free__g_free0_ (GList* self) {
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_list_foreach (self, (GFunc) _g_free0_, NULL);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_list_free (self);
#line 12769 "GomSerializationTest.c"
}


static void __lambda280_ (void) {
	GError * _inner_error_ = NULL;
	{
		Operations* ops = NULL;
		Operations* _tmp0_ = NULL;
		Operations* _tmp1_ = NULL;
		OperationMap* _tmp2_ = NULL;
		OperationMap* _tmp3_ = NULL;
		Operations* _tmp4_ = NULL;
		OperationMap* _tmp5_ = NULL;
		OperationMap* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
		Operation* op1 = NULL;
		Operations* _tmp9_ = NULL;
		OperationMap* _tmp10_ = NULL;
		OperationMap* _tmp11_ = NULL;
		GXmlGomElement* _tmp12_ = NULL;
		Operation* _tmp13_ = NULL;
		Operation* _tmp14_ = NULL;
		Operation* _tmp15_ = NULL;
		Operation* _tmp16_ = NULL;
		Operations* _tmp17_ = NULL;
		OperationMap* _tmp18_ = NULL;
		OperationMap* _tmp19_ = NULL;
		Operation* _tmp20_ = NULL;
		Operations* _tmp21_ = NULL;
		OperationMap* _tmp22_ = NULL;
		OperationMap* _tmp23_ = NULL;
		gint _tmp24_ = 0;
		gint _tmp25_ = 0;
		Operation* top1 = NULL;
		Operations* _tmp26_ = NULL;
		OperationMap* _tmp27_ = NULL;
		OperationMap* _tmp28_ = NULL;
		GXmlDomElement* _tmp29_ = NULL;
		Operation* _tmp30_ = NULL;
		Operation* _tmp31_ = NULL;
		Operation* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		Operation* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		GList* pkeys1 = NULL;
		Operations* _tmp38_ = NULL;
		OperationMap* _tmp39_ = NULL;
		OperationMap* _tmp40_ = NULL;
		GList* _tmp41_ = NULL;
		GList* _tmp42_ = NULL;
		guint _tmp43_ = 0U;
		Operation* op2 = NULL;
		Operations* _tmp44_ = NULL;
		OperationMap* _tmp45_ = NULL;
		OperationMap* _tmp46_ = NULL;
		GXmlGomElement* _tmp47_ = NULL;
		Operation* _tmp48_ = NULL;
		Operation* _tmp49_ = NULL;
		Operation* _tmp50_ = NULL;
		Operation* _tmp51_ = NULL;
		Operations* _tmp52_ = NULL;
		OperationMap* _tmp53_ = NULL;
		OperationMap* _tmp54_ = NULL;
		Operation* _tmp55_ = NULL;
		Operation* op3 = NULL;
		Operations* _tmp56_ = NULL;
		OperationMap* _tmp57_ = NULL;
		OperationMap* _tmp58_ = NULL;
		GXmlGomElement* _tmp59_ = NULL;
		Operation* _tmp60_ = NULL;
		Operation* _tmp61_ = NULL;
		Operation* _tmp62_ = NULL;
		Operation* _tmp63_ = NULL;
		Operations* _tmp64_ = NULL;
		OperationMap* _tmp65_ = NULL;
		OperationMap* _tmp66_ = NULL;
		Operation* _tmp67_ = NULL;
		Operations* _tmp68_ = NULL;
		OperationMap* _tmp69_ = NULL;
		OperationMap* _tmp70_ = NULL;
		gint _tmp71_ = 0;
		gint _tmp72_ = 0;
		Operation* op4 = NULL;
		Operations* _tmp73_ = NULL;
		OperationMap* _tmp74_ = NULL;
		OperationMap* _tmp75_ = NULL;
		GXmlGomElement* _tmp76_ = NULL;
		Operation* _tmp77_ = NULL;
		Operation* _tmp78_ = NULL;
		Operation* _tmp79_ = NULL;
		Operation* _tmp80_ = NULL;
		Operations* _tmp81_ = NULL;
		OperationMap* _tmp82_ = NULL;
		OperationMap* _tmp83_ = NULL;
		Operation* _tmp84_ = NULL;
		Operations* _tmp85_ = NULL;
		OperationMap* _tmp86_ = NULL;
		OperationMap* _tmp87_ = NULL;
		gint _tmp88_ = 0;
		gint _tmp89_ = 0;
		gchar* _tmp90_ = NULL;
		Operations* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		GList* pkeys2 = NULL;
		Operations* _tmp93_ = NULL;
		OperationMap* _tmp94_ = NULL;
		OperationMap* _tmp95_ = NULL;
		GList* _tmp96_ = NULL;
		GList* _tmp97_ = NULL;
		guint _tmp98_ = 0U;
		GList* _tmp99_ = NULL;
		GList* skeys1 = NULL;
		Operations* _tmp102_ = NULL;
		OperationMap* _tmp103_ = NULL;
		OperationMap* _tmp104_ = NULL;
		GList* _tmp105_ = NULL;
		GList* _tmp106_ = NULL;
		GList* _tmp109_ = NULL;
		guint _tmp110_ = 0U;
		Operation* _tmp111_ = NULL;
		Operations* _tmp112_ = NULL;
		OperationMap* _tmp113_ = NULL;
		OperationMap* _tmp114_ = NULL;
		Operations* _tmp115_ = NULL;
		OperationMap* _tmp116_ = NULL;
		OperationMap* _tmp117_ = NULL;
		gint _tmp118_ = 0;
		gint _tmp119_ = 0;
		GXmlDomElement* op3t = NULL;
		Operations* _tmp120_ = NULL;
		OperationMap* _tmp121_ = NULL;
		OperationMap* _tmp122_ = NULL;
		GXmlDomElement* _tmp123_ = NULL;
#line 1221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = operations_new ();
#line 1221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		ops = _tmp0_;
#line 1222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = ops;
#line 1222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = operations_get_map (_tmp1_);
#line 1222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 1222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "ops.map != null");
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = ops;
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = operations_get_map (_tmp4_);
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp6_);
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp8_ == 0, "ops.map.length == 0");
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = ops;
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = operations_get_map (_tmp9_);
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp11_);
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, TYPE_OPERATION) ? ((Operation*) _tmp12_) : NULL;
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp13_ == NULL) {
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp12_);
#line 12944 "GomSerializationTest.c"
		}
#line 1224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		op1 = _tmp13_;
#line 1225 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = op1;
#line 1225 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, TYPE_OPERATION), "op1 is Operation");
#line 1226 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = op1;
#line 1226 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_id (_tmp15_, "a1");
#line 1227 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = op1;
#line 1227 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_code (_tmp16_, "b1");
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = ops;
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = operations_get_map (_tmp17_);
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = op1;
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp19_, (GXmlDomElement*) _tmp20_, &_inner_error_);
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 12976 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = ops;
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = operations_get_map (_tmp21_);
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = _tmp22_;
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp23_);
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp25_ == 1, "ops.map.length == 1");
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = ops;
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = operations_get_map (_tmp26_);
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp28_, "a1", "b1");
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, TYPE_OPERATION) ? ((Operation*) _tmp29_) : NULL;
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp30_ == NULL) {
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp29_);
#line 13005 "GomSerializationTest.c"
		}
#line 1230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		top1 = _tmp30_;
#line 1231 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = top1;
#line 1231 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, TYPE_OPERATION), "top1 is Operation");
#line 1232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = top1;
#line 1232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = operation_get_id (_tmp32_);
#line 1232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = _tmp33_;
#line 1232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "a1") == 0, "top1.id == \"a1\"");
#line 1233 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = top1;
#line 1233 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = operation_get_code (_tmp35_);
#line 1233 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = _tmp36_;
#line 1233 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp37_, "b1") == 0, "top1.code == \"b1\"");
#line 1234 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = ops;
#line 1234 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = operations_get_map (_tmp38_);
#line 1234 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = _tmp39_;
#line 1234 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = gxml_gom_hash_paired_map_get_primary_keys ((GXmlGomHashPairedMap*) _tmp40_);
#line 1234 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		pkeys1 = _tmp41_;
#line 1235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = pkeys1;
#line 1235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = g_list_length (_tmp42_);
#line 1235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp43_ == ((guint) 1), "pkeys1.length () == 1");
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = ops;
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = operations_get_map (_tmp44_);
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp46_);
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp47_, TYPE_OPERATION) ? ((Operation*) _tmp47_) : NULL;
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp48_ == NULL) {
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp47_);
#line 13059 "GomSerializationTest.c"
		}
#line 1236 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		op2 = _tmp48_;
#line 1237 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = op2;
#line 1237 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp49_, TYPE_OPERATION), "op2 is Operation");
#line 1238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = op2;
#line 1238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_id (_tmp50_, "a1");
#line 1239 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = op2;
#line 1239 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_code (_tmp51_, "b2");
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = ops;
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = operations_get_map (_tmp52_);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = _tmp53_;
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = op2;
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp54_, (GXmlDomElement*) _tmp55_, &_inner_error_);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13097 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = ops;
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = operations_get_map (_tmp56_);
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp58_);
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, TYPE_OPERATION) ? ((Operation*) _tmp59_) : NULL;
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp60_ == NULL) {
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp59_);
#line 13114 "GomSerializationTest.c"
		}
#line 1241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		op3 = _tmp60_;
#line 1242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = op2;
#line 1242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp61_, TYPE_OPERATION), "op2 is Operation");
#line 1243 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = op3;
#line 1243 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_id (_tmp62_, "a2");
#line 1244 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = op3;
#line 1244 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_code (_tmp63_, "b1");
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = ops;
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = operations_get_map (_tmp64_);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = _tmp65_;
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = op3;
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp66_, (GXmlDomElement*) _tmp67_, &_inner_error_);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13154 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = ops;
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = operations_get_map (_tmp68_);
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = _tmp69_;
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp70_);
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = _tmp71_;
#line 1246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp72_ == 3, "ops.map.length == 3");
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = ops;
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = operations_get_map (_tmp73_);
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = _tmp74_;
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp75_);
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp76_, TYPE_OPERATION) ? ((Operation*) _tmp76_) : NULL;
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp77_ == NULL) {
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp76_);
#line 13183 "GomSerializationTest.c"
		}
#line 1247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		op4 = _tmp77_;
#line 1248 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = op4;
#line 1248 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp78_, TYPE_OPERATION), "op4 is Operation");
#line 1249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = op4;
#line 1249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_id (_tmp79_, "a2");
#line 1250 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = op4;
#line 1250 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		operation_set_code (_tmp80_, "b2");
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = ops;
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = operations_get_map (_tmp81_);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = _tmp82_;
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = op4;
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp83_, (GXmlDomElement*) _tmp84_, &_inner_error_);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1251 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13225 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = ops;
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = operations_get_map (_tmp85_);
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = _tmp86_;
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp87_);
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = _tmp88_;
#line 1252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp89_ == 4, "ops.map.length == 4");
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = ops;
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp91_, &_inner_error_);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = _tmp92_;
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13262 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1253 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1253: %s", _tmp90_);
#line 1254 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = ops;
#line 1254 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = operations_get_map (_tmp93_);
#line 1254 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = _tmp94_;
#line 1254 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = gxml_gom_hash_paired_map_get_primary_keys ((GXmlGomHashPairedMap*) _tmp95_);
#line 1254 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		pkeys2 = _tmp96_;
#line 1255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = pkeys2;
#line 1255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = g_list_length (_tmp97_);
#line 1255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp98_ == ((guint) 2), "pkeys2.length () == 2");
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = pkeys2;
#line 13285 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			pk_collection = _tmp99_;
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 13293 "GomSerializationTest.c"
				gchar* _tmp100_ = NULL;
				gchar* pk = NULL;
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				_tmp100_ = g_strdup ((const gchar*) pk_it->data);
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				pk = _tmp100_;
#line 13300 "GomSerializationTest.c"
				{
					const gchar* _tmp101_ = NULL;
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_tmp101_ = pk;
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1256: %s", _tmp101_);
#line 1256 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_g_free0 (pk);
#line 13309 "GomSerializationTest.c"
				}
			}
		}
#line 1257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = ops;
#line 1257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = operations_get_map (_tmp102_);
#line 1257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = _tmp103_;
#line 1257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp105_ = gxml_gom_hash_paired_map_get_secondary_keys ((GXmlGomHashPairedMap*) _tmp104_, "a1");
#line 1257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		skeys1 = _tmp105_;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp106_ = skeys1;
#line 13325 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			pk_collection = _tmp106_;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 13333 "GomSerializationTest.c"
				gchar* _tmp107_ = NULL;
				gchar* pk = NULL;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				_tmp107_ = g_strdup ((const gchar*) pk_it->data);
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				pk = _tmp107_;
#line 13340 "GomSerializationTest.c"
				{
					const gchar* _tmp108_ = NULL;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_tmp108_ = pk;
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1258: %s", _tmp108_);
#line 1258 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_g_free0 (pk);
#line 13349 "GomSerializationTest.c"
				}
			}
		}
#line 1259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp109_ = skeys1;
#line 1259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp110_ = g_list_length (_tmp109_);
#line 1259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp110_ == ((guint) 2), "skeys1.length () == 2");
#line 1260 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp111_ = op4;
#line 1260 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_dom_child_node_remove ((GXmlDomChildNode*) _tmp111_);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp112_ = ops;
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp113_ = operations_get_map (_tmp112_);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp114_ = _tmp113_;
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_search ((GXmlGomCollection*) _tmp114_, &_inner_error_);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (skeys1);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys2);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp90_);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op4);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op3);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op2);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (top1);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (op1);
#line 1261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ops);
#line 13393 "GomSerializationTest.c"
			goto __catch319_g_error;
		}
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp115_ = ops;
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp116_ = operations_get_map (_tmp115_);
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp117_ = _tmp116_;
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp118_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp117_);
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp119_ = _tmp118_;
#line 1262 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp119_ == 3, "ops.map.length == 3");
#line 1263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp120_ = ops;
#line 1263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp121_ = operations_get_map (_tmp120_);
#line 1263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp122_ = _tmp121_;
#line 1263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp123_ = gxml_gom_hash_paired_map_get ((GXmlGomHashPairedMap*) _tmp122_, "a2", "b1");
#line 1263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		op3t = _tmp123_;
#line 1264 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (op3t != NULL, "op3t != null");
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (op3t);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (skeys1);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (pkeys2);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp90_);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (op4);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (op3);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (op2);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (pkeys1);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (top1);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (op1);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (ops);
#line 13442 "GomSerializationTest.c"
	}
	goto __finally319;
	__catch319_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
		gchar* _tmp126_ = NULL;
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp124_ = e->message;
#line 1266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp125_ = g_strconcat ("ERROR: ", _tmp124_, NULL);
#line 1266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp126_ = _tmp125_;
#line 1266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1266: %s", _tmp126_);
#line 1266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp126_);
#line 1267 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 13469 "GomSerializationTest.c"
	}
	__finally319:
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1220 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 13480 "GomSerializationTest.c"
	}
}


static void ___lambda280__gtest_func (void) {
#line 1218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda280_ ();
#line 13488 "GomSerializationTest.c"
}


static void __lambda281_ (void) {
	GError * _inner_error_ = NULL;
	{
		ThreeKeys* ks = NULL;
		ThreeKeys* _tmp0_ = NULL;
		ThreeKeys* _tmp1_ = NULL;
		ThreeKeyMap* _tmp2_ = NULL;
		ThreeKeyMap* _tmp3_ = NULL;
		ThreeKeys* _tmp4_ = NULL;
		ThreeKeyMap* _tmp5_ = NULL;
		ThreeKeyMap* _tmp6_ = NULL;
		gint _tmp7_ = 0;
		gint _tmp8_ = 0;
		ThreeKey* k1 = NULL;
		ThreeKeys* _tmp9_ = NULL;
		ThreeKeyMap* _tmp10_ = NULL;
		ThreeKeyMap* _tmp11_ = NULL;
		GXmlGomElement* _tmp12_ = NULL;
		ThreeKey* _tmp13_ = NULL;
		ThreeKey* _tmp14_ = NULL;
		ThreeKey* _tmp15_ = NULL;
		ThreeKey* _tmp16_ = NULL;
		ThreeKey* _tmp17_ = NULL;
		ThreeKeys* _tmp18_ = NULL;
		ThreeKeyMap* _tmp19_ = NULL;
		ThreeKeyMap* _tmp20_ = NULL;
		ThreeKey* _tmp21_ = NULL;
		ThreeKeys* _tmp22_ = NULL;
		ThreeKeyMap* _tmp23_ = NULL;
		ThreeKeyMap* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		ThreeKey* tk1 = NULL;
		ThreeKeys* _tmp27_ = NULL;
		ThreeKeyMap* _tmp28_ = NULL;
		ThreeKeyMap* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		ThreeKey* _tmp31_ = NULL;
		ThreeKey* _tmp32_ = NULL;
		ThreeKey* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		ThreeKey* _tmp36_ = NULL;
		const gchar* _tmp37_ = NULL;
		const gchar* _tmp38_ = NULL;
		ThreeKey* _tmp39_ = NULL;
		const gchar* _tmp40_ = NULL;
		const gchar* _tmp41_ = NULL;
		GList* pkeys1 = NULL;
		ThreeKeys* _tmp42_ = NULL;
		ThreeKeyMap* _tmp43_ = NULL;
		ThreeKeyMap* _tmp44_ = NULL;
		GList* _tmp45_ = NULL;
		GList* _tmp46_ = NULL;
		guint _tmp47_ = 0U;
		ThreeKey* k2 = NULL;
		ThreeKeys* _tmp48_ = NULL;
		ThreeKeyMap* _tmp49_ = NULL;
		ThreeKeyMap* _tmp50_ = NULL;
		GXmlGomElement* _tmp51_ = NULL;
		ThreeKey* _tmp52_ = NULL;
		ThreeKey* _tmp53_ = NULL;
		ThreeKey* _tmp54_ = NULL;
		ThreeKey* _tmp55_ = NULL;
		ThreeKey* _tmp56_ = NULL;
		ThreeKeys* _tmp57_ = NULL;
		ThreeKeyMap* _tmp58_ = NULL;
		ThreeKeyMap* _tmp59_ = NULL;
		ThreeKey* _tmp60_ = NULL;
		ThreeKey* k3 = NULL;
		ThreeKeys* _tmp61_ = NULL;
		ThreeKeyMap* _tmp62_ = NULL;
		ThreeKeyMap* _tmp63_ = NULL;
		GXmlGomElement* _tmp64_ = NULL;
		ThreeKey* _tmp65_ = NULL;
		ThreeKey* _tmp66_ = NULL;
		ThreeKey* _tmp67_ = NULL;
		ThreeKey* _tmp68_ = NULL;
		ThreeKey* _tmp69_ = NULL;
		ThreeKeys* _tmp70_ = NULL;
		ThreeKeyMap* _tmp71_ = NULL;
		ThreeKeyMap* _tmp72_ = NULL;
		ThreeKey* _tmp73_ = NULL;
		ThreeKeys* _tmp74_ = NULL;
		ThreeKeyMap* _tmp75_ = NULL;
		ThreeKeyMap* _tmp76_ = NULL;
		gint _tmp77_ = 0;
		gint _tmp78_ = 0;
		ThreeKey* k4 = NULL;
		ThreeKeys* _tmp79_ = NULL;
		ThreeKeyMap* _tmp80_ = NULL;
		ThreeKeyMap* _tmp81_ = NULL;
		GXmlGomElement* _tmp82_ = NULL;
		ThreeKey* _tmp83_ = NULL;
		ThreeKey* _tmp84_ = NULL;
		ThreeKey* _tmp85_ = NULL;
		ThreeKey* _tmp86_ = NULL;
		ThreeKey* _tmp87_ = NULL;
		ThreeKeys* _tmp88_ = NULL;
		ThreeKeyMap* _tmp89_ = NULL;
		ThreeKeyMap* _tmp90_ = NULL;
		ThreeKey* _tmp91_ = NULL;
		ThreeKeys* _tmp92_ = NULL;
		ThreeKeyMap* _tmp93_ = NULL;
		ThreeKeyMap* _tmp94_ = NULL;
		gint _tmp95_ = 0;
		gint _tmp96_ = 0;
		gchar* _tmp97_ = NULL;
		ThreeKeys* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		GList* pkeys2 = NULL;
		ThreeKeys* _tmp100_ = NULL;
		ThreeKeyMap* _tmp101_ = NULL;
		ThreeKeyMap* _tmp102_ = NULL;
		GList* _tmp103_ = NULL;
		GList* _tmp104_ = NULL;
		guint _tmp105_ = 0U;
		GList* _tmp106_ = NULL;
		GList* skeys1 = NULL;
		ThreeKeys* _tmp109_ = NULL;
		ThreeKeyMap* _tmp110_ = NULL;
		ThreeKeyMap* _tmp111_ = NULL;
		GList* _tmp112_ = NULL;
		GList* _tmp113_ = NULL;
		GList* _tmp116_ = NULL;
		guint _tmp117_ = 0U;
		ThreeKey* _tmp118_ = NULL;
		ThreeKeys* _tmp119_ = NULL;
		ThreeKeyMap* _tmp120_ = NULL;
		ThreeKeyMap* _tmp121_ = NULL;
		GXmlDomElement* k3t = NULL;
		ThreeKeys* _tmp122_ = NULL;
		ThreeKeyMap* _tmp123_ = NULL;
		ThreeKeyMap* _tmp124_ = NULL;
		GXmlDomElement* _tmp125_ = NULL;
#line 1273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = three_keys_new ();
#line 1273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		ks = _tmp0_;
#line 1274 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = ks;
#line 1274 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = three_keys_get_map (_tmp1_);
#line 1274 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = _tmp2_;
#line 1274 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp3_ != NULL, "ks.map != null");
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = ks;
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = three_keys_get_map (_tmp4_);
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = _tmp5_;
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp6_);
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 1275 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp8_ == 0, "ks.map.length == 0");
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = ks;
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = three_keys_get_map (_tmp9_);
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = _tmp10_;
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp11_);
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp12_) : NULL;
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp13_ == NULL) {
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp12_);
#line 13665 "GomSerializationTest.c"
		}
#line 1276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		k1 = _tmp13_;
#line 1277 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = k1;
#line 1277 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, TYPE_THREE_KEY), "k1 is ThreeKey");
#line 1278 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = k1;
#line 1278 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_id (_tmp15_, "a1");
#line 1279 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = k1;
#line 1279 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_code (_tmp16_, "b1");
#line 1280 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = k1;
#line 1280 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_name (_tmp17_, "name1");
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = ks;
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = three_keys_get_map (_tmp18_);
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = _tmp19_;
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = k1;
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp20_, (GXmlDomElement*) _tmp21_, &_inner_error_);
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1281 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 13701 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = ks;
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = three_keys_get_map (_tmp22_);
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = _tmp23_;
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp24_);
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = _tmp25_;
#line 1282 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp26_ == 1, "ks.map.length == 1");
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = ks;
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = three_keys_get_map (_tmp27_);
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = _tmp28_;
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp29_, "a1", "b1", "name1");
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp30_) : NULL;
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp31_ == NULL) {
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp30_);
#line 13730 "GomSerializationTest.c"
		}
#line 1283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		tk1 = _tmp31_;
#line 1284 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = tk1;
#line 1284 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp32_, TYPE_THREE_KEY), "tk1 is ThreeKey");
#line 1285 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = tk1;
#line 1285 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = three_key_get_id (_tmp33_);
#line 1285 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1285 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp35_, "a1") == 0, "tk1.id == \"a1\"");
#line 1286 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = tk1;
#line 1286 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = three_key_get_code (_tmp36_);
#line 1286 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = _tmp37_;
#line 1286 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "b1") == 0, "tk1.code == \"b1\"");
#line 1287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = tk1;
#line 1287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = three_key_get_name (_tmp39_);
#line 1287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = _tmp40_;
#line 1287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp41_, "name1") == 0, "tk1.name == \"name1\"");
#line 1288 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = ks;
#line 1288 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = three_keys_get_map (_tmp42_);
#line 1288 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = _tmp43_;
#line 1288 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gxml_gom_hash_three_map_get_primary_keys ((GXmlGomHashThreeMap*) _tmp44_);
#line 1288 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		pkeys1 = _tmp45_;
#line 1289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = pkeys1;
#line 1289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = g_list_length (_tmp46_);
#line 1289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp47_ == ((guint) 1), "pkeys1.length () == 1");
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = ks;
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = three_keys_get_map (_tmp48_);
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = _tmp49_;
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp50_);
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp51_) : NULL;
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp52_ == NULL) {
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp51_);
#line 13792 "GomSerializationTest.c"
		}
#line 1290 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		k2 = _tmp52_;
#line 1291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = k2;
#line 1291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp53_, TYPE_THREE_KEY), "k2 is ThreeKey");
#line 1292 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = k2;
#line 1292 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_id (_tmp54_, "a1");
#line 1293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = k2;
#line 1293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_code (_tmp55_, "b2");
#line 1294 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = k2;
#line 1294 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_name (_tmp56_, "name2");
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = ks;
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = three_keys_get_map (_tmp57_);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp59_ = _tmp58_;
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp60_ = k2;
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp59_, (GXmlDomElement*) _tmp60_, &_inner_error_);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 13834 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp61_ = ks;
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp62_ = three_keys_get_map (_tmp61_);
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp63_ = _tmp62_;
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp64_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp63_);
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp65_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp64_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp64_) : NULL;
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp65_ == NULL) {
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp64_);
#line 13851 "GomSerializationTest.c"
		}
#line 1296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		k3 = _tmp65_;
#line 1297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp66_ = k3;
#line 1297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp66_, TYPE_THREE_KEY), "k3 is ThreeKey");
#line 1298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp67_ = k3;
#line 1298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_id (_tmp67_, "a2");
#line 1299 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp68_ = k3;
#line 1299 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_code (_tmp68_, "b1");
#line 1300 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp69_ = k3;
#line 1300 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_name (_tmp69_, "name3");
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp70_ = ks;
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp71_ = three_keys_get_map (_tmp70_);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp72_ = _tmp71_;
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp73_ = k3;
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp72_, (GXmlDomElement*) _tmp73_, &_inner_error_);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 13895 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp74_ = ks;
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp75_ = three_keys_get_map (_tmp74_);
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp76_ = _tmp75_;
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp77_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp76_);
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp78_ = _tmp77_;
#line 1302 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp78_ == 3, "ks.map.length == 3");
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp79_ = ks;
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp80_ = three_keys_get_map (_tmp79_);
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp81_ = _tmp80_;
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp82_ = gxml_gom_collection_create_item ((GXmlGomCollection*) _tmp81_);
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp83_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp82_, TYPE_THREE_KEY) ? ((ThreeKey*) _tmp82_) : NULL;
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp83_ == NULL) {
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp82_);
#line 13924 "GomSerializationTest.c"
		}
#line 1303 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		k4 = _tmp83_;
#line 1304 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp84_ = k4;
#line 1304 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp84_, TYPE_THREE_KEY), "k4 is ThreeKey");
#line 1305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp85_ = k4;
#line 1305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_id (_tmp85_, "a2");
#line 1306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp86_ = k4;
#line 1306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_code (_tmp86_, "b2");
#line 1307 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp87_ = k4;
#line 1307 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		three_key_set_name (_tmp87_, "name3");
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp88_ = ks;
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp89_ = three_keys_get_map (_tmp88_);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp90_ = _tmp89_;
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp91_ = k4;
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_append ((GXmlGomCollection*) _tmp90_, (GXmlDomElement*) _tmp91_, &_inner_error_);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1308 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 13970 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp92_ = ks;
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp93_ = three_keys_get_map (_tmp92_);
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp94_ = _tmp93_;
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp95_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp94_);
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp96_ = _tmp95_;
#line 1309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp96_ == 4, "ks.map.length == 4");
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp98_ = ks;
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp99_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp98_, &_inner_error_);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp97_ = _tmp99_;
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14007 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1310: %s", _tmp97_);
#line 1311 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp100_ = ks;
#line 1311 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp101_ = three_keys_get_map (_tmp100_);
#line 1311 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp102_ = _tmp101_;
#line 1311 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp103_ = gxml_gom_hash_three_map_get_primary_keys ((GXmlGomHashThreeMap*) _tmp102_);
#line 1311 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		pkeys2 = _tmp103_;
#line 1312 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp104_ = pkeys2;
#line 1312 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp105_ = g_list_length (_tmp104_);
#line 1312 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp105_ == ((guint) 2), "pkeys2.length () == 2");
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp106_ = pkeys2;
#line 14030 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			pk_collection = _tmp106_;
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 14038 "GomSerializationTest.c"
				gchar* _tmp107_ = NULL;
				gchar* pk = NULL;
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				_tmp107_ = g_strdup ((const gchar*) pk_it->data);
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				pk = _tmp107_;
#line 14045 "GomSerializationTest.c"
				{
					const gchar* _tmp108_ = NULL;
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_tmp108_ = pk;
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1313: %s", _tmp108_);
#line 1313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_g_free0 (pk);
#line 14054 "GomSerializationTest.c"
				}
			}
		}
#line 1314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp109_ = ks;
#line 1314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp110_ = three_keys_get_map (_tmp109_);
#line 1314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp111_ = _tmp110_;
#line 1314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp112_ = gxml_gom_hash_three_map_get_secondary_keys ((GXmlGomHashThreeMap*) _tmp111_, "a1");
#line 1314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		skeys1 = _tmp112_;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp113_ = skeys1;
#line 14070 "GomSerializationTest.c"
		{
			GList* pk_collection = NULL;
			GList* pk_it = NULL;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			pk_collection = _tmp113_;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			for (pk_it = pk_collection; pk_it != NULL; pk_it = pk_it->next) {
#line 14078 "GomSerializationTest.c"
				gchar* _tmp114_ = NULL;
				gchar* pk = NULL;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				_tmp114_ = g_strdup ((const gchar*) pk_it->data);
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
				pk = _tmp114_;
#line 14085 "GomSerializationTest.c"
				{
					const gchar* _tmp115_ = NULL;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_tmp115_ = pk;
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					g_message ("GomSerializationTest.vala:1315: %s", _tmp115_);
#line 1315 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
					_g_free0 (pk);
#line 14094 "GomSerializationTest.c"
				}
			}
		}
#line 1316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp116_ = skeys1;
#line 1316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp117_ = g_list_length (_tmp116_);
#line 1316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp117_ == ((guint) 2), "skeys1.length () == 2");
#line 1317 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp118_ = k4;
#line 1317 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_dom_child_node_remove ((GXmlDomChildNode*) _tmp118_);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp119_ = ks;
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp120_ = three_keys_get_map (_tmp119_);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp121_ = _tmp120_;
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_search ((GXmlGomCollection*) _tmp121_, &_inner_error_);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (skeys1);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys2);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp97_);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k4);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k3);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k2);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			__g_list_free__g_free0_0 (pkeys1);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (tk1);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (k1);
#line 1318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (ks);
#line 14138 "GomSerializationTest.c"
			goto __catch320_g_error;
		}
#line 1319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp122_ = ks;
#line 1319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp123_ = three_keys_get_map (_tmp122_);
#line 1319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp124_ = _tmp123_;
#line 1319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp125_ = gxml_gom_hash_three_map_get ((GXmlGomHashThreeMap*) _tmp124_, "a2", "b1", "name3");
#line 1319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		k3t = _tmp125_;
#line 1320 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (k3t != NULL, "k3t != null");
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (k3t);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (skeys1);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (pkeys2);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp97_);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (k4);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (k3);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (k2);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		__g_list_free__g_free0_0 (pkeys1);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (tk1);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (k1);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (ks);
#line 14175 "GomSerializationTest.c"
	}
	goto __finally320;
	__catch320_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp126_ = NULL;
		gchar* _tmp127_ = NULL;
		gchar* _tmp128_ = NULL;
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp126_ = e->message;
#line 1322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp127_ = g_strconcat ("ERROR: ", _tmp126_, NULL);
#line 1322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp128_ = _tmp127_;
#line 1322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1322: %s", _tmp128_);
#line 1322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp128_);
#line 1323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 14202 "GomSerializationTest.c"
	}
	__finally320:
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1272 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 14213 "GomSerializationTest.c"
	}
}


static void ___lambda281__gtest_func (void) {
#line 1270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda281_ ();
#line 14221 "GomSerializationTest.c"
}


static void __lambda282_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomBasicTypes* bt = NULL;
		GomBasicTypes* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GomBasicTypes* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GomBasicTypes* _tmp4_ = NULL;
		GomBasicTypes* _tmp5_ = NULL;
		GomBasicTypes* _tmp6_ = NULL;
		GomBasicTypes* _tmp7_ = NULL;
		GomBasicTypes* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GomBasicTypes* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GomBasicTypes* bt2 = NULL;
		GomBasicTypes* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GomBasicTypes* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		GomBasicTypes* _tmp16_ = NULL;
		GomBasicTypes* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		GomBasicTypes* _tmp20_ = NULL;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
		GomBasicTypes* _tmp23_ = NULL;
		guint _tmp24_ = 0U;
		guint _tmp25_ = 0U;
		GomBasicTypes* _tmp26_ = NULL;
		gfloat _tmp27_ = 0.0F;
		gfloat _tmp28_ = 0.0F;
		GomBasicTypes* _tmp29_ = NULL;
		gdouble _tmp30_ = 0.0;
		gdouble _tmp31_ = 0.0;
		GomBasicTypes* _tmp32_ = NULL;
		GomBasicTypes* _tmp33_ = NULL;
		gdouble _tmp34_ = 0.0;
		gdouble _tmp35_ = 0.0;
		GomBasicTypes* bt3 = NULL;
		GomBasicTypes* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		GomBasicTypes* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GomBasicTypes* _tmp40_ = NULL;
		GomBasicTypes* _tmp41_ = NULL;
		const gchar* _tmp42_ = NULL;
		const gchar* _tmp43_ = NULL;
		GomBasicTypes* _tmp44_ = NULL;
		gint _tmp45_ = 0;
		gint _tmp46_ = 0;
		GomBasicTypes* _tmp47_ = NULL;
		guint _tmp48_ = 0U;
		guint _tmp49_ = 0U;
		GomBasicTypes* _tmp50_ = NULL;
		gfloat _tmp51_ = 0.0F;
		gfloat _tmp52_ = 0.0F;
		GomBasicTypes* _tmp53_ = NULL;
		gdouble _tmp54_ = 0.0;
		gdouble _tmp55_ = 0.0;
#line 1329 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = gom_basic_types_new ();
#line 1329 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bt = _tmp0_;
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = bt;
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp2_, &_inner_error_);
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = _tmp3_;
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14301 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1330: %s", _tmp1_);
#line 1331 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = bt;
#line 1331 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_text (_tmp4_, "Text");
#line 1332 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = bt;
#line 1332 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_integer (_tmp5_, -1);
#line 1333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = bt;
#line 1333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_unsigned_integer (_tmp6_, (guint) 1);
#line 1334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = bt;
#line 1334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_real_float (_tmp7_, (gfloat) 1.1);
#line 1335 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = bt;
#line 1335 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_real_double (_tmp8_, 2.2);
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp10_ = bt;
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp11_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp10_, &_inner_error_);
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp9_ = _tmp11_;
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14338 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1336 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1336: %s", _tmp9_);
#line 1337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp12_ = gom_basic_types_new ();
#line 1337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bt2 = _tmp12_;
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp14_ = bt;
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp15_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp14_, &_inner_error_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp13_ = _tmp15_;
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14363 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp16_ = bt2;
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp16_, _tmp13_, &_inner_error_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp13_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14382 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1339 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp17_ = bt2;
#line 1339 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp18_ = gom_basic_types_get_text (_tmp17_);
#line 1339 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp19_ = _tmp18_;
#line 1339 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "Text") == 0, "bt2.text == \"Text\"");
#line 1340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp20_ = bt2;
#line 1340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp21_ = gom_basic_types_get_integer (_tmp20_);
#line 1340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp22_ = _tmp21_;
#line 1340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp22_ == -1, "bt2.integer == -1");
#line 1341 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp23_ = bt2;
#line 1341 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp24_ = gom_basic_types_get_unsigned_integer (_tmp23_);
#line 1341 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp25_ = _tmp24_;
#line 1341 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp25_ == ((guint) 1), "bt2.unsigned_integer == 1");
#line 1342 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp26_ = bt2;
#line 1342 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp27_ = gom_basic_types_get_real_float (_tmp26_);
#line 1342 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp28_ = _tmp27_;
#line 1342 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp28_ == ((gfloat) 1.1), "bt2.real_float == (float) 1.1");
#line 1343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp29_ = bt2;
#line 1343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp30_ = gom_basic_types_get_real_double (_tmp29_);
#line 1343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp31_ = _tmp30_;
#line 1343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp31_ == 2.2, "bt2.real_double == 2.2");
#line 1344 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp32_ = bt2;
#line 1344 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_basic_types_set_real_double (_tmp32_, 100.0);
#line 1345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp33_ = bt2;
#line 1345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp34_ = gom_basic_types_get_real_double (_tmp33_);
#line 1345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp35_ = _tmp34_;
#line 1345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp35_ == 100.0, "bt2.real_double == 100.0");
#line 1346 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp36_ = gom_basic_types_new ();
#line 1346 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		bt3 = _tmp36_;
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp38_ = bt2;
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp39_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp38_, &_inner_error_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp37_ = _tmp39_;
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt3);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp13_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14461 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp40_ = bt3;
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp40_, _tmp37_, &_inner_error_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp37_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt3);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp13_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt2);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp9_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_free0 (_tmp1_);
#line 1347 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (bt);
#line 14484 "GomSerializationTest.c"
			goto __catch321_g_error;
		}
#line 1348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp41_ = bt3;
#line 1348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp42_ = gom_basic_types_get_text (_tmp41_);
#line 1348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp43_ = _tmp42_;
#line 1348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp43_, "Text") == 0, "bt3.text == \"Text\"");
#line 1349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp44_ = bt3;
#line 1349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp45_ = gom_basic_types_get_integer (_tmp44_);
#line 1349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp46_ = _tmp45_;
#line 1349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp46_ == -1, "bt3.integer == -1");
#line 1350 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp47_ = bt3;
#line 1350 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp48_ = gom_basic_types_get_unsigned_integer (_tmp47_);
#line 1350 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp49_ = _tmp48_;
#line 1350 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp49_ == ((guint) 1), "bt3.unsigned_integer == 1");
#line 1351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp50_ = bt3;
#line 1351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp51_ = gom_basic_types_get_real_float (_tmp50_);
#line 1351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp52_ = _tmp51_;
#line 1351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp52_ == ((gfloat) 1.1), "bt3.real_float == (float) 1.1");
#line 1352 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp53_ = bt3;
#line 1352 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp54_ = gom_basic_types_get_real_double (_tmp53_);
#line 1352 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp55_ = _tmp54_;
#line 1352 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (_tmp55_ == 100.0, "bt3.real_double == 100.0");
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp37_);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bt3);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp13_);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bt2);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp9_);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp1_);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (bt);
#line 14541 "GomSerializationTest.c"
	}
	goto __finally321;
	__catch321_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 1354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp56_ = e->message;
#line 1354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp57_ = g_strconcat ("ERROR: ", _tmp56_, NULL);
#line 1354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp58_ = _tmp57_;
#line 1354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:1354: %s", _tmp58_);
#line 1354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp58_);
#line 1355 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 14568 "GomSerializationTest.c"
	}
	__finally321:
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 1328 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 14579 "GomSerializationTest.c"
	}
}


static void ___lambda282__gtest_func (void) {
#line 1326 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	__lambda282_ ();
#line 14587 "GomSerializationTest.c"
}


void gom_serialization_test_add_tests (void) {
#line 519 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/properties", ___lambda261__gtest_func);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-ignore", ___lambda262__gtest_func);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-long-name", ___lambda263__gtest_func);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-date", ___lambda264__gtest_func);
#line 618 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-date", ___lambda265__gtest_func);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-datetime", ___lambda266__gtest_func);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-arraylist", ___lambda267__gtest_func);
#line 753 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/property-hashmap", ___lambda268__gtest_func);
#line 808 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/mappeable", ___lambda269__gtest_func);
#line 835 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/mappeablepairedkey", ___lambda270__gtest_func);
#line 857 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/mappeablethreekey", ___lambda271__gtest_func);
#line 885 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/write/gom-property", ___lambda272__gtest_func);
#line 970 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/properties", ___lambda273__gtest_func);
#line 1004 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/bad-node-name", ___lambda274__gtest_func);
#line 1021 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/object-property", ___lambda275__gtest_func);
#line 1040 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/gom-property", ___lambda276__gtest_func);
#line 1076 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-arraylist", ___lambda277__gtest_func);
#line 1113 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/read/property-hashmap", ___lambda278__gtest_func);
#line 1158 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/multiple-child-collections", ___lambda279__gtest_func);
#line 1218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/collections/hashpairedmap/keys", ___lambda280__gtest_func);
#line 1270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/collections/hashthreemap/keys", ___lambda281__gtest_func);
#line 1326 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_test_add_func ("/gxml/gom-serialization/basic-types", ___lambda282__gtest_func);
#line 14636 "GomSerializationTest.c"
}


GomSerializationTest* gom_serialization_test_construct (GType object_type) {
	GomSerializationTest* self = NULL;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTest*) gxml_test_construct (object_type);
#line 218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 14646 "GomSerializationTest.c"
}


GomSerializationTest* gom_serialization_test_new (void) {
#line 218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_construct (TYPE_GOM_SERIALIZATION_TEST);
#line 14653 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_construct_document (GType object_type, GXmlDomDocument* doc) {
	GomSerializationTestBook * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
#line 223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (doc != NULL, NULL);
#line 223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBook*) gxml_gom_element_construct (object_type);
#line 224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = doc;
#line 224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
#line 224 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	((GXmlGomNode*) self)->_document = _tmp1_;
#line 223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 14675 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_new_document (GXmlDomDocument* doc) {
#line 223 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_construct_document (GOM_SERIALIZATION_TEST_TYPE_BOOK, doc);
#line 14682 "GomSerializationTest.c"
}


gchar* gom_serialization_test_book_to_string (GomSerializationTestBook* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 226 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 227 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 227 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 228 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 14703 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14714 "GomSerializationTest.c"
			goto __catch322_g_error;
		}
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 230 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 14727 "GomSerializationTest.c"
	}
	goto __finally322;
	__catch322_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:232: %s", _tmp7_);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 14754 "GomSerializationTest.c"
	}
	__finally322:
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 229 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 14769 "GomSerializationTest.c"
	}
#line 235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 14777 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_construct (GType object_type) {
	GomSerializationTestBook * self = NULL;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBook*) gxml_gom_element_construct (object_type);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 14787 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_new (void) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK);
#line 14794 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_book_get_name (GomSerializationTestBook* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 14809 "GomSerializationTest.c"
}


void gom_serialization_test_book_set_name (GomSerializationTestBook* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 14828 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBook * self;
	GError * _inner_error_ = NULL;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_parent_class);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 14843 "GomSerializationTest.c"
	{
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Book");
#line 14847 "GomSerializationTest.c"
	}
	goto __finally323;
	__catch323_g_error:
	{
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 14858 "GomSerializationTest.c"
	}
	__finally323:
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 14867 "GomSerializationTest.c"
	}
#line 222 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 14871 "GomSerializationTest.c"
}


static void gom_serialization_test_book_class_init (GomSerializationTestBookClass * klass) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_parent_class = g_type_class_peek_parent (klass);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestBookPrivate));
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_get_property;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_set_property;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_constructor;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_finalize;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY, g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 14890 "GomSerializationTest.c"
}


static void gom_serialization_test_book_instance_init (GomSerializationTestBook * self) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_BOOK_GET_PRIVATE (self);
#line 14897 "GomSerializationTest.c"
}


static void gom_serialization_test_book_finalize (GObject* obj) {
	GomSerializationTestBook * self;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_parent_class)->finalize (obj);
#line 14909 "GomSerializationTest.c"
}


GType gom_serialization_test_book_get_type (void) {
	static volatile gsize gom_serialization_test_book_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBook), 0, (GInstanceInitFunc) gom_serialization_test_book_instance_init, NULL };
		GType gom_serialization_test_book_type_id;
		gom_serialization_test_book_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBook", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_type_id__volatile, gom_serialization_test_book_type_id);
	}
	return gom_serialization_test_book_type_id__volatile;
}


static void _vala_gom_serialization_test_book_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY:
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_get_name (self));
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 14936 "GomSerializationTest.c"
		default:
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 14942 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_book_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestBook * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK, GomSerializationTestBook);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_NAME_PROPERTY:
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_set_name (self, g_value_get_string (value));
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 14958 "GomSerializationTest.c"
		default:
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 14964 "GomSerializationTest.c"
	}
}


gchar* gom_serialization_test_computer_to_string (GomSerializationTestComputer* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 243 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 244 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 244 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 245 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 14986 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 14997 "GomSerializationTest.c"
			goto __catch324_g_error;
		}
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 15010 "GomSerializationTest.c"
	}
	goto __finally324;
	__catch324_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:249: %s", _tmp7_);
#line 249 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 250 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 15037 "GomSerializationTest.c"
	}
	__finally324:
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 15052 "GomSerializationTest.c"
	}
#line 252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 252 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15060 "GomSerializationTest.c"
}


GomSerializationTestComputer* gom_serialization_test_computer_construct (GType object_type) {
	GomSerializationTestComputer * self = NULL;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestComputer*) gxml_gom_element_construct (object_type);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 15070 "GomSerializationTest.c"
}


GomSerializationTestComputer* gom_serialization_test_computer_new (void) {
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_computer_construct (GOM_SERIALIZATION_TEST_TYPE_COMPUTER);
#line 15077 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_computer_get_model (GomSerializationTestComputer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_model;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15092 "GomSerializationTest.c"
}


void gom_serialization_test_computer_set_model (GomSerializationTestComputer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_model);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_model = _tmp1_;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "model");
#line 15111 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_computer_get_ignore (GomSerializationTestComputer* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_ignore;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15126 "GomSerializationTest.c"
}


void gom_serialization_test_computer_set_ignore (GomSerializationTestComputer* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_ignore);
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_ignore = _tmp1_;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "ignore");
#line 15145 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_computer_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestComputer * self;
	GError * _inner_error_ = NULL;
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_computer_parent_class);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 15160 "GomSerializationTest.c"
	{
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Computer");
#line 15164 "GomSerializationTest.c"
	}
	goto __finally325;
	__catch325_g_error:
	{
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 15175 "GomSerializationTest.c"
	}
	__finally325:
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 15184 "GomSerializationTest.c"
	}
#line 242 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 15188 "GomSerializationTest.c"
}


static void gom_serialization_test_computer_class_init (GomSerializationTestComputerClass * klass) {
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_computer_parent_class = g_type_class_peek_parent (klass);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestComputerPrivate));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_computer_get_property;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_computer_set_property;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_computer_constructor;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_computer_finalize;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY, g_param_spec_string ("model", "::Model", "model", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY, g_param_spec_string ("ignore", "ignore", "ignore", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 15209 "GomSerializationTest.c"
}


static void gom_serialization_test_computer_instance_init (GomSerializationTestComputer * self) {
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_COMPUTER_GET_PRIVATE (self);
#line 15216 "GomSerializationTest.c"
}


static void gom_serialization_test_computer_finalize (GObject* obj) {
	GomSerializationTestComputer * self;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_model);
#line 241 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_ignore);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_computer_parent_class)->finalize (obj);
#line 15230 "GomSerializationTest.c"
}


GType gom_serialization_test_computer_get_type (void) {
	static volatile gsize gom_serialization_test_computer_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_computer_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestComputerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_computer_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestComputer), 0, (GInstanceInitFunc) gom_serialization_test_computer_instance_init, NULL };
		GType gom_serialization_test_computer_type_id;
		gom_serialization_test_computer_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestComputer", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_computer_type_id__volatile, gom_serialization_test_computer_type_id);
	}
	return gom_serialization_test_computer_type_id__volatile;
}


static void _vala_gom_serialization_test_computer_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestComputer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_computer_get_model (self));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_computer_get_ignore (self));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15263 "GomSerializationTest.c"
		default:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15269 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_computer_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestComputer * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_COMPUTER, GomSerializationTestComputer);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_MODEL_PROPERTY:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_computer_set_model (self, g_value_get_string (value));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_COMPUTER_IGNORE_PROPERTY:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_computer_set_ignore (self, g_value_get_string (value));
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15291 "GomSerializationTest.c"
		default:
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15297 "GomSerializationTest.c"
	}
}


GType gom_serialization_test_taxes_month_get_type (void) {
	static volatile gsize gom_serialization_test_taxes_month_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_taxes_month_type_id__volatile)) {
		static const GEnumValue values[] = {{GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY, "GOM_SERIALIZATION_TEST_TAXES_MONTH_JANUARY", "january"}, {GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY, "GOM_SERIALIZATION_TEST_TAXES_MONTH_FEBRUARY", "february"}, {0, NULL, NULL}};
		GType gom_serialization_test_taxes_month_type_id;
		gom_serialization_test_taxes_month_type_id = g_enum_register_static ("GomSerializationTestTaxesMonth", values);
		g_once_init_leave (&gom_serialization_test_taxes_month_type_id__volatile, gom_serialization_test_taxes_month_type_id);
	}
	return gom_serialization_test_taxes_month_type_id__volatile;
}


gchar* gom_serialization_test_taxes_to_string (GomSerializationTestTaxes* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 269 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 269 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 15331 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 15342 "GomSerializationTest.c"
			goto __catch326_g_error;
		}
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 15355 "GomSerializationTest.c"
	}
	goto __finally326;
	__catch326_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:273: %s", _tmp7_);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 274 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 15382 "GomSerializationTest.c"
	}
	__finally326:
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 15397 "GomSerializationTest.c"
	}
#line 276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15405 "GomSerializationTest.c"
}


GomSerializationTestTaxes* gom_serialization_test_taxes_construct (GType object_type) {
	GomSerializationTestTaxes * self = NULL;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestTaxes*) gxml_gom_element_construct (object_type);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 15415 "GomSerializationTest.c"
}


GomSerializationTestTaxes* gom_serialization_test_taxes_new (void) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_taxes_construct (GOM_SERIALIZATION_TEST_TYPE_TAXES);
#line 15422 "GomSerializationTest.c"
}


gdouble gom_serialization_test_taxes_get_month_rate (GomSerializationTestTaxes* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_month_rate;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15437 "GomSerializationTest.c"
}


void gom_serialization_test_taxes_set_month_rate (GomSerializationTestTaxes* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_month_rate = _tmp0_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "month-rate");
#line 15451 "GomSerializationTest.c"
}


gboolean gom_serialization_test_taxes_get_tax_free (GomSerializationTestTaxes* self) {
	gboolean result;
	gboolean _tmp0_ = FALSE;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_tax_free;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15466 "GomSerializationTest.c"
}


void gom_serialization_test_taxes_set_tax_free (GomSerializationTestTaxes* self, gboolean value) {
	gboolean _tmp0_ = FALSE;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_tax_free = _tmp0_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "tax-free");
#line 15480 "GomSerializationTest.c"
}


GomSerializationTestTaxesMonth gom_serialization_test_taxes_get_month (GomSerializationTestTaxes* self) {
	GomSerializationTestTaxesMonth result;
	GomSerializationTestTaxesMonth _tmp0_ = 0;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_month;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15495 "GomSerializationTest.c"
}


void gom_serialization_test_taxes_set_month (GomSerializationTestTaxes* self, GomSerializationTestTaxesMonth value) {
	GomSerializationTestTaxesMonth _tmp0_ = 0;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_month = _tmp0_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "month");
#line 15509 "GomSerializationTest.c"
}


GXmlGomDate* gom_serialization_test_taxes_get_pay_date (GomSerializationTestTaxes* self) {
	GXmlGomDate* result;
	GXmlGomDate* _tmp0_ = NULL;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_pay_date;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15524 "GomSerializationTest.c"
}


void gom_serialization_test_taxes_set_pay_date (GomSerializationTestTaxes* self, GXmlGomDate* value) {
	GXmlGomDate* _tmp0_ = NULL;
	GXmlGomDate* _tmp1_ = NULL;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_pay_date);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_pay_date = _tmp1_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "pay-date");
#line 15543 "GomSerializationTest.c"
}


GXmlGomDateTime* gom_serialization_test_taxes_get_timestamp (GomSerializationTestTaxes* self) {
	GXmlGomDateTime* result;
	GXmlGomDateTime* _tmp0_ = NULL;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_timestamp;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15558 "GomSerializationTest.c"
}


void gom_serialization_test_taxes_set_timestamp (GomSerializationTestTaxes* self, GXmlGomDateTime* value) {
	GXmlGomDateTime* _tmp0_ = NULL;
	GXmlGomDateTime* _tmp1_ = NULL;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_timestamp);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_timestamp = _tmp1_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "timestamp");
#line 15577 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_taxes_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestTaxes * self;
	GError * _inner_error_ = NULL;
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_taxes_parent_class);
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 15592 "GomSerializationTest.c"
	{
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Taxes");
#line 15596 "GomSerializationTest.c"
	}
	goto __finally327;
	__catch327_g_error:
	{
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 15607 "GomSerializationTest.c"
	}
	__finally327:
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 15616 "GomSerializationTest.c"
	}
#line 266 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 15620 "GomSerializationTest.c"
}


static void gom_serialization_test_taxes_class_init (GomSerializationTestTaxesClass * klass) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_taxes_parent_class = g_type_class_peek_parent (klass);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestTaxesPrivate));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_taxes_get_property;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_taxes_set_property;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_taxes_constructor;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_taxes_finalize;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY, g_param_spec_double ("month-rate", "::monthRate", "month-rate", -G_MAXDOUBLE, G_MAXDOUBLE, 0.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY, g_param_spec_boolean ("tax-free", "::TaxFree", "tax-free", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY, g_param_spec_enum ("month", "::Month", "month", GOM_SERIALIZATION_TEST_TAXES_TYPE_MONTH, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY, g_param_spec_object ("pay-date", "::PayDate", "pay-date", GXML_TYPE_GOM_DATE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY, g_param_spec_object ("timestamp", "::Timestamp", "timestamp", GXML_TYPE_GOM_DATE_TIME, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 15647 "GomSerializationTest.c"
}


static void gom_serialization_test_taxes_instance_init (GomSerializationTestTaxes * self) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_TAXES_GET_PRIVATE (self);
#line 15654 "GomSerializationTest.c"
}


static void gom_serialization_test_taxes_finalize (GObject* obj) {
	GomSerializationTestTaxes * self;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_pay_date);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_timestamp);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_taxes_parent_class)->finalize (obj);
#line 15668 "GomSerializationTest.c"
}


GType gom_serialization_test_taxes_get_type (void) {
	static volatile gsize gom_serialization_test_taxes_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_taxes_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestTaxesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_taxes_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestTaxes), 0, (GInstanceInitFunc) gom_serialization_test_taxes_instance_init, NULL };
		GType gom_serialization_test_taxes_type_id;
		gom_serialization_test_taxes_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestTaxes", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_taxes_type_id__volatile, gom_serialization_test_taxes_type_id);
	}
	return gom_serialization_test_taxes_type_id__volatile;
}


static void _vala_gom_serialization_test_taxes_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestTaxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_double (value, gom_serialization_test_taxes_get_month_rate (self));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_boolean (value, gom_serialization_test_taxes_get_tax_free (self));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_enum (value, gom_serialization_test_taxes_get_month (self));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_taxes_get_pay_date (self));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_taxes_get_timestamp (self));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15719 "GomSerializationTest.c"
		default:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15725 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_taxes_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestTaxes * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_TAXES, GomSerializationTestTaxes);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_RATE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_taxes_set_month_rate (self, g_value_get_double (value));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TAX_FREE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_taxes_set_tax_free (self, g_value_get_boolean (value));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_MONTH_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_taxes_set_month (self, g_value_get_enum (value));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_PAY_DATE_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_taxes_set_pay_date (self, g_value_get_object (value));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_TAXES_TIMESTAMP_PROPERTY:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_taxes_set_timestamp (self, g_value_get_object (value));
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15765 "GomSerializationTest.c"
		default:
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 15771 "GomSerializationTest.c"
	}
}


GomSerializationTestBookRegister* gom_serialization_test_book_register_construct_document (GType object_type, GXmlDomDocument* doc) {
	GomSerializationTestBookRegister * self = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (doc != NULL, NULL);
#line 309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) gxml_gom_element_construct (object_type);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = doc;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (((GXmlGomNode*) self)->_document);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	((GXmlGomNode*) self)->_document = _tmp1_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 15794 "GomSerializationTest.c"
}


GomSerializationTestBookRegister* gom_serialization_test_book_register_new_document (GXmlDomDocument* doc) {
#line 309 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_register_construct_document (GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, doc);
#line 15801 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_key (GXmlMappeableElement* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	GomSerializationTestBook* _tmp0_ = NULL;
	GomSerializationTestBook* _tmp1_ = NULL;
	gint _tmp3_ = 0;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	GomSerializationTestBook* _tmp8_ = NULL;
	GomSerializationTestBook* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_ = NULL;
	gchar* _tmp12_ = NULL;
	gchar* _tmp13_ = NULL;
#line 312 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_book_register_get_book (self);
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp1_ == NULL) {
#line 15829 "GomSerializationTest.c"
		gchar* _tmp2_ = NULL;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_strdup ("");
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		result = _tmp2_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return result;
#line 15837 "GomSerializationTest.c"
	}
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = self->priv->_year;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = g_strdup_printf ("%d", _tmp3_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = _tmp4_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = g_strconcat (_tmp5_, "-", NULL);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = _tmp6_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp8_ = gom_serialization_test_book_register_get_book (self);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp9_ = _tmp8_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp10_ = gom_serialization_test_book_get_name (_tmp9_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp11_ = _tmp10_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp12_ = g_strconcat (_tmp7_, _tmp11_, NULL);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp13_ = _tmp12_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp7_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (_tmp5_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp13_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15869 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_primary_key (GXmlMappeableElementPairKey* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gint _tmp0_ = 0;
	gchar* _tmp1_ = NULL;
#line 316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_year;
#line 316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup_printf ("%d", _tmp0_);
#line 316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15888 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_secondary_key (GXmlMappeableElementPairKey* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	GomSerializationTestBook* _tmp0_ = NULL;
	GomSerializationTestBook* _tmp1_ = NULL;
	GomSerializationTestBook* _tmp3_ = NULL;
	GomSerializationTestBook* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
#line 317 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gom_serialization_test_book_register_get_book (self);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp1_ == NULL) {
#line 15910 "GomSerializationTest.c"
		gchar* _tmp2_ = NULL;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = g_strdup ("");
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		result = _tmp2_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return result;
#line 15918 "GomSerializationTest.c"
	}
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = gom_serialization_test_book_register_get_book (self);
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = _tmp3_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = gom_serialization_test_book_get_name (_tmp4_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp6_ = _tmp5_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp7_ = g_strdup (_tmp6_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp7_;
#line 319 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15934 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_pkey (GXmlMappeableElementThreeKey* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_mappeable_element_pair_key_get_map_primary_key ((GXmlMappeableElementPairKey*) self);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15950 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_skey (GXmlMappeableElementThreeKey* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_mappeable_element_pair_key_get_map_secondary_key ((GXmlMappeableElementPairKey*) self);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15966 "GomSerializationTest.c"
}


static gchar* gom_serialization_test_book_register_real_get_map_tkey (GXmlMappeableElementThreeKey* base) {
	GomSerializationTestBookRegister * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) base;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_cover;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp1_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 15985 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_register_create_book (GomSerializationTestBookRegister* self, const gchar* name) {
	GomSerializationTestBook* result = NULL;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlDomDocument* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GObject* _tmp3_ = NULL;
	GObject* _tmp4_ = NULL;
	GomSerializationTestBook* _tmp5_ = NULL;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) self);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _tmp0_;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = name;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp3_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_BOOK, "owner-document", _tmp1_, "name", _tmp2_, NULL);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = G_IS_INITIALLY_UNOWNED (_tmp3_) ? g_object_ref_sink (_tmp3_) : _tmp3_;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GOM_SERIALIZATION_TEST_TYPE_BOOK) ? ((GomSerializationTestBook*) _tmp4_) : NULL;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp5_ == NULL) {
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp4_);
#line 16017 "GomSerializationTest.c"
	}
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp5_;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16023 "GomSerializationTest.c"
}


gchar* gom_serialization_test_book_register_to_string (GomSerializationTestBookRegister* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 332 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 16044 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16056 "GomSerializationTest.c"
			goto __catch328_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 335 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = s;
#line 335 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "") != 0, "s != \"\"");
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 16073 "GomSerializationTest.c"
	}
	goto __finally328;
	__catch328_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = e->message;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = g_strconcat ("Error: ", _tmp6_, NULL);
#line 337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp8_ = _tmp7_;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:337: %s", _tmp8_);
#line 337 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp8_);
#line 338 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 16100 "GomSerializationTest.c"
	}
	__finally328:
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 16115 "GomSerializationTest.c"
	}
#line 340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 340 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16123 "GomSerializationTest.c"
}


GomSerializationTestBookRegister* gom_serialization_test_book_register_construct (GType object_type) {
	GomSerializationTestBookRegister * self = NULL;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookRegister*) gxml_gom_element_construct (object_type);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 16133 "GomSerializationTest.c"
}


GomSerializationTestBookRegister* gom_serialization_test_book_register_new (void) {
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_register_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER);
#line 16140 "GomSerializationTest.c"
}


gint gom_serialization_test_book_register_get_year (GomSerializationTestBookRegister* self) {
	gint result;
	gint _tmp0_ = 0;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_year;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16155 "GomSerializationTest.c"
}


void gom_serialization_test_book_register_set_year (GomSerializationTestBookRegister* self, gint value) {
	gint _tmp0_ = 0;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_year = _tmp0_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "year");
#line 16169 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_book_register_get_cover (GomSerializationTestBookRegister* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_cover;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16184 "GomSerializationTest.c"
}


void gom_serialization_test_book_register_set_cover (GomSerializationTestBookRegister* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_cover);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_cover = _tmp1_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "cover");
#line 16203 "GomSerializationTest.c"
}


GomSerializationTestBook* gom_serialization_test_book_register_get_book (GomSerializationTestBookRegister* self) {
	GomSerializationTestBook* result;
	GomSerializationTestBook* _tmp0_ = NULL;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_book;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16218 "GomSerializationTest.c"
}


void gom_serialization_test_book_register_set_book (GomSerializationTestBookRegister* self, GomSerializationTestBook* value) {
	GError * _inner_error_ = NULL;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 16226 "GomSerializationTest.c"
	{
		GomSerializationTestBook* _tmp0_ = NULL;
		GomSerializationTestBook* _tmp1_ = NULL;
		GomSerializationTestBook* _tmp2_ = NULL;
		GXmlDomNode* _tmp3_ = NULL;
		GXmlDomNode* _tmp4_ = NULL;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "book", &_inner_error_);
#line 296 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16237 "GomSerializationTest.c"
			goto __catch329_g_error;
		}
#line 297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp0_ = value;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = _g_object_ref0 (_tmp0_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_book);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		self->priv->_book = _tmp1_;
#line 298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = self->priv->_book;
#line 298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_dom_node_append_child ((GXmlDomNode*) self, (GXmlDomNode*) _tmp2_, &_inner_error_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp3_;
#line 298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (_tmp4_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16258 "GomSerializationTest.c"
			goto __catch329_g_error;
		}
	}
	goto __finally329;
	__catch329_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 300 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 300 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_warning ("GomSerializationTest.vala:300: %s", _tmp5_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 16279 "GomSerializationTest.c"
	}
	__finally329:
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 295 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return;
#line 16290 "GomSerializationTest.c"
	}
#line 294 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "book");
#line 16294 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_register_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookRegister * self;
	GError * _inner_error_ = NULL;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_register_parent_class);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 16309 "GomSerializationTest.c"
	{
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookRegister");
#line 16313 "GomSerializationTest.c"
	}
	goto __finally330;
	__catch330_g_error:
	{
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 307 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 16324 "GomSerializationTest.c"
	}
	__finally330:
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 306 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 16333 "GomSerializationTest.c"
	}
#line 305 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 16337 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_class_init (GomSerializationTestBookRegisterClass * klass) {
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_register_parent_class = g_type_class_peek_parent (klass);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestBookRegisterPrivate));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_register_get_property;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_register_set_property;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_register_constructor;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_register_finalize;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY, g_param_spec_int ("year", "::Year", "year", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY, g_param_spec_string ("cover", "::Cover", "cover", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY, g_param_spec_object ("book", "book", "book", GOM_SERIALIZATION_TEST_TYPE_BOOK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 16360 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface) {
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_key = (gchar* (*)(GXmlMappeableElement*)) gom_serialization_test_book_register_real_get_map_key;
#line 16369 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_gxml_mappeable_element_pair_key_interface_init (GXmlMappeableElementPairKeyIface * iface) {
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_pair_key_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_primary_key = (gchar* (*)(GXmlMappeableElementPairKey*)) gom_serialization_test_book_register_real_get_map_primary_key;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_secondary_key = (gchar* (*)(GXmlMappeableElementPairKey*)) gom_serialization_test_book_register_real_get_map_secondary_key;
#line 16380 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_gxml_mappeable_element_three_key_interface_init (GXmlMappeableElementThreeKeyIface * iface) {
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_register_gxml_mappeable_element_three_key_parent_iface = g_type_interface_peek_parent (iface);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_pkey = (gchar* (*)(GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_pkey;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_skey = (gchar* (*)(GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_skey;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	iface->get_map_tkey = (gchar* (*)(GXmlMappeableElementThreeKey*)) gom_serialization_test_book_register_real_get_map_tkey;
#line 16393 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_instance_init (GomSerializationTestBookRegister * self) {
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_BOOK_REGISTER_GET_PRIVATE (self);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_book = NULL;
#line 16402 "GomSerializationTest.c"
}


static void gom_serialization_test_book_register_finalize (GObject* obj) {
	GomSerializationTestBookRegister * self;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_book);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_cover);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_register_parent_class)->finalize (obj);
#line 16416 "GomSerializationTest.c"
}


GType gom_serialization_test_book_register_get_type (void) {
	static volatile gsize gom_serialization_test_book_register_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_register_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookRegisterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_register_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookRegister), 0, (GInstanceInitFunc) gom_serialization_test_book_register_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_mappeable_element_pair_key_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_pair_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_mappeable_element_three_key_info = { (GInterfaceInitFunc) gom_serialization_test_book_register_gxml_mappeable_element_three_key_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_serialization_test_book_register_type_id;
		gom_serialization_test_book_register_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookRegister", &g_define_type_info, 0);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_PAIR_KEY, &gxml_mappeable_element_pair_key_info);
		g_type_add_interface_static (gom_serialization_test_book_register_type_id, GXML_TYPE_MAPPEABLE_ELEMENT_THREE_KEY, &gxml_mappeable_element_three_key_info);
		g_once_init_leave (&gom_serialization_test_book_register_type_id__volatile, gom_serialization_test_book_register_type_id);
	}
	return gom_serialization_test_book_register_type_id__volatile;
}


static void _vala_gom_serialization_test_book_register_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookRegister * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_int (value, gom_serialization_test_book_register_get_year (self));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_register_get_cover (self));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_register_get_book (self));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 16461 "GomSerializationTest.c"
		default:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 16467 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_book_register_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookRegister * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, GomSerializationTestBookRegister);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_YEAR_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_year (self, g_value_get_int (value));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_COVER_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_cover (self, g_value_get_string (value));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_REGISTER_BOOK_PROPERTY:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_register_set_book (self, g_value_get_object (value));
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 16495 "GomSerializationTest.c"
		default:
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 16501 "GomSerializationTest.c"
	}
}


gchar* gom_serialization_test_book_stand_to_string (GomSerializationTestBookStand* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 392 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 393 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 393 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 394 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 394 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 16523 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 16534 "GomSerializationTest.c"
			goto __catch331_g_error;
		}
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 396 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 16547 "GomSerializationTest.c"
	}
	goto __finally331;
	__catch331_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:398: %s", _tmp7_);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 16574 "GomSerializationTest.c"
	}
	__finally331:
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 395 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 16589 "GomSerializationTest.c"
	}
#line 401 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16597 "GomSerializationTest.c"
}


GomSerializationTestBookStand* gom_serialization_test_book_stand_construct (GType object_type) {
	GomSerializationTestBookStand * self = NULL;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookStand*) gxml_gom_element_construct (object_type);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 16607 "GomSerializationTest.c"
}


GomSerializationTestBookStand* gom_serialization_test_book_stand_new (void) {
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_stand_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND);
#line 16614 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_book_stand_get_classification (GomSerializationTestBookStand* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_classification;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16629 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_classification (GomSerializationTestBookStand* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_classification);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_classification = _tmp1_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "classification");
#line 16648 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_get_dimension_x (GomSerializationTestBookStand* self) {
	GomSerializationTestBookStandDimension* result;
	GomSerializationTestBookStandDimension* _tmp0_ = NULL;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_x;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16663 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_dimension_x (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimension* value) {
	GomSerializationTestBookStandDimension* _tmp0_ = NULL;
	GomSerializationTestBookStandDimension* _tmp1_ = NULL;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_x);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_dimension_x = _tmp1_;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "dimension-x");
#line 16682 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_get_dimension_y (GomSerializationTestBookStand* self) {
	GomSerializationTestBookStandDimensionY* result;
	GomSerializationTestBookStandDimensionY* _tmp0_ = NULL;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_y;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16697 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_dimension_y (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimensionY* value) {
	GomSerializationTestBookStandDimensionY* _tmp0_ = NULL;
	GomSerializationTestBookStandDimensionY* _tmp1_ = NULL;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_y);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_dimension_y = _tmp1_;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "dimension-y");
#line 16716 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_get_dimension_z (GomSerializationTestBookStand* self) {
	GomSerializationTestBookStandDimensionZ* result;
	GomSerializationTestBookStandDimensionZ* _tmp0_ = NULL;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_dimension_z;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16731 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_dimension_z (GomSerializationTestBookStand* self, GomSerializationTestBookStandDimensionZ* value) {
	GomSerializationTestBookStandDimensionZ* _tmp0_ = NULL;
	GomSerializationTestBookStandDimensionZ* _tmp1_ = NULL;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_z);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_dimension_z = _tmp1_;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "dimension-z");
#line 16750 "GomSerializationTest.c"
}


GomSerializationTestRegisters* gom_serialization_test_book_stand_get_registers (GomSerializationTestBookStand* self) {
	GomSerializationTestRegisters* result;
	GomSerializationTestRegisters* _tmp0_ = NULL;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_registers;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16765 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_registers (GomSerializationTestBookStand* self, GomSerializationTestRegisters* value) {
	GomSerializationTestRegisters* _tmp0_ = NULL;
	GomSerializationTestRegisters* _tmp1_ = NULL;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_registers);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_registers = _tmp1_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "registers");
#line 16784 "GomSerializationTest.c"
}


GomSerializationTestHashRegisters* gom_serialization_test_book_stand_get_hashmap_registers (GomSerializationTestBookStand* self) {
	GomSerializationTestHashRegisters* result;
	GomSerializationTestHashRegisters* _tmp0_ = NULL;
	GomSerializationTestHashRegisters* _tmp4_ = NULL;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashmap_registers;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 16798 "GomSerializationTest.c"
		GObject* _tmp1_ = NULL;
		GObject* _tmp2_ = NULL;
		GomSerializationTestHashRegisters* _tmp3_ = NULL;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, "element", self, NULL);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS) ? ((GomSerializationTestHashRegisters*) _tmp2_) : NULL;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 16812 "GomSerializationTest.c"
		}
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashmap_registers);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		self->priv->_hashmap_registers = _tmp3_;
#line 16818 "GomSerializationTest.c"
	}
#line 360 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashmap_registers;
#line 360 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp4_;
#line 360 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16826 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_hashmap_registers (GomSerializationTestBookStand* self, GomSerializationTestHashRegisters* value) {
	GomSerializationTestHashRegisters* _tmp0_ = NULL;
	GomSerializationTestHashRegisters* _tmp1_ = NULL;
#line 362 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 363 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 363 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 363 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashmap_registers);
#line 363 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashmap_registers = _tmp1_;
#line 362 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "hashmap-registers");
#line 16845 "GomSerializationTest.c"
}


GomSerializationTestHashPairRegisters* gom_serialization_test_book_stand_get_hashpair_registers (GomSerializationTestBookStand* self) {
	GomSerializationTestHashPairRegisters* result;
	GomSerializationTestHashPairRegisters* _tmp0_ = NULL;
	GomSerializationTestHashPairRegisters* _tmp4_ = NULL;
#line 367 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashpair_registers;
#line 368 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 16859 "GomSerializationTest.c"
		GObject* _tmp1_ = NULL;
		GObject* _tmp2_ = NULL;
		GomSerializationTestHashPairRegisters* _tmp3_ = NULL;
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, "element", self, NULL);
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS) ? ((GomSerializationTestHashPairRegisters*) _tmp2_) : NULL;
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 16873 "GomSerializationTest.c"
		}
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashpair_registers);
#line 369 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		self->priv->_hashpair_registers = _tmp3_;
#line 16879 "GomSerializationTest.c"
	}
#line 371 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashpair_registers;
#line 371 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp4_;
#line 371 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16887 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_hashpair_registers (GomSerializationTestBookStand* self, GomSerializationTestHashPairRegisters* value) {
	GomSerializationTestHashPairRegisters* _tmp0_ = NULL;
	GomSerializationTestHashPairRegisters* _tmp1_ = NULL;
#line 373 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 374 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 374 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 374 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashpair_registers);
#line 374 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashpair_registers = _tmp1_;
#line 373 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "hashpair-registers");
#line 16906 "GomSerializationTest.c"
}


GomSerializationTestHashThreeRegisters* gom_serialization_test_book_stand_get_hashthree_registers (GomSerializationTestBookStand* self) {
	GomSerializationTestHashThreeRegisters* result;
	GomSerializationTestHashThreeRegisters* _tmp0_ = NULL;
	GomSerializationTestHashThreeRegisters* _tmp4_ = NULL;
#line 378 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 379 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_hashthree_registers;
#line 379 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (_tmp0_ == NULL) {
#line 16920 "GomSerializationTest.c"
		GObject* _tmp1_ = NULL;
		GObject* _tmp2_ = NULL;
		GomSerializationTestHashThreeRegisters* _tmp3_ = NULL;
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp1_ = g_object_new (GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, "element", self, NULL);
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = G_IS_INITIALLY_UNOWNED (_tmp1_) ? g_object_ref_sink (_tmp1_) : _tmp1_;
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS) ? ((GomSerializationTestHashThreeRegisters*) _tmp2_) : NULL;
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (_tmp3_ == NULL) {
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
			_g_object_unref0 (_tmp2_);
#line 16934 "GomSerializationTest.c"
		}
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (self->priv->_hashthree_registers);
#line 380 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		self->priv->_hashthree_registers = _tmp3_;
#line 16940 "GomSerializationTest.c"
	}
#line 382 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp4_ = self->priv->_hashthree_registers;
#line 382 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp4_;
#line 382 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16948 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_hashthree_registers (GomSerializationTestBookStand* self, GomSerializationTestHashThreeRegisters* value) {
	GomSerializationTestHashThreeRegisters* _tmp0_ = NULL;
	GomSerializationTestHashThreeRegisters* _tmp1_ = NULL;
#line 384 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 385 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 385 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 385 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashthree_registers);
#line 385 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashthree_registers = _tmp1_;
#line 384 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "hashthree-registers");
#line 16967 "GomSerializationTest.c"
}


GomSerializationTestBooks* gom_serialization_test_book_stand_get_books (GomSerializationTestBookStand* self) {
	GomSerializationTestBooks* result;
	GomSerializationTestBooks* _tmp0_ = NULL;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 16982 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_set_books (GomSerializationTestBookStand* self, GomSerializationTestBooks* value) {
	GomSerializationTestBooks* _tmp0_ = NULL;
	GomSerializationTestBooks* _tmp1_ = NULL;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_books = _tmp1_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "books");
#line 17001 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_stand_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStand * self;
	GError * _inner_error_ = NULL;
#line 389 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_parent_class);
#line 389 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 389 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 17016 "GomSerializationTest.c"
	{
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStand");
#line 17020 "GomSerializationTest.c"
	}
	goto __finally332;
	__catch332_g_error:
	{
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17031 "GomSerializationTest.c"
	}
	__finally332:
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 390 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17040 "GomSerializationTest.c"
	}
#line 389 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17044 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_construct (GType object_type) {
	GomSerializationTestBookStandDimension * self = NULL;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimension*) gxml_gom_element_construct (object_type);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17054 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimension* gom_serialization_test_book_stand_dimension_new (void) {
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION);
#line 17061 "GomSerializationTest.c"
}


gdouble gom_serialization_test_book_stand_dimension_get_length (GomSerializationTestBookStandDimension* self) {
	gdouble result;
	gdouble _tmp0_ = 0.0;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, 0.0);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_length;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 17076 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_dimension_set_length (GomSerializationTestBookStandDimension* self, gdouble value) {
	gdouble _tmp0_ = 0.0;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_length = _tmp0_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "length");
#line 17090 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_book_stand_dimension_get_dtype (GomSerializationTestBookStandDimension* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_dtype;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 17105 "GomSerializationTest.c"
}


void gom_serialization_test_book_stand_dimension_set_dtype (GomSerializationTestBookStandDimension* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_dtype);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_dtype = _tmp1_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "dtype");
#line 17124 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_stand_dimension_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimension * self;
	GError * _inner_error_ = NULL;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_parent_class);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 17139 "GomSerializationTest.c"
	{
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Dimension");
#line 17143 "GomSerializationTest.c"
	}
	goto __finally333;
	__catch333_g_error:
	{
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17154 "GomSerializationTest.c"
	}
	__finally333:
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17163 "GomSerializationTest.c"
	}
#line 408 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17167 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_class_init (GomSerializationTestBookStandDimensionClass * klass) {
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_parent_class = g_type_class_peek_parent (klass);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestBookStandDimensionPrivate));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_stand_dimension_get_property;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_stand_dimension_set_property;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_constructor;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_stand_dimension_finalize;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY, g_param_spec_double ("length", "::Length", "length", -G_MAXDOUBLE, G_MAXDOUBLE, 1.0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY, g_param_spec_string ("dtype", "::Type", "dtype", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 17188 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_instance_init (GomSerializationTestBookStandDimension * self) {
	gchar* _tmp0_ = NULL;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_GET_PRIVATE (self);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_length = 1.0;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = g_strdup ("x");
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_dtype = _tmp0_;
#line 17202 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_finalize (GObject* obj) {
	GomSerializationTestBookStandDimension * self;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_dtype);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_parent_class)->finalize (obj);
#line 17214 "GomSerializationTest.c"
}


GType gom_serialization_test_book_stand_dimension_get_type (void) {
	static volatile gsize gom_serialization_test_book_stand_dimension_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimension), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_type_id;
		gom_serialization_test_book_stand_dimension_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStandDimension", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_type_id__volatile, gom_serialization_test_book_stand_dimension_type_id);
	}
	return gom_serialization_test_book_stand_dimension_type_id__volatile;
}


static void _vala_gom_serialization_test_book_stand_dimension_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStandDimension * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_double (value, gom_serialization_test_book_stand_dimension_get_length (self));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_stand_dimension_get_dtype (self));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17247 "GomSerializationTest.c"
		default:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17253 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_book_stand_dimension_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStandDimension * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, GomSerializationTestBookStandDimension);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_LENGTH_PROPERTY:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_dimension_set_length (self, g_value_get_double (value));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_DTYPE_PROPERTY:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_dimension_set_dtype (self, g_value_get_string (value));
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17275 "GomSerializationTest.c"
		default:
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17281 "GomSerializationTest.c"
	}
}


GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_construct (GType object_type) {
	GomSerializationTestBookStandDimensionY * self = NULL;
#line 412 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimensionY*) gom_serialization_test_book_stand_dimension_construct (object_type);
#line 412 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17292 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimensionY* gom_serialization_test_book_stand_dimension_y_new (void) {
#line 412 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_y_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y);
#line 17299 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_stand_dimension_y_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimensionY * self;
#line 413 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_y_parent_class);
#line 413 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 413 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, GomSerializationTestBookStandDimensionY);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_set_dtype ((GomSerializationTestBookStandDimension*) self, "y");
#line 413 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17317 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_y_class_init (GomSerializationTestBookStandDimensionYClass * klass) {
#line 412 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_y_parent_class = g_type_class_peek_parent (klass);
#line 412 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_y_constructor;
#line 17326 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_y_instance_init (GomSerializationTestBookStandDimensionY * self) {
}


GType gom_serialization_test_book_stand_dimension_y_get_type (void) {
	static volatile gsize gom_serialization_test_book_stand_dimension_y_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_y_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionYClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_y_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimensionY), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_y_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_y_type_id;
		gom_serialization_test_book_stand_dimension_y_type_id = g_type_register_static (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, "GomSerializationTestBookStandDimensionY", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_y_type_id__volatile, gom_serialization_test_book_stand_dimension_y_type_id);
	}
	return gom_serialization_test_book_stand_dimension_y_type_id__volatile;
}


GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_construct (GType object_type) {
	GomSerializationTestBookStandDimensionZ * self = NULL;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookStandDimensionZ*) gom_serialization_test_book_stand_dimension_construct (object_type);
#line 417 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17352 "GomSerializationTest.c"
}


GomSerializationTestBookStandDimensionZ* gom_serialization_test_book_stand_dimension_z_new (void) {
#line 417 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_stand_dimension_z_construct (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z);
#line 17359 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_stand_dimension_z_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStandDimensionZ * self;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_stand_dimension_z_parent_class);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, GomSerializationTestBookStandDimensionZ);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_set_dtype ((GomSerializationTestBookStandDimension*) self, "z");
#line 418 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17377 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_z_class_init (GomSerializationTestBookStandDimensionZClass * klass) {
#line 417 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_dimension_z_parent_class = g_type_class_peek_parent (klass);
#line 417 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_dimension_z_constructor;
#line 17386 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_dimension_z_instance_init (GomSerializationTestBookStandDimensionZ * self) {
}


GType gom_serialization_test_book_stand_dimension_z_get_type (void) {
	static volatile gsize gom_serialization_test_book_stand_dimension_z_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_dimension_z_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandDimensionZClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_dimension_z_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStandDimensionZ), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_dimension_z_instance_init, NULL };
		GType gom_serialization_test_book_stand_dimension_z_type_id;
		gom_serialization_test_book_stand_dimension_z_type_id = g_type_register_static (GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, "GomSerializationTestBookStandDimensionZ", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_dimension_z_type_id__volatile, gom_serialization_test_book_stand_dimension_z_type_id);
	}
	return gom_serialization_test_book_stand_dimension_z_type_id__volatile;
}


static void gom_serialization_test_book_stand_class_init (GomSerializationTestBookStandClass * klass) {
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_stand_parent_class = g_type_class_peek_parent (klass);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestBookStandPrivate));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_stand_get_property;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_stand_set_property;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_stand_constructor;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_stand_finalize;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY, g_param_spec_string ("classification", "::Classification", "classification", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY, g_param_spec_object ("dimension-x", "dimension-x", "dimension-x", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY, g_param_spec_object ("dimension-y", "::DimensionY", "dimension-y", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Y, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY, g_param_spec_object ("dimension-z", "DimensionZ", "dimension-z", GOM_SERIALIZATION_TEST_BOOK_STAND_TYPE_DIMENSION_Z, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY, g_param_spec_object ("registers", "registers", "registers", GOM_SERIALIZATION_TEST_TYPE_REGISTERS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY, g_param_spec_object ("hashmap-registers", "hashmap-registers", "hashmap-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY, g_param_spec_object ("hashpair-registers", "hashpair-registers", "hashpair-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY, g_param_spec_object ("hashthree-registers", "hashthree-registers", "hashthree-registers", GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY, g_param_spec_object ("books", "books", "books", GOM_SERIALIZATION_TEST_TYPE_BOOKS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 17437 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_instance_init (GomSerializationTestBookStand * self) {
	gchar* _tmp0_ = NULL;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_BOOK_STAND_GET_PRIVATE (self);
#line 344 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashmap_registers = NULL;
#line 345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashpair_registers = NULL;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_hashthree_registers = NULL;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = g_strdup ("Science");
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_classification = _tmp0_;
#line 17455 "GomSerializationTest.c"
}


static void gom_serialization_test_book_stand_finalize (GObject* obj) {
	GomSerializationTestBookStand * self;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 344 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashmap_registers);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashpair_registers);
#line 346 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_hashthree_registers);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_classification);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_x);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_y);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_dimension_z);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_registers);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 378 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_stand_parent_class)->finalize (obj);
#line 17483 "GomSerializationTest.c"
}


GType gom_serialization_test_book_stand_get_type (void) {
	static volatile gsize gom_serialization_test_book_stand_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_stand_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStandClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_stand_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStand), 0, (GInstanceInitFunc) gom_serialization_test_book_stand_instance_init, NULL };
		GType gom_serialization_test_book_stand_type_id;
		gom_serialization_test_book_stand_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStand", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_stand_type_id__volatile, gom_serialization_test_book_stand_type_id);
	}
	return gom_serialization_test_book_stand_type_id__volatile;
}


static void _vala_gom_serialization_test_book_stand_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStand * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_stand_get_classification (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_x (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_y (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_dimension_z (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_registers (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashmap_registers (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashpair_registers (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_hashthree_registers (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_stand_get_books (self));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17558 "GomSerializationTest.c"
		default:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17564 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_book_stand_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStand * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STAND, GomSerializationTestBookStand);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_CLASSIFICATION_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_classification (self, g_value_get_string (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_X_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_x (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Y_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_y (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_DIMENSION_Z_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_dimension_z (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_registers (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHMAP_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashmap_registers (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHPAIR_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashpair_registers (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_HASHTHREE_REGISTERS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_hashthree_registers (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STAND_BOOKS_PROPERTY:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_stand_set_books (self, g_value_get_object (value));
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17628 "GomSerializationTest.c"
		default:
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 343 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 17634 "GomSerializationTest.c"
	}
}


GomSerializationTestRegisters* gom_serialization_test_registers_construct (GType object_type) {
	GomSerializationTestRegisters * self = NULL;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestRegisters*) gxml_gom_array_list_construct (object_type);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17645 "GomSerializationTest.c"
}


GomSerializationTestRegisters* gom_serialization_test_registers_new (void) {
#line 424 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_registers_construct (GOM_SERIALIZATION_TEST_TYPE_REGISTERS);
#line 17652 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestRegisters * self;
	GError * _inner_error_ = NULL;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_registers_parent_class);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_REGISTERS, GomSerializationTestRegisters);
#line 17667 "GomSerializationTest.c"
	{
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error_);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17673 "GomSerializationTest.c"
			goto __catch334_g_error;
		}
	}
	goto __finally334;
	__catch334_g_error:
	{
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17686 "GomSerializationTest.c"
	}
	__finally334:
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17695 "GomSerializationTest.c"
	}
#line 425 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17699 "GomSerializationTest.c"
}


static void gom_serialization_test_registers_class_init (GomSerializationTestRegistersClass * klass) {
#line 424 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_registers_parent_class = g_type_class_peek_parent (klass);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_registers_constructor;
#line 17708 "GomSerializationTest.c"
}


static void gom_serialization_test_registers_instance_init (GomSerializationTestRegisters * self) {
}


GType gom_serialization_test_registers_get_type (void) {
	static volatile gsize gom_serialization_test_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestRegisters), 0, (GInstanceInitFunc) gom_serialization_test_registers_instance_init, NULL };
		GType gom_serialization_test_registers_type_id;
		gom_serialization_test_registers_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_LIST, "GomSerializationTestRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_registers_type_id__volatile, gom_serialization_test_registers_type_id);
	}
	return gom_serialization_test_registers_type_id__volatile;
}


GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_construct (GType object_type) {
	GomSerializationTestHashRegisters * self = NULL;
#line 430 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestHashRegisters*) gxml_gom_hash_map_construct (object_type);
#line 430 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17734 "GomSerializationTest.c"
}


GomSerializationTestHashRegisters* gom_serialization_test_hash_registers_new (void) {
#line 430 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_hash_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS);
#line 17741 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_hash_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashRegisters * self;
	GError * _inner_error_ = NULL;
#line 431 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_registers_parent_class);
#line 431 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 431 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_REGISTERS, GomSerializationTestHashRegisters);
#line 17756 "GomSerializationTest.c"
	{
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error_);
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17762 "GomSerializationTest.c"
			goto __catch335_g_error;
		}
	}
	goto __finally335;
	__catch335_g_error:
	{
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17775 "GomSerializationTest.c"
	}
	__finally335:
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 432 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17784 "GomSerializationTest.c"
	}
#line 431 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17788 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_registers_class_init (GomSerializationTestHashRegistersClass * klass) {
#line 430 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_hash_registers_parent_class = g_type_class_peek_parent (klass);
#line 430 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_registers_constructor;
#line 17797 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_registers_instance_init (GomSerializationTestHashRegisters * self) {
}


GType gom_serialization_test_hash_registers_get_type (void) {
	static volatile gsize gom_serialization_test_hash_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_registers_instance_init, NULL };
		GType gom_serialization_test_hash_registers_type_id;
		gom_serialization_test_hash_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomSerializationTestHashRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_registers_type_id__volatile, gom_serialization_test_hash_registers_type_id);
	}
	return gom_serialization_test_hash_registers_type_id__volatile;
}


GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_construct (GType object_type) {
	GomSerializationTestHashPairRegisters * self = NULL;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestHashPairRegisters*) gxml_gom_hash_paired_map_construct (object_type);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17823 "GomSerializationTest.c"
}


GomSerializationTestHashPairRegisters* gom_serialization_test_hash_pair_registers_new (void) {
#line 436 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_hash_pair_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS);
#line 17830 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_hash_pair_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashPairRegisters * self;
	GError * _inner_error_ = NULL;
#line 437 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_pair_registers_parent_class);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_PAIR_REGISTERS, GomSerializationTestHashPairRegisters);
#line 17845 "GomSerializationTest.c"
	{
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17851 "GomSerializationTest.c"
			goto __catch336_g_error;
		}
	}
	goto __finally336;
	__catch336_g_error:
	{
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17864 "GomSerializationTest.c"
	}
	__finally336:
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17873 "GomSerializationTest.c"
	}
#line 437 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17877 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_pair_registers_class_init (GomSerializationTestHashPairRegistersClass * klass) {
#line 436 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_hash_pair_registers_parent_class = g_type_class_peek_parent (klass);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_pair_registers_constructor;
#line 17886 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_pair_registers_instance_init (GomSerializationTestHashPairRegisters * self) {
}


GType gom_serialization_test_hash_pair_registers_get_type (void) {
	static volatile gsize gom_serialization_test_hash_pair_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_pair_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashPairRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_pair_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashPairRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_pair_registers_instance_init, NULL };
		GType gom_serialization_test_hash_pair_registers_type_id;
		gom_serialization_test_hash_pair_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_PAIRED_MAP, "GomSerializationTestHashPairRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_pair_registers_type_id__volatile, gom_serialization_test_hash_pair_registers_type_id);
	}
	return gom_serialization_test_hash_pair_registers_type_id__volatile;
}


GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_construct (GType object_type) {
	GomSerializationTestHashThreeRegisters * self = NULL;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestHashThreeRegisters*) gxml_gom_hash_three_map_construct (object_type);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 17912 "GomSerializationTest.c"
}


GomSerializationTestHashThreeRegisters* gom_serialization_test_hash_three_registers_new (void) {
#line 442 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_hash_three_registers_construct (GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS);
#line 17919 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_hash_three_registers_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestHashThreeRegisters * self;
	GError * _inner_error_ = NULL;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_hash_three_registers_parent_class);
#line 443 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 443 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_HASH_THREE_REGISTERS, GomSerializationTestHashThreeRegisters);
#line 17934 "GomSerializationTest.c"
	{
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK_REGISTER, &_inner_error_);
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 17940 "GomSerializationTest.c"
			goto __catch337_g_error;
		}
	}
	goto __finally337;
	__catch337_g_error:
	{
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 17953 "GomSerializationTest.c"
	}
	__finally337:
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 444 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 17962 "GomSerializationTest.c"
	}
#line 443 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 17966 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_three_registers_class_init (GomSerializationTestHashThreeRegistersClass * klass) {
#line 442 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_hash_three_registers_parent_class = g_type_class_peek_parent (klass);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_hash_three_registers_constructor;
#line 17975 "GomSerializationTest.c"
}


static void gom_serialization_test_hash_three_registers_instance_init (GomSerializationTestHashThreeRegisters * self) {
}


GType gom_serialization_test_hash_three_registers_get_type (void) {
	static volatile gsize gom_serialization_test_hash_three_registers_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_hash_three_registers_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestHashThreeRegistersClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_hash_three_registers_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestHashThreeRegisters), 0, (GInstanceInitFunc) gom_serialization_test_hash_three_registers_instance_init, NULL };
		GType gom_serialization_test_hash_three_registers_type_id;
		gom_serialization_test_hash_three_registers_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_THREE_MAP, "GomSerializationTestHashThreeRegisters", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_hash_three_registers_type_id__volatile, gom_serialization_test_hash_three_registers_type_id);
	}
	return gom_serialization_test_hash_three_registers_type_id__volatile;
}


GomSerializationTestBooks* gom_serialization_test_books_construct (GType object_type) {
	GomSerializationTestBooks * self = NULL;
#line 448 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBooks*) gxml_gom_hash_map_construct (object_type);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18001 "GomSerializationTest.c"
}


GomSerializationTestBooks* gom_serialization_test_books_new (void) {
#line 448 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_books_construct (GOM_SERIALIZATION_TEST_TYPE_BOOKS);
#line 18008 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_books_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBooks * self;
	GError * _inner_error_ = NULL;
#line 449 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_books_parent_class);
#line 449 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 449 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOKS, GomSerializationTestBooks);
#line 18023 "GomSerializationTest.c"
	{
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_hash_map_initialize_with_key ((GXmlGomHashMap*) self, GOM_SERIALIZATION_TEST_TYPE_BOOK, "Name", &_inner_error_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18029 "GomSerializationTest.c"
			goto __catch338_g_error;
		}
	}
	goto __finally338;
	__catch338_g_error:
	{
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 18042 "GomSerializationTest.c"
	}
	__finally338:
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 18051 "GomSerializationTest.c"
	}
#line 449 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 18055 "GomSerializationTest.c"
}


static void gom_serialization_test_books_class_init (GomSerializationTestBooksClass * klass) {
#line 448 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_books_parent_class = g_type_class_peek_parent (klass);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_books_constructor;
#line 18064 "GomSerializationTest.c"
}


static void gom_serialization_test_books_instance_init (GomSerializationTestBooks * self) {
}


GType gom_serialization_test_books_get_type (void) {
	static volatile gsize gom_serialization_test_books_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_books_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBooksClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_books_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBooks), 0, (GInstanceInitFunc) gom_serialization_test_books_instance_init, NULL };
		GType gom_serialization_test_books_type_id;
		gom_serialization_test_books_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomSerializationTestBooks", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_books_type_id__volatile, gom_serialization_test_books_type_id);
	}
	return gom_serialization_test_books_type_id__volatile;
}


gchar* gom_serialization_test_book_store_to_string (GomSerializationTestBookStore* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 461 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 462 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 462 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 463 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 463 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 18101 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18112 "GomSerializationTest.c"
			goto __catch339_g_error;
		}
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 465 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 18125 "GomSerializationTest.c"
	}
	goto __finally339;
	__catch339_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:467: %s", _tmp7_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 18152 "GomSerializationTest.c"
	}
	__finally339:
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 18167 "GomSerializationTest.c"
	}
#line 470 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18175 "GomSerializationTest.c"
}


GomSerializationTestBookStore* gom_serialization_test_book_store_construct (GType object_type) {
	GomSerializationTestBookStore * self = NULL;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestBookStore*) gxml_gom_element_construct (object_type);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18185 "GomSerializationTest.c"
}


GomSerializationTestBookStore* gom_serialization_test_book_store_new (void) {
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_book_store_construct (GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE);
#line 18192 "GomSerializationTest.c"
}


const gchar* gom_serialization_test_book_store_get_name (GomSerializationTestBookStore* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_name;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18207 "GomSerializationTest.c"
}


void gom_serialization_test_book_store_set_name (GomSerializationTestBookStore* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_name = _tmp1_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 18226 "GomSerializationTest.c"
}


GomSerializationTestBooks* gom_serialization_test_book_store_get_books (GomSerializationTestBookStore* self) {
	GomSerializationTestBooks* result;
	GomSerializationTestBooks* _tmp0_ = NULL;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_books;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18241 "GomSerializationTest.c"
}


void gom_serialization_test_book_store_set_books (GomSerializationTestBookStore* self, GomSerializationTestBooks* value) {
	GomSerializationTestBooks* _tmp0_ = NULL;
	GomSerializationTestBooks* _tmp1_ = NULL;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_books = _tmp1_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "books");
#line 18260 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_book_store_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestBookStore * self;
	GError * _inner_error_ = NULL;
#line 458 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_book_store_parent_class);
#line 458 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 458 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 18275 "GomSerializationTest.c"
	{
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "BookStore");
#line 18279 "GomSerializationTest.c"
	}
	goto __finally340;
	__catch340_g_error:
	{
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 18290 "GomSerializationTest.c"
	}
	__finally340:
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 18299 "GomSerializationTest.c"
	}
#line 458 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 18303 "GomSerializationTest.c"
}


static void gom_serialization_test_book_store_class_init (GomSerializationTestBookStoreClass * klass) {
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_book_store_parent_class = g_type_class_peek_parent (klass);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestBookStorePrivate));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_book_store_get_property;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_book_store_set_property;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_book_store_constructor;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_book_store_finalize;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY, g_param_spec_string ("name", "::Name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY, g_param_spec_object ("books", "books", "books", GOM_SERIALIZATION_TEST_TYPE_BOOKS, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 18324 "GomSerializationTest.c"
}


static void gom_serialization_test_book_store_instance_init (GomSerializationTestBookStore * self) {
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_BOOK_STORE_GET_PRIVATE (self);
#line 18331 "GomSerializationTest.c"
}


static void gom_serialization_test_book_store_finalize (GObject* obj) {
	GomSerializationTestBookStore * self;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_free0 (self->priv->_name);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_books);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_book_store_parent_class)->finalize (obj);
#line 18345 "GomSerializationTest.c"
}


GType gom_serialization_test_book_store_get_type (void) {
	static volatile gsize gom_serialization_test_book_store_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_book_store_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestBookStoreClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_book_store_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestBookStore), 0, (GInstanceInitFunc) gom_serialization_test_book_store_instance_init, NULL };
		GType gom_serialization_test_book_store_type_id;
		gom_serialization_test_book_store_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestBookStore", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_book_store_type_id__volatile, gom_serialization_test_book_store_type_id);
	}
	return gom_serialization_test_book_store_type_id__volatile;
}


static void _vala_gom_serialization_test_book_store_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_string (value, gom_serialization_test_book_store_get_name (self));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_book_store_get_books (self));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 18378 "GomSerializationTest.c"
		default:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 18384 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_book_store_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestBookStore * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_BOOK_STORE, GomSerializationTestBookStore);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_NAME_PROPERTY:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_store_set_name (self, g_value_get_string (value));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_BOOK_STORE_BOOKS_PROPERTY:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_book_store_set_books (self, g_value_get_object (value));
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 18406 "GomSerializationTest.c"
		default:
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 18412 "GomSerializationTest.c"
	}
}


GType gom_serialization_test_motor_tension_type_enum_get_type (void) {
	static volatile gsize gom_serialization_test_motor_tension_type_enum_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_enum_type_id__volatile)) {
		static const GEnumValue values[] = {{GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC, "GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_AC", "ac"}, {GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC, "GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_ENUM_DC", "dc"}, {0, NULL, NULL}};
		GType gom_serialization_test_motor_tension_type_enum_type_id;
		gom_serialization_test_motor_tension_type_enum_type_id = g_enum_register_static ("GomSerializationTestMotorTensionTypeEnum", values);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_enum_type_id__volatile, gom_serialization_test_motor_tension_type_enum_type_id);
	}
	return gom_serialization_test_motor_tension_type_enum_type_id__volatile;
}


gchar* gom_serialization_test_motor_to_string (GomSerializationTestMotor* self) {
	gchar* result = NULL;
	GXmlXParser* parser = NULL;
	GXmlXParser* _tmp0_ = NULL;
	gchar* s = NULL;
	gchar* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 488 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = gxml_xparser_new ((GXmlDomNode*) self);
#line 488 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parser = _tmp0_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("");
#line 489 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	s = _tmp1_;
#line 18446 "GomSerializationTest.c"
	{
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp3_ = gxml_parser_write_string ((GXmlParser*) parser, &_inner_error_);
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = _tmp3_;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 18457 "GomSerializationTest.c"
			goto __catch341_g_error;
		}
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp4_ = _tmp2_;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp2_ = NULL;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 491 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		s = _tmp4_;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp2_);
#line 18470 "GomSerializationTest.c"
	}
	goto __finally341;
	__catch341_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		e = _inner_error_;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp5_ = e->message;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp6_ = g_strconcat ("Error: ", _tmp5_, NULL);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_tmp7_ = _tmp6_;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_message ("GomSerializationTest.vala:493: %s", _tmp7_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (_tmp7_);
#line 494 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_error_free0 (e);
#line 18497 "GomSerializationTest.c"
	}
	__finally341:
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_free0 (s);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_g_object_unref0 (parser);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		return NULL;
#line 18512 "GomSerializationTest.c"
	}
#line 496 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = s;
#line 496 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (parser);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18520 "GomSerializationTest.c"
}


GomSerializationTestMotor* gom_serialization_test_motor_construct (GType object_type) {
	GomSerializationTestMotor * self = NULL;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotor*) gxml_gom_element_construct (object_type);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18530 "GomSerializationTest.c"
}


GomSerializationTestMotor* gom_serialization_test_motor_new (void) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_construct (GOM_SERIALIZATION_TEST_TYPE_MOTOR);
#line 18537 "GomSerializationTest.c"
}


GomSerializationTestMotorOn* gom_serialization_test_motor_get_is_on (GomSerializationTestMotor* self) {
	GomSerializationTestMotorOn* result;
	GomSerializationTestMotorOn* _tmp0_ = NULL;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_is_on;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18552 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_is_on (GomSerializationTestMotor* self, GomSerializationTestMotorOn* value) {
	GomSerializationTestMotorOn* _tmp0_ = NULL;
	GomSerializationTestMotorOn* _tmp1_ = NULL;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_is_on);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_is_on = _tmp1_;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "is-on");
#line 18571 "GomSerializationTest.c"
}


GomSerializationTestMotorTorque* gom_serialization_test_motor_get_torque (GomSerializationTestMotor* self) {
	GomSerializationTestMotorTorque* result;
	GomSerializationTestMotorTorque* _tmp0_ = NULL;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_torque;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18586 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_torque (GomSerializationTestMotor* self, GomSerializationTestMotorTorque* value) {
	GomSerializationTestMotorTorque* _tmp0_ = NULL;
	GomSerializationTestMotorTorque* _tmp1_ = NULL;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_torque);
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_torque = _tmp1_;
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "torque");
#line 18605 "GomSerializationTest.c"
}


GomSerializationTestMotorSpeed* gom_serialization_test_motor_get_speed (GomSerializationTestMotor* self) {
	GomSerializationTestMotorSpeed* result;
	GomSerializationTestMotorSpeed* _tmp0_ = NULL;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_speed;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18620 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_speed (GomSerializationTestMotor* self, GomSerializationTestMotorSpeed* value) {
	GomSerializationTestMotorSpeed* _tmp0_ = NULL;
	GomSerializationTestMotorSpeed* _tmp1_ = NULL;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_speed);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_speed = _tmp1_;
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "speed");
#line 18639 "GomSerializationTest.c"
}


GomSerializationTestMotorTensionType* gom_serialization_test_motor_get_tension_type (GomSerializationTestMotor* self) {
	GomSerializationTestMotorTensionType* result;
	GomSerializationTestMotorTensionType* _tmp0_ = NULL;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_tension_type;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18654 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_tension_type (GomSerializationTestMotor* self, GomSerializationTestMotorTensionType* value) {
	GomSerializationTestMotorTensionType* _tmp0_ = NULL;
	GomSerializationTestMotorTensionType* _tmp1_ = NULL;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension_type);
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_tension_type = _tmp1_;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "tension-type");
#line 18673 "GomSerializationTest.c"
}


GomSerializationTestMotorTension* gom_serialization_test_motor_get_tension (GomSerializationTestMotor* self) {
	GomSerializationTestMotorTension* result;
	GomSerializationTestMotorTension* _tmp0_ = NULL;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_tension;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18688 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_tension (GomSerializationTestMotor* self, GomSerializationTestMotorTension* value) {
	GomSerializationTestMotorTension* _tmp0_ = NULL;
	GomSerializationTestMotorTension* _tmp1_ = NULL;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_tension = _tmp1_;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "tension");
#line 18707 "GomSerializationTest.c"
}


GomSerializationTestMotorModel* gom_serialization_test_motor_get_model (GomSerializationTestMotor* self) {
	GomSerializationTestMotorModel* result;
	GomSerializationTestMotorModel* _tmp0_ = NULL;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = self->priv->_model;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	result = _tmp0_;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return result;
#line 18722 "GomSerializationTest.c"
}


void gom_serialization_test_motor_set_model (GomSerializationTestMotor* self, GomSerializationTestMotorModel* value) {
	GomSerializationTestMotorModel* _tmp0_ = NULL;
	GomSerializationTestMotorModel* _tmp1_ = NULL;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_return_if_fail (self != NULL);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = value;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_model);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv->_model = _tmp1_;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_notify ((GObject *) self, "model");
#line 18741 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_motor_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotor * self;
	GError * _inner_error_ = NULL;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_parent_class);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 18756 "GomSerializationTest.c"
	{
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "Motor");
#line 18760 "GomSerializationTest.c"
	}
	goto __finally342;
	__catch342_g_error:
	{
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 18771 "GomSerializationTest.c"
	}
	__finally342:
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 18780 "GomSerializationTest.c"
	}
#line 486 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 18784 "GomSerializationTest.c"
}


GomSerializationTestMotorOn* gom_serialization_test_motor_on_construct (GType object_type) {
	GomSerializationTestMotorOn * self = NULL;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorOn*) gxml_gom_boolean_construct (object_type);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18794 "GomSerializationTest.c"
}


GomSerializationTestMotorOn* gom_serialization_test_motor_on_new (void) {
#line 502 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_on_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON);
#line 18801 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_on_class_init (GomSerializationTestMotorOnClass * klass) {
#line 502 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_on_parent_class = g_type_class_peek_parent (klass);
#line 18808 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_on_instance_init (GomSerializationTestMotorOn * self) {
}


GType gom_serialization_test_motor_on_get_type (void) {
	static volatile gsize gom_serialization_test_motor_on_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_on_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorOnClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_on_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorOn), 0, (GInstanceInitFunc) gom_serialization_test_motor_on_instance_init, NULL };
		GType gom_serialization_test_motor_on_type_id;
		gom_serialization_test_motor_on_type_id = g_type_register_static (GXML_TYPE_GOM_BOOLEAN, "GomSerializationTestMotorOn", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_on_type_id__volatile, gom_serialization_test_motor_on_type_id);
	}
	return gom_serialization_test_motor_on_type_id__volatile;
}


GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_construct (GType object_type) {
	GomSerializationTestMotorTorque * self = NULL;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorTorque*) gxml_gom_double_construct (object_type);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18834 "GomSerializationTest.c"
}


GomSerializationTestMotorTorque* gom_serialization_test_motor_torque_new (void) {
#line 503 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_torque_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE);
#line 18841 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_torque_class_init (GomSerializationTestMotorTorqueClass * klass) {
#line 503 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_torque_parent_class = g_type_class_peek_parent (klass);
#line 18848 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_torque_instance_init (GomSerializationTestMotorTorque * self) {
}


GType gom_serialization_test_motor_torque_get_type (void) {
	static volatile gsize gom_serialization_test_motor_torque_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_torque_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTorqueClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_torque_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTorque), 0, (GInstanceInitFunc) gom_serialization_test_motor_torque_instance_init, NULL };
		GType gom_serialization_test_motor_torque_type_id;
		gom_serialization_test_motor_torque_type_id = g_type_register_static (GXML_TYPE_GOM_DOUBLE, "GomSerializationTestMotorTorque", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_torque_type_id__volatile, gom_serialization_test_motor_torque_type_id);
	}
	return gom_serialization_test_motor_torque_type_id__volatile;
}


GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_construct (GType object_type) {
	GomSerializationTestMotorSpeed * self = NULL;
#line 504 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorSpeed*) gxml_gom_float_construct (object_type);
#line 504 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18874 "GomSerializationTest.c"
}


GomSerializationTestMotorSpeed* gom_serialization_test_motor_speed_new (void) {
#line 504 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_speed_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED);
#line 18881 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_speed_class_init (GomSerializationTestMotorSpeedClass * klass) {
#line 504 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_speed_parent_class = g_type_class_peek_parent (klass);
#line 18888 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_speed_instance_init (GomSerializationTestMotorSpeed * self) {
}


GType gom_serialization_test_motor_speed_get_type (void) {
	static volatile gsize gom_serialization_test_motor_speed_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_speed_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorSpeedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_speed_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorSpeed), 0, (GInstanceInitFunc) gom_serialization_test_motor_speed_instance_init, NULL };
		GType gom_serialization_test_motor_speed_type_id;
		gom_serialization_test_motor_speed_type_id = g_type_register_static (GXML_TYPE_GOM_FLOAT, "GomSerializationTestMotorSpeed", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_speed_type_id__volatile, gom_serialization_test_motor_speed_type_id);
	}
	return gom_serialization_test_motor_speed_type_id__volatile;
}


GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_construct (GType object_type) {
	GomSerializationTestMotorTensionType * self = NULL;
#line 505 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorTensionType*) gxml_gom_enum_construct (object_type);
#line 505 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18914 "GomSerializationTest.c"
}


GomSerializationTestMotorTensionType* gom_serialization_test_motor_tension_type_new (void) {
#line 505 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_tension_type_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE);
#line 18921 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_motor_tension_type_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotorTensionType * self;
	GError * _inner_error_ = NULL;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_tension_type_parent_class);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, GomSerializationTestMotorTensionType);
#line 18936 "GomSerializationTest.c"
	{
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gxml_gom_enum_initialize_enum ((GXmlGomEnum*) self, GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE_ENUM);
#line 18940 "GomSerializationTest.c"
	}
	goto __finally343;
	__catch343_g_error:
	{
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		_inner_error_ = NULL;
#line 508 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_assert_not_reached ();
#line 18951 "GomSerializationTest.c"
	}
	__finally343:
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 507 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_clear_error (&_inner_error_);
#line 18960 "GomSerializationTest.c"
	}
#line 506 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 18964 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_tension_type_class_init (GomSerializationTestMotorTensionTypeClass * klass) {
#line 505 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_tension_type_parent_class = g_type_class_peek_parent (klass);
#line 505 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_tension_type_constructor;
#line 18973 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_tension_type_instance_init (GomSerializationTestMotorTensionType * self) {
}


GType gom_serialization_test_motor_tension_type_get_type (void) {
	static volatile gsize gom_serialization_test_motor_tension_type_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTensionTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_tension_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTensionType), 0, (GInstanceInitFunc) gom_serialization_test_motor_tension_type_instance_init, NULL };
		GType gom_serialization_test_motor_tension_type_type_id;
		gom_serialization_test_motor_tension_type_type_id = g_type_register_static (GXML_TYPE_GOM_ENUM, "GomSerializationTestMotorTensionType", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_type_id__volatile, gom_serialization_test_motor_tension_type_type_id);
	}
	return gom_serialization_test_motor_tension_type_type_id__volatile;
}


GomSerializationTestMotorTension* gom_serialization_test_motor_tension_construct (GType object_type) {
	GomSerializationTestMotorTension * self = NULL;
#line 511 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorTension*) gxml_gom_int_construct (object_type);
#line 511 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 18999 "GomSerializationTest.c"
}


GomSerializationTestMotorTension* gom_serialization_test_motor_tension_new (void) {
#line 511 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_tension_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION);
#line 19006 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_tension_class_init (GomSerializationTestMotorTensionClass * klass) {
#line 511 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_tension_parent_class = g_type_class_peek_parent (klass);
#line 19013 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_tension_instance_init (GomSerializationTestMotorTension * self) {
}


GType gom_serialization_test_motor_tension_get_type (void) {
	static volatile gsize gom_serialization_test_motor_tension_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_tension_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorTensionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_tension_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorTension), 0, (GInstanceInitFunc) gom_serialization_test_motor_tension_instance_init, NULL };
		GType gom_serialization_test_motor_tension_type_id;
		gom_serialization_test_motor_tension_type_id = g_type_register_static (GXML_TYPE_GOM_INT, "GomSerializationTestMotorTension", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_tension_type_id__volatile, gom_serialization_test_motor_tension_type_id);
	}
	return gom_serialization_test_motor_tension_type_id__volatile;
}


GomSerializationTestMotorModel* gom_serialization_test_motor_model_construct (GType object_type) {
	GomSerializationTestMotorModel * self = NULL;
#line 512 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = (GomSerializationTestMotorModel*) gxml_gom_array_string_construct (object_type);
#line 512 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return self;
#line 19039 "GomSerializationTest.c"
}


GomSerializationTestMotorModel* gom_serialization_test_motor_model_new (void) {
#line 512 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return gom_serialization_test_motor_model_construct (GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL);
#line 19046 "GomSerializationTest.c"
}


static GObject * gom_serialization_test_motor_model_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomSerializationTestMotorModel * self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
#line 513 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	parent_class = G_OBJECT_CLASS (gom_serialization_test_motor_model_parent_class);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, GomSerializationTestMotorModel);
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp0_ = g_strdup ("MODEL1");
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp1_ = g_strdup ("MODEL2");
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_ = g_new0 (gchar*, 2 + 1);
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_[0] = _tmp0_;
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_tmp2_[1] = _tmp1_;
#line 514 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gxml_gom_array_string_initialize_strings ((GXmlGomArrayString*) self, _tmp2_, 2);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	return obj;
#line 19077 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_model_class_init (GomSerializationTestMotorModelClass * klass) {
#line 512 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_model_parent_class = g_type_class_peek_parent (klass);
#line 512 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_model_constructor;
#line 19086 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_model_instance_init (GomSerializationTestMotorModel * self) {
}


GType gom_serialization_test_motor_model_get_type (void) {
	static volatile gsize gom_serialization_test_motor_model_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_model_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorModelClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_model_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotorModel), 0, (GInstanceInitFunc) gom_serialization_test_motor_model_instance_init, NULL };
		GType gom_serialization_test_motor_model_type_id;
		gom_serialization_test_motor_model_type_id = g_type_register_static (GXML_TYPE_GOM_ARRAY_STRING, "GomSerializationTestMotorModel", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_model_type_id__volatile, gom_serialization_test_motor_model_type_id);
	}
	return gom_serialization_test_motor_model_type_id__volatile;
}


static void gom_serialization_test_motor_class_init (GomSerializationTestMotorClass * klass) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_motor_parent_class = g_type_class_peek_parent (klass);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_type_class_add_private (klass, sizeof (GomSerializationTestMotorPrivate));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_serialization_test_motor_get_property;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_serialization_test_motor_set_property;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_serialization_test_motor_constructor;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_serialization_test_motor_finalize;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY, g_param_spec_object ("is-on", "::On", "is-on", GOM_SERIALIZATION_TEST_MOTOR_TYPE_ON, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY, g_param_spec_object ("torque", "::Torque", "torque", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TORQUE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY, g_param_spec_object ("speed", "::Speed", "speed", GOM_SERIALIZATION_TEST_MOTOR_TYPE_SPEED, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY, g_param_spec_object ("tension-type", "::TensionType", "tension-type", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION_TYPE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY, g_param_spec_object ("tension", "::Tension", "tension", GOM_SERIALIZATION_TEST_MOTOR_TYPE_TENSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY, g_param_spec_object ("model", "::Model", "model", GOM_SERIALIZATION_TEST_MOTOR_TYPE_MODEL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 19131 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_instance_init (GomSerializationTestMotor * self) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self->priv = GOM_SERIALIZATION_TEST_MOTOR_GET_PRIVATE (self);
#line 19138 "GomSerializationTest.c"
}


static void gom_serialization_test_motor_finalize (GObject* obj) {
	GomSerializationTestMotor * self;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_is_on);
#line 477 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_torque);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_speed);
#line 481 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension_type);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_tension);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	_g_object_unref0 (self->priv->_model);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	G_OBJECT_CLASS (gom_serialization_test_motor_parent_class)->finalize (obj);
#line 19160 "GomSerializationTest.c"
}


GType gom_serialization_test_motor_get_type (void) {
	static volatile gsize gom_serialization_test_motor_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_motor_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestMotorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_motor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTestMotor), 0, (GInstanceInitFunc) gom_serialization_test_motor_instance_init, NULL };
		GType gom_serialization_test_motor_type_id;
		gom_serialization_test_motor_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomSerializationTestMotor", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_motor_type_id__volatile, gom_serialization_test_motor_type_id);
	}
	return gom_serialization_test_motor_type_id__volatile;
}


static void _vala_gom_serialization_test_motor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomSerializationTestMotor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_is_on (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_torque (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_speed (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_tension_type (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_tension (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		g_value_set_object (value, gom_serialization_test_motor_get_model (self));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 19217 "GomSerializationTest.c"
		default:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 19223 "GomSerializationTest.c"
	}
}


static void _vala_gom_serialization_test_motor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomSerializationTestMotor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_SERIALIZATION_TEST_TYPE_MOTOR, GomSerializationTestMotor);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	switch (property_id) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_IS_ON_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_is_on (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TORQUE_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_torque (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_SPEED_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_speed (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_TYPE_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_tension_type (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_TENSION_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_tension (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		case GOM_SERIALIZATION_TEST_MOTOR_MODEL_PROPERTY:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		gom_serialization_test_motor_set_model (self, g_value_get_object (value));
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 19269 "GomSerializationTest.c"
		default:
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
		break;
#line 19275 "GomSerializationTest.c"
	}
}


static void gom_serialization_test_class_init (GomSerializationTestClass * klass) {
#line 218 "/home/despinosa/Proyectos/gxml/test/GomSerializationTest.vala"
	gom_serialization_test_parent_class = g_type_class_peek_parent (klass);
#line 19283 "GomSerializationTest.c"
}


static void gom_serialization_test_instance_init (GomSerializationTest * self) {
}


GType gom_serialization_test_get_type (void) {
	static volatile gsize gom_serialization_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_serialization_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomSerializationTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_serialization_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomSerializationTest), 0, (GInstanceInitFunc) gom_serialization_test_instance_init, NULL };
		GType gom_serialization_test_type_id;
		gom_serialization_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomSerializationTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_serialization_test_type_id__volatile, gom_serialization_test_type_id);
	}
	return gom_serialization_test_type_id__volatile;
}



