/* GomDocumentTest.c generated by valac 0.34.13, the Vala compiler
 * generated from GomDocumentTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* GomDocumentTest.vala
 *
 * Copyright (C) 2016 Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <gee.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_DOCUMENT_TEST (gom_document_test_get_type ())
#define GOM_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_DOCUMENT_TEST, GomDocumentTest))
#define GOM_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_DOCUMENT_TEST, GomDocumentTestClass))
#define IS_GOM_DOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_DOCUMENT_TEST))
#define IS_GOM_DOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_DOCUMENT_TEST))
#define GOM_DOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_DOCUMENT_TEST, GomDocumentTestClass))

typedef struct _GomDocumentTest GomDocumentTest;
typedef struct _GomDocumentTestClass GomDocumentTestClass;
typedef struct _GomDocumentTestPrivate GomDocumentTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_string_free0(var) ((var == NULL) ? NULL : (var = (g_string_free (var, TRUE), NULL)))
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomDocumentTest {
	GXmlTest parent_instance;
	GomDocumentTestPrivate * priv;
};

struct _GomDocumentTestClass {
	GXmlTestClass parent_class;
};


static gpointer gom_document_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_document_test_get_type (void) G_GNUC_CONST;
enum  {
	GOM_DOCUMENT_TEST_0_PROPERTY
};
void gom_document_test_add_tests (void);
static void __lambda206_ (void);
static void ___lambda206__gtest_func (void);
static void __lambda207_ (void);
static void ___lambda207__gtest_func (void);
static void __lambda208_ (void);
static void ___lambda208__gtest_func (void);
static void __lambda209_ (void);
static void ___lambda209__gtest_func (void);
static void __lambda210_ (void);
static void ___lambda210__gtest_func (void);
static void __lambda211_ (void);
static void ___lambda211__gtest_func (void);
static void __lambda212_ (void);
static void ___lambda212__gtest_func (void);
static void __lambda213_ (void);
static void ___lambda213__gtest_func (void);
static void __lambda214_ (void);
static void ___lambda214__gtest_func (void);
static void __lambda215_ (void);
static void ___lambda215__gtest_func (void);
static void __lambda216_ (void);
static void ___lambda216__gtest_func (void);
static void __lambda217_ (void);
static void ___lambda217__gtest_func (void);
static void __lambda218_ (void);
static void ___lambda218__gtest_func (void);
static void __lambda219_ (void);
static void ___lambda219__gtest_func (void);
static void __lambda220_ (void);
static void ___lambda220__gtest_func (void);
static void __lambda221_ (void);
static void ___lambda221__gtest_func (void);
static void __lambda222_ (void);
static void ___lambda222__gtest_func (void);
static void __lambda223_ (void);
static void ___lambda223__gtest_func (void);
static void __lambda224_ (void);
static void ___lambda224__gtest_func (void);
static void __lambda225_ (void);
static void ___lambda225__gtest_func (void);
static void __lambda226_ (void);
static void ___lambda226__gtest_func (void);
static void __lambda227_ (void);
static void ___lambda227__gtest_func (void);
static void __lambda228_ (void);
static void ___lambda228__gtest_func (void);
static void __lambda229_ (void);
static void ___lambda229__gtest_func (void);
static void __lambda230_ (void);
static void ___lambda230__gtest_func (void);
static void __lambda231_ (void);
static void ___lambda231__gtest_func (void);
static void __lambda232_ (void);
static void ___lambda232__gtest_func (void);
static void __lambda233_ (void);
static void ___lambda233__gtest_func (void);
static void __lambda234_ (void);
static void ___lambda234__gtest_func (void);
static void __lambda235_ (void);
static void ___lambda235__gtest_func (void);
static void __lambda236_ (void);
static void ___lambda236__gtest_func (void);
static void __lambda237_ (void);
static void ___lambda237__gtest_func (void);
static void __lambda238_ (void);
static void ___lambda238__gtest_func (void);
static void __lambda239_ (void);
static void ___lambda239__gtest_func (void);
static void __lambda240_ (void);
static void ___lambda240__gtest_func (void);
GomDocumentTest* gom_document_test_new (void);
GomDocumentTest* gom_document_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static void __lambda206_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlDomNodeNodeType _tmp8_ = 0;
		GXmlDomNodeNodeType _tmp9_ = 0;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
#line 29 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 29 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = (GXmlDomDocument*) _tmp0_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_create_element (d, "root", &_inner_error_);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp1_;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 30 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 222 "GomDocumentTest.c"
			goto __catch208_g_error;
		}
#line 31 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (r, GXML_TYPE_DOM_ELEMENT), "r is DomElement");
#line 32 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_element_get_local_name (r);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp4_, "root") == 0, "r.local_name == \"root\"");
#line 32 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp4_);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_element_get_tag_name (r);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "root") == 0, "r.tag_name == \"root\"");
#line 33 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_type ((GXmlDomNode*) r);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp9_ == GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE, "r.node_type == DomNode.NodeType.ELEMENT_NODE");
#line 35 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_node_name ((GXmlDomNode*) r);
#line 35 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 35 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "root") == 0, "r.node_name == \"root\"");
#line 35 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) d);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 36 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) r);
#line 36 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 37 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element (d);
#line 37 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 37 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp18_ != NULL, "d.document_element != null");
#line 37 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (d);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "root") == 0, "d.document_element.node_name == \"root\"");
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 305 "GomDocumentTest.c"
	}
	goto __finally208;
	__catch208_g_error:
	{
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 316 "GomDocumentTest.c"
	}
	__finally208:
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 28 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 327 "GomDocumentTest.c"
	}
}


static void ___lambda206__gtest_func (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda206_ ();
#line 335 "GomDocumentTest.c"
}


static void __lambda207_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
#line 46 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_test_message ("invalid file...");
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_path ("/tmp/asdfjlkansdlfjl", &_inner_error_);
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 354 "GomDocumentTest.c"
			goto __catch209_g_error;
		}
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 48 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 369 "GomDocumentTest.c"
	}
	goto __finally209;
	__catch209_g_error:
	{
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 378 "GomDocumentTest.c"
	}
	__finally209:
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 391 "GomDocumentTest.c"
	}
	{
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_gom_document_new_from_path ("/tmp/", &_inner_error_);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp4_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 403 "GomDocumentTest.c"
			goto __catch210_g_error;
		}
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp3_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = NULL;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp5_;
#line 55 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 418 "GomDocumentTest.c"
	}
	goto __finally210;
	__catch210_g_error:
	{
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 427 "GomDocumentTest.c"
	}
	__finally210:
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 440 "GomDocumentTest.c"
	}
	{
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlGomDocument* _tmp7_ = NULL;
		GXmlGomDocument* _tmp8_ = NULL;
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_gom_document_new_from_path ("test_invalid.xml", &_inner_error_);
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp7_;
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 452 "GomDocumentTest.c"
			goto __catch211_g_error;
		}
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp6_;
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = NULL;
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 58 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp8_;
#line 59 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 467 "GomDocumentTest.c"
	}
	goto __finally211;
	__catch211_g_error:
	{
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 476 "GomDocumentTest.c"
	}
	__finally211:
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 489 "GomDocumentTest.c"
	}
#line 43 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 493 "GomDocumentTest.c"
}


static void ___lambda207__gtest_func (void) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda207_ ();
#line 500 "GomDocumentTest.c"
}


static void __lambda208_ (void) {
	GFile* fin = NULL;
	GFile* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	GError * _inner_error_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp0_ = g_file_new_for_path (TEST_DIR "/test.xml");
#line 63 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	fin = _tmp0_;
#line 64 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp1_ = fin;
#line 64 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 64 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp2_, "fin.query_exists ()");
#line 520 "GomDocumentTest.c"
	{
		GFileInputStream* instream = NULL;
		GFile* _tmp3_ = NULL;
		GFileInputStream* _tmp4_ = NULL;
		GXmlGomDocument* doc = NULL;
		GFileInputStream* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlGomDocument* _tmp7_ = NULL;
#line 66 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = fin;
#line 66 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = g_file_read (_tmp3_, NULL, &_inner_error_);
#line 66 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		instream = _tmp4_;
#line 66 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 537 "GomDocumentTest.c"
			goto __catch212_g_error;
		}
#line 67 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = instream;
#line 67 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = gxml_gom_document_new_from_stream ((GInputStream*) _tmp5_, &_inner_error_);
#line 67 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = _tmp6_;
#line 67 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 67 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (instream);
#line 550 "GomDocumentTest.c"
			goto __catch212_g_error;
		}
#line 68 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = doc;
#line 68 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp7_ != NULL, "doc != null");
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (instream);
#line 561 "GomDocumentTest.c"
	}
	goto __finally212;
	__catch212_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_ = NULL;
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = e->message;
#line 71 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:71: %s", _tmp8_);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 580 "GomDocumentTest.c"
	}
	__finally212:
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 65 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 593 "GomDocumentTest.c"
	}
#line 62 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (fin);
#line 597 "GomDocumentTest.c"
}


static void ___lambda208__gtest_func (void) {
#line 62 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda208_ ();
#line 604 "GomDocumentTest.c"
}


static void __lambda209_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GString* s = NULL;
		GString* _tmp4_ = NULL;
		GString* _tmp5_ = NULL;
		GXmlGomDocument* d = NULL;
		GString* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GXmlGomDocument* _tmp8_ = NULL;
		GXmlGomDocument* _tmp9_ = NULL;
		GFile* _tmp10_ = NULL;
		GFile* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		GXmlGomDocument* d2 = NULL;
		GFile* _tmp13_ = NULL;
		GXmlGomDocument* _tmp14_ = NULL;
		GXmlGomDocument* _tmp15_ = NULL;
		GXmlGomDocument* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		GFile* _tmp27_ = NULL;
#line 77 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 77 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		f = _tmp0_;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = f;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp2_) {
#line 652 "GomDocumentTest.c"
			GFile* _tmp3_ = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp3_ = f;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			g_file_delete (_tmp3_, NULL, &_inner_error_);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_object_unref0 (f);
#line 662 "GomDocumentTest.c"
				goto __catch213_g_error;
			}
		}
#line 79 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = g_string_new ("");
#line 79 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		s = _tmp4_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = s;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_string_append (_tmp5_, "<document_element />");
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = s;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_->str;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_gom_document_new_from_string (_tmp7_, &_inner_error_);
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp8_;
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 81 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 688 "GomDocumentTest.c"
			goto __catch213_g_error;
		}
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = d;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = f;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_write_file (_tmp9_, _tmp10_, &_inner_error_);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 705 "GomDocumentTest.c"
			goto __catch213_g_error;
		}
#line 88 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = f;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = g_file_query_exists (_tmp11_, NULL);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp12_, "f.query_exists ()");
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = f;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = gxml_gom_document_new_from_file (_tmp13_, &_inner_error_);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d2 = _tmp14_;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 728 "GomDocumentTest.c"
			goto __catch213_g_error;
		}
#line 90 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = d2;
#line 90 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp15_ != NULL, "d2 != null");
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = d2;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp16_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp19_ != NULL, "d2.document_element != null");
#line 91 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = d2;
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp20_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp23_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "document_element") == 0, "d2.document_element.node_name == \"document_element\"");
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp26_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = f;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_file_delete (_tmp27_, NULL, &_inner_error_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 781 "GomDocumentTest.c"
			goto __catch213_g_error;
		}
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d2);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_string_free0 (s);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 792 "GomDocumentTest.c"
	}
	goto __finally213;
	__catch213_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = e->message;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = g_strconcat ("Error: ", _tmp28_, NULL);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 95 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:95: %s", _tmp30_);
#line 95 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 96 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 819 "GomDocumentTest.c"
	}
	__finally213:
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 830 "GomDocumentTest.c"
	}
}


static void ___lambda209__gtest_func (void) {
#line 75 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda209_ ();
#line 838 "GomDocumentTest.c"
}


static void __lambda210_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* f = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GString* s = NULL;
		GString* _tmp4_ = NULL;
		GString* _tmp5_ = NULL;
		GXmlGomDocument* d = NULL;
		GString* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GXmlGomDocument* _tmp8_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp9_ = NULL;
		GXmlXParser* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlXParser* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GFile* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		GXmlGomDocument* _tmp21_ = NULL;
		GFile* _tmp22_ = NULL;
		GFile* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		GXmlGomDocument* d2 = NULL;
		GXmlGomDocument* _tmp25_ = NULL;
		GXmlGomDocument* _tmp26_ = NULL;
		GXmlGomDocument* _tmp27_ = NULL;
		GFile* _tmp28_ = NULL;
		GXmlGomDocument* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlGomDocument* _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GFile* _tmp40_ = NULL;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_path (TEST_SAVE_DIR "/tw-test-file.xml");
#line 101 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		f = _tmp0_;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = f;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp2_) {
#line 900 "GomDocumentTest.c"
			GFile* _tmp3_ = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp3_ = f;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			g_file_delete (_tmp3_, NULL, &_inner_error_);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 102 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_object_unref0 (f);
#line 910 "GomDocumentTest.c"
				goto __catch214_g_error;
			}
		}
#line 103 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = g_string_new ("");
#line 103 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		s = _tmp4_;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = s;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_string_append (_tmp5_, "<document_element />");
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = s;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_->str;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_gom_document_new_from_string (_tmp7_, &_inner_error_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp8_;
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 936 "GomDocumentTest.c"
			goto __catch214_g_error;
		}
#line 106 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = d;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_xparser_new ((GXmlDomNode*) _tmp9_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		parser = _tmp10_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = parser;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_parser_write_string ((GXmlParser*) _tmp12_, &_inner_error_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp13_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 961 "GomDocumentTest.c"
			goto __catch214_g_error;
		}
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = f;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = g_file_get_uri (_tmp14_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = g_strconcat ("Saving to file: ", _tmp16_, NULL);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = g_strconcat (_tmp18_, _tmp11_, NULL);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_test_message ("%s", _tmp20_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 107 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = d;
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = f;
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_write_file (_tmp21_, _tmp22_, &_inner_error_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp11_);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 108 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1004 "GomDocumentTest.c"
			goto __catch214_g_error;
		}
#line 109 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = f;
#line 109 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = g_file_query_exists (_tmp23_, NULL);
#line 109 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp24_, "f.query_exists ()");
#line 110 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = gxml_gom_document_new ();
#line 110 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d2 = _tmp25_;
#line 111 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = d2;
#line 111 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp26_ != NULL, "d2 != null");
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = d2;
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = f;
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_read_from_file (_tmp27_, _tmp28_, &_inner_error_);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp11_);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 112 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1041 "GomDocumentTest.c"
			goto __catch214_g_error;
		}
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = d2;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp29_);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp32_ != NULL, "d2.document_element != null");
#line 113 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = d2;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp33_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp36_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp39_, "document_element") == 0, "d2.document_element.node_name == \"document_element\"");
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 114 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = f;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_file_delete (_tmp40_, NULL, &_inner_error_);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d2);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp11_);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_string_free0 (s);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 1094 "GomDocumentTest.c"
			goto __catch214_g_error;
		}
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d2);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_string_free0 (s);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 1109 "GomDocumentTest.c"
	}
	goto __finally214;
	__catch214_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = e->message;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = g_strconcat ("Error: ", _tmp41_, NULL);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:117: %s", _tmp43_);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp43_);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1136 "GomDocumentTest.c"
	}
	__finally214:
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 1147 "GomDocumentTest.c"
	}
}


static void ___lambda210__gtest_func (void) {
#line 99 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda210_ ();
#line 1155 "GomDocumentTest.c"
}


static void __lambda211_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GXmlGomDocument* d = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlGomDocument* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gboolean fname = FALSE;
		gboolean fshordesc = FALSE;
		gboolean fdescription = FALSE;
		gboolean fhomepage = FALSE;
		gboolean _tmp17_ = FALSE;
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
		gboolean _tmp56_ = FALSE;
		gboolean _tmp57_ = FALSE;
		gboolean _tmp58_ = FALSE;
		gboolean _tmp59_ = FALSE;
		GFile* f = NULL;
		GFile* _tmp60_ = NULL;
		GXmlGomDocument* _tmp61_ = NULL;
		GFile* _tmp62_ = NULL;
		GFile* _tmp63_ = NULL;
		gboolean _tmp64_ = FALSE;
		GFile* _tmp65_ = NULL;
#line 123 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 123 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		rf = _tmp0_;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = rf;
#line 124 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (!_tmp2_) {
#line 125 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			g_message ("GomDocumentTest.vala:125: No remote file available. Skiping...");
#line 126 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			return;
#line 1215 "GomDocumentTest.c"
		}
#line 128 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = rf;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_gom_document_new_from_file (_tmp3_, &_inner_error_);
#line 128 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp4_;
#line 128 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 128 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1227 "GomDocumentTest.c"
			goto __catch215_g_error;
		}
#line 129 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = d;
#line 129 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "d != null");
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = d;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp6_);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp9_ != NULL, "d.document_element != null");
#line 130 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = d;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp10_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp13_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "Project") == 0, "d.document_element.node_name == \"Project\"");
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 131 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		fhomepage = FALSE;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = fhomepage;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		fdescription = _tmp17_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = fdescription;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		fshordesc = _tmp18_;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = fshordesc;
#line 133 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		fname = _tmp19_;
#line 1280 "GomDocumentTest.c"
		{
			GXmlDomNodeList* _n_list = NULL;
			GXmlGomDocument* _tmp20_ = NULL;
			GXmlDomElement* _tmp21_ = NULL;
			GXmlDomElement* _tmp22_ = NULL;
			GXmlDomElement* _tmp23_ = NULL;
			GXmlDomNodeList* _tmp24_ = NULL;
			GXmlDomNodeList* _tmp25_ = NULL;
			GXmlDomNodeList* _tmp26_ = NULL;
			gint _n_size = 0;
			GXmlDomNodeList* _tmp27_ = NULL;
			gint _tmp28_ = 0;
			gint _tmp29_ = 0;
			gint _n_index = 0;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp20_ = d;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp21_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp20_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp22_ = _tmp21_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp23_ = _tmp22_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp25_ = _tmp24_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp26_ = _tmp25_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_n_list = _tmp26_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp27_ = _n_list;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp28_ = gee_collection_get_size ((GeeCollection*) _tmp27_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_tmp29_ = _tmp28_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_n_size = _tmp29_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_n_index = -1;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			while (TRUE) {
#line 1325 "GomDocumentTest.c"
				gint _tmp30_ = 0;
				gint _tmp31_ = 0;
				gint _tmp32_ = 0;
				GXmlDomNode* n = NULL;
				GXmlDomNodeList* _tmp33_ = NULL;
				gint _tmp34_ = 0;
				gpointer _tmp35_ = NULL;
				GXmlDomNode* _tmp36_ = NULL;
				gchar* _tmp37_ = NULL;
				gchar* _tmp38_ = NULL;
				gchar* _tmp39_ = NULL;
				gboolean _tmp40_ = FALSE;
				GXmlDomNode* _tmp41_ = NULL;
				gchar* _tmp42_ = NULL;
				gchar* _tmp43_ = NULL;
				gchar* _tmp44_ = NULL;
				gboolean _tmp45_ = FALSE;
				GXmlDomNode* _tmp46_ = NULL;
				gchar* _tmp47_ = NULL;
				gchar* _tmp48_ = NULL;
				gchar* _tmp49_ = NULL;
				gboolean _tmp50_ = FALSE;
				GXmlDomNode* _tmp51_ = NULL;
				gchar* _tmp52_ = NULL;
				gchar* _tmp53_ = NULL;
				gchar* _tmp54_ = NULL;
				gboolean _tmp55_ = FALSE;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp30_ = _n_index;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_n_index = _tmp30_ + 1;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp31_ = _n_index;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp32_ = _n_size;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				if (!(_tmp31_ < _tmp32_)) {
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
					break;
#line 1365 "GomDocumentTest.c"
				}
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp33_ = _n_list;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp34_ = _n_index;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp35_ = gee_list_get ((GeeList*) _tmp33_, _tmp34_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				n = (GXmlDomNode*) _tmp35_;
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp36_ = n;
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp37_ = gxml_dom_node_get_node_name (_tmp36_);
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp38_ = _tmp37_;
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp39_ = _tmp38_;
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp40_ = g_strcmp0 (_tmp39_, "name") == 0;
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_free0 (_tmp39_);
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				if (_tmp40_) {
#line 135 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
					fname = TRUE;
#line 1391 "GomDocumentTest.c"
				}
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp41_ = n;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp42_ = gxml_dom_node_get_node_name (_tmp41_);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp43_ = _tmp42_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp44_ = _tmp43_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp45_ = g_strcmp0 (_tmp44_, "shortdesc") == 0;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_free0 (_tmp44_);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				if (_tmp45_) {
#line 136 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
					fshordesc = TRUE;
#line 1409 "GomDocumentTest.c"
				}
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp46_ = n;
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp47_ = gxml_dom_node_get_node_name (_tmp46_);
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp48_ = _tmp47_;
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp49_ = _tmp48_;
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp50_ = g_strcmp0 (_tmp49_, "description") == 0;
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_free0 (_tmp49_);
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				if (_tmp50_) {
#line 137 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
					fdescription = TRUE;
#line 1427 "GomDocumentTest.c"
				}
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp51_ = n;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp52_ = gxml_dom_node_get_node_name (_tmp51_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp53_ = _tmp52_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp54_ = _tmp53_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_tmp55_ = g_strcmp0 (_tmp54_, "homepage") == 0;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_free0 (_tmp54_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				if (_tmp55_) {
#line 138 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
					fhomepage = TRUE;
#line 1445 "GomDocumentTest.c"
				}
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
				_g_object_unref0 (n);
#line 1449 "GomDocumentTest.c"
			}
#line 134 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_n_list);
#line 1453 "GomDocumentTest.c"
		}
#line 140 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp56_ = fname;
#line 140 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp56_, "fname");
#line 141 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp57_ = fshordesc;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp57_, "fshordesc");
#line 142 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp58_ = fdescription;
#line 142 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp58_, "fdescription");
#line 143 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp59_ = fhomepage;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp59_, "fhomepage");
#line 144 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp60_ = g_file_new_for_path (TEST_SAVE_DIR "/xml.doap");
#line 144 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		f = _tmp60_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp61_ = d;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp62_ = f;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_write_file (_tmp61_, _tmp62_, &_inner_error_);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 145 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1489 "GomDocumentTest.c"
			goto __catch215_g_error;
		}
#line 146 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp63_ = f;
#line 146 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp64_ = g_file_query_exists (_tmp63_, NULL);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp64_, "f.query_exists ()");
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp65_ = f;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_file_delete (_tmp65_, NULL, &_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1510 "GomDocumentTest.c"
			goto __catch215_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1519 "GomDocumentTest.c"
	}
	goto __finally215;
	__catch215_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 149 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp66_ = e->message;
#line 149 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp67_ = g_strconcat ("Error: ", _tmp66_, NULL);
#line 149 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 149 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:149: %s", _tmp68_);
#line 149 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp68_);
#line 150 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1546 "GomDocumentTest.c"
	}
	__finally215:
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 1557 "GomDocumentTest.c"
	}
}


static void ___lambda211__gtest_func (void) {
#line 121 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda211_ ();
#line 1565 "GomDocumentTest.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1585 "GomDocumentTest.c"
}


static void __lambda212_ (void) {
	GError * _inner_error_ = NULL;
	{
		GFile* rf = NULL;
		GFile* _tmp0_ = NULL;
		GFile* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		GXmlGomDocument* d = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp10_ = NULL;
		GXmlXParser* _tmp11_ = NULL;
		gchar* s = NULL;
		GXmlXParser* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		const gchar* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		const gchar* _tmp16_ = NULL;
		gboolean _tmp17_ = FALSE;
		const gchar* _tmp18_ = NULL;
		gboolean _tmp19_ = FALSE;
		const gchar* _tmp20_ = NULL;
		gboolean _tmp21_ = FALSE;
		const gchar* _tmp22_ = NULL;
		gboolean _tmp23_ = FALSE;
#line 155 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_file_new_for_uri ("https://git.gnome.org/browse/gxml/plain/gxml.doap");
#line 155 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		rf = _tmp0_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = rf;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = g_file_query_exists (_tmp1_, NULL);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (!_tmp2_) {
#line 157 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			g_message ("GomDocumentTest.vala:157: No remote file available. Skiping...");
#line 158 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 158 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			return;
#line 1636 "GomDocumentTest.c"
		}
#line 160 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = rf;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_gom_document_new_from_file (_tmp3_, &_inner_error_);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp4_;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1648 "GomDocumentTest.c"
			goto __catch216_g_error;
		}
#line 161 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = d;
#line 161 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "d != null");
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = d;
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp6_);
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp9_ != NULL, "d.document_element != null");
#line 162 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp9_);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = d;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = gxml_xparser_new ((GXmlDomNode*) _tmp10_);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		parser = _tmp11_;
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = parser;
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_parser_write_string ((GXmlParser*) _tmp12_, &_inner_error_);
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		s = _tmp13_;
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 164 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (rf);
#line 1687 "GomDocumentTest.c"
			goto __catch216_g_error;
		}
#line 168 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = s;
#line 168 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = string_contains (_tmp14_, "<name xml:lang=\"en\">GXml</name>");
#line 168 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp15_, "\"<name xml:lang=\\\"en\\\">GXml</name>\" in s");
#line 169 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = s;
#line 169 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = string_contains (_tmp16_, "<shortdesc xml:lang=\"en\">GObject XML and Serialization API</shortdes" \
"c>");
#line 169 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp17_, "\"<shortdesc xml:lang=\\\"en\\\">GObject XML and Serialization API</shortdesc>\" \t\t\t\t\t\t\t\tin s");
#line 171 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = s;
#line 171 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = string_contains (_tmp18_, "<homepage rdf:resource=\"https://wiki.gnome.org/GXml\"/>");
#line 171 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp19_, "\"<homepage rdf:resource=\\\"https://wiki.gnome.org/GXml\\\"/>\" in s");
#line 172 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = s;
#line 172 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = string_contains (_tmp20_, "<foaf:Person>");
#line 172 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp21_, "\"<foaf:Person>\" in s");
#line 173 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = s;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = string_contains (_tmp22_, "<foaf:name>Daniel Espinosa</foaf:name>");
#line 173 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp23_, "\"<foaf:name>Daniel Espinosa</foaf:name>\" in s");
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (s);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (rf);
#line 1728 "GomDocumentTest.c"
	}
	goto __finally216;
	__catch216_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = e->message;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = g_strconcat ("Error: ", _tmp24_, NULL);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:175: %s", _tmp26_);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp26_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1755 "GomDocumentTest.c"
	}
	__finally216:
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 1766 "GomDocumentTest.c"
	}
}


static void ___lambda212__gtest_func (void) {
#line 153 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda212_ ();
#line 1774 "GomDocumentTest.c"
}


static void __lambda213_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp15_ = NULL;
		GXmlXParser* _tmp16_ = NULL;
		gchar* s = NULL;
		GXmlXParser* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_ = NULL;
		gboolean _tmp23_ = FALSE;
		GXmlGomDocument* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomElement* _tmp27_ = NULL;
#line 181 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 181 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = _tmp0_;
#line 182 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = doc;
#line 182 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_element_ns ((GXmlDomDocument*) _tmp1_, "http://live.gnome.org/GXml", "root", &_inner_error_);
#line 182 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp2_;
#line 182 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 182 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1827 "GomDocumentTest.c"
			goto __catch217_g_error;
		}
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = doc;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = r;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error_);
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 183 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1846 "GomDocumentTest.c"
			goto __catch217_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = r;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_element_get_prefix (_tmp7_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp10_ == NULL, "r.prefix == null");
#line 184 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = r;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_namespace_uri (_tmp11_);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "http://live.gnome.org/GXml") == 0, "r.namespace_uri == \"http://live.gnome.org/GXml\"");
#line 185 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp14_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = doc;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_xparser_new ((GXmlDomNode*) _tmp15_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		parser = _tmp16_;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = parser;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gxml_parser_write_string ((GXmlParser*) _tmp17_, &_inner_error_);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		s = _tmp18_;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1893 "GomDocumentTest.c"
			goto __catch217_g_error;
		}
#line 188 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = s;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = g_strconcat ("DOC: ", _tmp19_, NULL);
#line 188 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_test_message ("%s", _tmp21_);
#line 188 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp21_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = s;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = string_contains (_tmp22_, "<root xmlns=\"http://live.gnome.org/GXml\"/>");
#line 189 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp23_, "\"<root xmlns=\\\"http://live.gnome.org/GXml\\\"/>\" in s");
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = doc;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp24_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp27_, "http://www.w3.org/2000/xmlns/", "xmlns", "http://live.gnome.org/GXml", &_inner_error_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (s);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 190 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 1934 "GomDocumentTest.c"
			goto __catch217_g_error;
		}
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (s);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 1945 "GomDocumentTest.c"
	}
	goto __finally217;
	__catch217_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = e->message;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = g_strconcat ("Error: ", _tmp28_, NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:194: %s", _tmp30_);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 1972 "GomDocumentTest.c"
	}
	__finally217:
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 180 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 1983 "GomDocumentTest.c"
	}
}


static void ___lambda213__gtest_func (void) {
#line 179 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda213_ ();
#line 1991 "GomDocumentTest.c"
}


static void __lambda214_ (void) {
	GFile* fin = NULL;
	GFileIOStream* iostream = NULL;
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GFile* _tmp0_ = NULL;
		GFileIOStream* _tmp1_ = NULL;
		GFile* _tmp2_ = NULL;
		GFile* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GFileIOStream* _tmp5_ = NULL;
		GInputStream* _tmp6_ = NULL;
		GInputStream* _tmp7_ = NULL;
		GXmlGomDocument* _tmp8_ = NULL;
		GXmlGomDocument* _tmp9_ = NULL;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = g_file_new_tmp ("gxml.XXXXXX", &_tmp1_, &_inner_error_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		iostream = _tmp1_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp2_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2021 "GomDocumentTest.c"
			goto __catch218_g_error;
		}
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp0_;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		fin = _tmp3_;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = iostream;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = g_io_stream_get_input_stream ((GIOStream*) _tmp5_);
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_gom_document_new_from_stream (_tmp7_, &_inner_error_);
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp8_;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2046 "GomDocumentTest.c"
			goto __catch218_g_error;
		}
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp4_;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = NULL;
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 205 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp9_;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:206: Passed parse error stream");
#line 207 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2065 "GomDocumentTest.c"
	}
	goto __finally218;
	__catch218_g_error:
	{
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 2074 "GomDocumentTest.c"
	}
	__finally218:
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (iostream);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (fin);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2091 "GomDocumentTest.c"
	}
#line 198 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 198 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (iostream);
#line 198 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (fin);
#line 2099 "GomDocumentTest.c"
}


static void ___lambda214__gtest_func (void) {
#line 198 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda214_ ();
#line 2106 "GomDocumentTest.c"
}


static void __lambda215_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		GXmlDomNode* document_element = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		gint _tmp15_ = 0;
		gint _tmp16_ = 0;
		GXmlDomNode* n1 = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		gpointer _tmp20_ = NULL;
		GXmlDomNode* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 216 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		xml = _tmp0_;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error_);
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (document_element);
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (xml);
#line 2160 "GomDocumentTest.c"
			goto __catch219_g_error;
		}
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 217 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (doc);
#line 218 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp6_ != NULL, "doc.document_element != null");
#line 218 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_document_get_document_element (doc);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		document_element = (GXmlDomNode*) _tmp8_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = gxml_dom_node_get_node_name (document_element);
#line 220 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "Fruits") == 0, "document_element.node_name == \"Fruits\"");
#line 220 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes (document_element);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = gee_collection_get_size ((GeeCollection*) _tmp14_);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp16_ == 2, "document_element.child_nodes.size == 2");
#line 221 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp14_);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = gxml_dom_node_get_child_nodes (document_element);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = gee_list_get ((GeeList*) _tmp19_, 0);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = (GXmlDomNode*) _tmp20_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp19_);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n1 = _tmp21_;
#line 223 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 224 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name (n1);
#line 224 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 224 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 224 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "Apple") == 0, "n1.node_name == \"Apple\"");
#line 224 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 2249 "GomDocumentTest.c"
	}
	goto __finally219;
	__catch219_g_error:
	{
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 225 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 2260 "GomDocumentTest.c"
	}
	__finally219:
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2271 "GomDocumentTest.c"
	}
}


static void ___lambda215__gtest_func (void) {
#line 210 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda215_ ();
#line 2279 "GomDocumentTest.c"
}


static void __lambda216_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlGomDocument* doc = NULL;
		GXmlDomNode* document_element = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GXmlDomNodeList* _tmp10_ = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GXmlDomNode* n1 = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		gpointer _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<Fruits><Apple></Apple><Orange></Orange></Fruits>");
#line 233 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		xml = _tmp0_;
#line 234 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new ();
#line 234 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 234 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = _tmp1_;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_read_from_string (doc, xml, &_inner_error_);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 235 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (document_element);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (xml);
#line 2335 "GomDocumentTest.c"
			goto __catch220_g_error;
		}
#line 236 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 236 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 236 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 237 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 237 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 237 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		document_element = (GXmlDomNode*) _tmp6_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_get_node_name (document_element);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "Fruits") == 0, "document_element.node_name == \"Fruits\"");
#line 238 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes (document_element);
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gee_collection_get_size ((GeeCollection*) _tmp12_);
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp14_ == 2, "document_element.child_nodes.size == 2");
#line 239 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes (document_element);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gee_list_get ((GeeList*) _tmp17_, 0);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = (GXmlDomNode*) _tmp18_;
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 240 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n1 = _tmp19_;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (n1 != NULL, "n1 != null");
#line 242 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = gxml_dom_node_get_node_name (n1);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 242 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 242 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "Apple") == 0, "n1.node_name == \"Apple\"");
#line 242 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp22_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (document_element);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 2414 "GomDocumentTest.c"
	}
	goto __finally220;
	__catch220_g_error:
	{
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 243 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 2425 "GomDocumentTest.c"
	}
	__finally220:
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 228 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2436 "GomDocumentTest.c"
	}
}


static void ___lambda216__gtest_func (void) {
#line 227 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda216_ ();
#line 2444 "GomDocumentTest.c"
}


static void __lambda217_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>");
#line 250 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 250 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		xml = _tmp0_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error_);
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (xml);
#line 2473 "GomDocumentTest.c"
			goto __catch221_g_error;
		}
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 251 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 2492 "GomDocumentTest.c"
	}
	goto __finally221;
	__catch221_g_error:
	{
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 2501 "GomDocumentTest.c"
	}
	__finally221:
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2512 "GomDocumentTest.c"
	}
}


static void ___lambda217__gtest_func (void) {
#line 245 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda217_ ();
#line 2520 "GomDocumentTest.c"
}


static void __lambda218_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* xml = NULL;
		GXmlDomDocument* doc = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = g_strdup ("");
#line 260 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		xml = _tmp0_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_new_from_string (xml, &_inner_error_);
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp2_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (xml);
#line 2549 "GomDocumentTest.c"
			goto __catch222_g_error;
		}
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp1_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = NULL;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 261 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp3_;
#line 262 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (xml);
#line 2568 "GomDocumentTest.c"
	}
	goto __finally222;
	__catch222_g_error:
	{
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 2577 "GomDocumentTest.c"
	}
	__finally222:
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 256 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2588 "GomDocumentTest.c"
	}
}


static void ___lambda218__gtest_func (void) {
#line 255 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda218_ ();
#line 2596 "GomDocumentTest.c"
}


static void __lambda219_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GFile* f = NULL;
		GFile* _tmp3_ = NULL;
		GXmlDomDocument* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
		GFile* _tmp6_ = NULL;
		gboolean _tmp7_ = FALSE;
		GFile* _tmp8_ = NULL;
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2620 "GomDocumentTest.c"
			goto __catch223_g_error;
		}
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 269 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 270 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = g_file_new_for_path (TEST_SAVE_DIR "/test_out_path.xml");
#line 270 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		f = _tmp3_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = doc;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = f;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_write_file (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp4_) : NULL, _tmp5_, &_inner_error_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2647 "GomDocumentTest.c"
			goto __catch223_g_error;
		}
#line 272 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = f;
#line 272 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = g_file_query_exists (_tmp6_, NULL);
#line 272 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp7_, "f.query_exists ()");
#line 273 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = f;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_file_delete (_tmp8_, NULL, &_inner_error_);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 273 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (f);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2666 "GomDocumentTest.c"
			goto __catch223_g_error;
		}
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (f);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2673 "GomDocumentTest.c"
	}
	goto __finally223;
	__catch223_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp9_ = NULL;
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = e->message;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:275: %s", _tmp9_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 2692 "GomDocumentTest.c"
	}
	__finally223:
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 268 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2705 "GomDocumentTest.c"
	}
#line 265 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 2709 "GomDocumentTest.c"
}


static void ___lambda219__gtest_func (void) {
#line 265 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda219_ ();
#line 2716 "GomDocumentTest.c"
}


static void __lambda220_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GFile* _tmp4_ = NULL;
		GFile* _tmp5_ = NULL;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2736 "GomDocumentTest.c"
			goto __catch224_g_error;
		}
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = doc;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = g_file_new_for_path ("/tmp/a/b/c/d/e/f/g/h/i");
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_gom_document_write_file (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp3_) : NULL, _tmp5_, &_inner_error_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp5_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 284 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 2761 "GomDocumentTest.c"
			goto __catch224_g_error;
		}
#line 285 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 2768 "GomDocumentTest.c"
	}
	goto __finally224;
	__catch224_g_error:
	{
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 2777 "GomDocumentTest.c"
	}
	__finally224:
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2790 "GomDocumentTest.c"
	}
#line 279 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 2794 "GomDocumentTest.c"
}


static void ___lambda220__gtest_func (void) {
#line 279 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda220_ ();
#line 2801 "GomDocumentTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 2808 "GomDocumentTest.c"
}


static void __lambda221_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* elem = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomDocument* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2842 "GomDocumentTest.c"
			goto __catch225_g_error;
		}
#line 292 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		elem = NULL;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = doc;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_element (_tmp2_, "Banana", &_inner_error_);
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (elem);
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2859 "GomDocumentTest.c"
			goto __catch225_g_error;
		}
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 293 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		elem = _tmp4_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = elem;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_DOM_ELEMENT), "elem is DomElement");
#line 295 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = elem;
#line 295 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_GOM_ELEMENT), "elem is GomElement");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = elem;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_element_get_tag_name (_tmp7_);
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Banana") == 0, "elem.tag_name == \"Banana\"");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = elem;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_element_get_tag_name (_tmp11_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "banana") != 0, "elem.tag_name != \"banana\"");
#line 297 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp14_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = doc;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = gxml_dom_document_create_element (_tmp16_, "ØÏØÏØ¯ÏØÏ  ²øœ³¤ïØ£", &_inner_error_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp17_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (elem);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 2914 "GomDocumentTest.c"
			goto __catch225_g_error;
		}
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		elem = _tmp18_;
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (elem);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 2931 "GomDocumentTest.c"
	}
	goto __finally225;
	__catch225_g_error:
	{
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 300 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 2942 "GomDocumentTest.c"
	}
	__finally225:
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 290 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 2953 "GomDocumentTest.c"
	}
}


static void ___lambda221__gtest_func (void) {
#line 289 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda221_ ();
#line 2961 "GomDocumentTest.c"
}


static void __lambda222_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomText* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomText* _tmp3_ = NULL;
		GXmlDomText* text = NULL;
		GXmlDomText* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 304 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 304 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2987 "GomDocumentTest.c"
			goto __catch226_g_error;
		}
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = doc;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_text_node (_tmp2_, "Star of my dreams", &_inner_error_);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3000 "GomDocumentTest.c"
			goto __catch226_g_error;
		}
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_TEXT, GXmlDomText));
#line 305 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		text = _tmp4_;
#line 306 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (text, GXML_TYPE_GOM_TEXT), "text is GomText");
#line 307 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (text, GXML_TYPE_DOM_TEXT), "text is DomText");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) text);
#line 309 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "#text") == 0, "text.node_name == \"#text\"");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_value ((GXmlDomNode*) text);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Star of my dreams") == 0, "text.node_value == \"Star of my dreams\"");
#line 310 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (text);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3037 "GomDocumentTest.c"
	}
	goto __finally226;
	__catch226_g_error:
	{
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 311 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3048 "GomDocumentTest.c"
	}
	__finally226:
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3059 "GomDocumentTest.c"
	}
}


static void ___lambda222__gtest_func (void) {
#line 302 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda222_ ();
#line 3067 "GomDocumentTest.c"
}


static void __lambda223_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3106 "GomDocumentTest.c"
			goto __catch227_g_error;
		}
#line 316 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element (doc);
#line 316 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 316 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp2_;
#line 317 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (r != NULL, "r != null");
#line 318 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_dom_node_get_text_content ((GXmlDomNode*) r);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp5_ == NULL, "r.text_content == null");
#line 318 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp5_);
#line 319 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_node_set_text_content ((GXmlDomNode*) r, "Starting");
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = gxml_dom_node_list_get_length (_tmp8_);
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp10_ == 1, "r.child_nodes.length == 1");
#line 320 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = gxml_dom_node_list_item (_tmp13_, 0);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_TEXT), "r.child_nodes.item (0) is DomText");
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) r);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_list_item (_tmp18_, 0);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_node_value (_tmp20_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp23_, "Starting") == 0, "r.child_nodes.item (0).node_value == \"Starting\"");
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp23_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp18_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3187 "GomDocumentTest.c"
	}
	goto __finally227;
	__catch227_g_error:
	{
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3198 "GomDocumentTest.c"
	}
	__finally227:
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3209 "GomDocumentTest.c"
	}
}


static void ___lambda223__gtest_func (void) {
#line 313 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda223_ ();
#line 3217 "GomDocumentTest.c"
}


static void __lambda224_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomComment* _tmp1_ = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		GXmlDomComment* _tmp3_ = NULL;
		GXmlDomComment* comment = NULL;
		GXmlDomComment* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 327 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 327 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3243 "GomDocumentTest.c"
			goto __catch228_g_error;
		}
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = doc;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_comment (_tmp2_, "Ever since the day we promised.", &_inner_error_);
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3256 "GomDocumentTest.c"
			goto __catch228_g_error;
		}
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_COMMENT, GXmlDomComment));
#line 328 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		comment = _tmp4_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) comment);
#line 330 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "#comment") == 0, "comment.node_name == \"#comment\"");
#line 330 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp7_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) comment);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Ever since the day we promised.") == 0, "comment.data == \"Ever since the day we promised.\"");
#line 331 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (comment);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3289 "GomDocumentTest.c"
	}
	goto __finally228;
	__catch228_g_error:
	{
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3300 "GomDocumentTest.c"
	}
	__finally228:
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3311 "GomDocumentTest.c"
	}
}


static void ___lambda224__gtest_func (void) {
#line 325 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda224_ ();
#line 3319 "GomDocumentTest.c"
}


static void __lambda225_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomProcessingInstruction* instruction = NULL;
		GXmlDomDocument* _tmp1_ = NULL;
		GXmlDomProcessingInstruction* _tmp2_ = NULL;
		GXmlDomProcessingInstruction* _tmp3_ = NULL;
		GXmlDomProcessingInstruction* _tmp4_ = NULL;
		GXmlDomProcessingInstruction* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GXmlDomProcessingInstruction* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		GXmlDomProcessingInstruction* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GXmlDomProcessingInstruction* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		GXmlDomProcessingInstruction* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 336 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3359 "GomDocumentTest.c"
			goto __catch229_g_error;
		}
#line 337 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = doc;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_processing_instruction (_tmp1_, "target", "data", &_inner_error_);
#line 337 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		instruction = _tmp2_;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 337 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3372 "GomDocumentTest.c"
			goto __catch229_g_error;
		}
#line 338 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = instruction;
#line 338 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_PROCESSING_INSTRUCTION), "instruction is GomProcessingInstruction");
#line 339 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = instruction;
#line 339 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION), "instruction is DomProcessingInstruction");
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = instruction;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp5_);
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "target") == 0, "instruction.node_name == \"target\"");
#line 340 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp8_);
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = instruction;
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp9_);
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp12_, "data") == 0, "instruction.node_value == \"data\"");
#line 341 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp12_);
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = instruction;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = gxml_dom_character_data_get_data ((GXmlDomCharacterData*) _tmp13_);
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "data") == 0, "instruction.data == \"data\"");
#line 346 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp16_);
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = instruction;
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gxml_dom_processing_instruction_get_target (_tmp17_);
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp20_ != NULL, "instruction.target != null");
#line 347 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp20_);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = instruction;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_processing_instruction_get_target (_tmp21_);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "target") == 0, "instruction.target == \"target\"");
#line 348 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (instruction);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3447 "GomDocumentTest.c"
	}
	goto __finally229;
	__catch229_g_error:
	{
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3458 "GomDocumentTest.c"
	}
	__finally229:
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3469 "GomDocumentTest.c"
	}
}


static void ___lambda225__gtest_func (void) {
#line 334 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda225_ ();
#line 3477 "GomDocumentTest.c"
}


static void __lambda226_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomDocument* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomDocument* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNamedNodeMap* _tmp13_ = NULL;
		GXmlDomNamedNodeMap* _tmp14_ = NULL;
		GXmlDomNamedNodeMap* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		gchar* attr = NULL;
		GXmlDomDocument* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element />", &_inner_error_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3516 "GomDocumentTest.c"
			goto __catch230_g_error;
		}
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = doc;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element (_tmp1_);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 354 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = doc;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element (_tmp5_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp8_, "attrname", "attrvalue", &_inner_error_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 355 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3547 "GomDocumentTest.c"
			goto __catch230_g_error;
		}
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = doc;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element (_tmp9_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_element_get_attributes (_tmp12_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gee_map_get_size ((GeeMap*) _tmp15_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 1, "doc.document_element.attributes.size == 1");
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = doc;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_document_get_document_element (_tmp18_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_element_get_attribute (_tmp21_, "attrname");
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		attr = _tmp23_;
#line 361 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (attr != NULL, "attr != null");
#line 362 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (attr, "attrvalue") == 0, "attr == \"attrvalue\"");
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (attr);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3598 "GomDocumentTest.c"
	}
	goto __finally230;
	__catch230_g_error:
	{
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 365 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3609 "GomDocumentTest.c"
	}
	__finally230:
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3620 "GomDocumentTest.c"
	}
}


static void ___lambda226__gtest_func (void) {
#line 351 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda226_ ();
#line 3628 "GomDocumentTest.c"
}


static void __lambda227_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlDomDocument* _tmp1_ = NULL;
		GXmlXParser* _tmp2_ = NULL;
		gchar* s1 = NULL;
		GXmlXParser* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar** cs1 = NULL;
		const gchar* _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		gchar** _tmp8_ = NULL;
		gint cs1_length1 = 0;
		gint _cs1_size_ = 0;
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_ = NULL;
#line 369 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>", &_inner_error_);
#line 369 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 369 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3658 "GomDocumentTest.c"
			goto __catch231_g_error;
		}
#line 372 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = doc;
#line 372 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_xparser_new ((GXmlDomNode*) _tmp1_);
#line 372 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		parser = _tmp2_;
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = parser;
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_parser_write_string ((GXmlParser*) _tmp3_, &_inner_error_);
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		s1 = _tmp4_;
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (parser);
#line 373 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 3679 "GomDocumentTest.c"
			goto __catch231_g_error;
		}
#line 374 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = s1;
#line 374 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp5_ != NULL, "s1 != null");
#line 378 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = s1;
#line 378 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "\n", 0);
#line 378 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		cs1 = _tmp8_;
#line 378 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		cs1_length1 = _vala_array_length (_tmp7_);
#line 378 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_cs1_size_ = cs1_length1;
#line 382 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = cs1[0];
#line 382 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "<?xml version=\"1.0\"?>") == 0, "cs1[0] == \"<?xml version=\\\"1.0\\\"?>\"");
#line 383 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = cs1[1];
#line 383 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "<Sentences><Sentence lang=\"en\">I like the colour blue.</Sentence><Se" \
"ntence lang=\"de\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author>" \
"<Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Autho" \
"r><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></" \
"Authors></Sentences>") == 0, "cs1[1] == \"<Sentences><Sentence lang=\\\"en\\\">I like the colour blue.</Sentence><Sentence lang=\\\"de\\\">Ich liebe die T&#xFC;r.</Sentence><Authors><Author><Name>Fred</Name><Email>fweasley@hogwarts.co.uk</Email></Author><Author><Name>George</Name><Email>gweasley@hogwarts.co.uk</Email></Author></Authors></Sentences>\"");
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		cs1 = (_vala_array_free (cs1, cs1_length1, (GDestroyNotify) g_free), NULL);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (s1);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (parser);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 3712 "GomDocumentTest.c"
	}
	goto __finally231;
	__catch231_g_error:
	{
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 384 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 3723 "GomDocumentTest.c"
	}
	__finally231:
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 368 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 3734 "GomDocumentTest.c"
	}
}


static void ___lambda227__gtest_func (void) {
#line 367 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda227_ ();
#line 3742 "GomDocumentTest.c"
}


static void __lambda228_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		gpointer _tmp16_ = NULL;
		GXmlDomNode* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomElement* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		GXmlDomNodeList* _tmp22_ = NULL;
		GXmlDomNodeList* _tmp23_ = NULL;
		gpointer _tmp24_ = NULL;
		GXmlDomNode* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomElement* _tmp27_ = NULL;
		GXmlDomElement* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		GXmlDomNodeList* _tmp30_ = NULL;
		GXmlDomNodeList* _tmp31_ = NULL;
		gpointer _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		gpointer _tmp40_ = NULL;
		GXmlDomNode* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		GXmlDomElement* _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GXmlDomNodeList* _tmp48_ = NULL;
		GXmlDomNodeList* _tmp49_ = NULL;
		GXmlDomNodeList* _tmp50_ = NULL;
		gint _tmp51_ = 0;
		gint _tmp52_ = 0;
		GXmlDomElement* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomNodeList* _tmp56_ = NULL;
		GXmlDomNodeList* _tmp57_ = NULL;
		GXmlDomNodeList* _tmp58_ = NULL;
		gpointer _tmp59_ = NULL;
		GXmlDomNode* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		GXmlDomElement* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GXmlDomNodeList* _tmp67_ = NULL;
		GXmlDomNodeList* _tmp68_ = NULL;
		GXmlDomNodeList* _tmp69_ = NULL;
		gpointer _tmp70_ = NULL;
		GXmlDomNode* _tmp71_ = NULL;
		GXmlDomNodeList* _tmp72_ = NULL;
		GXmlDomNodeList* _tmp73_ = NULL;
		GXmlDomNodeList* _tmp74_ = NULL;
		gint _tmp75_ = 0;
		gint _tmp76_ = 0;
		GXmlDomElement* _tmp77_ = NULL;
		GXmlDomElement* _tmp78_ = NULL;
		GXmlDomElement* _tmp79_ = NULL;
		GXmlDomNodeList* _tmp80_ = NULL;
		GXmlDomNodeList* _tmp81_ = NULL;
		GXmlDomNodeList* _tmp82_ = NULL;
		gpointer _tmp83_ = NULL;
		GXmlDomNode* _tmp84_ = NULL;
		GXmlDomNodeList* _tmp85_ = NULL;
		GXmlDomNodeList* _tmp86_ = NULL;
		GXmlDomNodeList* _tmp87_ = NULL;
		gpointer _tmp88_ = NULL;
		GXmlDomNode* _tmp89_ = NULL;
		gchar* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		GXmlDomElement* _tmp93_ = NULL;
		GXmlDomElement* _tmp94_ = NULL;
		GXmlDomElement* _tmp95_ = NULL;
		GXmlDomNodeList* _tmp96_ = NULL;
		GXmlDomNodeList* _tmp97_ = NULL;
		GXmlDomNodeList* _tmp98_ = NULL;
		gpointer _tmp99_ = NULL;
		GXmlDomNode* _tmp100_ = NULL;
		GXmlDomNodeList* _tmp101_ = NULL;
		GXmlDomNodeList* _tmp102_ = NULL;
		GXmlDomNodeList* _tmp103_ = NULL;
		gpointer _tmp104_ = NULL;
		GXmlDomNode* _tmp105_ = NULL;
		GXmlDomNodeList* _tmp106_ = NULL;
		GXmlDomNodeList* _tmp107_ = NULL;
		GXmlDomNodeList* _tmp108_ = NULL;
		gint _tmp109_ = 0;
		gint _tmp110_ = 0;
		GXmlDomElement* _tmp111_ = NULL;
		GXmlDomElement* _tmp112_ = NULL;
		GXmlDomElement* _tmp113_ = NULL;
		GXmlDomNodeList* _tmp114_ = NULL;
		GXmlDomNodeList* _tmp115_ = NULL;
		GXmlDomNodeList* _tmp116_ = NULL;
		gpointer _tmp117_ = NULL;
		GXmlDomNode* _tmp118_ = NULL;
		GXmlDomNodeList* _tmp119_ = NULL;
		GXmlDomNodeList* _tmp120_ = NULL;
		GXmlDomNodeList* _tmp121_ = NULL;
		gpointer _tmp122_ = NULL;
		GXmlDomNode* _tmp123_ = NULL;
		GXmlDomNodeList* _tmp124_ = NULL;
		GXmlDomNodeList* _tmp125_ = NULL;
		GXmlDomNodeList* _tmp126_ = NULL;
		gpointer _tmp127_ = NULL;
		GXmlDomNode* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
		GXmlDomElement* _tmp132_ = NULL;
		GXmlDomElement* _tmp133_ = NULL;
		GXmlDomElement* _tmp134_ = NULL;
		GXmlDomNodeList* _tmp135_ = NULL;
		GXmlDomNodeList* _tmp136_ = NULL;
		GXmlDomNodeList* _tmp137_ = NULL;
		gpointer _tmp138_ = NULL;
		GXmlDomNode* _tmp139_ = NULL;
		GXmlDomNodeList* _tmp140_ = NULL;
		GXmlDomNodeList* _tmp141_ = NULL;
		GXmlDomNodeList* _tmp142_ = NULL;
		gpointer _tmp143_ = NULL;
		GXmlDomNode* _tmp144_ = NULL;
		GXmlDomNodeList* _tmp145_ = NULL;
		GXmlDomNodeList* _tmp146_ = NULL;
		GXmlDomNodeList* _tmp147_ = NULL;
		gpointer _tmp148_ = NULL;
		GXmlDomNode* _tmp149_ = NULL;
		GXmlDomNodeList* _tmp150_ = NULL;
		GXmlDomNodeList* _tmp151_ = NULL;
		GXmlDomNodeList* _tmp152_ = NULL;
		gint _tmp153_ = 0;
		gint _tmp154_ = 0;
		GXmlDomElement* _tmp155_ = NULL;
		GXmlDomElement* _tmp156_ = NULL;
		GXmlDomElement* _tmp157_ = NULL;
		GXmlDomNodeList* _tmp158_ = NULL;
		GXmlDomNodeList* _tmp159_ = NULL;
		GXmlDomNodeList* _tmp160_ = NULL;
		gpointer _tmp161_ = NULL;
		GXmlDomNode* _tmp162_ = NULL;
		GXmlDomNodeList* _tmp163_ = NULL;
		GXmlDomNodeList* _tmp164_ = NULL;
		GXmlDomNodeList* _tmp165_ = NULL;
		gpointer _tmp166_ = NULL;
		GXmlDomNode* _tmp167_ = NULL;
		GXmlDomNodeList* _tmp168_ = NULL;
		GXmlDomNodeList* _tmp169_ = NULL;
		GXmlDomNodeList* _tmp170_ = NULL;
		gpointer _tmp171_ = NULL;
		GXmlDomNode* _tmp172_ = NULL;
		GXmlDomNodeList* _tmp173_ = NULL;
		GXmlDomNodeList* _tmp174_ = NULL;
		GXmlDomNodeList* _tmp175_ = NULL;
		gpointer _tmp176_ = NULL;
		GXmlDomNode* _tmp177_ = NULL;
		GXmlDomElement* _tmp178_ = NULL;
		GXmlDomElement* _tmp179_ = NULL;
		GXmlDomElement* _tmp180_ = NULL;
		GXmlDomNodeList* _tmp181_ = NULL;
		GXmlDomNodeList* _tmp182_ = NULL;
		GXmlDomNodeList* _tmp183_ = NULL;
		gpointer _tmp184_ = NULL;
		GXmlDomNode* _tmp185_ = NULL;
		GXmlDomNodeList* _tmp186_ = NULL;
		GXmlDomNodeList* _tmp187_ = NULL;
		GXmlDomNodeList* _tmp188_ = NULL;
		gpointer _tmp189_ = NULL;
		GXmlDomNode* _tmp190_ = NULL;
		GXmlDomNodeList* _tmp191_ = NULL;
		GXmlDomNodeList* _tmp192_ = NULL;
		GXmlDomNodeList* _tmp193_ = NULL;
		gpointer _tmp194_ = NULL;
		GXmlDomNode* _tmp195_ = NULL;
		GXmlDomNodeList* _tmp196_ = NULL;
		GXmlDomNodeList* _tmp197_ = NULL;
		GXmlDomNodeList* _tmp198_ = NULL;
		gpointer _tmp199_ = NULL;
		GXmlDomNode* _tmp200_ = NULL;
		gchar* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
		gchar* _tmp203_ = NULL;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_path (TEST_DIR "/gdocument-read.xml", &_inner_error_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 3960 "GomDocumentTest.c"
			goto __catch232_g_error;
		}
#line 393 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 393 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 393 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 393 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp3_ != NULL, "d.document_element != null");
#line 393 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp6_);
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp9_, "DataTypeTemplates") == 0, "d.document_element.node_name == \"DataTypeTemplates\"");
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 394 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = _tmp11_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gee_list_get ((GeeList*) _tmp15_, 0);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = (GXmlDomNode*) _tmp16_;
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[0] is GXml.DomText");
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 398 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp12_);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp20_);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = gee_list_get ((GeeList*) _tmp23_, 1);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = (GXmlDomNode*) _tmp24_;
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT), "d.document_element.child_nodes[1] is GXml.DomElement");
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp25_);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 399 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp28_);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = gee_list_get ((GeeList*) _tmp31_, 2);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = (GXmlDomNode*) _tmp32_;
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp33_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[2] is GXml.DomText");
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp33_);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp31_);
#line 400 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = gee_list_get ((GeeList*) _tmp39_, 2);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = (GXmlDomNode*) _tmp40_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = gxml_dom_node_get_node_value (_tmp41_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp44_ = _tmp43_;
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "\n") == 0, "d.document_element.child_nodes[2].node_value == \"\\n\"");
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp44_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp41_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 401 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp45_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp47_ = _tmp46_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp48_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp47_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp51_ = gee_collection_get_size ((GeeCollection*) _tmp50_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp52_ == 3, "d.document_element.child_nodes.size == 3");
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp47_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp53_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp54_ = _tmp53_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp56_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp55_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp57_ = _tmp56_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp59_ = gee_list_get ((GeeList*) _tmp58_, 1);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp60_ = (GXmlDomNode*) _tmp59_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp61_ = gxml_dom_node_get_node_name (_tmp60_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp63_, "DAType") == 0, "d.document_element.child_nodes[1].node_name == \"DAType\"");
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp63_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp60_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp58_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp55_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp64_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp67_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp66_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp69_ = _tmp68_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp70_ = gee_list_get ((GeeList*) _tmp69_, 1);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp71_ = (GXmlDomNode*) _tmp70_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp72_ = gxml_dom_node_get_child_nodes (_tmp71_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp73_ = _tmp72_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp75_ = gee_collection_get_size ((GeeCollection*) _tmp74_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp76_ == 3, "d.document_element.child_nodes[1].child_nodes.size == 3");
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp74_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp71_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp69_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp77_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp80_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp79_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp82_ = _tmp81_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp83_ = gee_list_get ((GeeList*) _tmp82_, 1);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp84_ = (GXmlDomNode*) _tmp83_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp85_ = gxml_dom_node_get_child_nodes (_tmp84_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp88_ = gee_list_get ((GeeList*) _tmp87_, 1);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp89_ = (GXmlDomNode*) _tmp88_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp90_ = gxml_dom_node_get_node_name (_tmp89_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp91_ = _tmp90_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp92_ = _tmp91_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp92_, "BDA") == 0, "d.document_element.child_nodes[1].child_nodes[1].node_name == \"BDA\"");
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp92_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp89_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp87_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp84_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp82_);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp79_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp93_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp94_ = _tmp93_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp95_ = _tmp94_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp96_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp95_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp97_ = _tmp96_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp99_ = gee_list_get ((GeeList*) _tmp98_, 1);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp100_ = (GXmlDomNode*) _tmp99_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp101_ = gxml_dom_node_get_child_nodes (_tmp100_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp102_ = _tmp101_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp104_ = gee_list_get ((GeeList*) _tmp103_, 1);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp105_ = (GXmlDomNode*) _tmp104_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp106_ = gxml_dom_node_get_child_nodes (_tmp105_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp109_ = gee_collection_get_size ((GeeCollection*) _tmp108_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp110_ == 3, "d.document_element.child_nodes[1].child_nodes[1].child_nodes.size == 3");
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp105_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp103_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp100_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp98_);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp95_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp111_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp112_ = _tmp111_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp113_ = _tmp112_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp114_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp113_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp115_ = _tmp114_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp116_ = _tmp115_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp117_ = gee_list_get ((GeeList*) _tmp116_, 1);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp118_ = (GXmlDomNode*) _tmp117_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp119_ = gxml_dom_node_get_child_nodes (_tmp118_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp121_ = _tmp120_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp122_ = gee_list_get ((GeeList*) _tmp121_, 1);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp123_ = (GXmlDomNode*) _tmp122_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp124_ = gxml_dom_node_get_child_nodes (_tmp123_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp126_ = _tmp125_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp127_ = gee_list_get ((GeeList*) _tmp126_, 1);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp128_ = (GXmlDomNode*) _tmp127_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp129_ = gxml_dom_node_get_node_name (_tmp128_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp130_ = _tmp129_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "Val") == 0, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].node_name == \"Val\"");
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp131_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp128_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp126_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp123_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp121_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp116_);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp113_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp132_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp134_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp138_ = gee_list_get ((GeeList*) _tmp137_, 1);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp139_ = (GXmlDomNode*) _tmp138_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp140_ = gxml_dom_node_get_child_nodes (_tmp139_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp141_ = _tmp140_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp143_ = gee_list_get ((GeeList*) _tmp142_, 1);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp144_ = (GXmlDomNode*) _tmp143_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp145_ = gxml_dom_node_get_child_nodes (_tmp144_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp147_ = _tmp146_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp148_ = gee_list_get ((GeeList*) _tmp147_, 1);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp149_ = (GXmlDomNode*) _tmp148_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp150_ = gxml_dom_node_get_child_nodes (_tmp149_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp151_ = _tmp150_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp152_ = _tmp151_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp153_ = gee_collection_get_size ((GeeCollection*) _tmp152_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp154_ == 1, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes.size == 1");
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp152_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp149_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp147_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp144_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp142_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp139_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp134_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp155_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp156_ = _tmp155_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp158_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp157_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp159_ = _tmp158_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp161_ = gee_list_get ((GeeList*) _tmp160_, 1);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp162_ = (GXmlDomNode*) _tmp161_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp163_ = gxml_dom_node_get_child_nodes (_tmp162_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp164_ = _tmp163_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp165_ = _tmp164_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp166_ = gee_list_get ((GeeList*) _tmp165_, 1);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp167_ = (GXmlDomNode*) _tmp166_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp168_ = gxml_dom_node_get_child_nodes (_tmp167_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp169_ = _tmp168_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp170_ = _tmp169_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp171_ = gee_list_get ((GeeList*) _tmp170_, 1);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp172_ = (GXmlDomNode*) _tmp171_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp173_ = gxml_dom_node_get_child_nodes (_tmp172_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp174_ = _tmp173_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp175_ = _tmp174_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp176_ = gee_list_get ((GeeList*) _tmp175_, 0);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp177_ = (GXmlDomNode*) _tmp176_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp177_, GXML_TYPE_DOM_TEXT), "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes[0] is GXml.DomText");
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp177_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp175_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp172_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp170_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp167_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp165_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp162_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp160_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp157_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp178_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp179_ = _tmp178_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp180_ = _tmp179_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp181_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp180_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp182_ = _tmp181_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp183_ = _tmp182_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp184_ = gee_list_get ((GeeList*) _tmp183_, 1);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp185_ = (GXmlDomNode*) _tmp184_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes (_tmp185_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp187_ = _tmp186_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp188_ = _tmp187_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 1);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp191_ = gxml_dom_node_get_child_nodes (_tmp190_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp192_ = _tmp191_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp193_ = _tmp192_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp194_ = gee_list_get ((GeeList*) _tmp193_, 1);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp195_ = (GXmlDomNode*) _tmp194_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp196_ = gxml_dom_node_get_child_nodes (_tmp195_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp197_ = _tmp196_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp198_ = _tmp197_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp199_ = gee_list_get ((GeeList*) _tmp198_, 0);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp200_ = (GXmlDomNode*) _tmp199_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp201_ = gxml_dom_node_get_node_value (_tmp200_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp202_ = _tmp201_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp203_ = _tmp202_;
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp203_, "status_only") == 0, "d.document_element.child_nodes[1].child_nodes[1].child_nodes[1].child_nodes[0].node_value == \"status_only\"");
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp203_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp200_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp198_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp195_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp193_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp190_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp188_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp185_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp183_);
#line 410 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp180_);
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 4547 "GomDocumentTest.c"
	}
	goto __finally232;
	__catch232_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp204_ = NULL;
		gchar* _tmp205_ = NULL;
		gchar* _tmp206_ = NULL;
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp204_ = e->message;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp205_ = g_strconcat ("ERROR: ", _tmp204_, NULL);
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp206_ = _tmp205_;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:411: %s", _tmp206_);
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp206_);
#line 411 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 4574 "GomDocumentTest.c"
	}
	__finally232:
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 387 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 4585 "GomDocumentTest.c"
	}
}


static void ___lambda228__gtest_func (void) {
#line 386 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda228_ ();
#line 4593 "GomDocumentTest.c"
}


static void __lambda229_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomDocument* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlDomDocument* _tmp12_ = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlDomDocument* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		GXmlDomDocument* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomElement* _tmp27_ = NULL;
		GXmlDomElement* _tmp28_ = NULL;
		GXmlDomDocument* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomDocument* _tmp33_ = NULL;
		GXmlDomElement* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		GXmlDomDocument* _tmp40_ = NULL;
		GXmlDomElement* _tmp41_ = NULL;
		GXmlDomElement* _tmp42_ = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		GXmlDomDocument* _tmp47_ = NULL;
		GXmlDomElement* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		GXmlDomDocument* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomElement* _tmp56_ = NULL;
		GXmlDomNodeList* _tmp57_ = NULL;
		GXmlDomNodeList* _tmp58_ = NULL;
		GXmlDomNodeList* _tmp59_ = NULL;
		GXmlDomDocument* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GXmlDomElement* _tmp62_ = NULL;
		GXmlDomElement* _tmp63_ = NULL;
		GXmlDomNodeList* _tmp64_ = NULL;
		GXmlDomNodeList* _tmp65_ = NULL;
		GXmlDomNodeList* _tmp66_ = NULL;
		gint _tmp67_ = 0;
		gint _tmp68_ = 0;
		GXmlDomElement* c = NULL;
		GXmlDomDocument* _tmp69_ = NULL;
		GXmlDomElement* _tmp70_ = NULL;
		GXmlDomElement* _tmp71_ = NULL;
		GXmlDomElement* _tmp72_ = NULL;
		GXmlDomNodeList* _tmp73_ = NULL;
		GXmlDomNodeList* _tmp74_ = NULL;
		GXmlDomNodeList* _tmp75_ = NULL;
		gpointer _tmp76_ = NULL;
		GXmlDomNode* _tmp77_ = NULL;
		GXmlDomElement* _tmp78_ = NULL;
		GXmlDomElement* _tmp79_ = NULL;
		GXmlDomElement* _tmp80_ = NULL;
		GXmlDomElement* _tmp81_ = NULL;
		GXmlDomElement* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		gchar* _tmp84_ = NULL;
		gchar* _tmp85_ = NULL;
		GXmlDomElement* _tmp86_ = NULL;
		gchar* _tmp87_ = NULL;
		gchar* _tmp88_ = NULL;
		gchar* _tmp89_ = NULL;
		GXmlDomElement* _tmp90_ = NULL;
		gchar* p = NULL;
		GXmlDomElement* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		const gchar* _tmp93_ = NULL;
		const gchar* _tmp94_ = NULL;
		gchar* _tmp95_ = NULL;
		GXmlDomDocument* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		GXmlDomDocument* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		GXmlDomElement* _tmp100_ = NULL;
		GXmlDomElement* _tmp101_ = NULL;
		gchar* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		GXmlDomElement* _tmp104_ = NULL;
		gchar* _tmp105_ = NULL;
		gchar* _tmp106_ = NULL;
		gchar* _tmp107_ = NULL;
		GXmlDomElement* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		gchar* _tmp111_ = NULL;
		GXmlDomElement* _tmp112_ = NULL;
		gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
		GXmlDomElement* _tmp115_ = NULL;
		gchar* _tmp116_ = NULL;
		gchar* _tmp117_ = NULL;
		GXmlDomElement* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
		gchar* _tmp120_ = NULL;
		GXmlDomElement* _tmp121_ = NULL;
		gchar* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		GXmlDomElement* c2 = NULL;
		GXmlDomDocument* _tmp124_ = NULL;
		GXmlDomElement* _tmp125_ = NULL;
		GXmlDomElement* _tmp126_ = NULL;
		gchar* _tmp127_ = NULL;
		gchar* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		GXmlDomElement* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
		gchar* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		GXmlDomElement* _tmp134_ = NULL;
		GXmlDomNamedNodeMap* _tmp135_ = NULL;
		GXmlDomNamedNodeMap* _tmp136_ = NULL;
		GXmlDomNamedNodeMap* _tmp137_ = NULL;
		gint _tmp138_ = 0;
		gint _tmp139_ = 0;
		GXmlDomDocument* _tmp140_ = NULL;
		GXmlDomElement* _tmp141_ = NULL;
		GXmlDomElement* _tmp142_ = NULL;
		GXmlDomElement* _tmp143_ = NULL;
		GXmlDomElement* _tmp144_ = NULL;
		GXmlDomNode* _tmp145_ = NULL;
		GXmlDomNode* _tmp146_ = NULL;
		GXmlDomElement* _tmp147_ = NULL;
		gchar* _tmp148_ = NULL;
		gchar* _tmp149_ = NULL;
		gchar* _tmp150_ = NULL;
		GXmlDomElement* _tmp151_ = NULL;
		gchar* _tmp152_ = NULL;
		gchar* _tmp153_ = NULL;
		gchar* _tmp154_ = NULL;
		GXmlDomElement* _tmp155_ = NULL;
		gchar* _tmp156_ = NULL;
		gchar* _tmp157_ = NULL;
#line 415 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<document_element><child/></document_element>", &_inner_error_);
#line 415 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 415 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4768 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = doc;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element (_tmp1_);
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 417 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp4_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = doc;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element (_tmp5_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = gxml_dom_element_get_namespace_uri (_tmp8_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp11_ == NULL, "doc.document_element.namespace_uri == null");
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = doc;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_document_get_document_element (_tmp12_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_element_get_prefix (_tmp15_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp17_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp18_ == NULL, "doc.document_element.prefix == null");
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = doc;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = gxml_dom_document_get_document_element (_tmp19_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = _tmp21_;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp22_, NULL);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = _tmp23_;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp24_ == NULL, "doc.document_element.lookup_namespace_uri (null) == null");
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp24_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp22_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = doc;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_document_get_document_element (_tmp25_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = _tmp27_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp28_, "http://www.w3.org/2000/xmlns/", "xmlns", "http://www.gnome.org/GXml", &_inner_error_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp28_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 421 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 4857 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = doc;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = _tmp30_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp32_ != NULL, "doc.document_element != null");
#line 423 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp32_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = doc;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = gxml_dom_document_get_document_element (_tmp33_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_element_get_namespace_uri (_tmp36_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp39_ == NULL, "doc.document_element.namespace_uri == null");
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp36_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = doc;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = gxml_dom_document_get_document_element (_tmp40_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = _tmp41_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = _tmp42_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp44_ = gxml_dom_element_get_prefix (_tmp43_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp45_ = _tmp44_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp46_ == NULL, "doc.document_element.prefix == null");
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp46_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp43_);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp47_ = doc;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp48_ = gxml_dom_document_get_document_element (_tmp47_);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp49_ = _tmp48_;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp50_ = _tmp49_;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp51_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp50_, NULL);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "http://www.gnome.org/GXml") == 0, "doc.document_element.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp52_);
#line 426 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp50_);
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp53_ = doc;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp54_ = gxml_dom_document_get_document_element (_tmp53_);
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp55_ = _tmp54_;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp56_ = _tmp55_;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp57_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp56_);
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp59_ = _tmp58_;
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp59_ != NULL, "doc.document_element.child_nodes != null");
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp59_);
#line 427 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp56_);
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp60_ = doc;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp61_ = gxml_dom_document_get_document_element (_tmp60_);
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp63_ = _tmp62_;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp64_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp63_);
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp65_ = _tmp64_;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp66_ = _tmp65_;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp67_ = gee_collection_get_size ((GeeCollection*) _tmp66_);
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp68_ = _tmp67_;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp68_ == 1, "doc.document_element.child_nodes.size == 1");
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp66_);
#line 428 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp63_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp69_ = doc;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp70_ = gxml_dom_document_get_document_element (_tmp69_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp71_ = _tmp70_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp72_ = _tmp71_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp73_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp72_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp74_ = _tmp73_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp75_ = _tmp74_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp76_ = gee_list_get ((GeeList*) _tmp75_, 0);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp77_ = (GXmlDomNode*) _tmp76_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp78_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp77_) : NULL;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp78_ == NULL) {
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp77_);
#line 4998 "GomDocumentTest.c"
		}
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp79_ = _tmp78_;
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp75_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp72_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c = _tmp79_;
#line 430 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp80_ = c;
#line 430 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp80_, GXML_TYPE_DOM_ELEMENT), "c is DomElement");
#line 431 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp81_ = c;
#line 431 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp81_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml2", &_inner_error_);
#line 431 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 431 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 431 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5022 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp82_ = c;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp83_ = gxml_dom_element_get_prefix (_tmp82_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp85_ = _tmp84_;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp85_ == NULL, "c.prefix == null");
#line 433 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp85_);
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp86_ = c;
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp87_ = gxml_dom_element_get_namespace_uri (_tmp86_);
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp88_ = _tmp87_;
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp89_ = _tmp88_;
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp89_ == NULL, "c.namespace_uri == null");
#line 434 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp89_);
#line 435 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp90_ = c;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp90_, "http://www.gnome.org/GXml2", "gxml2:prop", "val", &_inner_error_);
#line 435 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 435 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 435 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5059 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 436 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp91_ = c;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp92_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL, "http://www.gnome.org/GXml2", "prop");
#line 436 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		p = _tmp92_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp93_ = p;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp93_ != NULL, "p != null");
#line 439 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp94_ = p;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp94_, "val") == 0, "p == \"val\"");
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp96_ = doc;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp97_ = gxml_gom_document_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp96_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp96_) : NULL, &_inner_error_);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp95_ = _tmp97_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (p);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5090 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 440 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:440: %s", _tmp95_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp98_ = doc;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp99_ = gxml_dom_document_get_document_element (_tmp98_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp100_ = _tmp99_;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp101_ = _tmp100_;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp102_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp101_, NULL);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp103_ = _tmp102_;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp103_, "http://www.gnome.org/GXml") == 0, "doc.document_element.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp103_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp101_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp104_ = c;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp105_ = gxml_dom_element_get_prefix (_tmp104_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp106_ = _tmp105_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp107_ = _tmp106_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp107_ == NULL, "c.prefix == null");
#line 442 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp107_);
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp108_ = c;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp109_ = gxml_dom_element_get_namespace_uri (_tmp108_);
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp111_ == NULL, "c.namespace_uri == null");
#line 443 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp111_);
#line 444 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp112_ = c;
#line 444 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp113_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp112_, NULL);
#line 444 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp114_ = _tmp113_;
#line 444 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp114_, "http://www.gnome.org/GXml") == 0, "c.lookup_namespace_uri (null) == \"http://www.gnome.org/GXml\"");
#line 444 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp114_);
#line 445 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp115_ = c;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp116_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp115_, "gxml2");
#line 445 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp117_ = _tmp116_;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp117_, "http://www.gnome.org/GXml2") == 0, "c.lookup_namespace_uri (\"gxml2\") == \"http://www.gnome.org/GXml2\"");
#line 445 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp117_);
#line 446 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp118_ = c;
#line 446 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp119_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp118_, "http://www.gnome.org/GXml3");
#line 446 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp120_ = _tmp119_;
#line 446 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp120_ == NULL, "c.lookup_prefix (\"http://www.gnome.org/GXml3\") == null");
#line 446 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp120_);
#line 447 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp121_ = c;
#line 447 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp122_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp121_, "http://www.gnome.org/GXml2");
#line 447 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp123_ = _tmp122_;
#line 447 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp123_, "gxml2") == 0, "c.lookup_prefix (\"http://www.gnome.org/GXml2\") == \"gxml2\"");
#line 447 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp123_);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp124_ = doc;
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp125_ = gxml_dom_document_create_element_ns (_tmp124_, "http://www.gnome.org/GXml/testing", "t:child2", &_inner_error_);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c2 = _tmp125_;
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp95_);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (p);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 448 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5193 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp126_ = c2;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp127_ = gxml_dom_element_get_prefix (_tmp126_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp128_ = _tmp127_;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp129_ = _tmp128_;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp129_, "t") == 0, "c2.prefix == \"t\"");
#line 450 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp129_);
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp130_ = c2;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp131_ = gxml_dom_element_get_namespace_uri (_tmp130_);
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp132_ = _tmp131_;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp133_ = _tmp132_;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp133_, "http://www.gnome.org/GXml/testing") == 0, "c2.namespace_uri == \"http://www.gnome.org/GXml/testing\"");
#line 451 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp133_);
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp134_ = c2;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp135_ = gxml_dom_element_get_attributes (_tmp134_);
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp138_ = gee_map_get_size ((GeeMap*) _tmp137_);
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp139_ = _tmp138_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp139_ == 0, "c2.attributes.size == 0");
#line 452 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp137_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp140_ = doc;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp141_ = gxml_dom_document_get_document_element (_tmp140_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp142_ = _tmp141_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp143_ = _tmp142_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp144_ = c2;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp145_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp143_, (GXmlDomNode*) _tmp144_, &_inner_error_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp146_ = _tmp145_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp146_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp143_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp95_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (p);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (doc);
#line 5266 "GomDocumentTest.c"
			goto __catch233_g_error;
		}
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp147_ = c2;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp148_ = gxml_dom_element_get_prefix (_tmp147_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp149_ = _tmp148_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp150_ = _tmp149_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp150_, "t") == 0, "c2.prefix == \"t\"");
#line 454 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp150_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp151_ = c2;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp152_ = gxml_dom_element_get_namespace_uri (_tmp151_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp153_ = _tmp152_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp154_ = _tmp153_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp154_, "http://www.gnome.org/GXml/testing") == 0, "c2.namespace_uri == \"http://www.gnome.org/GXml/testing\"");
#line 455 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp154_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp155_ = c2;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp156_ = gxml_dom_element_get_attribute_ns (_tmp155_, "http://www.w3.org/2000/xmlns/", "t");
#line 456 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp157_ = _tmp156_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp157_ == NULL, "c2.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t\t \"t\") == null");
#line 456 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp157_);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c2);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp95_);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (p);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 5313 "GomDocumentTest.c"
	}
	goto __finally233;
	__catch233_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp158_ = NULL;
		gchar* _tmp159_ = NULL;
		gchar* _tmp160_ = NULL;
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp158_ = e->message;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp159_ = g_strconcat ("ERROR: ", _tmp158_, NULL);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp160_ = _tmp159_;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:459: %s", _tmp160_);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp160_);
#line 460 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5340 "GomDocumentTest.c"
	}
	__finally233:
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 414 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5351 "GomDocumentTest.c"
	}
}


static void ___lambda229__gtest_func (void) {
#line 413 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda229_ ();
#line 5359 "GomDocumentTest.c"
}


static void __lambda230_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlDomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("\n" \
"\t\t\t\t<Project xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-n" \
"s#\"\n" \
"         xmlns:rdfs=\"http://www.w3.org/2000/01/rdf-schema#\"\n" \
"         xmlns:foaf=\"http://xmlns.com/foaf/0.1/\"\n" \
"         xmlns:gnome=\"http://api.gnome.org/doap-extensions#\"\n" \
"         xmlns=\"http://usefulinc.com/ns/doap#\"><child/></Project>", &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp0_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5380 "GomDocumentTest.c"
			goto __catch234_g_error;
		}
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element (doc);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp1_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp2_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = gxml_dom_element_get_prefix (_tmp3_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = _tmp4_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp6_ == NULL, "doc.document_element.prefix == null");
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp6_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp3_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 5403 "GomDocumentTest.c"
	}
	goto __finally234;
	__catch234_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 478 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = e->message;
#line 478 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = g_strconcat ("ERROR: ", _tmp7_, NULL);
#line 478 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 478 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:478: %s", _tmp9_);
#line 478 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp9_);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5430 "GomDocumentTest.c"
	}
	__finally234:
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5441 "GomDocumentTest.c"
	}
}


static void ___lambda230__gtest_func (void) {
#line 463 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda230_ ();
#line 5449 "GomDocumentTest.c"
}


static void __lambda231_ (void) {
	GXmlDomDocument* doc = NULL;
	GXmlDomDocument* _tmp11_ = NULL;
	GXmlDomElement* _tmp12_ = NULL;
	GXmlDomElement* _tmp13_ = NULL;
	GXmlDomElement* _tmp14_ = NULL;
	GXmlDomDocument* _tmp15_ = NULL;
	GXmlDomElement* _tmp16_ = NULL;
	GXmlDomElement* _tmp17_ = NULL;
	GXmlDomElement* _tmp18_ = NULL;
	gchar* _tmp19_ = NULL;
	gchar* _tmp20_ = NULL;
	gchar* _tmp21_ = NULL;
	GXmlDomDocument* _tmp22_ = NULL;
	GXmlDomElement* _tmp23_ = NULL;
	GXmlDomElement* _tmp24_ = NULL;
	GXmlDomElement* _tmp25_ = NULL;
	gchar* _tmp26_ = NULL;
	gchar* _tmp27_ = NULL;
	gchar* _tmp28_ = NULL;
	GXmlDomDocument* _tmp29_ = NULL;
	GXmlDomElement* _tmp30_ = NULL;
	GXmlDomElement* _tmp31_ = NULL;
	GXmlDomElement* _tmp32_ = NULL;
	GXmlDomNodeList* _tmp33_ = NULL;
	GXmlDomNodeList* _tmp34_ = NULL;
	GXmlDomNodeList* _tmp35_ = NULL;
	GXmlDomDocument* _tmp40_ = NULL;
	GXmlDomElement* _tmp41_ = NULL;
	GXmlDomElement* _tmp42_ = NULL;
	GXmlDomElement* _tmp43_ = NULL;
	GXmlDomNodeList* _tmp44_ = NULL;
	GXmlDomNodeList* _tmp45_ = NULL;
	GXmlDomNodeList* _tmp46_ = NULL;
	gint _tmp47_ = 0;
	gint _tmp48_ = 0;
	GXmlDomElement* c = NULL;
	GXmlDomDocument* _tmp49_ = NULL;
	GXmlDomElement* _tmp50_ = NULL;
	GXmlDomElement* _tmp51_ = NULL;
	GXmlDomElement* _tmp52_ = NULL;
	GXmlDomNodeList* _tmp53_ = NULL;
	GXmlDomNodeList* _tmp54_ = NULL;
	GXmlDomNodeList* _tmp55_ = NULL;
	gpointer _tmp56_ = NULL;
	GXmlDomNode* _tmp57_ = NULL;
	GXmlDomElement* _tmp58_ = NULL;
	GXmlDomElement* _tmp59_ = NULL;
	GXmlDomNamedNodeMap* _tmp63_ = NULL;
	GXmlDomNamedNodeMap* _tmp64_ = NULL;
	GXmlDomNamedNodeMap* _tmp65_ = NULL;
	gint _tmp66_ = 0;
	gint _tmp67_ = 0;
	gchar* _tmp68_ = NULL;
	gchar* _tmp69_ = NULL;
	gchar* _tmp70_ = NULL;
	gchar* _tmp71_ = NULL;
	gchar* _tmp72_ = NULL;
	gchar* _tmp73_ = NULL;
	GXmlDomNamedNodeMap* _tmp74_ = NULL;
	GXmlDomNamedNodeMap* _tmp75_ = NULL;
	GXmlDomNamedNodeMap* _tmp76_ = NULL;
	gint _tmp77_ = 0;
	gint _tmp78_ = 0;
	gchar* _tmp79_ = NULL;
	gchar* _tmp80_ = NULL;
	gchar* _tmp81_ = NULL;
	gchar* _tmp82_ = NULL;
	gchar* _tmp83_ = NULL;
	gchar* _tmp84_ = NULL;
	gchar* p = NULL;
	gchar* _tmp85_ = NULL;
	GError * _inner_error_ = NULL;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	doc = NULL;
#line 5528 "GomDocumentTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<document_element><child/></document_element>", &_inner_error_);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5539 "GomDocumentTest.c"
			goto __catch235_g_error;
		}
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _tmp0_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = NULL;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 5552 "GomDocumentTest.c"
	}
	goto __finally235;
	__catch235_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = e;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _tmp3_->message;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = g_strconcat ("ERROR: ", _tmp4_, NULL);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:485: %s", _tmp6_);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp6_);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5580 "GomDocumentTest.c"
	}
	__finally235:
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5593 "GomDocumentTest.c"
	}
	{
		GXmlDomDocument* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = doc;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element (_tmp7_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp10_, "http://local", "xmlns:", "http://www.gnome.org/GXml", &_inner_error_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5614 "GomDocumentTest.c"
			goto __catch236_g_error;
		}
#line 489 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 5619 "GomDocumentTest.c"
	}
	goto __finally236;
	__catch236_g_error:
	{
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 5628 "GomDocumentTest.c"
	}
	__finally236:
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5641 "GomDocumentTest.c"
	}
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp11_ = doc;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp12_ = gxml_dom_document_get_document_element (_tmp11_);
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp13_ = _tmp12_;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp14_ = _tmp13_;
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp14_ != NULL, "doc.document_element != null");
#line 491 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp14_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp15_ = doc;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp16_ = gxml_dom_document_get_document_element (_tmp15_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp17_ = _tmp16_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp18_ = _tmp17_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp19_ = gxml_dom_element_get_namespace_uri (_tmp18_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp20_ = _tmp19_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp21_ = _tmp20_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp21_ == NULL, "doc.document_element.namespace_uri == null");
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp21_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp18_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp22_ = doc;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp23_ = gxml_dom_document_get_document_element (_tmp22_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp24_ = _tmp23_;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp25_ = _tmp24_;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp26_ = gxml_dom_element_get_prefix (_tmp25_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp27_ = _tmp26_;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp28_ = _tmp27_;
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp28_ == NULL, "doc.document_element.prefix == null");
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp28_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp25_);
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp29_ = doc;
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp30_ = gxml_dom_document_get_document_element (_tmp29_);
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp31_ = _tmp30_;
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp32_ = _tmp31_;
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp33_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp32_);
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp34_ = _tmp33_;
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp35_ = _tmp34_;
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp35_ != NULL, "doc.document_element.child_nodes != null");
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp35_);
#line 494 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp32_);
#line 5715 "GomDocumentTest.c"
	{
		GXmlDomDocument* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = doc;
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_document_get_document_element (_tmp36_);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp39_, "http://www.gnome.org/GXml", "xmlns", "http://www.gnome.org/GXml", &_inner_error_);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5735 "GomDocumentTest.c"
			goto __catch237_g_error;
		}
#line 498 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 5740 "GomDocumentTest.c"
	}
	goto __finally237;
	__catch237_g_error:
	{
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 5749 "GomDocumentTest.c"
	}
	__finally237:
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 495 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5762 "GomDocumentTest.c"
	}
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp40_ = doc;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp41_ = gxml_dom_document_get_document_element (_tmp40_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp42_ = _tmp41_;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp43_ = _tmp42_;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp45_ = _tmp44_;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp46_ = _tmp45_;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp47_ = gee_collection_get_size ((GeeCollection*) _tmp46_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp48_ = _tmp47_;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp48_ == 1, "doc.document_element.child_nodes.size == 1");
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp46_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp43_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp49_ = doc;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp50_ = gxml_dom_document_get_document_element (_tmp49_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp51_ = _tmp50_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp52_ = _tmp51_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp53_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp52_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp54_ = _tmp53_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp55_ = _tmp54_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp56_ = gee_list_get ((GeeList*) _tmp55_, 0);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp57_ = (GXmlDomNode*) _tmp56_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp58_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp57_) : NULL;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (_tmp58_ == NULL) {
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp57_);
#line 5812 "GomDocumentTest.c"
	}
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp59_ = _tmp58_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp55_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp52_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	c = _tmp59_;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_DOM_ELEMENT), "c is DomElement");
#line 5824 "GomDocumentTest.c"
	{
#line 504 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml2", &_inner_error_);
#line 504 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5830 "GomDocumentTest.c"
			goto __catch238_g_error;
		}
	}
	goto __finally238;
	__catch238_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp60_ = e->message;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp61_ = g_strconcat ("ERROR: ", _tmp60_, NULL);
#line 507 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp62_ = _tmp61_;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:507: %s", _tmp62_);
#line 507 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp62_);
#line 508 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 5859 "GomDocumentTest.c"
	}
	__finally238:
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5874 "GomDocumentTest.c"
	}
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp63_ = gxml_dom_element_get_attributes (c);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp64_ = _tmp63_;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp65_ = _tmp64_;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp66_ = gee_map_get_size ((GeeMap*) _tmp65_);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp67_ = _tmp66_;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp67_ == 1, "c.attributes.size == 1");
#line 510 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp65_);
#line 511 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp68_ = gxml_dom_element_get_prefix (c);
#line 511 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp69_ = _tmp68_;
#line 511 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp70_ = _tmp69_;
#line 511 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp70_ == NULL, "c.prefix == null");
#line 511 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp70_);
#line 512 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp71_ = gxml_dom_element_get_namespace_uri (c);
#line 512 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp72_ = _tmp71_;
#line 512 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp73_ = _tmp72_;
#line 512 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp73_ == NULL, "c.namespace_uri == null");
#line 512 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp73_);
#line 5910 "GomDocumentTest.c"
	{
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.w3.org/2000/xmlns/", "xmlns:gxml2", "http://www.gnome.org/GXml3", &_inner_error_);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5916 "GomDocumentTest.c"
			goto __catch239_g_error;
		}
	}
	goto __finally239;
	__catch239_g_error:
	{
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 5927 "GomDocumentTest.c"
	}
	__finally239:
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 513 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 5942 "GomDocumentTest.c"
	}
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp74_ = gxml_dom_element_get_attributes (c);
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp75_ = _tmp74_;
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp76_ = _tmp75_;
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp77_ = gee_map_get_size ((GeeMap*) _tmp76_);
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp78_ = _tmp77_;
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp78_ == 1, "c.attributes.size == 1");
#line 516 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp76_);
#line 517 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp79_ = gxml_dom_element_get_prefix (c);
#line 517 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp80_ = _tmp79_;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp81_ = _tmp80_;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp81_ == NULL, "c.prefix == null");
#line 517 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp81_);
#line 518 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp82_ = gxml_dom_element_get_namespace_uri (c);
#line 518 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp83_ = _tmp82_;
#line 518 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp84_ = _tmp83_;
#line 518 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp84_ == NULL, "c.namespace_uri == null");
#line 518 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (_tmp84_);
#line 5978 "GomDocumentTest.c"
	{
#line 520 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.gnome.org/GXml2", "gxml3:prop", "val", &_inner_error_);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5984 "GomDocumentTest.c"
			goto __catch240_g_error;
		}
#line 521 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 5989 "GomDocumentTest.c"
	}
	goto __finally240;
	__catch240_g_error:
	{
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 5998 "GomDocumentTest.c"
	}
	__finally240:
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 519 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 6013 "GomDocumentTest.c"
	}
	{
#line 524 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute_ns (c, "http://www.gnome.org/GXml3", "gxml2:prop", "val", &_inner_error_);
#line 524 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 6020 "GomDocumentTest.c"
			goto __catch241_g_error;
		}
	}
	goto __finally241;
	__catch241_g_error:
	{
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 6031 "GomDocumentTest.c"
	}
	__finally241:
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (doc);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 523 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 6046 "GomDocumentTest.c"
	}
#line 526 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp85_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (c, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) c) : NULL, "http://www.gnome.org/GXml4", "prop");
#line 526 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	p = _tmp85_;
#line 527 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (p == NULL, "p == null");
#line 482 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_free0 (p);
#line 482 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (c);
#line 482 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 6060 "GomDocumentTest.c"
}


static void ___lambda231__gtest_func (void) {
#line 482 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda231_ ();
#line 6067 "GomDocumentTest.c"
}


static void __lambda232_ (void) {
	GXmlGomDocument* doc = NULL;
	GXmlGomDocument* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
#line 530 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp0_ = gxml_gom_document_new ();
#line 530 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	doc = _tmp0_;
#line 531 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp1_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) doc);
#line 531 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp2_ = _tmp1_;
#line 531 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_tmp3_ = _tmp2_;
#line 531 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_vala_assert (_tmp3_ == NULL, "doc.parent_node == null");
#line 531 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (_tmp3_);
#line 529 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	_g_object_unref0 (doc);
#line 6093 "GomDocumentTest.c"
}


static void ___lambda232__gtest_func (void) {
#line 529 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda232_ ();
#line 6100 "GomDocumentTest.c"
}


static void __lambda233_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlGomElement* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomElement* n2 = NULL;
		GXmlGomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GXmlGomElement* _tmp15_ = NULL;
		GXmlDomNode* _tmp16_ = NULL;
		GXmlDomNode* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		GXmlGomDocument* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* str = NULL;
		GXmlGomDocument* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		const gchar* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 535 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = d;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "Node", &_inner_error_);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6152 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp1_) : NULL);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n = _tmp4_;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = d;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = n;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp5_, (GXmlDomNode*) _tmp6_, &_inner_error_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = _tmp7_;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp8_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6177 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = n;
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp9_, "name", "value", &_inner_error_);
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 538 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6192 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = d;
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "Node2", &_inner_error_);
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp12_;
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6209 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp10_) : NULL);
#line 539 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n2 = _tmp13_;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = n;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = n2;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp14_, (GXmlDomNode*) _tmp15_, &_inner_error_);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp17_);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 540 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6238 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = d;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = gxml_gom_document_write_string (_tmp19_, &_inner_error_);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = _tmp20_;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6259 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 541 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:541: %s", _tmp18_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = d;
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_gom_document_write_string (_tmp21_, &_inner_error_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		str = _tmp22_;
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp18_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp10_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp1_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6284 "GomDocumentTest.c"
			goto __catch242_g_error;
		}
#line 543 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = str;
#line 543 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = string_contains (_tmp23_, "<Node");
#line 543 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp24_, "\"<Node\" in str");
#line 544 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = str;
#line 544 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = string_contains (_tmp25_, "<Node name=\"value\"><Node2/></Node>");
#line 544 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp26_, "\"<Node name=\\\"value\\\"><Node2/></Node>\" in str");
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (str);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp18_);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n2);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp10_);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp1_);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 6313 "GomDocumentTest.c"
	}
	goto __finally242;
	__catch242_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = e->message;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = g_strconcat ("Error: ", _tmp27_, NULL);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:546: %s", _tmp29_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp29_);
#line 547 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 6340 "GomDocumentTest.c"
	}
	__finally242:
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 534 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 6351 "GomDocumentTest.c"
	}
}


static void ___lambda233__gtest_func (void) {
#line 533 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda233_ ();
#line 6359 "GomDocumentTest.c"
}


static void __lambda234_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomNode* _tmp26_ = NULL;
		GXmlDomNode* _tmp27_ = NULL;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp28_ = NULL;
		GXmlDomElement* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		GXmlDomNode* _tmp40_ = NULL;
		GXmlDomElement* c51 = NULL;
		GXmlGomDocument* _tmp41_ = NULL;
		GXmlDomElement* _tmp42_ = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		GXmlDomElement* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		GXmlDomElement* n1 = NULL;
		GXmlGomDocument* _tmp47_ = NULL;
		GXmlDomElement* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		GXmlDomElement* n2 = NULL;
		GXmlGomDocument* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomElement* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GXmlDomElement* n3 = NULL;
		GXmlGomDocument* _tmp59_ = NULL;
		GXmlDomElement* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GXmlDomElement* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		GXmlDomElement* n4 = NULL;
		GXmlGomDocument* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GXmlDomElement* _tmp67_ = NULL;
		GXmlDomElement* _tmp68_ = NULL;
		gchar* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		GXmlDomNodeList* l1 = NULL;
		GXmlGomDocument* _tmp71_ = NULL;
		GXmlDomNodeList* _tmp72_ = NULL;
		GXmlDomNodeList* _tmp73_ = NULL;
		GXmlDomNodeList* _tmp74_ = NULL;
		gint _tmp75_ = 0;
		gint _tmp76_ = 0;
		gchar* _tmp77_ = NULL;
		gchar* _tmp78_ = NULL;
		GXmlDomNodeList* _tmp79_ = NULL;
		gint _tmp80_ = 0;
		gint _tmp81_ = 0;
		GXmlDomNodeList* _tmp82_ = NULL;
		GXmlDomNode* _tmp83_ = NULL;
		GXmlDomNode* _tmp84_ = NULL;
		gchar* _tmp85_ = NULL;
		gchar* _tmp86_ = NULL;
		gchar* _tmp87_ = NULL;
		GXmlDomNodeList* l2 = NULL;
		GXmlGomDocument* _tmp88_ = NULL;
		GXmlDomNodeList* _tmp89_ = NULL;
		GXmlDomNodeList* _tmp90_ = NULL;
		GXmlDomNodeList* _tmp91_ = NULL;
		gint _tmp92_ = 0;
		gint _tmp93_ = 0;
		GXmlDomNodeList* _tmp94_ = NULL;
		GXmlDomNode* _tmp95_ = NULL;
		GXmlDomNode* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		GXmlDomNodeList* l3 = NULL;
		GXmlGomDocument* _tmp100_ = NULL;
		GXmlDomNodeList* _tmp101_ = NULL;
		GXmlDomNodeList* _tmp102_ = NULL;
		GXmlDomNodeList* _tmp103_ = NULL;
		gint _tmp104_ = 0;
		gint _tmp105_ = 0;
		GXmlDomNodeList* _tmp106_ = NULL;
		GXmlDomNode* _tmp107_ = NULL;
		GXmlDomNode* _tmp108_ = NULL;
		gchar* _tmp109_ = NULL;
		gchar* _tmp110_ = NULL;
		gchar* _tmp111_ = NULL;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp112_ = NULL;
		GXmlDomElement* _tmp113_ = NULL;
		GXmlDomElement* _tmp114_ = NULL;
		GXmlDomElement* _tmp115_ = NULL;
		GXmlDomElement* _tmp116_ = NULL;
		GXmlDomNode* _tmp117_ = NULL;
		GXmlDomNode* _tmp118_ = NULL;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp119_ = NULL;
		GXmlDomElement* _tmp120_ = NULL;
		GXmlDomElement* _tmp121_ = NULL;
		GXmlDomElement* _tmp122_ = NULL;
		GXmlDomElement* _tmp123_ = NULL;
		GXmlDomNode* _tmp124_ = NULL;
		GXmlDomNode* _tmp125_ = NULL;
		GXmlDomNodeList* l4 = NULL;
		GXmlGomDocument* _tmp126_ = NULL;
		GXmlDomNodeList* _tmp127_ = NULL;
		GXmlDomNodeList* _tmp128_ = NULL;
		GXmlDomNodeList* _tmp129_ = NULL;
		gint _tmp130_ = 0;
		gint _tmp131_ = 0;
		GXmlDomNodeList* _tmp132_ = NULL;
		GXmlDomNode* _tmp133_ = NULL;
		GXmlDomNode* _tmp134_ = NULL;
		gchar* _tmp135_ = NULL;
		gchar* _tmp136_ = NULL;
		gchar* _tmp137_ = NULL;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 552 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = d;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp1_, "root", &_inner_error_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp2_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 553 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6536 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = d;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = r;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp6_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6555 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = d;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp7_, "child", &_inner_error_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c1 = _tmp8_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6570 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = c1;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp9_, "class", "error", &_inner_error_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6585 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = r;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = c1;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp10_, (GXmlDomNode*) _tmp11_, &_inner_error_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp13_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6606 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = d;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp14_, "child", &_inner_error_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c2 = _tmp15_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6623 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = c2;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp16_, "class", "warning", &_inner_error_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6640 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = r;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = c2;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp17_, (GXmlDomNode*) _tmp18_, &_inner_error_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp20_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6663 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = d;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp21_, "child", &_inner_error_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c3 = _tmp22_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6682 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = c3;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp23_, "class", "error warning", &_inner_error_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6701 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = r;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = c3;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6726 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = d;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c4 = _tmp29_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6747 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = c4;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "class", "error calc", &_inner_error_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6768 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = r;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = c4;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp34_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6795 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = d;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c5 = _tmp36_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6818 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = r;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = c5;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, (GXmlDomNode*) _tmp38_, &_inner_error_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = _tmp39_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp40_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6847 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = d;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp41_, "child", &_inner_error_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c51 = _tmp42_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6872 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = c5;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp44_ = c51;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp45_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp43_, (GXmlDomNode*) _tmp44_, &_inner_error_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp46_ = _tmp45_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp46_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6903 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp47_ = d;
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp48_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp47_, "child", &_inner_error_);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n1 = _tmp48_;
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 571 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6930 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 572 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp49_ = n1;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp49_ != NULL, "n1 != null");
#line 573 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp50_ = n1;
#line 573 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp51_ = gxml_dom_element_get_attribute (_tmp50_, "class");
#line 573 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp52_ = _tmp51_;
#line 573 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 573 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp52_);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp53_ = d;
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp54_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp53_, "child.warning", &_inner_error_);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n2 = _tmp54_;
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 574 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 6973 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 575 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp55_ = n2;
#line 575 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp55_ != NULL, "n2 != null");
#line 576 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp56_ = n2;
#line 576 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp57_ = gxml_dom_element_get_attribute (_tmp56_, "class");
#line 576 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp58_ = _tmp57_;
#line 576 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 576 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp58_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp59_ = d;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp60_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp59_, "child[class]", &_inner_error_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n3 = _tmp60_;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7018 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 578 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp61_ = n3;
#line 578 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp61_ != NULL, "n3 != null");
#line 579 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp62_ = n3;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute (_tmp62_, "class");
#line 579 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp64_ = _tmp63_;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 579 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp64_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp65_ = d;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp66_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp65_, "child[class=\"error calc\"]", &_inner_error_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		n4 = _tmp66_;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7065 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 581 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp67_ = n4;
#line 581 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp67_ != NULL, "n4 != null");
#line 582 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp68_ = n4;
#line 582 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp69_ = gxml_dom_element_get_attribute (_tmp68_, "class");
#line 582 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp70_ = _tmp69_;
#line 582 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp70_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 582 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp70_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp71_ = d;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp72_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp71_, "child", &_inner_error_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		l1 = _tmp72_;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7114 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 584 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp73_ = l1;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp73_ != NULL, "l1 != null");
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp74_ = l1;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp75_ = gxml_dom_node_list_get_length (_tmp74_);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp76_ = _tmp75_;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp77_ = g_strdup_printf ("%i", _tmp76_);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp78_ = _tmp77_;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:585: %s", _tmp78_);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp78_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp79_ = l1;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp80_ = gxml_dom_node_list_get_length (_tmp79_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp81_ = _tmp80_;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp81_ == 6, "l1.length == 6");
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp82_ = l1;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp83_ = gxml_dom_node_list_item (_tmp82_, 4);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp84_ = _tmp83_;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp85_ = gxml_dom_node_get_node_name (_tmp84_);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp86_ = _tmp85_;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp87_ = _tmp86_;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp87_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp87_);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp84_);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp88_ = d;
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp89_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp88_, "child[class]", &_inner_error_);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		l2 = _tmp89_;
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7195 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 589 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp90_ = l2;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp90_ != NULL, "l2 != null");
#line 590 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp91_ = l2;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp92_ = gxml_dom_node_list_get_length (_tmp91_);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp93_ = _tmp92_;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp93_ == 4, "l2.length == 4");
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp94_ = l2;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp95_ = gxml_dom_node_list_item (_tmp94_, 3);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp96_ = _tmp95_;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp97_ = gxml_dom_node_get_node_name (_tmp96_);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp98_ = _tmp97_;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp99_ = _tmp98_;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp99_);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp96_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp100_ = d;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp101_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp100_, "child[class=\"error\"]", &_inner_error_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		l3 = _tmp101_;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7264 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 593 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp102_ = l3;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp102_ != NULL, "l3 != null");
#line 594 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp103_ = l3;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp104_ = gxml_dom_node_list_get_length (_tmp103_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp105_ = _tmp104_;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp105_ == 1, "l3.length == 1");
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp106_ = l3;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp107_ = gxml_dom_node_list_item (_tmp106_, 0);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp108_ = _tmp107_;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp109_ = gxml_dom_node_get_node_name (_tmp108_);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp110_ = _tmp109_;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp111_ = _tmp110_;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp111_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp111_);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp108_);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp112_ = d;
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp113_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp112_, "child", &_inner_error_);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c6 = _tmp113_;
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 596 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7335 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp114_ = c6;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp114_, "prop", "val1", &_inner_error_);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 597 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7376 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp115_ = r;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp116_ = c6;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp117_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp115_, (GXmlDomNode*) _tmp116_, &_inner_error_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp118_ = _tmp117_;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp118_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7423 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp119_ = d;
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp120_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp119_, "child", &_inner_error_);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		c7 = _tmp120_;
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 599 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7466 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp121_ = c7;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		gxml_dom_element_set_attribute (_tmp121_, "prop", "val1", &_inner_error_);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 600 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7509 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp122_ = r;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp123_ = c7;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp124_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp122_, (GXmlDomNode*) _tmp123_, &_inner_error_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp125_ = _tmp124_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp125_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7558 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp126_ = d;
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp127_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp126_, "child[prop=\"val1\"]", &_inner_error_);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		l4 = _tmp127_;
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c7);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c6);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l3);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l2);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (l1);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n4);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n3);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n2);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (n1);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c51);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c5);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c4);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c3);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c2);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (c1);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 602 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7603 "GomDocumentTest.c"
			goto __catch243_g_error;
		}
#line 603 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp128_ = l4;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp128_ != NULL, "l4 != null");
#line 604 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp129_ = l4;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp130_ = gxml_dom_node_list_get_length (_tmp129_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp131_ = _tmp130_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp131_ == 2, "l4.length == 2");
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp132_ = l4;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp133_ = gxml_dom_node_list_item (_tmp132_, 0);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp134_ = _tmp133_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp135_ = gxml_dom_node_get_node_name (_tmp134_);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp136_ = _tmp135_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp137_ = _tmp136_;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp137_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp137_);
#line 605 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp134_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (l4);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c7);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c6);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (l3);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (l2);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (l1);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n4);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n3);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n2);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (n1);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c51);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c5);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c4);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c3);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c2);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (c1);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 7672 "GomDocumentTest.c"
	}
	goto __finally243;
	__catch243_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp138_ = NULL;
		gchar* _tmp139_ = NULL;
		gchar* _tmp140_ = NULL;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp138_ = e->message;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp139_ = g_strconcat ("Error: ", _tmp138_, NULL);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp140_ = _tmp139_;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:607: %s", _tmp140_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp140_);
#line 608 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 7699 "GomDocumentTest.c"
	}
	__finally243:
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 7710 "GomDocumentTest.c"
	}
}


static void ___lambda234__gtest_func (void) {
#line 550 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda234_ ();
#line 7718 "GomDocumentTest.c"
}


static void __lambda235_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocumentType* _tmp2_ = NULL;
		GXmlGomDocumentType* _tmp3_ = NULL;
		GXmlGomDocumentType* _tmp4_ = NULL;
		GXmlDomNodeNodeType _tmp5_ = 0;
		GXmlDomNodeNodeType _tmp6_ = 0;
		GXmlGomDocumentType* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlGomDocumentType* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GXmlGomDocumentType* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		GXmlGomDocumentType* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_ = NULL;
		GXmlGomDocumentType* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlGomDocument* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlGomDocument* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlGomDocument* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
		gchar* _tmp42_ = NULL;
		GXmlGomDocument* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		GXmlGomDocument* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gboolean _tmp48_ = FALSE;
#line 613 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 613 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:614: Creating a DocumentType");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = d;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_type_new ((GXmlDomDocument*) _tmp1_, "svg", "-//W3C//DTD SVG 1.1//EN", "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		dt1 = _tmp2_;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = dt1;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 617 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = dt1;
#line 617 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_type ((GXmlDomNode*) _tmp4_);
#line 617 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 617 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp6_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = dt1;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 618 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = dt1;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_type_get_name ((GXmlDomDocumentType*) _tmp11_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "svg") == 0, "dt1.name == \"svg\"");
#line 620 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = dt1;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) _tmp14_);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 621 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = dt1;
#line 621 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) _tmp17_);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 621 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = d;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = dt1;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp20_, (GXmlDomNode*) _tmp21_, &_inner_error_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7853 "GomDocumentTest.c"
			goto __catch244_g_error;
		}
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = d;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp24_);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_list_get_length (_tmp27_);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp29_ == 1, "d.child_nodes.length == 1");
#line 623 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = d;
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp30_, "svg", &_inner_error_);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp31_;
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7884 "GomDocumentTest.c"
			goto __catch244_g_error;
		}
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = d;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = r;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7905 "GomDocumentTest.c"
			goto __catch244_g_error;
		}
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = d;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp41_ == 2, "d.child_nodes.length == 2");
#line 626 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = d;
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp44_ = gxml_gom_document_write_string (_tmp43_, &_inner_error_);
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = _tmp44_;
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7938 "GomDocumentTest.c"
			goto __catch244_g_error;
		}
#line 627 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:627: %s", _tmp42_);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp46_ = d;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp47_ = gxml_gom_document_write_string (_tmp46_, &_inner_error_);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp45_ = _tmp47_;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp42_);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 7959 "GomDocumentTest.c"
			goto __catch244_g_error;
		}
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp48_ = string_contains (_tmp45_, "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/G" \
"raphics/SVG/1.1/DTD/svg11.dtd\">");
#line 628 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp48_, "\"<!DOCTYPE svg PUBLIC \\\"-//W3C//DTD SVG 1.1//EN\\\" \\\"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\\\">\" in d.write_string ()");
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp42_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 7976 "GomDocumentTest.c"
	}
	goto __finally244;
	__catch244_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 630 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp49_ = e->message;
#line 630 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 630 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 630 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:630: %s", _tmp51_);
#line 630 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp51_);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8003 "GomDocumentTest.c"
	}
	__finally244:
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 8014 "GomDocumentTest.c"
	}
}


static void ___lambda235__gtest_func (void) {
#line 611 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda235_ ();
#line 8022 "GomDocumentTest.c"
}


static void __lambda236_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocumentType* _tmp2_ = NULL;
		GXmlGomDocumentType* _tmp3_ = NULL;
		GXmlGomDocumentType* _tmp4_ = NULL;
		GXmlDomNodeNodeType _tmp5_ = 0;
		GXmlDomNodeNodeType _tmp6_ = 0;
		GXmlGomDocumentType* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlGomDocumentType* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		GXmlGomDocumentType* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		const gchar* _tmp16_ = NULL;
		GXmlGomDocumentType* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_ = NULL;
		GXmlGomDocumentType* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlGomDocument* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		gint _tmp28_ = 0;
		gint _tmp29_ = 0;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlGomDocument* _tmp32_ = NULL;
		GXmlDomElement* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		GXmlGomDocument* _tmp36_ = NULL;
		GXmlDomNodeList* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
		gchar* _tmp42_ = NULL;
		GXmlGomDocument* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		GXmlGomDocument* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gboolean _tmp48_ = FALSE;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 636 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 637 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:637: Creating a DocumentType");
#line 638 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = d;
#line 638 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = gxml_gom_document_type_new ((GXmlDomDocument*) _tmp1_, "svg", NULL, NULL);
#line 638 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		dt1 = _tmp2_;
#line 639 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = dt1;
#line 639 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 640 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = dt1;
#line 640 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_node_type ((GXmlDomNode*) _tmp4_);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 640 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp6_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = dt1;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = _tmp9_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 641 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp10_);
#line 642 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = dt1;
#line 642 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = gxml_dom_document_type_get_name ((GXmlDomDocumentType*) _tmp11_);
#line 642 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = _tmp12_;
#line 642 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "svg") == 0, "dt1.name == \"svg\"");
#line 643 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = dt1;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = gxml_dom_document_type_get_public_id ((GXmlDomDocumentType*) _tmp14_);
#line 643 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = _tmp15_;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp16_ == NULL, "dt1.public_id == null");
#line 644 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = dt1;
#line 644 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = gxml_dom_document_type_get_system_id ((GXmlDomDocumentType*) _tmp17_);
#line 644 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = _tmp18_;
#line 644 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp19_ == NULL, "dt1.system_id == null");
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = d;
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = dt1;
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp20_, (GXmlDomNode*) _tmp21_, &_inner_error_);
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = _tmp22_;
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp23_);
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 645 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8157 "GomDocumentTest.c"
			goto __catch245_g_error;
		}
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = d;
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp24_);
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = _tmp25_;
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_list_get_length (_tmp27_);
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp29_ == 1, "d.child_nodes.length == 1");
#line 646 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp27_);
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = d;
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp30_, "svg", &_inner_error_);
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		r = _tmp31_;
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 647 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8188 "GomDocumentTest.c"
			goto __catch245_g_error;
		}
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = d;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = r;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp32_, (GXmlDomNode*) _tmp33_, &_inner_error_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = _tmp34_;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp35_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8209 "GomDocumentTest.c"
			goto __catch245_g_error;
		}
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = d;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp36_);
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = _tmp37_;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp40_ = gxml_dom_node_list_get_length (_tmp39_);
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp41_ = _tmp40_;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp41_ == 2, "d.child_nodes.length == 2");
#line 649 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp39_);
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp43_ = d;
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp44_ = gxml_gom_document_write_string (_tmp43_, &_inner_error_);
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp42_ = _tmp44_;
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8242 "GomDocumentTest.c"
			goto __catch245_g_error;
		}
#line 650 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:650: %s", _tmp42_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp46_ = d;
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp47_ = gxml_gom_document_write_string (_tmp46_, &_inner_error_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp45_ = _tmp47_;
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp42_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (r);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (dt1);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8263 "GomDocumentTest.c"
			goto __catch245_g_error;
		}
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp48_ = string_contains (_tmp45_, "<!DOCTYPE svg>");
#line 651 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp48_, "\"<!DOCTYPE svg>\" in d.write_string ()");
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp45_);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp42_);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (r);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8280 "GomDocumentTest.c"
	}
	goto __finally245;
	__catch245_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp49_ = e->message;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp51_ = _tmp50_;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:653: %s", _tmp51_);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp51_);
#line 654 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8307 "GomDocumentTest.c"
	}
	__finally245:
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 8318 "GomDocumentTest.c"
	}
}


static void ___lambda236__gtest_func (void) {
#line 634 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda236_ ();
#line 8326 "GomDocumentTest.c"
}


static void __lambda237_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		gint _tmp9_ = 0;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlGomDocument* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomDocumentType* _tmp24_ = NULL;
		GXmlDomDocumentType* _tmp25_ = NULL;
		GXmlDomNodeNodeType _tmp26_ = 0;
		GXmlDomNodeNodeType _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
#line 659 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\" \"http://www.w3.org/G" \
"raphics/SVG/1.1/DTD/svg11.dtd\"><svg/>", &_inner_error_);
#line 659 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 659 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8378 "GomDocumentTest.c"
			goto __catch246_g_error;
		}
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = d;
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_gom_document_write_string (_tmp2_, &_inner_error_);
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8391 "GomDocumentTest.c"
			goto __catch246_g_error;
		}
#line 660 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:660: %s", _tmp1_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = d;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:661: %s", _tmp11_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = d;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 662 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = d;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 8452 "GomDocumentTest.c"
		}
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 663 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 665 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 666 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 666 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 666 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 667 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 667 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 667 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 667 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 667 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 668 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 668 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 668 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 669 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 669 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 670 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 670 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8504 "GomDocumentTest.c"
	}
	goto __finally246;
	__catch246_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 672 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:672: %s", _tmp39_);
#line 672 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8531 "GomDocumentTest.c"
	}
	__finally246:
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 8542 "GomDocumentTest.c"
	}
}


static void ___lambda237__gtest_func (void) {
#line 657 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda237_ ();
#line 8550 "GomDocumentTest.c"
}


static void __lambda238_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		gint _tmp9_ = 0;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlGomDocument* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomDocumentType* _tmp24_ = NULL;
		GXmlDomDocumentType* _tmp25_ = NULL;
		GXmlDomNodeNodeType _tmp26_ = 0;
		GXmlDomNodeNodeType _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n" \
"<!DOCTYPE     svg     PUBLIC     \"-//W3C//DTD SVG 1.1//EN\"     \"htt" \
"p://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"    ><svg/>", &_inner_error_);
#line 678 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8602 "GomDocumentTest.c"
			goto __catch247_g_error;
		}
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = d;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_gom_document_write_string (_tmp2_, &_inner_error_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8615 "GomDocumentTest.c"
			goto __catch247_g_error;
		}
#line 679 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:679: %s", _tmp1_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = d;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:680: %s", _tmp11_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = d;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 681 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = d;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 8676 "GomDocumentTest.c"
		}
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 684 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 685 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 685 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 686 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 686 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 686 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 688 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "-//W3C//DTD SVG 1.1//EN") == 0, "dt1.public_id == \"-//W3C//DTD SVG 1.1//EN\"");
#line 689 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 689 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 689 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp36_, "http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd") == 0, "dt1.system_id == \"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\"");
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8728 "GomDocumentTest.c"
	}
	goto __finally247;
	__catch247_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 691 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 691 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 691 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 691 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:691: %s", _tmp39_);
#line 691 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 692 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8755 "GomDocumentTest.c"
	}
	__finally247:
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 8766 "GomDocumentTest.c"
	}
}


static void ___lambda238__gtest_func (void) {
#line 676 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda238_ ();
#line 8774 "GomDocumentTest.c"
}


static void __lambda239_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GXmlGomDocument* _tmp4_ = NULL;
		GXmlDomNodeList* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		gint _tmp8_ = 0;
		gint _tmp9_ = 0;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GXmlGomDocument* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		gint _tmp16_ = 0;
		gint _tmp17_ = 0;
		GXmlDomDocumentType* dt1 = NULL;
		GXmlGomDocument* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomDocumentType* _tmp24_ = NULL;
		GXmlDomDocumentType* _tmp25_ = NULL;
		GXmlDomNodeNodeType _tmp26_ = 0;
		GXmlDomNodeNodeType _tmp27_ = 0;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		const gchar* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		const gchar* _tmp34_ = NULL;
		const gchar* _tmp35_ = NULL;
		const gchar* _tmp36_ = NULL;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<?xml version=\"1.0\"?>\n<!DOCTYPE     svg     ><svg/>", &_inner_error_);
#line 697 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp0_;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 8826 "GomDocumentTest.c"
			goto __catch248_g_error;
		}
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = d;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = gxml_gom_document_write_string (_tmp2_, &_inner_error_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = _tmp3_;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 8839 "GomDocumentTest.c"
			goto __catch248_g_error;
		}
#line 698 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:698: %s", _tmp1_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = d;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp4_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = _tmp5_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = _tmp6_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = gxml_dom_node_list_get_length (_tmp7_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = _tmp8_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = g_strdup_printf ("%i", _tmp9_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:699: %s", _tmp11_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp7_);
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp12_ = d;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp14_ = _tmp13_;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp15_ = _tmp14_;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp16_ = gxml_dom_node_list_get_length (_tmp15_);
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp17_ = _tmp16_;
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp17_ == 2, "d.child_nodes.length == 2");
#line 700 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp15_);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp18_ = d;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp20_ = _tmp19_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp21_ = _tmp20_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp24_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_DOCUMENT_TYPE) ? ((GXmlDomDocumentType*) _tmp23_) : NULL;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (_tmp24_ == NULL) {
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp23_);
#line 8900 "GomDocumentTest.c"
		}
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp25_ = _tmp24_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp21_);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		dt1 = _tmp25_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (dt1 != NULL, "dt1 != null");
#line 703 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (dt1, GXML_TYPE_DOM_DOCUMENT_TYPE), "dt1 is DomDocumentType");
#line 704 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp26_ = gxml_dom_node_get_node_type ((GXmlDomNode*) dt1);
#line 704 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp27_ = _tmp26_;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp27_ == GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE, "dt1.node_type == DomNode.NodeType.DOCUMENT_TYPE_NODE");
#line 705 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp28_ = gxml_dom_node_get_node_name ((GXmlDomNode*) dt1);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp29_ = _tmp28_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp30_ = _tmp29_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "!DOCTYPE") == 0, "dt1.node_name == \"!DOCTYPE\"");
#line 705 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp30_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp31_ = gxml_dom_document_type_get_name (dt1);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp32_ = _tmp31_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "svg") == 0, "dt1.name == \"svg\"");
#line 707 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp33_ = gxml_dom_document_type_get_public_id (dt1);
#line 707 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp34_ = _tmp33_;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp34_ == NULL, "dt1.public_id == null");
#line 708 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp35_ = gxml_dom_document_type_get_system_id (dt1);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp36_ = _tmp35_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp36_ == NULL, "dt1.system_id == null");
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (dt1);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp1_);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 8952 "GomDocumentTest.c"
	}
	goto __finally248;
	__catch248_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp37_ = e->message;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp38_ = g_strconcat ("Error: ", _tmp37_, NULL);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp39_ = _tmp38_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:710: %s", _tmp39_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp39_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 8979 "GomDocumentTest.c"
	}
	__finally248:
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 8990 "GomDocumentTest.c"
	}
}


static void ___lambda239__gtest_func (void) {
#line 695 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda239_ ();
#line 8998 "GomDocumentTest.c"
}


static void __lambda240_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomDocument* d = NULL;
		GXmlDomDocument* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		GXmlDomDocument* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GXmlDomElement* e = NULL;
		GXmlDomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
#line 716 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<root><child id=\"id1\"/><child id=\"id2\"/></root>", &_inner_error_);
#line 716 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp0_ = _tmp1_;
#line 716 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 9022 "GomDocumentTest.c"
			goto __catch249_g_error;
		}
#line 716 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_DOM_DOCUMENT) ? ((GXmlDomDocument*) _tmp0_) : NULL);
#line 716 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		d = _tmp2_;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp4_ = d;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp5_ = gxml_gom_document_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_GOM_DOCUMENT) ? ((GXmlGomDocument*) _tmp4_) : NULL, &_inner_error_);
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp3_ = _tmp5_;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 9041 "GomDocumentTest.c"
			goto __catch249_g_error;
		}
#line 717 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:717: %s", _tmp3_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp6_ = d;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp7_ = gxml_dom_non_element_parent_node_get_element_by_id ((GXmlDomNonElementParentNode*) _tmp6_, "id1", &_inner_error_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _tmp7_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_free0 (_tmp3_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (d);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
			_g_object_unref0 (_tmp0_);
#line 9060 "GomDocumentTest.c"
			goto __catch249_g_error;
		}
#line 719 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp8_ = e;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_vala_assert (_tmp8_ != NULL, "e != null");
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (e);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp3_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (d);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_object_unref0 (_tmp0_);
#line 9075 "GomDocumentTest.c"
	}
	goto __finally249;
	__catch249_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		e = _inner_error_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_inner_error_ = NULL;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp9_ = e->message;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp10_ = g_strconcat ("Error: ", _tmp9_, NULL);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_tmp11_ = _tmp10_;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_message ("GomDocumentTest.vala:721: %s", _tmp11_);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_free0 (_tmp11_);
#line 722 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_assert_not_reached ();
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		_g_error_free0 (e);
#line 9102 "GomDocumentTest.c"
	}
	__finally249:
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		g_clear_error (&_inner_error_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
		return;
#line 9113 "GomDocumentTest.c"
	}
}


static void ___lambda240__gtest_func (void) {
#line 714 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	__lambda240_ ();
#line 9121 "GomDocumentTest.c"
}


void gom_document_test_add_tests (void) {
#line 27 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_api", ___lambda206__gtest_func);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_path_error", ___lambda207__gtest_func);
#line 62 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_stream", ___lambda208__gtest_func);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/local", ___lambda209__gtest_func);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/read-gfile/local", ___lambda210__gtest_func);
#line 121 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/remote/read", ___lambda211__gtest_func);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/gfile/remote/write", ___lambda212__gtest_func);
#line 179 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/write", ___lambda213__gtest_func);
#line 198 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_stream_error", ___lambda214__gtest_func);
#line 210 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string", ___lambda215__gtest_func);
#line 227 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/read_from_string", ___lambda216__gtest_func);
#line 245 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string_no_document_element", ___lambda217__gtest_func);
#line 255 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/construct_from_string_invalid", ___lambda218__gtest_func);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/save", ___lambda219__gtest_func);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/save_error", ___lambda220__gtest_func);
#line 289 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_element", ___lambda221__gtest_func);
#line 302 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_text_node", ___lambda222__gtest_func);
#line 313 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/node_text_content", ___lambda223__gtest_func);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_comment", ___lambda224__gtest_func);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_processing_instruction", ___lambda225__gtest_func);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/create_attribute", ___lambda226__gtest_func);
#line 367 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/to_string/basic", ___lambda227__gtest_func);
#line 386 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/to_string/extended", ___lambda228__gtest_func);
#line 413 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/create", ___lambda229__gtest_func);
#line 463 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/read", ___lambda230__gtest_func);
#line 482 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/namespace/invalid", ___lambda231__gtest_func);
#line 529 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/parent", ___lambda232__gtest_func);
#line 533 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/write/string", ___lambda233__gtest_func);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/css-selector", ___lambda234__gtest_func);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/write/full", ___lambda235__gtest_func);
#line 634 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/write/no-ids", ___lambda236__gtest_func);
#line 657 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/full", ___lambda237__gtest_func);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/spaces", ___lambda238__gtest_func);
#line 695 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/doc-type/read/no-ids", ___lambda239__gtest_func);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	g_test_add_func ("/gxml/gom-document/element-id", ___lambda240__gtest_func);
#line 9196 "GomDocumentTest.c"
}


GomDocumentTest* gom_document_test_construct (GType object_type) {
	GomDocumentTest* self = NULL;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	self = (GomDocumentTest*) gxml_test_construct (object_type);
#line 25 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	return self;
#line 9206 "GomDocumentTest.c"
}


GomDocumentTest* gom_document_test_new (void) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	return gom_document_test_construct (TYPE_GOM_DOCUMENT_TEST);
#line 9213 "GomDocumentTest.c"
}


static void gom_document_test_class_init (GomDocumentTestClass * klass) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomDocumentTest.vala"
	gom_document_test_parent_class = g_type_class_peek_parent (klass);
#line 9220 "GomDocumentTest.c"
}


static void gom_document_test_instance_init (GomDocumentTest * self) {
}


GType gom_document_test_get_type (void) {
	static volatile gsize gom_document_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_document_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_document_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomDocumentTest), 0, (GInstanceInitFunc) gom_document_test_instance_init, NULL };
		GType gom_document_test_type_id;
		gom_document_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_document_test_type_id__volatile, gom_document_test_type_id);
	}
	return gom_document_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



