/* GomElementTest.c generated by valac 0.34.13, the Vala compiler
 * generated from GomElementTest.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: t; c-basic-offset: 2; tab-width: 2 -*- */
/* Notation.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>


#define TYPE_NO_INSTANTIATABLE (no_instantiatable_get_type ())
#define NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatable))
#define IS_NO_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NO_INSTANTIATABLE))
#define NO_INSTANTIATABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_NO_INSTANTIATABLE, NoInstantiatableIface))

typedef struct _NoInstantiatable NoInstantiatable;
typedef struct _NoInstantiatableIface NoInstantiatableIface;

#define TYPE_PROPERTY (property_get_type ())
#define PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PROPERTY, Property))
#define IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PROPERTY))
#define PROPERTY_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_PROPERTY, PropertyIface))

typedef struct _Property Property;
typedef struct _PropertyIface PropertyIface;

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_GOM_ELEMENT_TEST (gom_element_test_get_type ())
#define GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTest))
#define GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))
#define IS_GOM_ELEMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GOM_ELEMENT_TEST))
#define IS_GOM_ELEMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GOM_ELEMENT_TEST))
#define GOM_ELEMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GOM_ELEMENT_TEST, GomElementTestClass))

typedef struct _GomElementTest GomElementTest;
typedef struct _GomElementTestClass GomElementTestClass;
typedef struct _GomElementTestPrivate GomElementTestPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GOM_ELEMENT_TEST_TYPE_POTION (gom_element_test_potion_get_type ())
#define GOM_ELEMENT_TEST_POTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion))
#define GOM_ELEMENT_TEST_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))
#define GOM_ELEMENT_TEST_IS_POTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_IS_POTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_POTION))
#define GOM_ELEMENT_TEST_POTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionClass))

typedef struct _GomElementTestPotion GomElementTestPotion;
typedef struct _GomElementTestPotionClass GomElementTestPotionClass;

#define GOM_ELEMENT_TEST_TYPE_INGREDIENT (gom_element_test_ingredient_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient))
#define GOM_ELEMENT_TEST_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))
#define GOM_ELEMENT_TEST_IS_INGREDIENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_IS_INGREDIENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INGREDIENT))
#define GOM_ELEMENT_TEST_INGREDIENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientClass))

typedef struct _GomElementTestIngredient GomElementTestIngredient;
typedef struct _GomElementTestIngredientClass GomElementTestIngredientClass;

#define GOM_ELEMENT_TEST_METHOD_TYPE_MAP (gom_element_test_method_map_get_type ())
#define GOM_ELEMENT_TEST_METHOD_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap))
#define GOM_ELEMENT_TEST_METHOD_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_METHOD_TYPE_MAP))
#define GOM_ELEMENT_TEST_METHOD_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMapClass))

typedef struct _GomElementTestMethodMap GomElementTestMethodMap;
typedef struct _GomElementTestMethodMapClass GomElementTestMethodMapClass;

#define GOM_ELEMENT_TEST_TYPE_METHOD (gom_element_test_method_get_type ())
#define GOM_ELEMENT_TEST_METHOD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod))
#define GOM_ELEMENT_TEST_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))
#define GOM_ELEMENT_TEST_IS_METHOD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_IS_METHOD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_METHOD))
#define GOM_ELEMENT_TEST_METHOD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodClass))

typedef struct _GomElementTestMethod GomElementTestMethod;
typedef struct _GomElementTestMethodClass GomElementTestMethodClass;

#define GOM_ELEMENT_TEST_TYPE_REPOSITORY (gom_element_test_repository_get_type ())
#define GOM_ELEMENT_TEST_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository))
#define GOM_ELEMENT_TEST_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))
#define GOM_ELEMENT_TEST_IS_REPOSITORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_IS_REPOSITORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_REPOSITORY))
#define GOM_ELEMENT_TEST_REPOSITORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryClass))

typedef struct _GomElementTestRepository GomElementTestRepository;
typedef struct _GomElementTestRepositoryClass GomElementTestRepositoryClass;

#define GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED (gom_element_test_parsed_delayed_get_type ())
#define GOM_ELEMENT_TEST_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_IS_PARSED_DELAYED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED))
#define GOM_ELEMENT_TEST_PARSED_DELAYED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayedClass))

typedef struct _GomElementTestParsedDelayed GomElementTestParsedDelayed;
typedef struct _GomElementTestParsedDelayedClass GomElementTestParsedDelayedClass;

#define GOM_ELEMENT_TEST_TYPE_TOP (gom_element_test_top_get_type ())
#define GOM_ELEMENT_TEST_TOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop))
#define GOM_ELEMENT_TEST_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))
#define GOM_ELEMENT_TEST_IS_TOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_IS_TOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TOP))
#define GOM_ELEMENT_TEST_TOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopClass))

typedef struct _GomElementTestTop GomElementTestTop;
typedef struct _GomElementTestTopClass GomElementTestTopClass;

#define GOM_ELEMENT_TEST_TYPE_GTOP (gom_element_test_gtop_get_type ())
#define GOM_ELEMENT_TEST_GTOP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop))
#define GOM_ELEMENT_TEST_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))
#define GOM_ELEMENT_TEST_IS_GTOP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_IS_GTOP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GTOP))
#define GOM_ELEMENT_TEST_GTOP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopClass))

typedef struct _GomElementTestGTop GomElementTestGTop;
typedef struct _GomElementTestGTopClass GomElementTestGTopClass;
typedef struct _GomElementTestParsedDelayedPrivate GomElementTestParsedDelayedPrivate;

#define GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE (gom_element_test_instantiatable_get_type ())
#define GOM_ELEMENT_TEST_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_IS_INSTANTIATABLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE))
#define GOM_ELEMENT_TEST_INSTANTIATABLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatableClass))

typedef struct _GomElementTestInstantiatable GomElementTestInstantiatable;
typedef struct _GomElementTestInstantiatableClass GomElementTestInstantiatableClass;
typedef struct _GomElementTestInstantiatablePrivate GomElementTestInstantiatablePrivate;
typedef struct _GomElementTestTopPrivate GomElementTestTopPrivate;

#define GOM_ELEMENT_TEST_TYPE_GPROPERTY (gom_element_test_gproperty_get_type ())
#define GOM_ELEMENT_TEST_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGProperty))
#define GOM_ELEMENT_TEST_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))
#define GOM_ELEMENT_TEST_IS_GPROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_IS_GPROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_GPROPERTY))
#define GOM_ELEMENT_TEST_GPROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_GPROPERTY, GomElementTestGPropertyClass))

typedef struct _GomElementTestGProperty GomElementTestGProperty;
typedef struct _GomElementTestGPropertyClass GomElementTestGPropertyClass;
typedef struct _GomElementTestGPropertyPrivate GomElementTestGPropertyPrivate;
typedef struct _GomElementTestGTopPrivate GomElementTestGTopPrivate;
typedef struct _GomElementTestPotionPrivate GomElementTestPotionPrivate;
typedef struct _GomElementTestIngredientPrivate GomElementTestIngredientPrivate;

#define GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP (gom_element_test_ingredient_map_get_type ())
#define GOM_ELEMENT_TEST_INGREDIENT_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP))
#define GOM_ELEMENT_TEST_INGREDIENT_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMapClass))

typedef struct _GomElementTestIngredientMap GomElementTestIngredientMap;
typedef struct _GomElementTestIngredientMapClass GomElementTestIngredientMapClass;
typedef struct _GomElementTestIngredientMapPrivate GomElementTestIngredientMapPrivate;
typedef struct _GomElementTestMethodPrivate GomElementTestMethodPrivate;
typedef struct _GomElementTestMethodMapPrivate GomElementTestMethodMapPrivate;
typedef struct _GomElementTestRepositoryPrivate GomElementTestRepositoryPrivate;

#define GOM_ELEMENT_TEST_TYPE_NAMESPACE (gom_element_test_namespace_get_type ())
#define GOM_ELEMENT_TEST_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace))
#define GOM_ELEMENT_TEST_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))
#define GOM_ELEMENT_TEST_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_IS_NAMESPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_NAMESPACE))
#define GOM_ELEMENT_TEST_NAMESPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespaceClass))

typedef struct _GomElementTestNamespace GomElementTestNamespace;
typedef struct _GomElementTestNamespaceClass GomElementTestNamespaceClass;
typedef struct _GomElementTestNamespacePrivate GomElementTestNamespacePrivate;

#define GOM_ELEMENT_TEST_TCLASS_TYPE_MAP (gom_element_test_tclass_map_get_type ())
#define GOM_ELEMENT_TEST_TCLASS_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap))
#define GOM_ELEMENT_TEST_TCLASS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP))
#define GOM_ELEMENT_TEST_TCLASS_MAP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMapClass))

typedef struct _GomElementTestTClassMap GomElementTestTClassMap;
typedef struct _GomElementTestTClassMapClass GomElementTestTClassMapClass;

#define GOM_ELEMENT_TEST_TYPE_TCLASS (gom_element_test_tclass_get_type ())
#define GOM_ELEMENT_TEST_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass))
#define GOM_ELEMENT_TEST_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))
#define GOM_ELEMENT_TEST_IS_TCLASS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_IS_TCLASS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GOM_ELEMENT_TEST_TYPE_TCLASS))
#define GOM_ELEMENT_TEST_TCLASS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassClass))

typedef struct _GomElementTestTClass GomElementTestTClass;
typedef struct _GomElementTestTClassClass GomElementTestTClassClass;
typedef struct _GomElementTestTClassPrivate GomElementTestTClassPrivate;
typedef struct _GomElementTestTClassMapPrivate GomElementTestTClassMapPrivate;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _NoInstantiatableIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (NoInstantiatable* self);
	void (*set_name) (NoInstantiatable* self, const gchar* value);
};

struct _PropertyIface {
	GTypeInterface parent_iface;
};

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _GomElementTest {
	GXmlTest parent_instance;
	GomElementTestPrivate * priv;
};

struct _GomElementTestClass {
	GXmlTestClass parent_class;
};

struct _GomElementTestParsedDelayed {
	GXmlGomElement parent_instance;
	GomElementTestParsedDelayedPrivate * priv;
};

struct _GomElementTestParsedDelayedClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatable {
	GXmlGomElement parent_instance;
	GomElementTestInstantiatablePrivate * priv;
};

struct _GomElementTestInstantiatableClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestInstantiatablePrivate {
	gchar* _name;
};

struct _GomElementTestTop {
	GXmlGomElement parent_instance;
	GomElementTestTopPrivate * priv;
};

struct _GomElementTestTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTopPrivate {
	GomElementTestInstantiatable* _inst_i;
	Property* _pq;
};

struct _GomElementTestGProperty {
	GXmlGomString parent_instance;
	GomElementTestGPropertyPrivate * priv;
};

struct _GomElementTestGPropertyClass {
	GXmlGomStringClass parent_class;
};

struct _GomElementTestGTop {
	GXmlGomElement parent_instance;
	GomElementTestGTopPrivate * priv;
};

struct _GomElementTestGTopClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestGTopPrivate {
	NoInstantiatable* _inst;
	Property* _pq;
};

struct _GomElementTestPotion {
	GXmlGomElement parent_instance;
	GomElementTestPotionPrivate * priv;
};

struct _GomElementTestPotionClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestPotionPrivate {
	gchar* _cname;
	GomElementTestIngredient* _ingredient;
};

struct _GomElementTestIngredient {
	GXmlGomElement parent_instance;
	GomElementTestIngredientPrivate * priv;
};

struct _GomElementTestIngredientClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestIngredientPrivate {
	gchar* _cname;
	GomElementTestMethodMap* _methods;
};

struct _GomElementTestIngredientMap {
	GXmlGomHashMap parent_instance;
	GomElementTestIngredientMapPrivate * priv;
};

struct _GomElementTestIngredientMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestMethod {
	GXmlGomElement parent_instance;
	GomElementTestMethodPrivate * priv;
};

struct _GomElementTestMethodClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestMethodPrivate {
	gchar* _cname;
};

struct _GomElementTestMethodMap {
	GXmlGomHashMap parent_instance;
	GomElementTestMethodMapPrivate * priv;
};

struct _GomElementTestMethodMapClass {
	GXmlGomHashMapClass parent_class;
};

struct _GomElementTestRepository {
	GXmlGomElement parent_instance;
	GomElementTestRepositoryPrivate * priv;
};

struct _GomElementTestRepositoryClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestRepositoryPrivate {
	gchar* _version;
	GomElementTestNamespace* _ns;
};

struct _GomElementTestNamespace {
	GXmlGomElement parent_instance;
	GomElementTestNamespacePrivate * priv;
};

struct _GomElementTestNamespaceClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestNamespacePrivate {
	GomElementTestTClassMap* _classes;
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClass {
	GXmlGomElement parent_instance;
	GomElementTestTClassPrivate * priv;
};

struct _GomElementTestTClassClass {
	GXmlGomElementClass parent_class;
};

struct _GomElementTestTClassPrivate {
	gchar* _name;
	gchar* _version;
	gchar* _cprefix;
};

struct _GomElementTestTClassMap {
	GXmlGomHashMap parent_instance;
	GomElementTestTClassMapPrivate * priv;
};

struct _GomElementTestTClassMapClass {
	GXmlGomHashMapClass parent_class;
};


static gpointer gom_element_test_parent_class = NULL;
static gpointer gom_element_test_parsed_delayed_parent_class = NULL;
static gpointer gom_element_test_instantiatable_parent_class = NULL;
static NoInstantiatableIface* gom_element_test_instantiatable_no_instantiatable_parent_iface = NULL;
static gpointer gom_element_test_top_parent_class = NULL;
static gpointer gom_element_test_gproperty_parent_class = NULL;
static PropertyIface* gom_element_test_gproperty_property_parent_iface = NULL;
static gpointer gom_element_test_gtop_parent_class = NULL;
static gpointer gom_element_test_potion_parent_class = NULL;
static gpointer gom_element_test_ingredient_parent_class = NULL;
static gpointer gom_element_test_ingredient_map_parent_class = NULL;
static GXmlMappeableElementIface* gom_element_test_ingredient_gxml_mappeable_element_parent_iface = NULL;
static gpointer gom_element_test_method_parent_class = NULL;
static gpointer gom_element_test_method_map_parent_class = NULL;
static GXmlMappeableElementIface* gom_element_test_method_gxml_mappeable_element_parent_iface = NULL;
static gpointer gom_element_test_repository_parent_class = NULL;
static gpointer gom_element_test_namespace_parent_class = NULL;
static gpointer gom_element_test_tclass_parent_class = NULL;
static gpointer gom_element_test_tclass_map_parent_class = NULL;
static GXmlMappeableElementIface* gom_element_test_tclass_gxml_mappeable_element_parent_iface = NULL;

GType no_instantiatable_get_type (void) G_GNUC_CONST;
const gchar* no_instantiatable_get_name (NoInstantiatable* self);
void no_instantiatable_set_name (NoInstantiatable* self, const gchar* value);
GType property_get_type (void) G_GNUC_CONST;
gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void value_set_gxml_test (GValue* value, gpointer v_object);
void value_take_gxml_test (GValue* value, gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType gom_element_test_get_type (void) G_GNUC_CONST;
enum  {
	GOM_ELEMENT_TEST_0_PROPERTY
};
void gom_element_test_add_tests (void);
static void __lambda241_ (void);
static void ___lambda241__gtest_func (void);
static void __lambda242_ (void);
static void ___lambda242__gtest_func (void);
static void __lambda243_ (void);
static void ___lambda243__gtest_func (void);
static void __lambda244_ (void);
static void ___lambda244__gtest_func (void);
static void __lambda245_ (void);
GType gom_element_test_potion_get_type (void) G_GNUC_CONST;
GomElementTestPotion* gom_element_test_potion_new (void);
GomElementTestPotion* gom_element_test_potion_construct (GType object_type);
const gchar* gom_element_test_potion_get_cname (GomElementTestPotion* self);
GType gom_element_test_ingredient_get_type (void) G_GNUC_CONST;
GomElementTestIngredient* gom_element_test_potion_get_ingredient (GomElementTestPotion* self);
const gchar* gom_element_test_ingredient_get_cname (GomElementTestIngredient* self);
GType gom_element_test_method_map_get_type (void) G_GNUC_CONST;
GomElementTestMethodMap* gom_element_test_ingredient_get_methods (GomElementTestIngredient* self);
GType gom_element_test_method_get_type (void) G_GNUC_CONST;
const gchar* gom_element_test_method_get_cname (GomElementTestMethod* self);
static void ___lambda245__gtest_func (void);
static void __lambda246_ (void);
GType gom_element_test_repository_get_type (void) G_GNUC_CONST;
GomElementTestRepository* gom_element_test_repository_new (void);
GomElementTestRepository* gom_element_test_repository_construct (GType object_type);
static void ___lambda246__gtest_func (void);
static void __lambda247_ (void);
static void ___lambda247__gtest_func (void);
static void __lambda248_ (void);
static void ___lambda248__gtest_func (void);
static void __lambda249_ (void);
static void ___lambda249__gtest_func (void);
static void __lambda250_ (void);
static void ___lambda250__gtest_func (void);
static void __lambda251_ (void);
static void ___lambda251__gtest_func (void);
static void __lambda252_ (void);
GType gom_element_test_parsed_delayed_get_type (void) G_GNUC_CONST;
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_new (void);
GomElementTestParsedDelayed* gom_element_test_parsed_delayed_construct (GType object_type);
static void ___lambda252__gtest_func (void);
static void __lambda253_ (void);
static void ___lambda253__gtest_func (void);
static void __lambda254_ (void);
static void ___lambda254__gtest_func (void);
static void __lambda255_ (void);
static void ___lambda255__gtest_func (void);
static void __lambda256_ (void);
static void ___lambda256__gtest_func (void);
static void __lambda257_ (void);
static void ___lambda257__gtest_func (void);
static void __lambda258_ (void);
GType gom_element_test_top_get_type (void) G_GNUC_CONST;
GomElementTestTop* gom_element_test_top_new (void);
GomElementTestTop* gom_element_test_top_construct (GType object_type);
NoInstantiatable* gom_element_test_top_get_inst (GomElementTestTop* self);
static void ___lambda258__gtest_func (void);
static void __lambda259_ (void);
GType gom_element_test_gtop_get_type (void) G_GNUC_CONST;
GomElementTestGTop* gom_element_test_gtop_new (void);
GomElementTestGTop* gom_element_test_gtop_construct (GType object_type);
NoInstantiatable* gom_element_test_gtop_get_inst (GomElementTestGTop* self);
Property* gom_element_test_gtop_get_pq (GomElementTestGTop* self);
static void ___lambda259__gtest_func (void);
static void __lambda260_ (void);
static void ___lambda260__gtest_func (void);
GomElementTest* gom_element_test_new (void);
GomElementTest* gom_element_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);
enum  {
	GOM_ELEMENT_TEST_PARSED_DELAYED_0_PROPERTY
};
static GObject * gom_element_test_parsed_delayed_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_element_test_instantiatable_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_INSTANTIATABLE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatablePrivate))
enum  {
	GOM_ELEMENT_TEST_INSTANTIATABLE_0_PROPERTY,
	GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY
};
GomElementTestInstantiatable* gom_element_test_instantiatable_new (void);
GomElementTestInstantiatable* gom_element_test_instantiatable_construct (GType object_type);
static GObject * gom_element_test_instantiatable_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_instantiatable_finalize (GObject* obj);
static void _vala_gom_element_test_instantiatable_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_instantiatable_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_ELEMENT_TEST_TOP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTopPrivate))
enum  {
	GOM_ELEMENT_TEST_TOP_0_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_TOP_PQ_PROPERTY
};
GomElementTestInstantiatable* gom_element_test_top_get_inst_i (GomElementTestTop* self);
void gom_element_test_top_set_inst (GomElementTestTop* self, NoInstantiatable* value);
void gom_element_test_top_set_inst_i (GomElementTestTop* self, GomElementTestInstantiatable* value);
Property* gom_element_test_top_get_pq (GomElementTestTop* self);
void gom_element_test_top_set_pq (GomElementTestTop* self, Property* value);
static GObject * gom_element_test_top_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_top_finalize (GObject* obj);
static void _vala_gom_element_test_top_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_top_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_element_test_gproperty_get_type (void) G_GNUC_CONST;
enum  {
	GOM_ELEMENT_TEST_GPROPERTY_0_PROPERTY
};
GomElementTestGProperty* gom_element_test_gproperty_new (void);
GomElementTestGProperty* gom_element_test_gproperty_construct (GType object_type);
#define GOM_ELEMENT_TEST_GTOP_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTopPrivate))
enum  {
	GOM_ELEMENT_TEST_GTOP_0_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY,
	GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY
};
void gom_element_test_gtop_set_inst (GomElementTestGTop* self, NoInstantiatable* value);
GomElementTestInstantiatable* gom_element_test_gtop_get_inst_i (GomElementTestGTop* self);
void gom_element_test_gtop_set_inst_i (GomElementTestGTop* self, GomElementTestInstantiatable* value);
GomElementTestGProperty* gom_element_test_gtop_get_gpq (GomElementTestGTop* self);
void gom_element_test_gtop_set_gpq (GomElementTestGTop* self, GomElementTestGProperty* value);
void gom_element_test_gtop_set_pq (GomElementTestGTop* self, Property* value);
static GObject * gom_element_test_gtop_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_gtop_finalize (GObject* obj);
static void _vala_gom_element_test_gtop_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_gtop_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_ELEMENT_TEST_POTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotionPrivate))
enum  {
	GOM_ELEMENT_TEST_POTION_0_PROPERTY,
	GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY
};
void gom_element_test_potion_set_cname (GomElementTestPotion* self, const gchar* value);
void gom_element_test_potion_set_ingredient (GomElementTestPotion* self, GomElementTestIngredient* value);
static GObject * gom_element_test_potion_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_potion_finalize (GObject* obj);
static void _vala_gom_element_test_potion_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_potion_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_ELEMENT_TEST_INGREDIENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredientPrivate))
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_0_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY,
	GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY
};
static gchar* gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base);
GomElementTestIngredient* gom_element_test_ingredient_new (void);
GomElementTestIngredient* gom_element_test_ingredient_construct (GType object_type);
void gom_element_test_ingredient_set_cname (GomElementTestIngredient* self, const gchar* value);
void gom_element_test_ingredient_set_methods (GomElementTestIngredient* self, GomElementTestMethodMap* value);
static GObject * gom_element_test_ingredient_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GType gom_element_test_ingredient_map_get_type (void) G_GNUC_CONST;
enum  {
	GOM_ELEMENT_TEST_INGREDIENT_MAP_0_PROPERTY
};
GomElementTestIngredientMap* gom_element_test_ingredient_map_new (void);
GomElementTestIngredientMap* gom_element_test_ingredient_map_construct (GType object_type);
static GObject * gom_element_test_ingredient_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_ingredient_finalize (GObject* obj);
static void _vala_gom_element_test_ingredient_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_ingredient_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
#define GOM_ELEMENT_TEST_METHOD_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethodPrivate))
enum  {
	GOM_ELEMENT_TEST_METHOD_0_PROPERTY,
	GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY
};
static gchar* gom_element_test_method_real_get_map_key (GXmlMappeableElement* base);
GomElementTestMethod* gom_element_test_method_new (void);
GomElementTestMethod* gom_element_test_method_construct (GType object_type);
void gom_element_test_method_set_cname (GomElementTestMethod* self, const gchar* value);
static GObject * gom_element_test_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_ELEMENT_TEST_METHOD_MAP_0_PROPERTY
};
GomElementTestMethodMap* gom_element_test_method_map_new (void);
GomElementTestMethodMap* gom_element_test_method_map_construct (GType object_type);
static GObject * gom_element_test_method_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_method_finalize (GObject* obj);
static void _vala_gom_element_test_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_element_test_namespace_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_REPOSITORY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepositoryPrivate))
enum  {
	GOM_ELEMENT_TEST_REPOSITORY_0_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY
};
const gchar* gom_element_test_repository_get_version (GomElementTestRepository* self);
void gom_element_test_repository_set_version (GomElementTestRepository* self, const gchar* value);
GomElementTestNamespace* gom_element_test_repository_get_ns (GomElementTestRepository* self);
void gom_element_test_repository_set_ns (GomElementTestRepository* self, GomElementTestNamespace* value);
static GObject * gom_element_test_repository_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_repository_finalize (GObject* obj);
static void _vala_gom_element_test_repository_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_repository_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_element_test_tclass_map_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_NAMESPACE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespacePrivate))
enum  {
	GOM_ELEMENT_TEST_NAMESPACE_0_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY,
	GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY
};
GomElementTestNamespace* gom_element_test_namespace_new (void);
GomElementTestNamespace* gom_element_test_namespace_construct (GType object_type);
const gchar* gom_element_test_namespace_get_name (GomElementTestNamespace* self);
void gom_element_test_namespace_set_name (GomElementTestNamespace* self, const gchar* value);
const gchar* gom_element_test_namespace_get_version (GomElementTestNamespace* self);
void gom_element_test_namespace_set_version (GomElementTestNamespace* self, const gchar* value);
const gchar* gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self);
void gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self, const gchar* value);
GomElementTestTClassMap* gom_element_test_namespace_get_classes (GomElementTestNamespace* self);
void gom_element_test_namespace_set_classes (GomElementTestNamespace* self, GomElementTestTClassMap* value);
static GObject * gom_element_test_namespace_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
GomElementTestTClassMap* gom_element_test_tclass_map_new (void);
GomElementTestTClassMap* gom_element_test_tclass_map_construct (GType object_type);
static void gom_element_test_namespace_finalize (GObject* obj);
static void _vala_gom_element_test_namespace_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_namespace_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType gom_element_test_tclass_get_type (void) G_GNUC_CONST;
#define GOM_ELEMENT_TEST_TCLASS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClassPrivate))
enum  {
	GOM_ELEMENT_TEST_TCLASS_0_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY,
	GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY
};
static gchar* gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base);
const gchar* gom_element_test_tclass_get_name (GomElementTestTClass* self);
GomElementTestTClass* gom_element_test_tclass_new (void);
GomElementTestTClass* gom_element_test_tclass_construct (GType object_type);
void gom_element_test_tclass_set_name (GomElementTestTClass* self, const gchar* value);
const gchar* gom_element_test_tclass_get_version (GomElementTestTClass* self);
void gom_element_test_tclass_set_version (GomElementTestTClass* self, const gchar* value);
const gchar* gom_element_test_tclass_get_cprefix (GomElementTestTClass* self);
void gom_element_test_tclass_set_cprefix (GomElementTestTClass* self, const gchar* value);
static GObject * gom_element_test_tclass_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
enum  {
	GOM_ELEMENT_TEST_TCLASS_MAP_0_PROPERTY
};
static GObject * gom_element_test_tclass_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void gom_element_test_tclass_finalize (GObject* obj);
static void _vala_gom_element_test_tclass_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_gom_element_test_tclass_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


const gchar* no_instantiatable_get_name (NoInstantiatable* self) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return NO_INSTANTIATABLE_GET_INTERFACE (self)->get_name (self);
#line 729 "GomElementTest.c"
}


void no_instantiatable_set_name (NoInstantiatable* self, const gchar* value) {
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	NO_INSTANTIATABLE_GET_INTERFACE (self)->set_name (self, value);
#line 738 "GomElementTest.c"
}


static void no_instantiatable_base_init (NoInstantiatableIface * iface) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	static gboolean initialized = FALSE;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (!initialized) {
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		initialized = TRUE;
#line 25 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_object_interface_install_property (iface, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 751 "GomElementTest.c"
	}
}


GType no_instantiatable_get_type (void) {
	static volatile gsize no_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&no_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (NoInstantiatableIface), (GBaseInitFunc) no_instantiatable_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType no_instantiatable_type_id;
		no_instantiatable_type_id = g_type_register_static (G_TYPE_INTERFACE, "NoInstantiatable", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (no_instantiatable_type_id, GXML_TYPE_GOM_OBJECT);
		g_once_init_leave (&no_instantiatable_type_id__volatile, no_instantiatable_type_id);
	}
	return no_instantiatable_type_id__volatile;
}


static void property_base_init (PropertyIface * iface) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	static gboolean initialized = FALSE;
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (!initialized) {
#line 28 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		initialized = TRUE;
#line 777 "GomElementTest.c"
	}
}


GType property_get_type (void) {
	static volatile gsize property_type_id__volatile = 0;
	if (g_once_init_enter (&property_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PropertyIface), (GBaseInitFunc) property_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType property_type_id;
		property_type_id = g_type_register_static (G_TYPE_INTERFACE, "Property", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (property_type_id, G_TYPE_OBJECT);
		g_type_interface_add_prerequisite (property_type_id, GXML_TYPE_GOM_PROPERTY);
		g_once_init_leave (&property_type_id__volatile, property_type_id);
	}
	return property_type_id__volatile;
}


static void __lambda241_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
#line 183 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	doc = NULL;
#line 801 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlGomNode* root = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlGomNode* _tmp6_ = NULL;
		GXmlGomNode* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		gpointer _tmp15_ = NULL;
		GXmlGomNode* _tmp16_ = NULL;
		GXmlGomNode* _tmp17_ = NULL;
		GXmlGomNode* _tmp18_ = NULL;
		GXmlGomNode* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		GXmlGomNode* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		GXmlGomNode* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		GXmlGomNode* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		GXmlGomNode* _tmp35_ = NULL;
		GXmlDomNamedNodeMap* _tmp36_ = NULL;
		GXmlDomNamedNodeMap* _tmp37_ = NULL;
		GXmlDomNamedNodeMap* _tmp38_ = NULL;
		gint _tmp39_ = 0;
		gint _tmp40_ = 0;
		GXmlGomNode* _tmp41_ = NULL;
		GXmlDomNamedNodeMap* _tmp42_ = NULL;
		GXmlDomNamedNodeMap* _tmp43_ = NULL;
		GXmlDomNamedNodeMap* _tmp44_ = NULL;
		gint _tmp45_ = 0;
		gint _tmp46_ = 0;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		GXmlGomNode* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		GXmlGomNode* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		GXmlGomNode* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		GXmlGomNode* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		GXmlGomNode* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		GXmlGomNode* _tmp66_ = NULL;
		gchar* _tmp67_ = NULL;
		gchar* _tmp68_ = NULL;
		GXmlGomNode* _tmp69_ = NULL;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"><ingredient products" \
":name=\"spider\"/></magic:Potion></Potions>", &_inner_error_);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 881 "GomElementTest.c"
			goto __catch250_g_error;
		}
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = NULL;
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 185 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = doc;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 186 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = root;
#line 187 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "root != null");
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = root;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp7_);
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 188 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = root;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp11_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) _tmp14_, 0);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp15_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp14_);
#line 189 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp16_;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = node;
#line 190 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp17_ != NULL, "node != null");
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = node;
#line 191 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = node;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp19_) : NULL);
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 192 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = node;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp23_);
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp26_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 193 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp26_);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = node;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp27_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp27_) : NULL);
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp30_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 194 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = node;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 195 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = node;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gee_map_get_size ((GeeMap*) _tmp38_);
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp40_ == 2, "(node as DomElement).attributes.size == 2");
#line 196 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp38_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = node;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp41_) : NULL);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = gee_map_get_size ((GeeMap*) _tmp44_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = g_strdup_printf ("%i", _tmp46_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = g_strconcat ("Attributes: ", _tmp48_, NULL);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:197: %s", _tmp50_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 197 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp44_);
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = node;
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "xmlns:magic");
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 198 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = node;
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp54_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp54_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 199 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = node;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp57_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp57_) : NULL, "xmlns:products");
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 200 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = node;
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp60_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp60_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 201 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = node;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp63_, "http://diagonalley.co.uk/products");
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = _tmp64_;
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp65_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 202 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp65_);
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = node;
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp66_, "products");
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = _tmp67_;
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp68_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 203 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp68_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = node;
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp69_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp69_) : NULL, "http://www.w3.org/2000/xmlns", "xmlns:gxmlt", "http://org.gnome.org/GXmlTest/", &_inner_error_);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (node);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 204 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp0_);
#line 1104 "GomElementTest.c"
			goto __catch250_g_error;
		}
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1113 "GomElementTest.c"
	}
	goto __finally250;
	__catch250_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp70_ = NULL;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = e->message;
#line 206 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:206: %s", _tmp70_);
#line 207 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1132 "GomElementTest.c"
	}
	__finally250:
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 184 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1145 "GomElementTest.c"
	}
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (doc);
#line 1149 "GomElementTest.c"
}


static void ___lambda241__gtest_func (void) {
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda241_ ();
#line 1156 "GomElementTest.c"
}


static void __lambda242_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomNode* root = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomNode* _tmp4_ = NULL;
		GXmlGomNode* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		GXmlGomNode* node = NULL;
		GXmlGomNode* _tmp9_ = NULL;
		GXmlDomNodeList* _tmp10_ = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		gpointer _tmp13_ = NULL;
		GXmlGomNode* _tmp14_ = NULL;
		GXmlGomNode* _tmp15_ = NULL;
		GXmlGomNode* _tmp16_ = NULL;
		GXmlGomNode* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		GXmlGomNode* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		GXmlGomNode* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlGomNode* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		GXmlGomNode* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		GXmlGomNode* _tmp36_ = NULL;
		GXmlDomNamedNodeMap* _tmp37_ = NULL;
		GXmlDomNamedNodeMap* _tmp38_ = NULL;
		GXmlDomNamedNodeMap* _tmp39_ = NULL;
		gint _tmp40_ = 0;
		gint _tmp41_ = 0;
		GXmlGomNode* _tmp42_ = NULL;
		gchar* _tmp43_ = NULL;
		gchar* _tmp44_ = NULL;
		GXmlGomNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		GXmlGomNode* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		GXmlGomNode* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		GXmlGomNode* _tmp54_ = NULL;
		gchar* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		GXmlGomNode* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<Potions><magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xml" \
"ns:products=\"http://diagonalley.co.uk/products\"/></Potions>", &_inner_error_);
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 212 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1232 "GomElementTest.c"
			goto __catch251_g_error;
		}
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 213 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 214 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = root;
#line 214 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "root != null");
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = root;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp5_);
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp8_, "Potions") == 0, "root.node_name == \"Potions\"");
#line 215 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp8_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp9_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gee_list_get ((GeeList*) _tmp12_, 0);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomNode*) _tmp13_, GXML_TYPE_GOM_NODE, GXmlGomNode);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 216 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		node = _tmp14_;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = node;
#line 217 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp15_ != NULL, "node != null");
#line 218 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = node;
#line 218 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp16_, GXML_TYPE_DOM_ELEMENT), "node is DomElement");
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = node;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp17_) : NULL);
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "Potion") == 0, "(node as DomElement).local_name == \"Potion\"");
#line 219 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = node;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp21_);
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp24_, "magic:Potion") == 0, "node.node_name == \"magic:Potion\"");
#line 220 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp24_);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = node;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp25_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp25_) : NULL);
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 221 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = node;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp29_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp29_) : NULL);
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp32_, "magic") == 0, "(node as DomElement).prefix == \"magic\"");
#line 222 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp32_);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = node;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_gom_element_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp34_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp34_) : NULL, &_inner_error_);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp35_;
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (node);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 1345 "GomElementTest.c"
			goto __catch251_g_error;
		}
#line 232 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:232: %s", _tmp33_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = node;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = gxml_dom_element_get_attributes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp36_) : NULL);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_named_node_map_get_length (_tmp39_);
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp41_ == 2, "(node as DomElement).attributes.length == 2");
#line 233 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp39_);
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = node;
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp42_) : NULL, "xmlns:magic");
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp44_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute (\"xmlns:magic\") == \"http://hogwarts.co.uk/magic\"");
#line 234 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp44_);
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = node;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp45_) : NULL, "http://www.w3.org/2000/xmlns/", "magic");
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp47_, "http://hogwarts.co.uk/magic") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 235 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp47_);
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = node;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_element_get_attribute (G_TYPE_CHECK_INSTANCE_TYPE (_tmp48_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp48_) : NULL, "xmlns:products");
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute (\"xmlns:products\") == \"http://diagonalley.co.uk/products\"");
#line 236 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = node;
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attribute_ns (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL, "http://www.w3.org/2000/xmlns/", "products");
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp53_, "http://diagonalley.co.uk/products") == 0, "(node as DomElement).get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"products\") == \"http://diagonalley.co.uk/products\"");
#line 237 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp53_);
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = node;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp54_, "http://diagonalley.co.uk/products");
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp56_, "products") == 0, "node.lookup_prefix (\"http://diagonalley.co.uk/products\") == \"products\"");
#line 238 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp56_);
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = node;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp57_, "products");
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "http://diagonalley.co.uk/products") == 0, "node.lookup_namespace_uri (\"products\") == \"http://diagonalley.co.uk/products\"");
#line 239 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp33_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (node);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 1434 "GomElementTest.c"
	}
	goto __finally251;
	__catch251_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp60_ = NULL;
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = e->message;
#line 241 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:241: %s", _tmp60_);
#line 242 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1453 "GomElementTest.c"
	}
	__finally251:
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 211 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1464 "GomElementTest.c"
	}
}


static void ___lambda242__gtest_func (void) {
#line 210 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda242_ ();
#line 1472 "GomElementTest.c"
}


static void __lambda243_ (void) {
	GXmlDomDocument* doc = NULL;
	GError * _inner_error_ = NULL;
#line 245 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	doc = NULL;
#line 1481 "GomElementTest.c"
	{
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlDomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomNodeList* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		gint _tmp21_ = 0;
		gint _tmp22_ = 0;
		GXmlDomNode* n1 = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomNode* _tmp27_ = NULL;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNode* _tmp29_ = NULL;
		GXmlDomNode* _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		GXmlDomNode* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		GXmlDomNode* n2 = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		GXmlDomNodeList* _tmp44_ = NULL;
		GXmlDomNodeList* _tmp45_ = NULL;
		GXmlDomNodeList* _tmp46_ = NULL;
		GXmlDomNode* _tmp47_ = NULL;
		GXmlDomNode* _tmp48_ = NULL;
		GXmlDomNode* _tmp49_ = NULL;
		GXmlDomNode* _tmp50_ = NULL;
		GXmlDomNode* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		gchar* _tmp53_ = NULL;
		gchar* _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
		gchar* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GXmlDomNode* _tmp59_ = NULL;
		gchar* _tmp60_ = NULL;
		gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string ("<magic:Potion xmlns:magic=\"http://hogwarts.co.uk/magic\" xmlns:produc" \
"ts=\"http://hogwarts.co.uk/magic\"><magic:Arc/><products:Diamond/></ma" \
"gic:Potion>", &_inner_error_);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = _tmp1_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1555 "GomElementTest.c"
			goto __catch252_g_error;
		}
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp0_;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = NULL;
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 247 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = (GXmlDomDocument*) _tmp2_;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = doc;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element (_tmp3_);
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 248 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp5_;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = r;
#line 249 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp6_ != NULL, "r != null");
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = r;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_element_get_local_name (_tmp7_);
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp10_, "Potion") == 0, "r.local_name == \"Potion\"");
#line 250 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = r;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_element_get_attribute_ns (_tmp11_, "http://www.w3.org/2000/xmlns/", "magic");
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp13_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"magic\") == \"http://hogwarts.co.uk/magic\"");
#line 251 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp13_);
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = r;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_element_get_attribute_ns (_tmp14_, "http://www.w3.org/2000/xmlns/", "products");
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp16_, "http://hogwarts.co.uk/magic") == 0, "r.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\", \"products\") == \"http://hogwarts.co.uk/magic\"");
#line 252 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = r;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp17_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_node_list_get_length (_tmp20_);
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp22_ == 2, "r.child_nodes.length == 2");
#line 253 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = r;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_list_item (_tmp26_, 0);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 254 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n1 = _tmp28_;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = n1;
#line 255 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp29_ != NULL, "n1 != null");
#line 256 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = n1;
#line 256 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_ELEMENT), "n1 is DomElement");
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = n1;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp31_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp31_) : NULL);
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp34_, "Arc") == 0, "(n1 as DomElement).local_name == \"Arc\"");
#line 257 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp34_);
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = n1;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp35_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp35_) : NULL);
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp38_, "magic") == 0, "(n1 as DomElement).prefix == \"magic\"");
#line 258 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp38_);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = n1;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp39_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp39_) : NULL);
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "http://hogwarts.co.uk/magic") == 0, "(n1 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 259 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp42_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = r;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp43_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = gxml_dom_node_list_item (_tmp46_, 1);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 260 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp48_;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = n2;
#line 261 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 262 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = n2;
#line 262 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_DOM_ELEMENT), "n2 is DomElement");
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = n2;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_local_name (G_TYPE_CHECK_INSTANCE_TYPE (_tmp51_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp51_) : NULL);
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp54_, "Diamond") == 0, "(n2 as DomElement).local_name == \"Diamond\"");
#line 263 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp54_);
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = n2;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = gxml_dom_element_get_prefix (G_TYPE_CHECK_INSTANCE_TYPE (_tmp55_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp55_) : NULL);
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = _tmp56_;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "products") == 0, "(n2 as DomElement).prefix == \"products\"");
#line 264 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = n2;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_element_get_namespace_uri (G_TYPE_CHECK_INSTANCE_TYPE (_tmp59_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp59_) : NULL);
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp62_, "http://hogwarts.co.uk/magic") == 0, "(n2 as DomElement).namespace_uri == \"http://hogwarts.co.uk/magic\"");
#line 265 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp62_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n1);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp0_);
#line 1754 "GomElementTest.c"
	}
	goto __finally252;
	__catch252_g_error:
	{
		GError* e = NULL;
		GError* _tmp63_ = NULL;
		const gchar* _tmp64_ = NULL;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = e;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_->message;
#line 267 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:267: %s", _tmp64_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 1774 "GomElementTest.c"
	}
	__finally252:
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 246 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 1787 "GomElementTest.c"
	}
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (doc);
#line 1791 "GomElementTest.c"
}


static void ___lambda243__gtest_func (void) {
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda243_ ();
#line 1798 "GomElementTest.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self ? g_object_ref (self) : NULL;
#line 1805 "GomElementTest.c"
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1384 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp0_ = needle;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	result = _tmp1_ != NULL;
#line 1385 "/usr/share/vala-0.34/vapi/glib-2.0.vapi"
	return result;
#line 1825 "GomElementTest.c"
}


static void __lambda244_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlGomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlGomElement* elem = NULL;
		GXmlGomElement* _tmp8_ = NULL;
		GXmlGomDocument* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		GXmlDomNodeList* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlGomElement* _tmp16_ = NULL;
		GXmlGomElement* _tmp17_ = NULL;
		GXmlDomNamedNodeMap* _tmp18_ = NULL;
		GXmlDomNamedNodeMap* _tmp19_ = NULL;
		GXmlDomNamedNodeMap* _tmp20_ = NULL;
		GXmlGomElement* _tmp21_ = NULL;
		GXmlDomNamedNodeMap* _tmp22_ = NULL;
		GXmlDomNamedNodeMap* _tmp23_ = NULL;
		GXmlDomNamedNodeMap* _tmp24_ = NULL;
		gint _tmp25_ = 0;
		gint _tmp26_ = 0;
		GXmlGomElement* _tmp27_ = NULL;
		GXmlGomElement* _tmp28_ = NULL;
		GXmlGomElement* _tmp29_ = NULL;
		GXmlDomNamedNodeMap* _tmp30_ = NULL;
		GXmlDomNamedNodeMap* _tmp31_ = NULL;
		GXmlDomNamedNodeMap* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gint _tmp34_ = 0;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp35_ = NULL;
		GXmlXParser* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		GXmlXParser* _tmp38_ = NULL;
		gchar* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		GXmlGomElement* _tmp42_ = NULL;
		GXmlDomNamedNodeMap* _tmp43_ = NULL;
		GXmlDomNamedNodeMap* _tmp44_ = NULL;
		GXmlDomNamedNodeMap* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		GXmlDomNode* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		GXmlGomElement* _tmp51_ = NULL;
		GXmlDomNamedNodeMap* _tmp52_ = NULL;
		GXmlDomNamedNodeMap* _tmp53_ = NULL;
		GXmlDomNamedNodeMap* _tmp54_ = NULL;
		GXmlDomNode* _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		GXmlGomElement* _tmp60_ = NULL;
		GXmlGomAttr* attr = NULL;
		GXmlGomElement* _tmp61_ = NULL;
		GXmlDomNamedNodeMap* _tmp62_ = NULL;
		GXmlDomNamedNodeMap* _tmp63_ = NULL;
		GXmlDomNamedNodeMap* _tmp64_ = NULL;
		GXmlDomNode* _tmp65_ = NULL;
		GXmlGomAttr* _tmp66_ = NULL;
		GXmlGomAttr* _tmp67_ = NULL;
		GXmlGomAttr* _tmp68_ = NULL;
		GXmlGomAttr* _tmp69_ = NULL;
		gchar* _tmp70_ = NULL;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		GXmlGomElement* _tmp73_ = NULL;
		GXmlDomNamedNodeMap* _tmp74_ = NULL;
		GXmlDomNamedNodeMap* _tmp75_ = NULL;
		GXmlDomNamedNodeMap* _tmp76_ = NULL;
		gint _tmp77_ = 0;
		gint _tmp78_ = 0;
		GXmlGomElement* _tmp79_ = NULL;
		gchar* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		GXmlGomElement* _tmp82_ = NULL;
		GXmlDomNamedNodeMap* _tmp83_ = NULL;
		GXmlDomNamedNodeMap* _tmp84_ = NULL;
		GXmlDomNamedNodeMap* _tmp85_ = NULL;
		GXmlDomNode* _tmp86_ = NULL;
		GXmlDomNode* _tmp87_ = NULL;
		GXmlGomElement* _tmp88_ = NULL;
		gchar* _tmp89_ = NULL;
		gchar* _tmp90_ = NULL;
		GXmlGomElement* _tmp91_ = NULL;
		GXmlDomNamedNodeMap* _tmp92_ = NULL;
		GXmlDomNamedNodeMap* _tmp93_ = NULL;
		GXmlDomNamedNodeMap* _tmp94_ = NULL;
		gint _tmp95_ = 0;
		gint _tmp96_ = 0;
		GXmlGomElement* _tmp97_ = NULL;
		GXmlGomElement* _tmp98_ = NULL;
		GXmlDomNamedNodeMap* _tmp99_ = NULL;
		GXmlDomNamedNodeMap* _tmp100_ = NULL;
		GXmlDomNamedNodeMap* _tmp101_ = NULL;
		gint _tmp102_ = 0;
		gint _tmp103_ = 0;
		GXmlGomElement* _tmp104_ = NULL;
		GXmlGomElement* _tmp105_ = NULL;
		GXmlDomNamedNodeMap* _tmp106_ = NULL;
		GXmlDomNamedNodeMap* _tmp107_ = NULL;
		GXmlDomNamedNodeMap* _tmp108_ = NULL;
		gint _tmp109_ = 0;
		gint _tmp110_ = 0;
		GXmlGomElement* _tmp111_ = NULL;
		GXmlGomElement* _tmp112_ = NULL;
		GXmlDomNamedNodeMap* _tmp113_ = NULL;
		GXmlDomNamedNodeMap* _tmp114_ = NULL;
		GXmlDomNamedNodeMap* _tmp115_ = NULL;
		gint _tmp116_ = 0;
		gint _tmp117_ = 0;
		GXmlGomElement* _tmp118_ = NULL;
		gchar* _tmp119_ = NULL;
		gchar* _tmp120_ = NULL;
		GXmlGomElement* _tmp121_ = NULL;
		GXmlGomElement* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		gchar* _tmp124_ = NULL;
		GXmlGomElement* _tmp125_ = NULL;
		gchar* _tmp126_ = NULL;
		gchar* _tmp127_ = NULL;
		GXmlGomElement* _tmp128_ = NULL;
		GXmlDomNamedNodeMap* _tmp129_ = NULL;
		GXmlDomNamedNodeMap* _tmp130_ = NULL;
		GXmlDomNamedNodeMap* _tmp131_ = NULL;
		gint _tmp132_ = 0;
		gint _tmp133_ = 0;
		GXmlGomElement* _tmp134_ = NULL;
		gchar* _tmp135_ = NULL;
		GXmlGomElement* _tmp136_ = NULL;
		gchar* _tmp137_ = NULL;
		gboolean _tmp138_ = FALSE;
		GXmlGomElement* _tmp139_ = NULL;
		gchar* _tmp140_ = NULL;
		gchar* _tmp141_ = NULL;
		gchar* _tmp142_ = NULL;
		GXmlGomElement* _tmp148_ = NULL;
		GXmlGomElement* _tmp149_ = NULL;
		GXmlDomNamedNodeMap* _tmp150_ = NULL;
		GXmlDomNamedNodeMap* _tmp151_ = NULL;
		GXmlDomNamedNodeMap* _tmp152_ = NULL;
		GXmlGomElement* _tmp153_ = NULL;
		GXmlDomNamedNodeMap* _tmp154_ = NULL;
		GXmlDomNamedNodeMap* _tmp155_ = NULL;
		GXmlDomNamedNodeMap* _tmp156_ = NULL;
		gint _tmp157_ = 0;
		gint _tmp158_ = 0;
		GXmlDomElement* n = NULL;
		GXmlGomDocument* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlGomElement* _tmp161_ = NULL;
		GXmlDomElement* _tmp162_ = NULL;
		GXmlDomNode* _tmp163_ = NULL;
		GXmlDomNode* _tmp164_ = NULL;
		GXmlDomElement* child = NULL;
		GXmlGomDocument* _tmp165_ = NULL;
		GXmlDomElement* _tmp166_ = NULL;
		GXmlDomElement* _tmp167_ = NULL;
		GXmlDomElement* _tmp168_ = NULL;
		GXmlDomNode* _tmp169_ = NULL;
		GXmlDomNode* _tmp170_ = NULL;
		GXmlGomElement* _tmp171_ = NULL;
		GXmlGomElement* _tmp172_ = NULL;
		gchar* _tmp173_ = NULL;
		gchar* _tmp174_ = NULL;
		GXmlDomElement* _tmp175_ = NULL;
		gchar* _tmp176_ = NULL;
		gchar* _tmp177_ = NULL;
		GXmlDomElement* _tmp178_ = NULL;
		gchar* _tmp179_ = NULL;
		gchar* _tmp180_ = NULL;
		GXmlGomElement* _tmp181_ = NULL;
		gchar* _tmp182_ = NULL;
		gchar* _tmp183_ = NULL;
		GXmlDomElement* _tmp184_ = NULL;
		gchar* _tmp185_ = NULL;
		gchar* _tmp186_ = NULL;
		GXmlDomElement* _tmp187_ = NULL;
		gchar* _tmp188_ = NULL;
		gchar* _tmp189_ = NULL;
		gchar* _tmp190_ = NULL;
		GXmlGomElement* _tmp191_ = NULL;
		gchar* _tmp192_ = NULL;
		GXmlDomElement* _tmp193_ = NULL;
		GXmlGomElement* _tmp194_ = NULL;
		gchar* _tmp195_ = NULL;
		gchar* _tmp196_ = NULL;
		GXmlGomElement* _tmp197_ = NULL;
		gchar* _tmp198_ = NULL;
		gchar* _tmp199_ = NULL;
		GXmlDomElement* _tmp200_ = NULL;
		gchar* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root />", &_inner_error_);
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 272 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2042 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 273 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = doc;
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp6_, "alphanumeric", &_inner_error_);
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp7_;
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2067 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 274 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		elem = _tmp8_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = doc;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp9_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp12_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = elem;
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp15_, (GXmlDomNode*) _tmp16_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 275 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = elem;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp17_);
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp20_ != NULL, "elem.attributes != null");
#line 276 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = elem;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = gee_map_get_size ((GeeMap*) _tmp24_);
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp26_ == 0, "elem.attributes.size == 0");
#line 277 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = elem;
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp27_, "alley", "Diagon", &_inner_error_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 278 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2136 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = elem;
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp28_, "train", "Hogwarts Express", &_inner_error_);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 279 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2151 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = elem;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp29_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gee_map_get_size ((GeeMap*) _tmp32_);
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ == 2, "elem.attributes.size == 2");
#line 280 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp32_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = doc;
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_xparser_new ((GXmlDomNode*) _tmp35_);
#line 281 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp36_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = parser;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gxml_parser_write_string ((GXmlParser*) _tmp38_, &_inner_error_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp39_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2192 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = g_strconcat ("Getting attributes value alley... Node: ", _tmp37_, NULL);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp41_);
#line 282 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp41_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = elem;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp42_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_named_node_map_get_named_item (_tmp45_, "alley");
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_node_get_node_value (_tmp47_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp50_, "Diagon") == 0, "elem.attributes.get_named_item (\"alley\").node_value == \"Diagon\"");
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp50_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 283 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = elem;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp51_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_named_node_map_get_named_item (_tmp54_, "train");
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_node_get_node_value (_tmp56_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp59_, "Hogwarts Express") == 0, "elem.attributes.get_named_item (\"train\").node_value == \"Hogwarts Express\"");
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp59_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 284 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = elem;
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp60_, "owl", "Hedwig", &_inner_error_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 286 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2271 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = elem;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp61_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = gxml_dom_named_node_map_get_named_item (_tmp64_, "owl");
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp65_, GXML_TYPE_GOM_ATTR) ? ((GXmlGomAttr*) _tmp65_) : NULL;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp66_ == NULL) {
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp65_);
#line 2290 "GomElementTest.c"
		}
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 287 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		attr = _tmp67_;
#line 288 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = attr;
#line 288 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp68_ != NULL, "attr != null");
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = attr;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = gxml_dom_node_get_node_value ((GXmlDomNode*) _tmp69_);
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = _tmp70_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp72_, "Hedwig") == 0, "attr.node_value == \"Hedwig\"");
#line 289 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = elem;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp73_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = _tmp75_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = gee_map_get_size ((GeeMap*) _tmp76_);
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp78_ == 3, "elem.attributes.size == 3");
#line 291 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp76_);
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = elem;
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp79_, "owl");
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "Hedwig") == 0, "elem.get_attribute (\"owl\") == \"Hedwig\"");
#line 292 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = elem;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp82_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = _tmp83_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = gxml_dom_named_node_map_remove_named_item (_tmp85_, "alley", &_inner_error_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp87_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp85_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 294 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2370 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = elem;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp88_, "alley");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp90_ == NULL, "elem.get_attribute (\"alley\") == null");
#line 296 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp90_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = elem;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp91_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = gee_map_get_size ((GeeMap*) _tmp94_);
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ == 2, "elem.attributes.size == 2");
#line 297 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 298 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = elem;
#line 298 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp97_, "owl");
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = elem;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp98_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = _tmp99_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = gee_map_get_size ((GeeMap*) _tmp101_);
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp103_ == 1, "elem.attributes.size == 1");
#line 299 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp101_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = elem;
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp104_, "http://www.w3.org/2000/xmlns/", "xmlns:gxml", "http://www.gnome.org/GXml", &_inner_error_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 301 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2437 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = elem;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp105_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = _tmp106_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = gee_map_get_size ((GeeMap*) _tmp108_);
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = _tmp109_;
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp110_ == 2, "elem.attributes.size == 2");
#line 303 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp108_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = elem;
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp111_, "http://www.gnome.org/GXml", "gxml:xola", "Mexico", &_inner_error_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 304 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2474 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = elem;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp112_);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = gee_map_get_size ((GeeMap*) _tmp115_);
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = _tmp116_;
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp117_ == 3, "elem.attributes.size == 3");
#line 305 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = elem;
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp118_, "http://www.gnome.org/GXml", "xola");
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp120_, "Mexico") == 0, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == \"Mexico\"");
#line 306 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp120_);
#line 307 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = elem;
#line 307 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp121_, "http://www.gnome.org/GXml", "xola");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = elem;
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp122_, "http://www.gnome.org/GXml", "xola");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp124_ == NULL, "elem.get_attribute_ns (\"http://www.gnome.org/GXml\", \"xola\") == null");
#line 308 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp124_);
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = elem;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = gxml_dom_element_get_attribute ((GXmlDomElement*) _tmp125_, "xola");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp127_ == NULL, "elem.get_attribute (\"xola\") == null");
#line 309 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp127_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = elem;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp128_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = gee_map_get_size ((GeeMap*) _tmp131_);
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = _tmp132_;
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp133_ == 2, "elem.attributes.size == 2");
#line 310 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 311 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = elem;
#line 311 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_id ((GXmlDomElement*) _tmp134_, "idnode");
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp136_ = elem;
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp137_ = gxml_gom_element_write_string (_tmp136_, &_inner_error_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = _tmp137_;
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2567 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp138_ = string_contains (_tmp135_, "id=\"idnode\"");
#line 312 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp138_, "\"id=\\\"idnode\\\"\" in elem.write_string ()");
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp139_ = elem;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = gxml_dom_element_get_id ((GXmlDomElement*) _tmp139_);
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = _tmp140_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp142_ = _tmp141_;
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp142_, "idnode") == 0, "elem.id == \"idnode\"");
#line 313 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp142_);
#line 2586 "GomElementTest.c"
		{
			GXmlGomElement* _tmp143_ = NULL;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp143_ = elem;
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp143_, "http://www.gnome.org/GXml", "gxml2:xola", "Mexico", &_inner_error_);
#line 315 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2595 "GomElementTest.c"
				goto __catch254_g_error;
			}
#line 316 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_assert_not_reached ();
#line 2600 "GomElementTest.c"
		}
		goto __finally254;
		__catch254_g_error:
		{
			GError* e = NULL;
			GError* _tmp144_ = NULL;
			const gchar* _tmp145_ = NULL;
			gchar* _tmp146_ = NULL;
			gchar* _tmp147_ = NULL;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			e = _inner_error_;
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_inner_error_ = NULL;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp144_ = e;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp145_ = _tmp144_->message;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp146_ = g_strconcat ("Correctly Cough Error:", _tmp145_, NULL);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp147_ = _tmp146_;
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_message ("GomElementTest.vala:318: %s", _tmp147_);
#line 318 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp147_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_error_free0 (e);
#line 2628 "GomElementTest.c"
		}
		__finally254:
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 314 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2647 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 320 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = elem;
#line 320 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp148_ != NULL, "elem != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = elem;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp149_);
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = _tmp150_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp152_ = _tmp151_;
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp152_ != NULL, "elem.attributes != null");
#line 321 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp153_ = elem;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp154_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp153_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp156_ = _tmp155_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp157_ = gee_map_get_size ((GeeMap*) _tmp156_);
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp158_ == 2, "elem.attributes.size == 2");
#line 322 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp156_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp159_ = doc;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp160_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp159_, "node", &_inner_error_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp160_;
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 323 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2704 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp161_ = elem;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp162_ = n;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp163_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp161_, (GXmlDomNode*) _tmp162_, &_inner_error_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp164_ = _tmp163_;
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp164_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 324 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2735 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp165_ = doc;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp166_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp165_, "child", &_inner_error_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		child = _tmp166_;
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 325 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2762 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp167_ = n;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp168_ = child;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp169_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp167_, (GXmlDomNode*) _tmp168_, &_inner_error_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp170_ = _tmp169_;
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp170_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 326 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2795 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp171_ = elem;
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp171_, "http://www.w3.org/2000/xmlns", "xmlns:xtest", "http://www.w3c.org/test", &_inner_error_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 327 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2822 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp172_ = elem;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp173_ = gxml_gom_element_lookup_prefix (_tmp172_, "http://www.w3c.org/test");
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp174_ = _tmp173_;
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp174_, "xtest") == 0, "elem.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 328 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp174_);
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp175_ = n;
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp176_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp175_, "http://www.w3c.org/test");
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp177_ = _tmp176_;
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp177_, "xtest") == 0, "n.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 329 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp177_);
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp178_ = child;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp179_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) _tmp178_, "http://www.w3c.org/test");
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp180_ = _tmp179_;
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp180_, "xtest") == 0, "child.lookup_prefix (\"http://www.w3c.org/test\") == \"xtest\"");
#line 330 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp180_);
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp181_ = elem;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp182_ = gxml_gom_element_lookup_namespace_uri (_tmp181_, "xtest");
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp183_ = _tmp182_;
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp183_, "http://www.w3c.org/test") == 0, "elem.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 331 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp183_);
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp184_ = n;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp185_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp184_, "xtest");
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp186_ = _tmp185_;
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp186_, "http://www.w3c.org/test") == 0, "n.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 332 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp186_);
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp187_ = child;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp188_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) _tmp187_, "xtest");
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp189_ = _tmp188_;
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp189_, "http://www.w3c.org/test") == 0, "child.lookup_namespace_uri (\"xtest\") == \"http://www.w3c.org/test\"");
#line 333 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp189_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp191_ = elem;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp192_ = gxml_gom_element_write_string (G_TYPE_CHECK_INSTANCE_TYPE (_tmp191_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp191_) : NULL, &_inner_error_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp190_ = _tmp192_;
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2911 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 334 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:334: %s", _tmp190_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp193_ = child;
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns (_tmp193_, "http://www.w3c.org/test", "xtest:val", "Value", &_inner_error_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp190_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (child);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp135_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (attr);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp37_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (elem);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp5_);
#line 335 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 2942 "GomElementTest.c"
			goto __catch253_g_error;
		}
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp194_ = elem;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp195_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp194_, "http://www.w3.org/2000/xmlns/", "xtest");
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp196_ = _tmp195_;
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp196_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns/\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 336 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp196_);
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp197_ = elem;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp198_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp197_, "http://www.w3.org/2000/xmlns", "xtest");
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp199_, "http://www.w3c.org/test") == 0, "elem.get_attribute_ns (\"http://www.w3.org/2000/xmlns\",\"xtest\") == \"http://www.w3c.org/test\"");
#line 337 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp199_);
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp200_ = child;
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp201_ = gxml_dom_element_get_attribute_ns (_tmp200_, "http://www.w3c.org/test", "val");
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp202_ = _tmp201_;
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp202_, "Value") == 0, "child.get_attribute_ns (\"http://www.w3c.org/test\",\"val\") == \"Value\"");
#line 338 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp202_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp190_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (child);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp135_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (attr);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp37_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (elem);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp5_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 2995 "GomElementTest.c"
	}
	goto __finally253;
	__catch253_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp203_ = NULL;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp203_ = e->message;
#line 340 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:340: %s", _tmp203_);
#line 341 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3014 "GomElementTest.c"
	}
	__finally253:
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 271 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3025 "GomElementTest.c"
	}
}


static void ___lambda244__gtest_func (void) {
#line 270 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda244_ ();
#line 3033 "GomElementTest.c"
}


static void __lambda245_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_ = NULL;
		GomElementTestPotion* p = NULL;
		GomElementTestPotion* _tmp1_ = NULL;
		GomElementTestPotion* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GomElementTestPotion* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		GomElementTestPotion* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		GomElementTestPotion* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		GomElementTestPotion* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		GomElementTestPotion* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		GomElementTestPotion* _tmp20_ = NULL;
		GomElementTestIngredient* _tmp21_ = NULL;
		GomElementTestIngredient* _tmp22_ = NULL;
		GomElementTestPotion* _tmp23_ = NULL;
		GomElementTestIngredient* _tmp24_ = NULL;
		GomElementTestIngredient* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
		GomElementTestPotion* _tmp28_ = NULL;
		GomElementTestIngredient* _tmp29_ = NULL;
		GomElementTestIngredient* _tmp30_ = NULL;
		GomElementTestMethodMap* _tmp31_ = NULL;
		GomElementTestMethodMap* _tmp32_ = NULL;
		GomElementTestPotion* _tmp33_ = NULL;
		GomElementTestIngredient* _tmp34_ = NULL;
		GomElementTestIngredient* _tmp35_ = NULL;
		GomElementTestMethodMap* _tmp36_ = NULL;
		GomElementTestMethodMap* _tmp37_ = NULL;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		GXmlDomElement* _tmp40_ = NULL;
		GomElementTestPotion* _tmp41_ = NULL;
		GomElementTestIngredient* _tmp42_ = NULL;
		GomElementTestIngredient* _tmp43_ = NULL;
		GomElementTestMethodMap* _tmp44_ = NULL;
		GomElementTestMethodMap* _tmp45_ = NULL;
		GXmlDomElement* _tmp46_ = NULL;
		GomElementTestMethod* m = NULL;
		GomElementTestMethod* _tmp47_ = NULL;
		const gchar* _tmp48_ = NULL;
		const gchar* _tmp49_ = NULL;
#line 346 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Potion xmlns:c=\"http://c.org/1.0\" c:name=\"edumor\"><ingredient c:n" \
"ame=\"spider\"><child/><method c:name=\"move\"/></ingredient></Potion>");
#line 346 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 347 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_potion_new ();
#line 347 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		p = _tmp1_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = p;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp2_);
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp5_, "Potion") == 0, "p.node_name == \"Potion\"");
#line 348 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = p;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gom_element_test_potion_get_cname (_tmp6_);
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 349 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp8_ == NULL, "p.cname == null");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = p;
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_element_get_attribute_ns ((GXmlDomElement*) _tmp9_, "http://www.w3.org/2000/xmlns", "c");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "http://c.org/1.0") == 0, "p.get_attribute_ns (\"http://www.w3.org/2000/xmlns\", \"c\") == \"http://c.org/1.0\"");
#line 350 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp11_);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = p;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = str;
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp12_, _tmp13_, &_inner_error_);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 351 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3143 "GomElementTest.c"
			goto __catch255_g_error;
		}
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = p;
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_gom_element_write_string ((GXmlGomElement*) _tmp15_, &_inner_error_);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp16_;
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3158 "GomElementTest.c"
			goto __catch255_g_error;
		}
#line 352 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:352: %s", _tmp14_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = p;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gom_element_test_potion_get_cname (_tmp17_);
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp18_;
#line 353 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp19_, "edumor") == 0, "p.cname == \"edumor\"");
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = p;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gom_element_test_potion_get_ingredient (_tmp20_);
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 354 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp22_ != NULL, "p.ingredient != null");
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = p;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gom_element_test_potion_get_ingredient (_tmp23_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gom_element_test_ingredient_get_cname (_tmp25_);
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 355 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp27_, "spider") == 0, "p.ingredient.cname == \"spider\"");
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = p;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gom_element_test_potion_get_ingredient (_tmp28_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = gom_element_test_ingredient_get_methods (_tmp30_);
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_;
#line 356 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp32_ != NULL, "p.ingredient.methods != null");
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = p;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = gom_element_test_potion_get_ingredient (_tmp33_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gom_element_test_ingredient_get_methods (_tmp35_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_gom_collection_get_length ((GXmlGomCollection*) _tmp37_);
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 357 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp39_ == 1, "p.ingredient.methods.length == 1");
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = p;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gom_element_test_potion_get_ingredient (_tmp41_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gom_element_test_ingredient_get_methods (_tmp43_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_gom_collection_get_item ((GXmlGomCollection*) _tmp45_, 0, &_inner_error_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp46_;
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp14_);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (p);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3241 "GomElementTest.c"
			goto __catch255_g_error;
		}
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GOM_ELEMENT_TEST_TYPE_METHOD) ? ((GomElementTestMethod*) _tmp40_) : NULL);
#line 358 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		m = _tmp47_;
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gom_element_test_method_get_cname (m);
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = _tmp48_;
#line 359 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp49_, "move") == 0, "m.cname == \"move\"");
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (m);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (p);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3264 "GomElementTest.c"
	}
	goto __finally255;
	__catch255_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp50_ = NULL;
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 361 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = e->message;
#line 361 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:361: %s", _tmp50_);
#line 362 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3283 "GomElementTest.c"
	}
	__finally255:
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 345 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3294 "GomElementTest.c"
	}
}


static void ___lambda245__gtest_func (void) {
#line 344 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda245_ ();
#line 3302 "GomElementTest.c"
}


static void __lambda246_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_ = NULL;
		GomElementTestRepository* r = NULL;
		GomElementTestRepository* _tmp1_ = NULL;
#line 367 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 367 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 380 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_repository_new ();
#line 380 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp1_;
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) r, str, &_inner_error_);
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 381 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3329 "GomElementTest.c"
			goto __catch256_g_error;
		}
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3336 "GomElementTest.c"
	}
	goto __finally256;
	__catch256_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp2_ = NULL;
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 383 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = e->message;
#line 383 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:383: %s", _tmp2_);
#line 384 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3355 "GomElementTest.c"
	}
	__finally256:
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 366 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3366 "GomElementTest.c"
	}
}


static void ___lambda246__gtest_func (void) {
#line 365 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda246_ ();
#line 3374 "GomElementTest.c"
}


static void __lambda247_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_ = NULL;
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
		gchar* _tmp7_ = NULL;
		GXmlDomHTMLCollection* lt = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomHTMLCollection* _tmp11_ = NULL;
		GXmlDomHTMLCollection* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GXmlDomElement* n = NULL;
		gpointer _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_ = NULL;
		gchar* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
#line 389 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<?xml version=\"1.0\"?>\n" \
"<repository version=\"1.2\" xmlns=\"http://www.gtk.org/introspection/c" \
"ore/1.0\" xmlns:c=\"http://www.gtk.org/introspection/c/1.0\" xmlns:gli" \
"b=\"http://www.gtk.org/introspection/glib/1.0\">\n" \
"<include name=\"GXml\" version=\"0.16\"/>\n" \
"<package name=\"girp-0.2\"/>\n" \
"<c:include name=\"girp.h\"/>\n" \
"<namespace name=\"Girp\" version=\"0.2\" c:prefix=\"Girp\">\n" \
"\t<attribute name=\"ccode.gir-version\" value=\"0.2\"/>\n" \
"\t<attribute name=\"ccode.cheader-filename\" value=\"girp.h\"/>\n" \
"\t<attribute name=\"ccode.gir-namespace\" value=\"Girp\"/>\n" \
"\t<class name=\"Repository\" c:type=\"GirpRepository\" glib:type-name=" \
"\"GirpRepository\" glib:get-type=\"girp_repository_get_type\" glib:typ" \
"e-struct=\"RepositoryClass\" parent=\"GXml.GomElement\">\n" \
"\t</class>\n" \
"</namespace>\n" \
"</repository>");
#line 389 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_gom_document_new_from_string (str, &_inner_error_);
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		d = _tmp1_;
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 402 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 3420 "GomElementTest.c"
			goto __catch257_g_error;
		}
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp4_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "repository") == 0, "d.document_element.node_name == \"repository\"");
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp7_);
#line 403 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) d);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_element_get_elements_by_tag_name (_tmp10_, "class");
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 404 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		lt = _tmp12_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_html_collection_get_length (lt);
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 405 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp14_ == 1, "lt.length == 1");
#line 406 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gee_list_get ((GeeList*) lt, 0);
#line 406 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = (GXmlDomElement*) _tmp15_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_node_name ((GXmlDomNode*) n);
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp18_, "class") == 0, "n.node_name == \"class\"");
#line 407 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp18_);
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) n, "c");
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp20_, "http://www.gtk.org/introspection/c/1.0") == 0, "n.lookup_namespace_uri (\"c\") == \"http://www.gtk.org/introspection/c/1.0\"");
#line 408 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp20_);
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_node_lookup_prefix ((GXmlDomNode*) n, "http://www.gtk.org/introspection/c/1.0");
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp22_, "c") == 0, "n.lookup_prefix (\"http://www.gtk.org/introspection/c/1.0\") == \"c\"");
#line 409 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp22_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (lt);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (d);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 3499 "GomElementTest.c"
	}
	goto __finally257;
	__catch257_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp23_ = NULL;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = e->message;
#line 411 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:411: %s", _tmp23_);
#line 412 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3518 "GomElementTest.c"
	}
	__finally257:
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 388 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3529 "GomElementTest.c"
	}
}


static void ___lambda247__gtest_func (void) {
#line 387 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda247_ ();
#line 3537 "GomElementTest.c"
}


static void __lambda248_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_ = NULL;
		GXmlDomText* t = NULL;
		GXmlGomDocument* _tmp19_ = NULL;
		GXmlDomText* _tmp20_ = NULL;
		GXmlGomElement* _tmp21_ = NULL;
		GXmlDomNodeList* _tmp22_ = NULL;
		GXmlDomNodeList* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomText* _tmp25_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp26_ = NULL;
		GXmlXParser* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		GXmlXParser* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		gchar* s = NULL;
		gchar** _tmp31_ = NULL;
		gchar** _tmp32_ = NULL;
		gchar** _tmp33_ = NULL;
		gint _tmp33__length1 = 0;
		const gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
#line 417 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 417 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3602 "GomElementTest.c"
			goto __catch258_g_error;
		}
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 418 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = _tmp4_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 419 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3637 "GomElementTest.c"
			goto __catch258_g_error;
		}
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 420 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp13_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 421 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = doc;
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp19_, "TEXT1", &_inner_error_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp20_;
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 422 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3676 "GomElementTest.c"
			goto __catch258_g_error;
		}
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = root;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp21_);
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = _tmp22_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = t;
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp24_, (GXmlDomNode*) _tmp25_);
#line 423 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp24_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = doc;
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_xparser_new ((GXmlDomNode*) _tmp26_);
#line 424 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp27_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = parser;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gxml_parser_write_string ((GXmlParser*) _tmp29_, &_inner_error_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp30_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3721 "GomElementTest.c"
			goto __catch258_g_error;
		}
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = _tmp31_ = g_strsplit (_tmp28_, "\n", 0);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33__length1 = _vala_array_length (_tmp31_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_[1];
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = g_strdup (_tmp34_);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = (_vala_array_free (_tmp33_, _tmp33__length1, (GDestroyNotify) g_free), NULL);
#line 425 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp36_;
#line 426 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp28_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 3760 "GomElementTest.c"
	}
	goto __finally258;
	__catch258_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp37_ = NULL;
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = e->message;
#line 428 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp37_);
#line 429 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 3779 "GomElementTest.c"
	}
	__finally258:
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 416 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 3790 "GomElementTest.c"
	}
}


static void ___lambda248__gtest_func (void) {
#line 415 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda248_ ();
#line 3798 "GomElementTest.c"
}


static void __lambda249_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlGomDocument* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* root = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlDomNodeList* _tmp6_ = NULL;
		GXmlDomNodeList* _tmp7_ = NULL;
		GXmlDomNodeList* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlGomDocument* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp13_ = NULL;
		GXmlGomElement* _tmp14_ = NULL;
		GXmlDomNodeList* _tmp15_ = NULL;
		GXmlDomNodeList* _tmp16_ = NULL;
		GXmlDomNodeList* _tmp17_ = NULL;
		GXmlGomElement* _tmp18_ = NULL;
		GXmlDomText* _tmp19_ = NULL;
		GXmlGomDocument* _tmp20_ = NULL;
		GXmlDomText* _tmp21_ = NULL;
		GXmlDomText* t = NULL;
		GXmlDomText* _tmp22_ = NULL;
		GXmlGomElement* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		GXmlDomText* _tmp27_ = NULL;
		GXmlXParser* parser = NULL;
		GXmlGomDocument* _tmp28_ = NULL;
		GXmlXParser* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
		GXmlXParser* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		gchar* s = NULL;
		gchar** _tmp33_ = NULL;
		gchar** _tmp34_ = NULL;
		gchar** _tmp35_ = NULL;
		gint _tmp35__length1 = 0;
		const gchar* _tmp36_ = NULL;
		gchar* _tmp37_ = NULL;
		gchar* _tmp38_ = NULL;
#line 434 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 434 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = doc;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp2_, "root", &_inner_error_);
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp3_;
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3865 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 435 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		root = _tmp4_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp5_);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = root;
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp8_, (GXmlDomNode*) _tmp9_);
#line 436 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = doc;
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp11_, "child", &_inner_error_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp12_;
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3900 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_GOM_ELEMENT, GXmlGomElement));
#line 437 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp13_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = root;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp14_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = n;
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp17_, (GXmlDomNode*) _tmp18_);
#line 438 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp17_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = doc;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_dom_document_create_text_node ((GXmlDomDocument*) _tmp20_, "TEXT1", &_inner_error_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp21_;
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3939 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_TEXT) ? ((GXmlDomText*) _tmp19_) : NULL);
#line 439 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp22_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = root;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp23_);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = t;
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gee_collection_add ((GeeCollection*) _tmp26_, (GXmlDomNode*) _tmp27_);
#line 440 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = doc;
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_xparser_new ((GXmlDomNode*) _tmp28_);
#line 441 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		parser = _tmp29_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = parser;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_parser_write_string ((GXmlParser*) _tmp31_, &_inner_error_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp32_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (parser);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp19_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp10_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (root);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp1_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 3990 "GomElementTest.c"
			goto __catch259_g_error;
		}
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_ = g_strsplit (_tmp30_, "\n", 0);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = _tmp34_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35__length1 = _vala_array_length (_tmp33_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_[1];
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = g_strdup (_tmp36_);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = _tmp37_;
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = (_vala_array_free (_tmp35_, _tmp35__length1, (GDestroyNotify) g_free), NULL);
#line 442 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		s = _tmp38_;
#line 443 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (s, "<root><child/>TEXT1</root>") == 0, "s == \"<root><child/>TEXT1</root>\"");
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (s);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (parser);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp19_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp10_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (root);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp1_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4031 "GomElementTest.c"
	}
	goto __finally259;
	__catch259_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp39_ = NULL;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = e->message;
#line 445 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp39_);
#line 446 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4050 "GomElementTest.c"
	}
	__finally259:
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 433 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4061 "GomElementTest.c"
	}
}


static void ___lambda249__gtest_func (void) {
#line 432 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda249_ ();
#line 4069 "GomElementTest.c"
}


static void __lambda250_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		GXmlDomNodeList* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		gpointer _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		GXmlDomNodeList* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error_);
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 451 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4132 "GomElementTest.c"
			goto __catch260_g_error;
		}
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 452 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 453 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 454 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 455 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 456 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 457 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4279 "GomElementTest.c"
	}
	goto __finally260;
	__catch260_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = e->message;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = g_strconcat ("Error: ", _tmp49_, NULL);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:459: %s", _tmp51_);
#line 459 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 460 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4306 "GomElementTest.c"
	}
	__finally260:
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 450 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4317 "GomElementTest.c"
	}
}


static void ___lambda250__gtest_func (void) {
#line 449 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda250_ ();
#line 4325 "GomElementTest.c"
}


static void __lambda251_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlGomDocument* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomNode* _tmp10_ = NULL;
		GXmlDomNode* _tmp11_ = NULL;
		GXmlGomDocument* _tmp12_ = NULL;
		GXmlDomElement* _tmp13_ = NULL;
		GXmlDomElement* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomNode* _tmp16_ = NULL;
		GXmlDomNode* _tmp17_ = NULL;
		GXmlDomNode* _tmp18_ = NULL;
		GXmlGomDocument* _tmp19_ = NULL;
		GXmlDomElement* _tmp20_ = NULL;
		GXmlDomElement* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomNodeList* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		gint _tmp26_ = 0;
		gint _tmp27_ = 0;
		GXmlGomDocument* _tmp28_ = NULL;
		GXmlDomElement* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomNodeList* _tmp32_ = NULL;
		GXmlDomNodeList* _tmp33_ = NULL;
		GXmlDomNodeList* _tmp34_ = NULL;
		gpointer _tmp35_ = NULL;
		GXmlDomNode* _tmp36_ = NULL;
		GXmlGomDocument* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomElement* _tmp39_ = NULL;
		GXmlDomElement* _tmp40_ = NULL;
		GXmlDomNodeList* _tmp41_ = NULL;
		GXmlDomNodeList* _tmp42_ = NULL;
		GXmlDomNodeList* _tmp43_ = NULL;
		gpointer _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomChildNode* _tmp46_ = NULL;
		GXmlDomChildNode* _tmp47_ = NULL;
		GXmlGomDocument* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomElement* _tmp51_ = NULL;
		GXmlDomNodeList* _tmp52_ = NULL;
		GXmlDomNodeList* _tmp53_ = NULL;
		GXmlDomNodeList* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		gint _tmp56_ = 0;
		gchar* _tmp57_ = NULL;
		GXmlGomDocument* _tmp58_ = NULL;
		gchar* _tmp59_ = NULL;
		gboolean _tmp60_ = FALSE;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root><child/></root>", &_inner_error_);
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 465 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 4400 "GomElementTest.c"
			goto __catch261_g_error;
		}
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = doc;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp1_);
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "doc.document_element != null");
#line 466 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp4_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = doc;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp5_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp8_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp11_);
#line 467 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = doc;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp12_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp15_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 468 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = doc;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp19_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp22_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_node_list_get_length (_tmp25_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp27_ == 1, "doc.document_element.child_nodes.length == 1");
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp25_);
#line 469 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp22_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = doc;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp28_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp31_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gee_list_get ((GeeList*) _tmp34_, 0);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = (GXmlDomNode*) _tmp35_;
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_DOM_CHILD_NODE), "doc.document_element.child_nodes[0] is DomChildNode");
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp36_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 470 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = doc;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp37_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp40_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = _tmp42_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gee_list_get ((GeeList*) _tmp43_, 0);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = (GXmlDomNode*) _tmp44_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp45_, GXML_TYPE_DOM_CHILD_NODE) ? ((GXmlDomChildNode*) _tmp45_) : NULL;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp46_ == NULL) {
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp45_);
#line 4529 "GomElementTest.c"
		}
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_child_node_remove (_tmp47_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp47_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp43_);
#line 471 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = doc;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) _tmp48_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gxml_dom_node_list_get_length (_tmp54_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = _tmp55_;
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp56_ == 0, "doc.document_element.child_nodes.length == 0");
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 472 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = doc;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = gxml_gom_document_write_string (_tmp58_, &_inner_error_);
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = _tmp59_;
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (doc);
#line 4575 "GomElementTest.c"
			goto __catch261_g_error;
		}
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = string_contains (_tmp57_, "<root/>");
#line 473 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp60_, "\"<root/>\" in  doc.write_string ()");
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp57_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 4586 "GomElementTest.c"
	}
	goto __finally261;
	__catch261_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp61_ = NULL;
		gchar* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = e->message;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = g_strconcat ("Error: ", _tmp61_, NULL);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:475: %s", _tmp63_);
#line 475 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp63_);
#line 476 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4613 "GomElementTest.c"
	}
	__finally261:
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 464 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4624 "GomElementTest.c"
	}
}


static void ___lambda251__gtest_func (void) {
#line 463 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda251_ ();
#line 4632 "GomElementTest.c"
}


static void __lambda252_ (void) {
	GError * _inner_error_ = NULL;
	{
		GomElementTestParsedDelayed* n = NULL;
		GomElementTestParsedDelayed* _tmp0_ = NULL;
		GomElementTestParsedDelayed* _tmp1_ = NULL;
		GomElementTestParsedDelayed* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		GomElementTestParsedDelayed* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GomElementTestParsedDelayed* _tmp8_ = NULL;
		gboolean _tmp9_ = FALSE;
		GomElementTestParsedDelayed* _tmp10_ = NULL;
		GXmlDomNodeList* _tmp11_ = NULL;
		GXmlDomNodeList* _tmp12_ = NULL;
		GXmlDomNodeList* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		GomElementTestParsedDelayed* _tmp16_ = NULL;
		GomElementTestParsedDelayed* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		GomElementTestParsedDelayed* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		GXmlDomNodeList* _tmp22_ = NULL;
		gint _tmp23_ = 0;
		gint _tmp24_ = 0;
		GomElementTestParsedDelayed* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		const gchar* _tmp27_ = NULL;
#line 481 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gom_element_test_parsed_delayed_new ();
#line 481 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) _tmp1_, "<root><child p1=\"Value1\" p2=\"Value2\"><child2/></child></root>", &_inner_error_);
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 482 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4680 "GomElementTest.c"
			goto __catch262_g_error;
		}
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp2_);
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = _tmp3_;
#line 483 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp4_ != NULL, "n.unparsed != null");
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = n;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp5_);
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 484 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "<child p1=\"Value1\" p2=\"Value2\"><child2/></child>") == 0, "n.unparsed == \"<child p1=\\\"Value1\\\" p2=\\\"Value2\\\"><child2/></child>\"");
#line 485 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = n;
#line 485 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp8_);
#line 485 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (!_tmp9_, "!n.has_child_nodes ()");
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = n;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp10_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = gxml_dom_node_list_get_length (_tmp13_);
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp15_ == 0, "n.child_nodes.length == 0");
#line 486 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp13_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = n;
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_unparsed ((GXmlGomElement*) _tmp16_, &_inner_error_);
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 487 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4729 "GomElementTest.c"
			goto __catch262_g_error;
		}
#line 488 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = n;
#line 488 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = gxml_dom_node_has_child_nodes ((GXmlDomNode*) _tmp17_);
#line 488 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp18_, "n.has_child_nodes ()");
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = n;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp19_);
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp21_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = gxml_dom_node_list_get_length (_tmp22_);
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = _tmp23_;
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp24_ == 1, "n.child_nodes.length == 1");
#line 489 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp22_);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = n;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_gom_element_get_unparsed ((GXmlGomElement*) _tmp25_);
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 490 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp27_ == NULL, "n.unparsed == null");
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 4764 "GomElementTest.c"
	}
	goto __finally262;
	__catch262_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
		gchar* _tmp30_ = NULL;
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = e->message;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = g_strconcat ("Error: ", _tmp28_, NULL);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:492: %s", _tmp30_);
#line 492 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp30_);
#line 493 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 4791 "GomElementTest.c"
	}
	__finally262:
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 480 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 4802 "GomElementTest.c"
	}
}


static void ___lambda252__gtest_func (void) {
#line 479 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda252_ ();
#line 4810 "GomElementTest.c"
}


static void __lambda253_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_ = NULL;
		GXmlGomElement* _tmp1_ = NULL;
		GXmlGomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GXmlDomDocument* _tmp5_ = NULL;
		GXmlDomDocument* _tmp6_ = NULL;
		GXmlDomElement* _tmp7_ = NULL;
		GXmlGomElement* n2 = NULL;
		GXmlGomElement* _tmp8_ = NULL;
		GXmlGomElement* _tmp9_ = NULL;
		GXmlGomElement* _tmp10_ = NULL;
		GXmlDomNode* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		gchar* str = NULL;
		GXmlGomElement* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		const gchar* _tmp15_ = NULL;
		gboolean _tmp16_ = FALSE;
		const gchar* _tmp17_ = NULL;
		gboolean _tmp18_ = FALSE;
		gchar* _tmp19_ = NULL;
		GXmlGomElement* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		gboolean _tmp24_ = FALSE;
		const gchar* _tmp25_ = NULL;
		gboolean _tmp26_ = FALSE;
#line 498 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 498 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 499 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 499 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 500 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4863 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_get_owner_document ((GXmlDomNode*) _tmp4_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_document_create_element (_tmp6_, "Node2", &_inner_error_);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp7_;
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4880 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp3_, GXML_TYPE_GOM_ELEMENT) ? ((GXmlGomElement*) _tmp3_) : NULL);
#line 501 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp8_;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = n;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = n2;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp9_, (GXmlDomNode*) _tmp10_, &_inner_error_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 502 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4905 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = n;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = gxml_gom_element_write_string (_tmp13_, &_inner_error_);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp14_;
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 503 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4922 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 504 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = str;
#line 504 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = string_contains (_tmp15_, "<Node");
#line 504 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp16_, "\"<Node\" in str");
#line 505 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = str;
#line 505 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = string_contains (_tmp17_, "<Node name=\"value\"><Node2/></Node>");
#line 505 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp18_, "\"<Node name=\\\"value\\\"><Node2/></Node>\" in str");
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = n2;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = gxml_gom_element_write_string (_tmp20_, &_inner_error_);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = _tmp21_;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp3_);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 4953 "GomElementTest.c"
			goto __catch263_g_error;
		}
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = _tmp19_;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = NULL;
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 506 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp22_;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = str;
#line 507 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = string_contains (_tmp23_, "<Node2/>");
#line 507 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp24_, "\"<Node2/>\" in str");
#line 508 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = str;
#line 508 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = string_contains (_tmp25_, "<Node name=\"value\"><Node2/></Node>");
#line 508 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (!_tmp26_, "!(\"<Node name=\\\"value\\\"><Node2/></Node>\" in str)");
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp19_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 4986 "GomElementTest.c"
	}
	goto __finally263;
	__catch263_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		gchar* _tmp29_ = NULL;
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = e->message;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = g_strconcat ("Error: ", _tmp27_, NULL);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:510: %s", _tmp29_);
#line 510 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp29_);
#line 511 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5013 "GomElementTest.c"
	}
	__finally263:
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 497 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5024 "GomElementTest.c"
	}
}


static void ___lambda253__gtest_func (void) {
#line 496 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda253_ ();
#line 5032 "GomElementTest.c"
}


static void __lambda254_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_ = NULL;
		GXmlGomElement* _tmp1_ = NULL;
		GXmlGomElement* _tmp2_ = NULL;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_ = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GMemoryOutputStream* _tmp5_ = NULL;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp6_ = NULL;
		void* _tmp7_ = NULL;
		void* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gboolean _tmp10_ = FALSE;
		gboolean _tmp11_ = FALSE;
#line 516 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 516 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 517 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 518 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5070 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 519 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 519 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		ostream = _tmp3_;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = ostream;
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_write_stream (_tmp4_, (GOutputStream*) _tmp5_, &_inner_error_);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 520 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5089 "GomElementTest.c"
			goto __catch264_g_error;
		}
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = ostream;
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = g_memory_output_stream_get_data (_tmp6_);
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_strdup ((const gchar*) _tmp8_);
#line 521 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp9_;
#line 522 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = string_contains (str, "<Node");
#line 522 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp10_, "\"<Node\" in str");
#line 523 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = string_contains (str, "<Node name=\"value\"/>");
#line 523 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp11_, "\"<Node name=\\\"value\\\"/>\" in str");
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 5116 "GomElementTest.c"
	}
	goto __finally264;
	__catch264_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = e->message;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = g_strconcat ("Error: ", _tmp12_, NULL);
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:525: %s", _tmp14_);
#line 525 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 526 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5143 "GomElementTest.c"
	}
	__finally264:
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 515 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5154 "GomElementTest.c"
	}
}


static void ___lambda254__gtest_func (void) {
#line 514 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda254_ ();
#line 5162 "GomElementTest.c"
}


static void __lambda255_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* n = NULL;
		GXmlGomElement* _tmp0_ = NULL;
		GXmlGomElement* _tmp1_ = NULL;
		GXmlGomElement* _tmp2_ = NULL;
		GMemoryOutputStream* ostream = NULL;
		GMemoryOutputStream* _tmp3_ = NULL;
		GInputStream* istream = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GInputStream* _tmp5_ = NULL;
		GMemoryOutputStream* _tmp6_ = NULL;
		GInputStream* _tmp7_ = NULL;
		gchar* str = NULL;
		GMemoryOutputStream* _tmp8_ = NULL;
		void* _tmp9_ = NULL;
		void* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gboolean _tmp12_ = FALSE;
		gboolean _tmp13_ = FALSE;
#line 531 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 531 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n = _tmp0_;
#line 532 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = n;
#line 532 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize (_tmp1_, "Node");
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = n;
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "name", "value", &_inner_error_);
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 533 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5203 "GomElementTest.c"
			goto __catch265_g_error;
		}
#line 534 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = (GMemoryOutputStream*) g_memory_output_stream_new_resizable ();
#line 534 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		ostream = _tmp3_;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = n;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_gom_element_create_stream (_tmp4_, &_inner_error_);
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		istream = _tmp5_;
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 535 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5222 "GomElementTest.c"
			goto __catch265_g_error;
		}
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = ostream;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = istream;
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_output_stream_splice ((GOutputStream*) _tmp6_, _tmp7_, G_OUTPUT_STREAM_SPLICE_NONE, NULL, &_inner_error_);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (istream);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (ostream);
#line 536 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n);
#line 5239 "GomElementTest.c"
			goto __catch265_g_error;
		}
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = ostream;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_memory_output_stream_get_data (_tmp8_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = g_strdup ((const gchar*) _tmp10_);
#line 537 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp11_;
#line 538 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = string_contains (str, "<Node");
#line 538 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp12_, "\"<Node\" in str");
#line 539 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = string_contains (str, "<Node name=\"value\"/>");
#line 539 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp13_, "\"<Node name=\\\"value\\\"/>\" in str");
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (istream);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (ostream);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n);
#line 5268 "GomElementTest.c"
	}
	goto __finally265;
	__catch265_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = e->message;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = g_strconcat ("Error: ", _tmp14_, NULL);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = _tmp15_;
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:541: %s", _tmp16_);
#line 541 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp16_);
#line 542 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 5295 "GomElementTest.c"
	}
	__finally265:
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 530 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 5306 "GomElementTest.c"
	}
}


static void ___lambda255__gtest_func (void) {
#line 529 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda255_ ();
#line 5314 "GomElementTest.c"
}


static void __lambda256_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* doc = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlDomElement* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomElement* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomElement* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomNode* _tmp14_ = NULL;
		GXmlDomNode* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNodeList* _tmp19_ = NULL;
		GXmlDomNodeList* _tmp20_ = NULL;
		GXmlDomNodeList* _tmp21_ = NULL;
		gpointer _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomElement* _tmp26_ = NULL;
		GXmlDomNodeList* _tmp27_ = NULL;
		GXmlDomNodeList* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		gpointer _tmp30_ = NULL;
		GXmlDomNode* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomElement* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomNodeList* _tmp38_ = NULL;
		GXmlDomNodeList* _tmp39_ = NULL;
		GXmlDomNodeList* _tmp40_ = NULL;
		gpointer _tmp41_ = NULL;
		GXmlDomNode* _tmp42_ = NULL;
		GXmlDomNode* _tmp43_ = NULL;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		gchar* _tmp47_ = NULL;
		gchar* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		GXmlDomElement* _tmp51_ = NULL;
		GXmlDomNodeList* _tmp52_ = NULL;
		GXmlDomNodeList* _tmp53_ = NULL;
		GXmlDomNodeList* _tmp54_ = NULL;
		gpointer _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		GXmlDomElement* _tmp57_ = NULL;
		GXmlDomElement* _tmp58_ = NULL;
		GXmlDomElement* _tmp59_ = NULL;
		GXmlDomNodeList* _tmp60_ = NULL;
		GXmlDomNodeList* _tmp61_ = NULL;
		GXmlDomNodeList* _tmp62_ = NULL;
		gpointer _tmp63_ = NULL;
		GXmlDomNode* _tmp64_ = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomElement* _tmp66_ = NULL;
		GXmlDomElement* _tmp67_ = NULL;
		GXmlDomNodeList* _tmp68_ = NULL;
		GXmlDomNodeList* _tmp69_ = NULL;
		GXmlDomNodeList* _tmp70_ = NULL;
		gpointer _tmp71_ = NULL;
		GXmlDomNode* _tmp72_ = NULL;
		GXmlDomElement* _tmp73_ = NULL;
		GXmlDomElement* _tmp74_ = NULL;
		GXmlDomElement* _tmp75_ = NULL;
		GXmlDomNodeList* _tmp76_ = NULL;
		GXmlDomNodeList* _tmp77_ = NULL;
		GXmlDomNodeList* _tmp78_ = NULL;
		gpointer _tmp79_ = NULL;
		GXmlDomNode* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		gchar* _tmp82_ = NULL;
		gchar* _tmp83_ = NULL;
		GXmlDomElement* _tmp84_ = NULL;
		GXmlDomElement* _tmp85_ = NULL;
		GXmlDomElement* _tmp86_ = NULL;
		GXmlDomNodeList* _tmp87_ = NULL;
		GXmlDomNodeList* _tmp88_ = NULL;
		GXmlDomNodeList* _tmp89_ = NULL;
		gpointer _tmp90_ = NULL;
		GXmlDomNode* _tmp91_ = NULL;
		GXmlDomElement* _tmp92_ = NULL;
		GXmlDomElement* _tmp93_ = NULL;
		GXmlDomElement* _tmp94_ = NULL;
		GXmlDomElement* _tmp95_ = NULL;
		GXmlDomElement* _tmp96_ = NULL;
		GXmlDomElement* _tmp97_ = NULL;
		GXmlDomElement* _tmp98_ = NULL;
		GXmlDomElement* _tmp99_ = NULL;
		GXmlDomNodeList* _tmp100_ = NULL;
		GXmlDomNodeList* _tmp101_ = NULL;
		GXmlDomNodeList* _tmp102_ = NULL;
		gpointer _tmp103_ = NULL;
		GXmlDomNode* _tmp104_ = NULL;
		GXmlDomElement* _tmp105_ = NULL;
		GXmlDomElement* _tmp106_ = NULL;
		GXmlDomElement* _tmp107_ = NULL;
		GXmlDomElement* _tmp108_ = NULL;
		GXmlDomElement* _tmp109_ = NULL;
		GXmlDomElement* _tmp110_ = NULL;
		GXmlDomElement* _tmp111_ = NULL;
		GXmlDomElement* _tmp112_ = NULL;
		GXmlDomNodeList* _tmp113_ = NULL;
		GXmlDomNodeList* _tmp114_ = NULL;
		GXmlDomNodeList* _tmp115_ = NULL;
		gpointer _tmp116_ = NULL;
		GXmlDomNode* _tmp117_ = NULL;
		GXmlDomElement* _tmp118_ = NULL;
		GXmlDomElement* _tmp119_ = NULL;
		GXmlDomElement* _tmp120_ = NULL;
		GXmlDomElement* _tmp121_ = NULL;
		GXmlDomElement* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		gchar* _tmp124_ = NULL;
		gchar* _tmp125_ = NULL;
		GXmlDomElement* _tmp126_ = NULL;
		GXmlDomElement* _tmp127_ = NULL;
		GXmlDomElement* _tmp128_ = NULL;
		GXmlDomNodeList* _tmp129_ = NULL;
		GXmlDomNodeList* _tmp130_ = NULL;
		GXmlDomNodeList* _tmp131_ = NULL;
		gpointer _tmp132_ = NULL;
		GXmlDomNode* _tmp133_ = NULL;
		GXmlDomElement* _tmp134_ = NULL;
		GXmlDomElement* _tmp135_ = NULL;
		GXmlDomElement* _tmp136_ = NULL;
		GXmlDomNodeList* _tmp137_ = NULL;
		GXmlDomNodeList* _tmp138_ = NULL;
		GXmlDomNodeList* _tmp139_ = NULL;
		gpointer _tmp140_ = NULL;
		GXmlDomNode* _tmp141_ = NULL;
		GXmlDomNode* _tmp142_ = NULL;
		GXmlDomNode* _tmp143_ = NULL;
		GXmlDomNode* _tmp144_ = NULL;
		GXmlDomElement* _tmp145_ = NULL;
		GXmlDomElement* _tmp146_ = NULL;
		GXmlDomElement* _tmp147_ = NULL;
		GXmlDomNodeList* _tmp148_ = NULL;
		GXmlDomNodeList* _tmp149_ = NULL;
		GXmlDomNodeList* _tmp150_ = NULL;
		gpointer _tmp151_ = NULL;
		GXmlDomNode* _tmp152_ = NULL;
		GXmlDomNode* _tmp153_ = NULL;
		GXmlDomNode* _tmp154_ = NULL;
		GXmlDomNode* _tmp155_ = NULL;
		gchar* _tmp156_ = NULL;
		gchar* _tmp157_ = NULL;
		gchar* _tmp158_ = NULL;
		GXmlDomElement* _tmp159_ = NULL;
		GXmlDomElement* _tmp160_ = NULL;
		GXmlDomElement* _tmp161_ = NULL;
		GXmlDomNodeList* _tmp162_ = NULL;
		GXmlDomNodeList* _tmp163_ = NULL;
		GXmlDomNodeList* _tmp164_ = NULL;
		gpointer _tmp165_ = NULL;
		GXmlDomNode* _tmp166_ = NULL;
		GXmlDomElement* _tmp167_ = NULL;
		GXmlDomElement* _tmp168_ = NULL;
		GXmlDomElement* _tmp169_ = NULL;
		GXmlDomNodeList* _tmp170_ = NULL;
		GXmlDomNodeList* _tmp171_ = NULL;
		GXmlDomNodeList* _tmp172_ = NULL;
		gpointer _tmp173_ = NULL;
		GXmlDomNode* _tmp174_ = NULL;
		GXmlDomElement* _tmp175_ = NULL;
		GXmlDomElement* _tmp176_ = NULL;
		GXmlDomElement* _tmp177_ = NULL;
		GXmlDomNodeList* _tmp178_ = NULL;
		GXmlDomNodeList* _tmp179_ = NULL;
		GXmlDomNodeList* _tmp180_ = NULL;
		gpointer _tmp181_ = NULL;
		GXmlDomNode* _tmp182_ = NULL;
		GXmlDomElement* _tmp183_ = NULL;
		GXmlDomElement* _tmp184_ = NULL;
		GXmlDomElement* _tmp185_ = NULL;
		GXmlDomNodeList* _tmp186_ = NULL;
		GXmlDomNodeList* _tmp187_ = NULL;
		GXmlDomNodeList* _tmp188_ = NULL;
		gpointer _tmp189_ = NULL;
		GXmlDomNode* _tmp190_ = NULL;
		gchar* _tmp191_ = NULL;
		gchar* _tmp192_ = NULL;
		gchar* _tmp193_ = NULL;
		GXmlDomElement* _tmp194_ = NULL;
		GXmlDomElement* _tmp195_ = NULL;
		GXmlDomElement* _tmp196_ = NULL;
		GXmlDomNodeList* _tmp197_ = NULL;
		GXmlDomNodeList* _tmp198_ = NULL;
		GXmlDomNodeList* _tmp199_ = NULL;
		gpointer _tmp200_ = NULL;
		GXmlDomNode* _tmp201_ = NULL;
		GXmlDomElement* _tmp202_ = NULL;
		GXmlDomElement* _tmp203_ = NULL;
		GXmlDomElement* _tmp204_ = NULL;
		GXmlDomElement* _tmp205_ = NULL;
		GXmlDomElement* _tmp206_ = NULL;
		GXmlDomElement* _tmp207_ = NULL;
		GXmlDomElement* _tmp208_ = NULL;
		GXmlDomElement* _tmp209_ = NULL;
		GXmlDomNodeList* _tmp210_ = NULL;
		GXmlDomNodeList* _tmp211_ = NULL;
		GXmlDomNodeList* _tmp212_ = NULL;
		gpointer _tmp213_ = NULL;
		GXmlDomNode* _tmp214_ = NULL;
		GXmlDomElement* _tmp215_ = NULL;
		GXmlDomElement* _tmp216_ = NULL;
		GXmlDomElement* _tmp217_ = NULL;
		GXmlDomElement* _tmp218_ = NULL;
		GXmlDomElement* _tmp219_ = NULL;
		GXmlDomElement* _tmp220_ = NULL;
		GXmlDomElement* _tmp221_ = NULL;
		GXmlDomElement* _tmp222_ = NULL;
		GXmlDomNodeList* _tmp223_ = NULL;
		GXmlDomNodeList* _tmp224_ = NULL;
		GXmlDomNodeList* _tmp225_ = NULL;
		gpointer _tmp226_ = NULL;
		GXmlDomNode* _tmp227_ = NULL;
		GXmlDomElement* _tmp228_ = NULL;
		GXmlDomElement* _tmp229_ = NULL;
		GXmlDomElement* _tmp230_ = NULL;
		GXmlDomElement* _tmp231_ = NULL;
		GXmlDomElement* _tmp232_ = NULL;
		gchar* _tmp233_ = NULL;
		gchar* _tmp234_ = NULL;
		gchar* _tmp235_ = NULL;
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new_from_string ("<root> <child/> <child/></root>", &_inner_error_);
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		doc = _tmp0_;
#line 547 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 5564 "GomElementTest.c"
			goto __catch266_g_error;
		}
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = _tmp1_;
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "doc.document_element != null");
#line 548 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp3_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp6_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, GXML_TYPE_DOM_NODE), "doc.document_element.parent_node is GXml.DomNode");
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp9_);
#line 549 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = _tmp11_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) _tmp12_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = _tmp14_;
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_DOCUMENT), "doc.document_element.parent_node is GXml.DomDocument");
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp15_);
#line 550 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp12_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = _tmp17_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp18_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = _tmp20_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gee_list_get ((GeeList*) _tmp21_, 0);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = (GXmlDomNode*) _tmp22_;
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp23_ != NULL, "doc.document_element.child_nodes[0] != null");
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp23_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp21_);
#line 551 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp18_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = _tmp24_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = _tmp25_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp26_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = _tmp27_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = _tmp28_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = gee_list_get ((GeeList*) _tmp29_, 0);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = (GXmlDomNode*) _tmp30_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_node_get_parent_node (_tmp31_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp34_ != NULL, "doc.document_element.child_nodes[0].parent_node != null");
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp29_);
#line 552 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp26_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp37_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = gee_list_get ((GeeList*) _tmp40_, 0);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = (GXmlDomNode*) _tmp41_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = gxml_dom_node_get_parent_node (_tmp42_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = _tmp43_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = gxml_dom_node_get_node_name (_tmp45_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = _tmp46_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp48_, "root") == 0, "doc.document_element.child_nodes[0].parent_node.node_name == \"root\"");
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp48_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp45_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp42_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 553 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp51_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = _tmp52_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = gee_list_get ((GeeList*) _tmp54_, 0);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = (GXmlDomNode*) _tmp55_;
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[0] is DomText");
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp56_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp54_);
#line 554 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp51_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = _tmp58_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp59_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = _tmp61_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = gee_list_get ((GeeList*) _tmp62_, 1);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = (GXmlDomNode*) _tmp63_;
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp64_ != NULL, "doc.document_element.child_nodes[1] != null");
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp64_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp62_);
#line 555 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp59_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = _tmp65_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = _tmp66_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp67_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = _tmp68_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = gee_list_get ((GeeList*) _tmp70_, 1);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = (GXmlDomNode*) _tmp71_;
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp72_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[1] is DomElement");
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 556 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp67_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp75_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = _tmp76_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = gee_list_get ((GeeList*) _tmp78_, 1);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = (GXmlDomNode*) _tmp79_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = gxml_dom_node_get_node_name (_tmp80_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = _tmp81_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = _tmp82_;
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp83_, "child") == 0, "doc.document_element.child_nodes[1].node_name == \"child\"");
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp83_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp80_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 557 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp75_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = _tmp85_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp86_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = _tmp87_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = gee_list_get ((GeeList*) _tmp89_, 1);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = (GXmlDomNode*) _tmp90_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp91_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp91_) : NULL;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp92_ == NULL) {
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp91_);
#line 5835 "GomElementTest.c"
		}
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp93_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = _tmp94_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling != null");
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp93_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp89_);
#line 558 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp86_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = _tmp97_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp99_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = _tmp100_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = gee_list_get ((GeeList*) _tmp102_, 1);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = (GXmlDomNode*) _tmp103_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp104_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp104_) : NULL;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp105_ == NULL) {
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp104_);
#line 5877 "GomElementTest.c"
		}
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = _tmp105_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp106_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp109_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling is DomElement");
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp106_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 559 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp99_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = _tmp110_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp112_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = _tmp114_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = gee_list_get ((GeeList*) _tmp115_, 1);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = (GXmlDomNode*) _tmp116_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp117_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp117_) : NULL;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp118_ == NULL) {
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp117_);
#line 5919 "GomElementTest.c"
		}
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = gxml_dom_non_document_type_child_node_get_next_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp119_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = _tmp120_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp122_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = _tmp123_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp125_, "child") == 0, "(doc.document_element.child_nodes[1] as DomElement).next_element_sibling.node_name == \"child\"");
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp125_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp122_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp115_);
#line 560 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp128_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = gee_list_get ((GeeList*) _tmp131_, 2);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = (GXmlDomNode*) _tmp132_;
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp133_ != NULL, "doc.document_element.child_nodes[2] != null");
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp133_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp131_);
#line 561 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = _tmp134_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp136_ = _tmp135_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp137_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp136_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp138_ = _tmp137_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp139_ = _tmp138_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = gee_list_get ((GeeList*) _tmp139_, 2);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = (GXmlDomNode*) _tmp140_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp142_ = gxml_dom_node_get_parent_node (_tmp141_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp143_ = _tmp142_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp144_ != NULL, "doc.document_element.child_nodes[2].parent_node != null");
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp144_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp141_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp139_);
#line 562 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp136_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp145_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp146_ = _tmp145_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp147_ = _tmp146_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp147_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = _tmp149_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = gee_list_get ((GeeList*) _tmp150_, 2);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp152_ = (GXmlDomNode*) _tmp151_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp153_ = gxml_dom_node_get_parent_node (_tmp152_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp155_ = _tmp154_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp156_ = gxml_dom_node_get_node_name (_tmp155_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp158_, "root") == 0, "doc.document_element.child_nodes[2].parent_node.node_name == \"root\"");
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp158_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp155_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp152_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp150_);
#line 563 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp147_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp159_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp160_ = _tmp159_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp161_ = _tmp160_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp162_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp161_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp163_ = _tmp162_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp164_ = _tmp163_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp165_ = gee_list_get ((GeeList*) _tmp164_, 2);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp166_ = (GXmlDomNode*) _tmp165_;
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp166_, GXML_TYPE_DOM_TEXT), "doc.document_element.child_nodes[2] is DomText");
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp166_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp164_);
#line 564 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp161_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp167_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp168_ = _tmp167_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp170_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp169_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp171_ = _tmp170_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp172_ = _tmp171_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp173_ = gee_list_get ((GeeList*) _tmp172_, 3);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp174_ = (GXmlDomNode*) _tmp173_;
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp174_ != NULL, "doc.document_element.child_nodes[3] != null");
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp174_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp172_);
#line 565 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp169_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp175_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp176_ = _tmp175_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp177_ = _tmp176_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp178_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp177_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp179_ = _tmp178_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp180_ = _tmp179_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp181_ = gee_list_get ((GeeList*) _tmp180_, 3);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp182_ = (GXmlDomNode*) _tmp181_;
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp182_, GXML_TYPE_DOM_ELEMENT), "doc.document_element.child_nodes[3] is DomElement");
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp182_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp180_);
#line 566 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp177_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp183_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp184_ = _tmp183_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp185_ = _tmp184_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp186_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp185_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp187_ = _tmp186_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp188_ = _tmp187_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp189_ = gee_list_get ((GeeList*) _tmp188_, 3);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp190_ = (GXmlDomNode*) _tmp189_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp191_ = gxml_dom_node_get_node_name (_tmp190_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp192_ = _tmp191_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp193_ = _tmp192_;
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp193_, "child") == 0, "doc.document_element.child_nodes[3].node_name == \"child\"");
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp193_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp190_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp188_);
#line 567 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp185_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp194_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp196_ = _tmp195_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp197_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp196_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp200_ = gee_list_get ((GeeList*) _tmp199_, 3);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp201_ = (GXmlDomNode*) _tmp200_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp202_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp201_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp201_) : NULL;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp202_ == NULL) {
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp201_);
#line 6169 "GomElementTest.c"
		}
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp204_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp203_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp205_ = _tmp204_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp206_ = _tmp205_;
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp206_ != NULL, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling != null");
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp206_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp203_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp199_);
#line 568 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp196_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp207_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp208_ = _tmp207_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp209_ = _tmp208_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp210_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp209_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp211_ = _tmp210_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp212_ = _tmp211_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp213_ = gee_list_get ((GeeList*) _tmp212_, 3);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp214_ = (GXmlDomNode*) _tmp213_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp215_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp214_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp214_) : NULL;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp215_ == NULL) {
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp214_);
#line 6211 "GomElementTest.c"
		}
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp216_ = _tmp215_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp217_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp216_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp218_ = _tmp217_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp219_, GXML_TYPE_DOM_ELEMENT), "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling is DomElement");
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp216_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp212_);
#line 569 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp209_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp220_ = gxml_dom_document_get_document_element ((GXmlDomDocument*) doc);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp221_ = _tmp220_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp222_ = _tmp221_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp223_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) _tmp222_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp224_ = _tmp223_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp225_ = _tmp224_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp226_ = gee_list_get ((GeeList*) _tmp225_, 3);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp227_ = (GXmlDomNode*) _tmp226_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp228_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp227_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp227_) : NULL;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (_tmp228_ == NULL) {
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (_tmp227_);
#line 6253 "GomElementTest.c"
		}
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp229_ = _tmp228_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp230_ = gxml_dom_non_document_type_child_node_get_previous_element_sibling ((GXmlDomNonDocumentTypeChildNode*) _tmp229_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp231_ = _tmp230_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp232_ = _tmp231_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp233_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp232_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp234_ = _tmp233_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp235_ = _tmp234_;
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp235_, "child") == 0, "(doc.document_element.child_nodes[3] as DomElement).previous_element_sibling.node_name == \"child\"");
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp235_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp232_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp229_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp225_);
#line 570 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp222_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (doc);
#line 6283 "GomElementTest.c"
	}
	goto __finally266;
	__catch266_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp236_ = NULL;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp236_ = e->message;
#line 572 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_test_message ("%s", _tmp236_);
#line 573 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 6302 "GomElementTest.c"
	}
	__finally266:
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 546 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 6313 "GomElementTest.c"
	}
}


static void ___lambda256__gtest_func (void) {
#line 545 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda256_ ();
#line 6321 "GomElementTest.c"
}


static void __lambda257_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomDocument* d = NULL;
		GXmlGomDocument* _tmp0_ = NULL;
		GXmlDomElement* r = NULL;
		GXmlGomDocument* _tmp1_ = NULL;
		GXmlDomElement* _tmp2_ = NULL;
		GXmlGomDocument* _tmp3_ = NULL;
		GXmlDomElement* _tmp4_ = NULL;
		GXmlDomNode* _tmp5_ = NULL;
		GXmlDomNode* _tmp6_ = NULL;
		GXmlDomElement* c1 = NULL;
		GXmlGomDocument* _tmp7_ = NULL;
		GXmlDomElement* _tmp8_ = NULL;
		GXmlDomElement* _tmp9_ = NULL;
		GXmlDomElement* _tmp10_ = NULL;
		GXmlDomElement* _tmp11_ = NULL;
		GXmlDomNode* _tmp12_ = NULL;
		GXmlDomNode* _tmp13_ = NULL;
		GXmlDomElement* c2 = NULL;
		GXmlGomDocument* _tmp14_ = NULL;
		GXmlDomElement* _tmp15_ = NULL;
		GXmlDomElement* _tmp16_ = NULL;
		GXmlDomElement* _tmp17_ = NULL;
		GXmlDomElement* _tmp18_ = NULL;
		GXmlDomNode* _tmp19_ = NULL;
		GXmlDomNode* _tmp20_ = NULL;
		GXmlDomElement* c3 = NULL;
		GXmlGomDocument* _tmp21_ = NULL;
		GXmlDomElement* _tmp22_ = NULL;
		GXmlDomElement* _tmp23_ = NULL;
		GXmlDomElement* _tmp24_ = NULL;
		GXmlDomElement* _tmp25_ = NULL;
		GXmlDomNode* _tmp26_ = NULL;
		GXmlDomNode* _tmp27_ = NULL;
		GXmlDomElement* c4 = NULL;
		GXmlGomDocument* _tmp28_ = NULL;
		GXmlDomElement* _tmp29_ = NULL;
		GXmlDomElement* _tmp30_ = NULL;
		GXmlDomElement* _tmp31_ = NULL;
		GXmlDomElement* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlDomNode* _tmp34_ = NULL;
		GXmlDomElement* c5 = NULL;
		GXmlGomDocument* _tmp35_ = NULL;
		GXmlDomElement* _tmp36_ = NULL;
		GXmlDomElement* _tmp37_ = NULL;
		GXmlDomElement* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		GXmlDomNode* _tmp40_ = NULL;
		GXmlDomElement* n1 = NULL;
		GXmlDomElement* _tmp41_ = NULL;
		GXmlDomElement* _tmp42_ = NULL;
		GXmlDomElement* _tmp43_ = NULL;
		GXmlDomElement* _tmp44_ = NULL;
		gchar* _tmp45_ = NULL;
		gchar* _tmp46_ = NULL;
		GXmlDomElement* n2 = NULL;
		GXmlDomElement* _tmp47_ = NULL;
		GXmlDomElement* _tmp48_ = NULL;
		GXmlDomElement* _tmp49_ = NULL;
		GXmlDomElement* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		gchar* _tmp52_ = NULL;
		GXmlDomElement* n3 = NULL;
		GXmlDomElement* _tmp53_ = NULL;
		GXmlDomElement* _tmp54_ = NULL;
		GXmlDomElement* _tmp55_ = NULL;
		GXmlDomElement* _tmp56_ = NULL;
		gchar* _tmp57_ = NULL;
		gchar* _tmp58_ = NULL;
		GXmlDomElement* n4 = NULL;
		GXmlDomElement* _tmp59_ = NULL;
		GXmlDomElement* _tmp60_ = NULL;
		GXmlDomElement* _tmp61_ = NULL;
		GXmlDomElement* _tmp62_ = NULL;
		gchar* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		GXmlDomNodeList* l1 = NULL;
		GXmlDomElement* _tmp65_ = NULL;
		GXmlDomNodeList* _tmp66_ = NULL;
		GXmlDomNodeList* _tmp67_ = NULL;
		GXmlDomNodeList* _tmp68_ = NULL;
		gint _tmp69_ = 0;
		gint _tmp70_ = 0;
		gchar* _tmp71_ = NULL;
		gchar* _tmp72_ = NULL;
		GXmlDomNodeList* _tmp73_ = NULL;
		gint _tmp74_ = 0;
		gint _tmp75_ = 0;
		GXmlDomNodeList* _tmp76_ = NULL;
		GXmlDomNode* _tmp77_ = NULL;
		GXmlDomNode* _tmp78_ = NULL;
		gchar* _tmp79_ = NULL;
		gchar* _tmp80_ = NULL;
		gchar* _tmp81_ = NULL;
		GXmlDomNodeList* l2 = NULL;
		GXmlDomElement* _tmp82_ = NULL;
		GXmlDomNodeList* _tmp83_ = NULL;
		GXmlDomNodeList* _tmp84_ = NULL;
		GXmlDomNodeList* _tmp85_ = NULL;
		gint _tmp86_ = 0;
		gint _tmp87_ = 0;
		GXmlDomNodeList* _tmp88_ = NULL;
		GXmlDomNode* _tmp89_ = NULL;
		GXmlDomNode* _tmp90_ = NULL;
		gchar* _tmp91_ = NULL;
		gchar* _tmp92_ = NULL;
		gchar* _tmp93_ = NULL;
		GXmlDomNodeList* l3 = NULL;
		GXmlDomElement* _tmp94_ = NULL;
		GXmlDomNodeList* _tmp95_ = NULL;
		GXmlDomNodeList* _tmp96_ = NULL;
		GXmlDomNodeList* _tmp97_ = NULL;
		gint _tmp98_ = 0;
		gint _tmp99_ = 0;
		GXmlDomNodeList* _tmp100_ = NULL;
		GXmlDomNode* _tmp101_ = NULL;
		GXmlDomNode* _tmp102_ = NULL;
		gchar* _tmp103_ = NULL;
		gchar* _tmp104_ = NULL;
		gchar* _tmp105_ = NULL;
		GXmlDomElement* c6 = NULL;
		GXmlGomDocument* _tmp106_ = NULL;
		GXmlDomElement* _tmp107_ = NULL;
		GXmlDomElement* _tmp108_ = NULL;
		GXmlDomElement* _tmp109_ = NULL;
		GXmlDomElement* _tmp110_ = NULL;
		GXmlDomNode* _tmp111_ = NULL;
		GXmlDomNode* _tmp112_ = NULL;
		GXmlDomElement* c7 = NULL;
		GXmlGomDocument* _tmp113_ = NULL;
		GXmlDomElement* _tmp114_ = NULL;
		GXmlDomElement* _tmp115_ = NULL;
		GXmlDomElement* _tmp116_ = NULL;
		GXmlDomElement* _tmp117_ = NULL;
		GXmlDomNode* _tmp118_ = NULL;
		GXmlDomNode* _tmp119_ = NULL;
		GXmlDomNodeList* l4 = NULL;
		GXmlDomElement* _tmp120_ = NULL;
		GXmlDomNodeList* _tmp121_ = NULL;
		GXmlDomNodeList* _tmp122_ = NULL;
		GXmlDomNodeList* _tmp123_ = NULL;
		gint _tmp124_ = 0;
		gint _tmp125_ = 0;
		GXmlDomNodeList* _tmp126_ = NULL;
		GXmlDomNode* _tmp127_ = NULL;
		GXmlDomNode* _tmp128_ = NULL;
		gchar* _tmp129_ = NULL;
		gchar* _tmp130_ = NULL;
		gchar* _tmp131_ = NULL;
#line 578 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_document_new ();
#line 578 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		d = _tmp0_;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = d;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp1_, "root", &_inner_error_);
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		r = _tmp2_;
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 579 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6491 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = d;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = r;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp3_, (GXmlDomNode*) _tmp4_, &_inner_error_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = _tmp5_;
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp6_);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 580 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6510 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = d;
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp7_, "child", &_inner_error_);
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c1 = _tmp8_;
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 581 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6525 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = c1;
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp9_, "class", "error", &_inner_error_);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 582 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6540 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = r;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = c1;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp10_, (GXmlDomNode*) _tmp11_, &_inner_error_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp13_);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 583 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6561 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = d;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp14_, "child", &_inner_error_);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c2 = _tmp15_;
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 584 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6578 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = c2;
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp16_, "class", "warning", &_inner_error_);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 585 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6595 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = r;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp18_ = c2;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp19_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp17_, (GXmlDomNode*) _tmp18_, &_inner_error_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp20_ = _tmp19_;
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp20_);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 586 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6618 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp21_ = d;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp22_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp21_, "child", &_inner_error_);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c3 = _tmp22_;
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 587 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6637 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp23_ = c3;
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp23_, "class", "error warning", &_inner_error_);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 588 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6656 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp24_ = r;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp25_ = c3;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp26_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp24_, (GXmlDomNode*) _tmp25_, &_inner_error_);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp27_ = _tmp26_;
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp27_);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 589 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6681 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = d;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp28_, "child", &_inner_error_);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c4 = _tmp29_;
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 590 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6702 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = c4;
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp30_, "class", "error calc", &_inner_error_);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 591 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6723 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = r;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = c4;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp31_, (GXmlDomNode*) _tmp32_, &_inner_error_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = _tmp33_;
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp34_);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 592 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6750 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = d;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp35_, "child", &_inner_error_);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c5 = _tmp36_;
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 593 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6773 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = r;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = c5;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp37_, (GXmlDomNode*) _tmp38_, &_inner_error_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = _tmp39_;
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp40_);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 594 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6802 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = r;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp41_, "child", &_inner_error_);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n1 = _tmp42_;
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 595 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6827 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 596 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = n1;
#line 596 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp43_ != NULL, "n1 != null");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = n1;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = gxml_dom_element_get_attribute (_tmp44_, "class");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp46_, "error") == 0, "n1.get_attribute (\"class\") == \"error\"");
#line 597 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp46_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = r;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp47_, "child.warning", &_inner_error_);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n2 = _tmp48_;
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 598 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6868 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 599 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = n2;
#line 599 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp49_ != NULL, "n2 != null");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = n2;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = gxml_dom_element_get_attribute (_tmp50_, "class");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = _tmp51_;
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp52_, "warning") == 0, "n2.get_attribute (\"class\") == \"warning\"");
#line 600 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp52_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = r;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp53_, "child[class]", &_inner_error_);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n3 = _tmp54_;
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 601 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6911 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 602 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = n3;
#line 602 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp55_ != NULL, "n3 != null");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = n3;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = gxml_dom_element_get_attribute (_tmp56_, "class");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = _tmp57_;
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "error") == 0, "n3.get_attribute (\"class\") == \"error\"");
#line 603 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp58_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = r;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = gxml_dom_parent_node_query_selector ((GXmlDomParentNode*) _tmp59_, "child[class=\"error calc\"]", &_inner_error_);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		n4 = _tmp60_;
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 604 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 6956 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 605 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = n4;
#line 605 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp61_ != NULL, "n4 != null");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = n4;
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = gxml_dom_element_get_attribute (_tmp62_, "class");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = _tmp63_;
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp64_, "error calc") == 0, "n4.get_attribute (\"class\") == \"error calc\"");
#line 606 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp64_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = r;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp65_, "child", &_inner_error_);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l1 = _tmp66_;
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 607 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7003 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 608 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = l1;
#line 608 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp67_ != NULL, "l1 != null");
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = l1;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = gxml_dom_node_list_get_length (_tmp68_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = g_strdup_printf ("%i", _tmp70_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:609: %s", _tmp72_);
#line 609 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp72_);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = l1;
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = gxml_dom_node_list_get_length (_tmp73_);
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 610 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp75_ == 5, "l1.length == 5");
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = l1;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = gxml_dom_node_list_item (_tmp76_, 4);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = gxml_dom_node_get_node_name (_tmp78_);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = _tmp79_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp81_, "child") == 0, "l1.item (4).node_name == \"child\"");
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp81_);
#line 611 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp78_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = r;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp82_, "child[class]", &_inner_error_);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l2 = _tmp83_;
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 612 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7082 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 613 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = l2;
#line 613 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp84_ != NULL, "l2 != null");
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = l2;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = gxml_dom_node_list_get_length (_tmp85_);
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 614 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp87_ == 4, "l2.length == 4");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = l2;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = gxml_dom_node_list_item (_tmp88_, 3);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = gxml_dom_node_get_node_name (_tmp90_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = _tmp91_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp93_, "child") == 0, "l2.item (3).node_name == \"child\"");
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp93_);
#line 615 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp90_);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = r;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp94_, "child[class=\"error\"]", &_inner_error_);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l3 = _tmp95_;
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 616 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7149 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 617 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = l3;
#line 617 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp96_ != NULL, "l3 != null");
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = l3;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = gxml_dom_node_list_get_length (_tmp97_);
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 618 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp99_ == 1, "l3.length == 1");
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = l3;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = gxml_dom_node_list_item (_tmp100_, 0);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = gxml_dom_node_get_node_name (_tmp102_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = _tmp103_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp105_, "child") == 0, "l3.item (0).node_name == \"child\"");
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp105_);
#line 619 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp102_);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = d;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp106_, "child", &_inner_error_);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c6 = _tmp107_;
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 620 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7218 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = c6;
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp108_, "prop", "val1", &_inner_error_);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 621 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7257 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = r;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = c6;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp109_, (GXmlDomNode*) _tmp110_, &_inner_error_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = _tmp111_;
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp112_);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 622 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7302 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = d;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = gxml_dom_document_create_element ((GXmlDomDocument*) _tmp113_, "child", &_inner_error_);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		c7 = _tmp114_;
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 623 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7343 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = c7;
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute (_tmp115_, "prop", "val1", &_inner_error_);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 624 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7384 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = r;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = c7;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = gxml_dom_node_append_child ((GXmlDomNode*) _tmp116_, (GXmlDomNode*) _tmp117_, &_inner_error_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = _tmp118_;
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp119_);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 625 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7431 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = r;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = gxml_dom_parent_node_query_selector_all ((GXmlDomParentNode*) _tmp120_, "child[prop=\"val1\"]", &_inner_error_);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		l4 = _tmp121_;
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c7);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c6);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (l1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n4);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (n1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c5);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c4);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c3);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c2);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (c1);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (r);
#line 626 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (d);
#line 7474 "GomElementTest.c"
			goto __catch267_g_error;
		}
#line 627 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = l4;
#line 627 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp122_ != NULL, "l4 != null");
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = l4;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = gxml_dom_node_list_get_length (_tmp123_);
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = _tmp124_;
#line 628 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp125_ == 2, "l4.length == 2");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = l4;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = gxml_dom_node_list_item (_tmp126_, 0);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_node_get_node_name (_tmp128_);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = _tmp130_;
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp131_, "child") == 0, "l4.item (0).node_name == \"child\"");
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp131_);
#line 629 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c7);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c6);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (l1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (n1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c5);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c4);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c3);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c2);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (c1);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (r);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (d);
#line 7541 "GomElementTest.c"
	}
	goto __finally267;
	__catch267_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp132_ = NULL;
		gchar* _tmp133_ = NULL;
		gchar* _tmp134_ = NULL;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = e->message;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = g_strconcat ("Error: ", _tmp132_, NULL);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:631: %s", _tmp134_);
#line 631 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp134_);
#line 632 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7568 "GomElementTest.c"
	}
	__finally267:
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 577 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7579 "GomElementTest.c"
	}
}


static void ___lambda257__gtest_func (void) {
#line 576 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda257_ ();
#line 7587 "GomElementTest.c"
}


static void __lambda258_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_ = NULL;
		GomElementTestTop* t = NULL;
		GomElementTestTop* _tmp1_ = NULL;
		NoInstantiatable* _tmp2_ = NULL;
		NoInstantiatable* _tmp3_ = NULL;
		NoInstantiatable* _tmp4_ = NULL;
		NoInstantiatable* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
#line 637 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 637 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 638 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_top_new ();
#line 638 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp1_;
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) t, str, &_inner_error_);
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 639 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 7620 "GomElementTest.c"
			goto __catch268_g_error;
		}
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gom_element_test_top_get_inst (t);
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 640 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gom_element_test_top_get_inst (t);
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 641 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 7643 "GomElementTest.c"
	}
	goto __finally268;
	__catch268_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = e->message;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = g_strconcat ("Error: ", _tmp8_, NULL);
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:643: %s", _tmp10_);
#line 643 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp10_);
#line 644 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7670 "GomElementTest.c"
	}
	__finally268:
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 636 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7681 "GomElementTest.c"
	}
}


static void ___lambda258__gtest_func (void) {
#line 635 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda258_ ();
#line 7689 "GomElementTest.c"
}


static void __lambda259_ (void) {
	GError * _inner_error_ = NULL;
	{
		gchar* str = NULL;
		gchar* _tmp0_ = NULL;
		GomElementTestGTop* t = NULL;
		GomElementTestGTop* _tmp1_ = NULL;
		NoInstantiatable* _tmp2_ = NULL;
		NoInstantiatable* _tmp3_ = NULL;
		NoInstantiatable* _tmp4_ = NULL;
		NoInstantiatable* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		Property* _tmp8_ = NULL;
		Property* _tmp9_ = NULL;
		Property* _tmp10_ = NULL;
		Property* _tmp11_ = NULL;
		gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
#line 649 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = g_strdup ("<Top pq=\"Qlt\"><Instantiatable name=\"Nop\"/></Top>");
#line 649 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		str = _tmp0_;
#line 650 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = gom_element_test_gtop_new ();
#line 650 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		t = _tmp1_;
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_read_from_string ((GXmlGomElement*) t, str, &_inner_error_);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (t);
#line 651 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (str);
#line 7729 "GomElementTest.c"
			goto __catch269_g_error;
		}
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = gom_element_test_gtop_get_inst (t);
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 652 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp3_ != NULL, "t.inst != null");
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = gom_element_test_gtop_get_inst (t);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = no_instantiatable_get_name (_tmp5_);
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 653 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp7_, "Nop") == 0, "t.inst.name == \"Nop\"");
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = gom_element_test_gtop_get_pq (t);
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = _tmp8_;
#line 654 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp9_ != NULL, "t.pq != null");
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = gom_element_test_gtop_get_pq (t);
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp11_ = _tmp10_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp12_ = gxml_gom_property_get_value ((GXmlGomProperty*) _tmp11_);
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp13_ = _tmp12_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp14_ = _tmp13_;
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp14_, "Qlt") == 0, "t.pq.value == \"Qlt\"");
#line 655 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp14_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (t);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (str);
#line 7772 "GomElementTest.c"
	}
	goto __finally269;
	__catch269_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp15_ = e->message;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp16_ = g_strconcat ("Error: ", _tmp15_, NULL);
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp17_ = _tmp16_;
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:657: %s", _tmp17_);
#line 657 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp17_);
#line 658 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 7799 "GomElementTest.c"
	}
	__finally269:
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 648 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 7810 "GomElementTest.c"
	}
}


static void ___lambda259__gtest_func (void) {
#line 647 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda259_ ();
#line 7818 "GomElementTest.c"
}


static void __lambda260_ (void) {
	GError * _inner_error_ = NULL;
	{
		GXmlGomElement* e = NULL;
		GXmlGomElement* _tmp0_ = NULL;
		GXmlGomElement* _tmp1_ = NULL;
		GXmlGomElement* _tmp2_ = NULL;
		GXmlGomElement* _tmp3_ = NULL;
		GXmlGomElement* _tmp4_ = NULL;
		GXmlGomElement* _tmp5_ = NULL;
		GXmlDomNamedNodeMap* _tmp6_ = NULL;
		GXmlDomNamedNodeMap* _tmp7_ = NULL;
		GXmlDomNamedNodeMap* _tmp8_ = NULL;
		gint _tmp9_ = 0;
		gint _tmp10_ = 0;
		GXmlGomElement* _tmp28_ = NULL;
		GXmlDomNamedNodeMap* _tmp29_ = NULL;
		GXmlDomNamedNodeMap* _tmp30_ = NULL;
		GXmlDomNamedNodeMap* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		GXmlDomNode* _tmp33_ = NULL;
		GXmlGomElement* _tmp34_ = NULL;
		GXmlDomNamedNodeMap* _tmp35_ = NULL;
		GXmlDomNamedNodeMap* _tmp36_ = NULL;
		GXmlDomNamedNodeMap* _tmp37_ = NULL;
		GXmlDomNode* _tmp38_ = NULL;
		GXmlDomNode* _tmp39_ = NULL;
		gchar* _tmp40_ = NULL;
		gchar* _tmp41_ = NULL;
		gchar* _tmp42_ = NULL;
		GXmlGomElement* _tmp43_ = NULL;
		GXmlDomNamedNodeMap* _tmp44_ = NULL;
		GXmlDomNamedNodeMap* _tmp45_ = NULL;
		GXmlDomNamedNodeMap* _tmp46_ = NULL;
		GXmlDomNode* _tmp47_ = NULL;
		GXmlDomNode* _tmp48_ = NULL;
		gchar* _tmp49_ = NULL;
		gchar* _tmp50_ = NULL;
		gchar* _tmp51_ = NULL;
		GXmlGomElement* _tmp52_ = NULL;
		GXmlDomNamedNodeMap* _tmp53_ = NULL;
		GXmlDomNamedNodeMap* _tmp54_ = NULL;
		GXmlDomNamedNodeMap* _tmp55_ = NULL;
		GXmlDomNode* _tmp56_ = NULL;
		GXmlDomNode* _tmp57_ = NULL;
		GXmlGomElement* _tmp58_ = NULL;
		GXmlDomNamedNodeMap* _tmp59_ = NULL;
		GXmlDomNamedNodeMap* _tmp60_ = NULL;
		GXmlDomNamedNodeMap* _tmp61_ = NULL;
		GXmlDomNode* _tmp62_ = NULL;
		GXmlDomNode* _tmp63_ = NULL;
		gchar* _tmp64_ = NULL;
		gchar* _tmp65_ = NULL;
		gchar* _tmp66_ = NULL;
		GXmlGomElement* _tmp67_ = NULL;
		GXmlDomNamedNodeMap* _tmp68_ = NULL;
		GXmlDomNamedNodeMap* _tmp69_ = NULL;
		GXmlDomNamedNodeMap* _tmp70_ = NULL;
		GXmlDomNode* _tmp71_ = NULL;
		GXmlDomNode* _tmp72_ = NULL;
		gchar* _tmp73_ = NULL;
		gchar* _tmp74_ = NULL;
		gchar* _tmp75_ = NULL;
		GXmlGomElement* _tmp76_ = NULL;
		GXmlDomNamedNodeMap* _tmp77_ = NULL;
		GXmlDomNamedNodeMap* _tmp78_ = NULL;
		GXmlDomNamedNodeMap* _tmp79_ = NULL;
		GXmlDomNode* _tmp80_ = NULL;
		GXmlDomNode* _tmp81_ = NULL;
		GXmlGomElement* _tmp82_ = NULL;
		GXmlDomNamedNodeMap* _tmp83_ = NULL;
		GXmlDomNamedNodeMap* _tmp84_ = NULL;
		GXmlDomNamedNodeMap* _tmp85_ = NULL;
		GXmlDomNode* _tmp86_ = NULL;
		GXmlDomNode* _tmp87_ = NULL;
		gchar* _tmp88_ = NULL;
		gchar* _tmp89_ = NULL;
		gchar* _tmp90_ = NULL;
		GXmlGomElement* _tmp91_ = NULL;
		GXmlDomNamedNodeMap* _tmp92_ = NULL;
		GXmlDomNamedNodeMap* _tmp93_ = NULL;
		GXmlDomNamedNodeMap* _tmp94_ = NULL;
		GXmlDomNode* _tmp95_ = NULL;
		GXmlDomNode* _tmp96_ = NULL;
		gchar* _tmp97_ = NULL;
		gchar* _tmp98_ = NULL;
		gchar* _tmp99_ = NULL;
		GXmlGomElement* _tmp100_ = NULL;
		GXmlDomNamedNodeMap* _tmp101_ = NULL;
		GXmlDomNamedNodeMap* _tmp102_ = NULL;
		GXmlDomNamedNodeMap* _tmp103_ = NULL;
		GXmlDomNode* _tmp104_ = NULL;
		GXmlDomNode* _tmp105_ = NULL;
		GXmlGomElement* _tmp106_ = NULL;
		GXmlDomNamedNodeMap* _tmp107_ = NULL;
		GXmlDomNamedNodeMap* _tmp108_ = NULL;
		GXmlDomNamedNodeMap* _tmp109_ = NULL;
		GXmlDomNode* _tmp110_ = NULL;
		GXmlDomNode* _tmp111_ = NULL;
		gchar* _tmp112_ = NULL;
		gchar* _tmp113_ = NULL;
		gchar* _tmp114_ = NULL;
		GXmlGomElement* _tmp115_ = NULL;
		GXmlDomNamedNodeMap* _tmp116_ = NULL;
		GXmlDomNamedNodeMap* _tmp117_ = NULL;
		GXmlDomNamedNodeMap* _tmp118_ = NULL;
		GXmlDomNode* _tmp119_ = NULL;
		GXmlDomNode* _tmp120_ = NULL;
		gchar* _tmp121_ = NULL;
		gchar* _tmp122_ = NULL;
		gchar* _tmp123_ = NULL;
		GXmlGomElement* _tmp124_ = NULL;
		GXmlGomElement* _tmp125_ = NULL;
		GXmlDomNamedNodeMap* _tmp126_ = NULL;
		GXmlDomNamedNodeMap* _tmp127_ = NULL;
		GXmlDomNamedNodeMap* _tmp128_ = NULL;
		gint _tmp129_ = 0;
		gint _tmp130_ = 0;
		GXmlGomElement* _tmp131_ = NULL;
		GXmlDomNamedNodeMap* _tmp132_ = NULL;
		GXmlDomNamedNodeMap* _tmp133_ = NULL;
		GXmlDomNamedNodeMap* _tmp134_ = NULL;
		GXmlDomNode* _tmp135_ = NULL;
		GXmlDomNode* _tmp136_ = NULL;
		GXmlGomElement* _tmp137_ = NULL;
		GXmlDomNamedNodeMap* _tmp138_ = NULL;
		GXmlDomNamedNodeMap* _tmp139_ = NULL;
		GXmlDomNamedNodeMap* _tmp140_ = NULL;
		GXmlDomNode* _tmp141_ = NULL;
		GXmlDomNode* _tmp142_ = NULL;
		gchar* _tmp143_ = NULL;
		gchar* _tmp144_ = NULL;
		gchar* _tmp145_ = NULL;
		GXmlGomElement* _tmp146_ = NULL;
		GXmlDomNamedNodeMap* _tmp147_ = NULL;
		GXmlDomNamedNodeMap* _tmp148_ = NULL;
		GXmlDomNamedNodeMap* _tmp149_ = NULL;
		GXmlDomNode* _tmp150_ = NULL;
		GXmlDomNode* _tmp151_ = NULL;
		gchar* _tmp152_ = NULL;
		gchar* _tmp153_ = NULL;
		gchar* _tmp154_ = NULL;
		GXmlGomElement* _tmp155_ = NULL;
		GXmlDomNamedNodeMap* _tmp156_ = NULL;
		GXmlDomNamedNodeMap* _tmp157_ = NULL;
		GXmlDomNamedNodeMap* _tmp158_ = NULL;
		GXmlDomNode* _tmp159_ = NULL;
		GXmlDomNode* _tmp160_ = NULL;
		GXmlGomElement* e2 = NULL;
		GXmlGomElement* _tmp161_ = NULL;
		GXmlGomElement* _tmp162_ = NULL;
		GXmlGomElement* _tmp163_ = NULL;
		GXmlGomElement* _tmp164_ = NULL;
		GXmlGomElement* _tmp165_ = NULL;
		GXmlGomElement* _tmp166_ = NULL;
		GXmlGomElement* _tmp167_ = NULL;
		GXmlDomNamedNodeMap* _tmp168_ = NULL;
		GXmlDomNamedNodeMap* _tmp169_ = NULL;
		GXmlDomNamedNodeMap* _tmp170_ = NULL;
		gint _tmp171_ = 0;
		gint _tmp172_ = 0;
		GXmlGomElement* _tmp190_ = NULL;
		GXmlDomNamedNodeMap* _tmp191_ = NULL;
		GXmlDomNamedNodeMap* _tmp192_ = NULL;
		GXmlDomNamedNodeMap* _tmp193_ = NULL;
		GXmlDomNode* _tmp194_ = NULL;
		GXmlDomNode* _tmp195_ = NULL;
		GXmlGomElement* _tmp196_ = NULL;
		GXmlDomNamedNodeMap* _tmp197_ = NULL;
		GXmlDomNamedNodeMap* _tmp198_ = NULL;
		GXmlDomNamedNodeMap* _tmp199_ = NULL;
		GXmlDomNode* _tmp200_ = NULL;
		GXmlDomNode* _tmp201_ = NULL;
		gchar* _tmp202_ = NULL;
		gchar* _tmp203_ = NULL;
		gchar* _tmp204_ = NULL;
		GXmlGomElement* _tmp205_ = NULL;
		GXmlDomNamedNodeMap* _tmp206_ = NULL;
		GXmlDomNamedNodeMap* _tmp207_ = NULL;
		GXmlDomNamedNodeMap* _tmp208_ = NULL;
		GXmlDomNode* _tmp209_ = NULL;
		GXmlDomNode* _tmp210_ = NULL;
		gchar* _tmp211_ = NULL;
		gchar* _tmp212_ = NULL;
		gchar* _tmp213_ = NULL;
		GXmlGomElement* _tmp214_ = NULL;
		GXmlDomNamedNodeMap* _tmp215_ = NULL;
		GXmlDomNamedNodeMap* _tmp216_ = NULL;
		GXmlDomNamedNodeMap* _tmp217_ = NULL;
		GXmlDomNode* _tmp218_ = NULL;
		GXmlDomNode* _tmp219_ = NULL;
		GXmlGomElement* _tmp220_ = NULL;
		GXmlDomNamedNodeMap* _tmp221_ = NULL;
		GXmlDomNamedNodeMap* _tmp222_ = NULL;
		GXmlDomNamedNodeMap* _tmp223_ = NULL;
		GXmlDomNode* _tmp224_ = NULL;
		GXmlDomNode* _tmp225_ = NULL;
		gchar* _tmp226_ = NULL;
		gchar* _tmp227_ = NULL;
		gchar* _tmp228_ = NULL;
		GXmlGomElement* _tmp229_ = NULL;
		GXmlDomNamedNodeMap* _tmp230_ = NULL;
		GXmlDomNamedNodeMap* _tmp231_ = NULL;
		GXmlDomNamedNodeMap* _tmp232_ = NULL;
		GXmlDomNode* _tmp233_ = NULL;
		GXmlDomNode* _tmp234_ = NULL;
		gchar* _tmp235_ = NULL;
		gchar* _tmp236_ = NULL;
		gchar* _tmp237_ = NULL;
		GXmlGomElement* _tmp238_ = NULL;
		GXmlDomNamedNodeMap* _tmp239_ = NULL;
		GXmlDomNamedNodeMap* _tmp240_ = NULL;
		GXmlDomNamedNodeMap* _tmp241_ = NULL;
		GXmlDomNode* _tmp242_ = NULL;
		GXmlDomNode* _tmp243_ = NULL;
		GXmlGomElement* _tmp244_ = NULL;
		GXmlDomNamedNodeMap* _tmp245_ = NULL;
		GXmlDomNamedNodeMap* _tmp246_ = NULL;
		GXmlDomNamedNodeMap* _tmp247_ = NULL;
		GXmlDomNode* _tmp248_ = NULL;
		GXmlDomNode* _tmp249_ = NULL;
		gchar* _tmp250_ = NULL;
		gchar* _tmp251_ = NULL;
		gchar* _tmp252_ = NULL;
		GXmlGomElement* _tmp253_ = NULL;
		GXmlDomNamedNodeMap* _tmp254_ = NULL;
		GXmlDomNamedNodeMap* _tmp255_ = NULL;
		GXmlDomNamedNodeMap* _tmp256_ = NULL;
		GXmlDomNode* _tmp257_ = NULL;
		GXmlDomNode* _tmp258_ = NULL;
		gchar* _tmp259_ = NULL;
		gchar* _tmp260_ = NULL;
		gchar* _tmp261_ = NULL;
		GXmlGomElement* _tmp262_ = NULL;
		GXmlDomNamedNodeMap* _tmp263_ = NULL;
		GXmlDomNamedNodeMap* _tmp264_ = NULL;
		GXmlDomNamedNodeMap* _tmp265_ = NULL;
		GXmlDomNode* _tmp266_ = NULL;
		GXmlDomNode* _tmp267_ = NULL;
		GXmlGomElement* _tmp268_ = NULL;
		GXmlDomNamedNodeMap* _tmp269_ = NULL;
		GXmlDomNamedNodeMap* _tmp270_ = NULL;
		GXmlDomNamedNodeMap* _tmp271_ = NULL;
		GXmlDomNode* _tmp272_ = NULL;
		GXmlDomNode* _tmp273_ = NULL;
		gchar* _tmp274_ = NULL;
		gchar* _tmp275_ = NULL;
		gchar* _tmp276_ = NULL;
		GXmlGomElement* _tmp277_ = NULL;
		GXmlDomNamedNodeMap* _tmp278_ = NULL;
		GXmlDomNamedNodeMap* _tmp279_ = NULL;
		GXmlDomNamedNodeMap* _tmp280_ = NULL;
		GXmlDomNode* _tmp281_ = NULL;
		GXmlDomNode* _tmp282_ = NULL;
		gchar* _tmp283_ = NULL;
		gchar* _tmp284_ = NULL;
		gchar* _tmp285_ = NULL;
		GXmlGomElement* _tmp286_ = NULL;
		GXmlDomNamedNodeMap* _tmp287_ = NULL;
		GXmlDomNamedNodeMap* _tmp288_ = NULL;
		GXmlDomNamedNodeMap* _tmp289_ = NULL;
		GXmlDomNode* _tmp290_ = NULL;
		GXmlDomNode* _tmp291_ = NULL;
		GXmlGomElement* _tmp292_ = NULL;
		GXmlDomNamedNodeMap* _tmp293_ = NULL;
		GXmlDomNamedNodeMap* _tmp294_ = NULL;
		GXmlDomNamedNodeMap* _tmp295_ = NULL;
		GXmlDomNode* _tmp296_ = NULL;
		GXmlDomNode* _tmp297_ = NULL;
		gchar* _tmp298_ = NULL;
		gchar* _tmp299_ = NULL;
		gchar* _tmp300_ = NULL;
		GXmlGomElement* _tmp301_ = NULL;
		GXmlDomNamedNodeMap* _tmp302_ = NULL;
		GXmlDomNamedNodeMap* _tmp303_ = NULL;
		GXmlDomNamedNodeMap* _tmp304_ = NULL;
		GXmlDomNode* _tmp305_ = NULL;
		GXmlDomNode* _tmp306_ = NULL;
		gchar* _tmp307_ = NULL;
		gchar* _tmp308_ = NULL;
		gchar* _tmp309_ = NULL;
		GXmlGomElement* _tmp310_ = NULL;
		GXmlGomElement* _tmp311_ = NULL;
		GXmlDomNamedNodeMap* _tmp312_ = NULL;
		GXmlDomNamedNodeMap* _tmp313_ = NULL;
		GXmlDomNamedNodeMap* _tmp314_ = NULL;
		gint _tmp315_ = 0;
		gint _tmp316_ = 0;
		GXmlGomElement* _tmp317_ = NULL;
		GXmlDomNamedNodeMap* _tmp318_ = NULL;
		GXmlDomNamedNodeMap* _tmp319_ = NULL;
		GXmlDomNamedNodeMap* _tmp320_ = NULL;
		GXmlDomNode* _tmp321_ = NULL;
		GXmlDomNode* _tmp322_ = NULL;
		GXmlGomElement* _tmp323_ = NULL;
		GXmlDomNamedNodeMap* _tmp324_ = NULL;
		GXmlDomNamedNodeMap* _tmp325_ = NULL;
		GXmlDomNamedNodeMap* _tmp326_ = NULL;
		GXmlDomNode* _tmp327_ = NULL;
		GXmlDomNode* _tmp328_ = NULL;
		gchar* _tmp329_ = NULL;
		gchar* _tmp330_ = NULL;
		gchar* _tmp331_ = NULL;
		GXmlGomElement* _tmp332_ = NULL;
		GXmlDomNamedNodeMap* _tmp333_ = NULL;
		GXmlDomNamedNodeMap* _tmp334_ = NULL;
		GXmlDomNamedNodeMap* _tmp335_ = NULL;
		GXmlDomNode* _tmp336_ = NULL;
		GXmlDomNode* _tmp337_ = NULL;
		gchar* _tmp338_ = NULL;
		gchar* _tmp339_ = NULL;
		gchar* _tmp340_ = NULL;
		GXmlGomElement* _tmp341_ = NULL;
		GXmlDomNamedNodeMap* _tmp342_ = NULL;
		GXmlDomNamedNodeMap* _tmp343_ = NULL;
		GXmlDomNamedNodeMap* _tmp344_ = NULL;
		GXmlDomNode* _tmp345_ = NULL;
		GXmlDomNode* _tmp346_ = NULL;
#line 663 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = gxml_gom_element_new ();
#line 663 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _tmp0_;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = e;
#line 664 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp1_, "a1", "v1", &_inner_error_);
#line 664 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 664 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8152 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 665 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = e;
#line 665 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp2_, "a2", "v2", &_inner_error_);
#line 665 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 665 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8163 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 666 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = e;
#line 666 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp3_, "a3", "v3", &_inner_error_);
#line 666 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 666 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8174 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 667 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = e;
#line 667 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute ((GXmlDomElement*) _tmp4_, "a4", "v4", &_inner_error_);
#line 667 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 667 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8185 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = e;
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp6_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp5_);
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp7_ = _tmp6_;
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp8_ = _tmp7_;
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp9_ = gxml_dom_named_node_map_get_length (_tmp8_);
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp10_ = _tmp9_;
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp10_ == 4, "e.attributes.length == 4");
#line 668 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp8_);
#line 8204 "GomElementTest.c"
		{
			gint i = 0;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			i = 0;
#line 8209 "GomElementTest.c"
			{
				gboolean _tmp11_ = FALSE;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
				_tmp11_ = TRUE;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
				while (TRUE) {
#line 8216 "GomElementTest.c"
					gint _tmp13_ = 0;
					GXmlGomElement* _tmp14_ = NULL;
					GXmlDomNamedNodeMap* _tmp15_ = NULL;
					GXmlDomNamedNodeMap* _tmp16_ = NULL;
					GXmlDomNamedNodeMap* _tmp17_ = NULL;
					gint _tmp18_ = 0;
					gint _tmp19_ = 0;
					gboolean _tmp20_ = FALSE;
					GXmlGomElement* _tmp21_ = NULL;
					GXmlDomNamedNodeMap* _tmp22_ = NULL;
					GXmlDomNamedNodeMap* _tmp23_ = NULL;
					GXmlDomNamedNodeMap* _tmp24_ = NULL;
					gint _tmp25_ = 0;
					GXmlDomNode* _tmp26_ = NULL;
					GXmlDomNode* _tmp27_ = NULL;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					if (!_tmp11_) {
#line 8234 "GomElementTest.c"
						gint _tmp12_ = 0;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						_tmp12_ = i;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						i = _tmp12_ + 1;
#line 8240 "GomElementTest.c"
					}
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp11_ = FALSE;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp13_ = i;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp14_ = e;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp15_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp14_);
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp16_ = _tmp15_;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp17_ = _tmp16_;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp18_ = gxml_dom_named_node_map_get_length (_tmp17_);
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp19_ = _tmp18_;
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp20_ = !(_tmp13_ < _tmp19_);
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp17_);
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					if (_tmp20_) {
#line 669 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						break;
#line 8266 "GomElementTest.c"
					}
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp21_ = e;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp22_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp21_);
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp23_ = _tmp22_;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp24_ = _tmp23_;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp25_ = i;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp26_ = gxml_dom_named_node_map_item (_tmp24_, _tmp25_);
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp27_ = _tmp26_;
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_vala_assert (_tmp27_ != NULL, "e.attributes.item (i) != null");
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp27_);
#line 670 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp24_);
#line 8288 "GomElementTest.c"
				}
			}
		}
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp28_ = e;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp29_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp28_);
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp30_ = _tmp29_;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp31_ = _tmp30_;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp32_ = gxml_dom_named_node_map_item (_tmp31_, 0);
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp33_ = _tmp32_;
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp33_ != NULL, "e.attributes.item (0) != null");
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp33_);
#line 672 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp31_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp34_ = e;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp35_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp34_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp36_ = _tmp35_;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp37_ = _tmp36_;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp38_ = gxml_dom_named_node_map_item (_tmp37_, 0);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp39_ = _tmp38_;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp40_ = gxml_dom_node_get_node_name (_tmp39_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp41_ = _tmp40_;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp42_ = _tmp41_;
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp42_, "a1") == 0, "e.attributes.item (0).node_name == \"a1\"");
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp42_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp39_);
#line 673 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp37_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp43_ = e;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp44_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp43_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp45_ = _tmp44_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp46_ = _tmp45_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp47_ = gxml_dom_named_node_map_item (_tmp46_, 0);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp48_ = _tmp47_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp49_ = gxml_dom_node_get_node_value (_tmp48_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp50_ = _tmp49_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp51_ = _tmp50_;
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp51_, "v1") == 0, "e.attributes.item (0).node_value == \"v1\"");
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp51_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp48_);
#line 674 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp46_);
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp52_ = e;
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp53_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp52_);
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp54_ = _tmp53_;
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp55_ = _tmp54_;
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp56_ = gxml_dom_named_node_map_item (_tmp55_, 1);
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp57_ = _tmp56_;
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp57_ != NULL, "e.attributes.item (1) != null");
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp57_);
#line 675 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp55_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp58_ = e;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp59_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp58_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp60_ = _tmp59_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp61_ = _tmp60_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp62_ = gxml_dom_named_node_map_item (_tmp61_, 1);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp63_ = _tmp62_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp64_ = gxml_dom_node_get_node_name (_tmp63_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp65_ = _tmp64_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp66_ = _tmp65_;
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp66_, "a2") == 0, "e.attributes.item (1).node_name == \"a2\"");
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp66_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp63_);
#line 676 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp61_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp67_ = e;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp68_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp67_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp69_ = _tmp68_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp70_ = _tmp69_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp71_ = gxml_dom_named_node_map_item (_tmp70_, 1);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp72_ = _tmp71_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp73_ = gxml_dom_node_get_node_value (_tmp72_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp74_ = _tmp73_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp75_ = _tmp74_;
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp75_, "v2") == 0, "e.attributes.item (1).node_value == \"v2\"");
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp75_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp72_);
#line 677 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp70_);
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp76_ = e;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp77_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp76_);
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp78_ = _tmp77_;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp79_ = _tmp78_;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp80_ = gxml_dom_named_node_map_item (_tmp79_, 2);
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp81_ = _tmp80_;
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp81_ != NULL, "e.attributes.item (2) != null");
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp81_);
#line 678 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp79_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp82_ = e;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp83_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp82_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp84_ = _tmp83_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp85_ = _tmp84_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp86_ = gxml_dom_named_node_map_item (_tmp85_, 2);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp87_ = _tmp86_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp88_ = gxml_dom_node_get_node_name (_tmp87_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp89_ = _tmp88_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp90_ = _tmp89_;
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp90_, "a3") == 0, "e.attributes.item (2).node_name == \"a3\"");
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp90_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp87_);
#line 679 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp85_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp91_ = e;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp92_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp91_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp93_ = _tmp92_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp94_ = _tmp93_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp95_ = gxml_dom_named_node_map_item (_tmp94_, 2);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp96_ = _tmp95_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp97_ = gxml_dom_node_get_node_value (_tmp96_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp98_ = _tmp97_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp99_ = _tmp98_;
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp99_, "v3") == 0, "e.attributes.item (2).node_value == \"v3\"");
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp99_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp96_);
#line 680 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp94_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp100_ = e;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp101_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp100_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp102_ = _tmp101_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp103_ = _tmp102_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp104_ = gxml_dom_named_node_map_item (_tmp103_, 3);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp105_ = _tmp104_;
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp105_ != NULL, "e.attributes.item (3) != null");
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp105_);
#line 681 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp103_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp106_ = e;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp107_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp106_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp108_ = _tmp107_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp109_ = _tmp108_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp110_ = gxml_dom_named_node_map_item (_tmp109_, 3);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp111_ = _tmp110_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp112_ = gxml_dom_node_get_node_name (_tmp111_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp113_ = _tmp112_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp114_ = _tmp113_;
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp114_, "a4") == 0, "e.attributes.item (3).node_name == \"a4\"");
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp114_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp111_);
#line 682 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp109_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp115_ = e;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp116_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp115_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp117_ = _tmp116_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp118_ = _tmp117_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp119_ = gxml_dom_named_node_map_item (_tmp118_, 3);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp120_ = _tmp119_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp121_ = gxml_dom_node_get_node_value (_tmp120_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp122_ = _tmp121_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp123_ = _tmp122_;
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp123_, "v4") == 0, "e.attributes.item (3).node_value == \"v4\"");
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp123_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp120_);
#line 683 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp118_);
#line 684 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp124_ = e;
#line 684 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute ((GXmlDomElement*) _tmp124_, "a3");
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp125_ = e;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp126_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp125_);
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp127_ = _tmp126_;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp128_ = _tmp127_;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp129_ = gxml_dom_named_node_map_get_length (_tmp128_);
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp130_ = _tmp129_;
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp130_ == 3, "e.attributes.length == 3");
#line 685 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp128_);
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp131_ = e;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp132_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp131_);
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp133_ = _tmp132_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp134_ = _tmp133_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp135_ = gxml_dom_named_node_map_item (_tmp134_, 2);
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp136_ = _tmp135_;
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp136_ != NULL, "e.attributes.item (2) != null");
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp136_);
#line 686 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp134_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp137_ = e;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp138_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp137_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp139_ = _tmp138_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp140_ = _tmp139_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp141_ = gxml_dom_named_node_map_item (_tmp140_, 2);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp142_ = _tmp141_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp143_ = gxml_dom_node_get_node_name (_tmp142_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp144_ = _tmp143_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp145_ = _tmp144_;
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp145_, "a4") == 0, "e.attributes.item (2).node_name == \"a4\"");
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp145_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp142_);
#line 687 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp140_);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp146_ = e;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp147_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp146_);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp148_ = _tmp147_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp149_ = _tmp148_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp150_ = gxml_dom_named_node_map_item (_tmp149_, 2);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp151_ = _tmp150_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp152_ = gxml_dom_node_get_node_value (_tmp151_);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp153_ = _tmp152_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp154_ = _tmp153_;
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp154_, "v4") == 0, "e.attributes.item (2).node_value == \"v4\"");
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp154_);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp151_);
#line 688 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp149_);
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp155_ = e;
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp156_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp155_);
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp157_ = _tmp156_;
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp158_ = _tmp157_;
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp159_ = gxml_dom_named_node_map_item (_tmp158_, 3);
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp160_ = _tmp159_;
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp160_ == NULL, "e.attributes.item (3) == null");
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp160_);
#line 689 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp158_);
#line 691 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp161_ = gxml_gom_element_new ();
#line 691 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e2 = _tmp161_;
#line 692 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp162_ = e2;
#line 692 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp162_, "http://www.w3.org/2000/xmlns", "xmlns:gxml", "http://wiki.gnome.org/GXml", &_inner_error_);
#line 692 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 692 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e2);
#line 692 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8694 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 693 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp163_ = e2;
#line 693 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp163_, "http://wiki.gnome.org/GXml", "gxml:a1", "v1", &_inner_error_);
#line 693 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 693 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e2);
#line 693 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8707 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 694 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp164_ = e2;
#line 694 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp164_, "http://wiki.gnome.org/GXml", "gxml:a2", "v2", &_inner_error_);
#line 694 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 694 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e2);
#line 694 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8720 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 695 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp165_ = e2;
#line 695 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp165_, "http://wiki.gnome.org/GXml", "gxml:a3", "v3", &_inner_error_);
#line 695 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 695 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e2);
#line 695 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8733 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 696 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp166_ = e2;
#line 696 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) _tmp166_, "http://wiki.gnome.org/GXml", "gxml:a4", "v4", &_inner_error_);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 696 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e2);
#line 696 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_object_unref0 (e);
#line 8746 "GomElementTest.c"
			goto __catch270_g_error;
		}
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp167_ = e2;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp168_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp167_);
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp169_ = _tmp168_;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp170_ = _tmp169_;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp171_ = gxml_dom_named_node_map_get_length (_tmp170_);
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp172_ = _tmp171_;
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp172_ == 5, "e2.attributes.length == 5");
#line 697 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp170_);
#line 8765 "GomElementTest.c"
		{
			gint i = 0;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			i = 0;
#line 8770 "GomElementTest.c"
			{
				gboolean _tmp173_ = FALSE;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
				_tmp173_ = TRUE;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
				while (TRUE) {
#line 8777 "GomElementTest.c"
					gint _tmp175_ = 0;
					GXmlGomElement* _tmp176_ = NULL;
					GXmlDomNamedNodeMap* _tmp177_ = NULL;
					GXmlDomNamedNodeMap* _tmp178_ = NULL;
					GXmlDomNamedNodeMap* _tmp179_ = NULL;
					gint _tmp180_ = 0;
					gint _tmp181_ = 0;
					gboolean _tmp182_ = FALSE;
					GXmlGomElement* _tmp183_ = NULL;
					GXmlDomNamedNodeMap* _tmp184_ = NULL;
					GXmlDomNamedNodeMap* _tmp185_ = NULL;
					GXmlDomNamedNodeMap* _tmp186_ = NULL;
					gint _tmp187_ = 0;
					GXmlDomNode* _tmp188_ = NULL;
					GXmlDomNode* _tmp189_ = NULL;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					if (!_tmp173_) {
#line 8795 "GomElementTest.c"
						gint _tmp174_ = 0;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						_tmp174_ = i;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						i = _tmp174_ + 1;
#line 8801 "GomElementTest.c"
					}
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp173_ = FALSE;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp175_ = i;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp176_ = e2;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp177_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp176_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp178_ = _tmp177_;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp179_ = _tmp178_;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp180_ = gxml_dom_named_node_map_get_length (_tmp179_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp181_ = _tmp180_;
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp182_ = !(_tmp175_ < _tmp181_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp179_);
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					if (_tmp182_) {
#line 698 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
						break;
#line 8827 "GomElementTest.c"
					}
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp183_ = e2;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp184_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp183_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp185_ = _tmp184_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp186_ = _tmp185_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp187_ = i;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp188_ = gxml_dom_named_node_map_item (_tmp186_, _tmp187_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_tmp189_ = _tmp188_;
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_vala_assert (_tmp189_ != NULL, "e2.attributes.item (i) != null");
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp189_);
#line 699 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
					_g_object_unref0 (_tmp186_);
#line 8849 "GomElementTest.c"
				}
			}
		}
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp190_ = e2;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp191_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp190_);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp192_ = _tmp191_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp193_ = _tmp192_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp194_ = gxml_dom_named_node_map_item (_tmp193_, 0);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp195_ = _tmp194_;
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp195_ != NULL, "e2.attributes.item (0) != null");
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp195_);
#line 701 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp193_);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp196_ = e2;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp197_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp196_);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp198_ = _tmp197_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp199_ = _tmp198_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp200_ = gxml_dom_named_node_map_item (_tmp199_, 0);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp201_ = _tmp200_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp202_ = gxml_dom_node_get_node_name (_tmp201_);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp203_ = _tmp202_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp204_ = _tmp203_;
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp204_, "xmlns:gxml") == 0, "e2.attributes.item (0).node_name == \"xmlns:gxml\"");
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp204_);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp201_);
#line 702 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp199_);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp205_ = e2;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp206_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp205_);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp207_ = _tmp206_;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp208_ = _tmp207_;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp209_ = gxml_dom_named_node_map_item (_tmp208_, 0);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp210_ = _tmp209_;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp211_ = gxml_dom_node_get_node_value (_tmp210_);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp212_ = _tmp211_;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp213_ = _tmp212_;
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp213_, "http://wiki.gnome.org/GXml") == 0, "e2.attributes.item (0).node_value == \"http://wiki.gnome.org/GXml\"");
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp213_);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp210_);
#line 703 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp208_);
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp214_ = e2;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp215_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp214_);
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp216_ = _tmp215_;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp217_ = _tmp216_;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp218_ = gxml_dom_named_node_map_item (_tmp217_, 1);
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp219_ = _tmp218_;
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp219_ != NULL, "e2.attributes.item (1) != null");
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp219_);
#line 704 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp217_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp220_ = e2;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp221_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp220_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp222_ = _tmp221_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp223_ = _tmp222_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp224_ = gxml_dom_named_node_map_item (_tmp223_, 1);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp225_ = _tmp224_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp226_ = gxml_dom_node_get_node_name (_tmp225_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp227_ = _tmp226_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp228_ = _tmp227_;
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp228_, "gxml:a1") == 0, "e2.attributes.item (1).node_name == \"gxml:a1\"");
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp228_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp225_);
#line 705 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp223_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp229_ = e2;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp230_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp229_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp231_ = _tmp230_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp232_ = _tmp231_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp233_ = gxml_dom_named_node_map_item (_tmp232_, 1);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp234_ = _tmp233_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp235_ = gxml_dom_node_get_node_value (_tmp234_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp236_ = _tmp235_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp237_ = _tmp236_;
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp237_, "v1") == 0, "e2.attributes.item (1).node_value == \"v1\"");
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp237_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp234_);
#line 706 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp232_);
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp238_ = e2;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp239_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp238_);
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp240_ = _tmp239_;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp241_ = _tmp240_;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp242_ = gxml_dom_named_node_map_item (_tmp241_, 2);
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp243_ = _tmp242_;
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp243_ != NULL, "e2.attributes.item (2) != null");
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp243_);
#line 707 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp241_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp244_ = e2;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp245_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp244_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp246_ = _tmp245_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp247_ = _tmp246_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp248_ = gxml_dom_named_node_map_item (_tmp247_, 2);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp249_ = _tmp248_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp250_ = gxml_dom_node_get_node_name (_tmp249_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp251_ = _tmp250_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp252_ = _tmp251_;
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp252_, "gxml:a2") == 0, "e2.attributes.item (2).node_name == \"gxml:a2\"");
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp252_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp249_);
#line 708 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp247_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp253_ = e2;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp254_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp253_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp255_ = _tmp254_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp256_ = _tmp255_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp257_ = gxml_dom_named_node_map_item (_tmp256_, 2);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp258_ = _tmp257_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp259_ = gxml_dom_node_get_node_value (_tmp258_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp260_ = _tmp259_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp261_ = _tmp260_;
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp261_, "v2") == 0, "e2.attributes.item (2).node_value == \"v2\"");
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp261_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp258_);
#line 709 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp256_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp262_ = e2;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp263_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp262_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp264_ = _tmp263_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp265_ = _tmp264_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp266_ = gxml_dom_named_node_map_item (_tmp265_, 3);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp267_ = _tmp266_;
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp267_ != NULL, "e2.attributes.item (3) != null");
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp267_);
#line 710 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp265_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp268_ = e2;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp269_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp268_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp270_ = _tmp269_;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp271_ = _tmp270_;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp272_ = gxml_dom_named_node_map_item (_tmp271_, 3);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp273_ = _tmp272_;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp274_ = gxml_dom_node_get_node_name (_tmp273_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp275_ = _tmp274_;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp276_ = _tmp275_;
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp276_, "gxml:a3") == 0, "e2.attributes.item (3).node_name == \"gxml:a3\"");
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp276_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp273_);
#line 711 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp271_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp277_ = e2;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp278_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp277_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp279_ = _tmp278_;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp280_ = _tmp279_;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp281_ = gxml_dom_named_node_map_item (_tmp280_, 3);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp282_ = _tmp281_;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp283_ = gxml_dom_node_get_node_value (_tmp282_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp284_ = _tmp283_;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp285_ = _tmp284_;
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp285_, "v3") == 0, "e2.attributes.item (3).node_value == \"v3\"");
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp285_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp282_);
#line 712 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp280_);
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp286_ = e2;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp287_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp286_);
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp288_ = _tmp287_;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp289_ = _tmp288_;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp290_ = gxml_dom_named_node_map_item (_tmp289_, 4);
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp291_ = _tmp290_;
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp291_ != NULL, "e2.attributes.item (4) != null");
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp291_);
#line 713 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp289_);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp292_ = e2;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp293_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp292_);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp294_ = _tmp293_;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp295_ = _tmp294_;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp296_ = gxml_dom_named_node_map_item (_tmp295_, 4);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp297_ = _tmp296_;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp298_ = gxml_dom_node_get_node_name (_tmp297_);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp299_ = _tmp298_;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp300_ = _tmp299_;
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp300_, "gxml:a4") == 0, "e2.attributes.item (4).node_name == \"gxml:a4\"");
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp300_);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp297_);
#line 714 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp295_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp301_ = e2;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp302_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp301_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp303_ = _tmp302_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp304_ = _tmp303_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp305_ = gxml_dom_named_node_map_item (_tmp304_, 4);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp306_ = _tmp305_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp307_ = gxml_dom_node_get_node_value (_tmp306_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp308_ = _tmp307_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp309_ = _tmp308_;
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp309_, "v4") == 0, "e2.attributes.item (4).node_value == \"v4\"");
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp309_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp306_);
#line 715 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp304_);
#line 716 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp310_ = e2;
#line 716 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_remove_attribute_ns ((GXmlDomElement*) _tmp310_, "http://wiki.gnome.org/GXml", "a3");
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp311_ = e2;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp312_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp311_);
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp313_ = _tmp312_;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp314_ = _tmp313_;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp315_ = gxml_dom_named_node_map_get_length (_tmp314_);
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp316_ = _tmp315_;
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp316_ == 4, "e2.attributes.length == 4");
#line 717 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp314_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp317_ = e2;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp318_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp317_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp319_ = _tmp318_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp320_ = _tmp319_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp321_ = gxml_dom_named_node_map_item (_tmp320_, 3);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp322_ = _tmp321_;
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp322_ != NULL, "e2.attributes.item (3) != null");
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp322_);
#line 718 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp320_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp323_ = e2;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp324_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp323_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp325_ = _tmp324_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp326_ = _tmp325_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp327_ = gxml_dom_named_node_map_item (_tmp326_, 3);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp328_ = _tmp327_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp329_ = gxml_dom_node_get_node_name (_tmp328_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp330_ = _tmp329_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp331_ = _tmp330_;
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp331_, "gxml:a4") == 0, "e2.attributes.item (3).node_name == \"gxml:a4\"");
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp331_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp328_);
#line 719 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp326_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp332_ = e2;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp333_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp332_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp334_ = _tmp333_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp335_ = _tmp334_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp336_ = gxml_dom_named_node_map_item (_tmp335_, 3);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp337_ = _tmp336_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp338_ = gxml_dom_node_get_node_value (_tmp337_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp339_ = _tmp338_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp340_ = _tmp339_;
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (g_strcmp0 (_tmp340_, "v4") == 0, "e2.attributes.item (3).node_value == \"v4\"");
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp340_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp337_);
#line 720 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp335_);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp341_ = e2;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp342_ = gxml_dom_element_get_attributes ((GXmlDomElement*) _tmp341_);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp343_ = _tmp342_;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp344_ = _tmp343_;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp345_ = gxml_dom_named_node_map_item (_tmp344_, 4);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp346_ = _tmp345_;
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_vala_assert (_tmp346_ == NULL, "e2.attributes.item (4) == null");
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp346_);
#line 721 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (_tmp344_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (e2);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_object_unref0 (e);
#line 9315 "GomElementTest.c"
	}
	goto __finally270;
	__catch270_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp347_ = NULL;
		gchar* _tmp348_ = NULL;
		gchar* _tmp349_ = NULL;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp347_ = e->message;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp348_ = g_strconcat ("Error: ", _tmp347_, NULL);
#line 723 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp349_ = _tmp348_;
#line 723 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_message ("GomElementTest.vala:723: %s", _tmp349_);
#line 723 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp349_);
#line 724 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_assert_not_reached ();
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 9342 "GomElementTest.c"
	}
	__finally270:
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 662 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		return;
#line 9353 "GomElementTest.c"
	}
}


static void ___lambda260__gtest_func (void) {
#line 661 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	__lambda260_ ();
#line 9361 "GomElementTest.c"
}


void gom_element_test_add_tests (void) {
#line 182 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace_uri", ___lambda241__gtest_func);
#line 210 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/namespace_uri", ___lambda242__gtest_func);
#line 244 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/read/namespace/redefinition", ___lambda243__gtest_func);
#line 270 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes", ___lambda244__gtest_func);
#line 344 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attributes/property-ns", ___lambda245__gtest_func);
#line 365 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/attribute-ns/collection", ___lambda246__gtest_func);
#line 387 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/lookup-prefix", ___lambda247__gtest_func);
#line 415 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/add_aside_child_nodes", ___lambda248__gtest_func);
#line 432 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/content/keep_child_nodes", ___lambda249__gtest_func);
#line 449 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parent", ___lambda250__gtest_func);
#line 463 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/remove", ___lambda251__gtest_func);
#line 479 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/parsed-delayed", ___lambda252__gtest_func);
#line 496 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/string", ___lambda253__gtest_func);
#line 514 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/stream", ___lambda254__gtest_func);
#line 529 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/write/input_stream", ___lambda255__gtest_func);
#line 545 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/previous_element_sibling", ___lambda256__gtest_func);
#line 576 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/css-selector", ___lambda257__gtest_func);
#line 635 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/avoid", ___lambda258__gtest_func);
#line 647 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/no-instantiatable/set", ___lambda259__gtest_func);
#line 661 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_test_add_func ("/gxml/gom-element/ordered-attributes", ___lambda260__gtest_func);
#line 9406 "GomElementTest.c"
}


GomElementTest* gom_element_test_construct (GType object_type) {
	GomElementTest* self = NULL;
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTest*) gxml_test_construct (object_type);
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9416 "GomElementTest.c"
}


GomElementTest* gom_element_test_new (void) {
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_construct (TYPE_GOM_ELEMENT_TEST);
#line 9423 "GomElementTest.c"
}


GomElementTestParsedDelayed* gom_element_test_parsed_delayed_construct (GType object_type) {
	GomElementTestParsedDelayed * self = NULL;
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestParsedDelayed*) gxml_gom_element_construct (object_type);
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9433 "GomElementTest.c"
}


GomElementTestParsedDelayed* gom_element_test_parsed_delayed_new (void) {
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_parsed_delayed_construct (GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED);
#line 9440 "GomElementTest.c"
}


static GObject * gom_element_test_parsed_delayed_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestParsedDelayed * self;
	GError * _inner_error_ = NULL;
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_parsed_delayed_parent_class);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_PARSED_DELAYED, GomElementTestParsedDelayed);
#line 9455 "GomElementTest.c"
	{
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_element_initialize ((GXmlGomElement*) self, "root");
#line 9459 "GomElementTest.c"
	}
	goto __finally271;
	__catch271_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:34: %s", _tmp3_);
#line 34 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 9487 "GomElementTest.c"
	}
	__finally271:
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 33 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 9496 "GomElementTest.c"
	}
#line 35 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_set_parse_children ((GXmlGomElement*) self, FALSE);
#line 32 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9502 "GomElementTest.c"
}


static void gom_element_test_parsed_delayed_class_init (GomElementTestParsedDelayedClass * klass) {
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_parsed_delayed_parent_class = g_type_class_peek_parent (klass);
#line 31 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_parsed_delayed_constructor;
#line 9511 "GomElementTest.c"
}


static void gom_element_test_parsed_delayed_instance_init (GomElementTestParsedDelayed * self) {
}


GType gom_element_test_parsed_delayed_get_type (void) {
	static volatile gsize gom_element_test_parsed_delayed_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_parsed_delayed_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestParsedDelayedClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_parsed_delayed_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestParsedDelayed), 0, (GInstanceInitFunc) gom_element_test_parsed_delayed_instance_init, NULL };
		GType gom_element_test_parsed_delayed_type_id;
		gom_element_test_parsed_delayed_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestParsedDelayed", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_parsed_delayed_type_id__volatile, gom_element_test_parsed_delayed_type_id);
	}
	return gom_element_test_parsed_delayed_type_id__volatile;
}


GomElementTestInstantiatable* gom_element_test_instantiatable_construct (GType object_type) {
	GomElementTestInstantiatable * self = NULL;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) gxml_gom_element_construct (object_type);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9537 "GomElementTest.c"
}


GomElementTestInstantiatable* gom_element_test_instantiatable_new (void) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_instantiatable_construct (GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE);
#line 9544 "GomElementTest.c"
}


static const gchar* gom_element_test_instantiatable_real_get_name (NoInstantiatable* base) {
	const gchar* result;
	GomElementTestInstantiatable* self;
	const gchar* _tmp0_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9560 "GomElementTest.c"
}


static void gom_element_test_instantiatable_real_set_name (NoInstantiatable* base, const gchar* value) {
	GomElementTestInstantiatable* self;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestInstantiatable*) base;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_name = _tmp1_;
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 9580 "GomElementTest.c"
}


static GObject * gom_element_test_instantiatable_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestInstantiatable * self;
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Instantiatable");
#line 41 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9598 "GomElementTest.c"
}


static void gom_element_test_instantiatable_class_init (GomElementTestInstantiatableClass * klass) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_instantiatable_parent_class = g_type_class_peek_parent (klass);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestInstantiatablePrivate));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_instantiatable_get_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_instantiatable_set_property;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_instantiatable_constructor;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_instantiatable_finalize;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY, g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9617 "GomElementTest.c"
}


static void gom_element_test_instantiatable_no_instantiatable_interface_init (NoInstantiatableIface * iface) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_instantiatable_no_instantiatable_parent_iface = g_type_interface_peek_parent (iface);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_name = gom_element_test_instantiatable_real_get_name;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->set_name = gom_element_test_instantiatable_real_set_name;
#line 9628 "GomElementTest.c"
}


static void gom_element_test_instantiatable_instance_init (GomElementTestInstantiatable * self) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_INSTANTIATABLE_GET_PRIVATE (self);
#line 9635 "GomElementTest.c"
}


static void gom_element_test_instantiatable_finalize (GObject* obj) {
	GomElementTestInstantiatable * self;
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 40 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_instantiatable_parent_class)->finalize (obj);
#line 9647 "GomElementTest.c"
}


GType gom_element_test_instantiatable_get_type (void) {
	static volatile gsize gom_element_test_instantiatable_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_instantiatable_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestInstantiatableClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_instantiatable_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestInstantiatable), 0, (GInstanceInitFunc) gom_element_test_instantiatable_instance_init, NULL };
		static const GInterfaceInfo no_instantiatable_info = { (GInterfaceInitFunc) gom_element_test_instantiatable_no_instantiatable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_instantiatable_type_id;
		gom_element_test_instantiatable_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestInstantiatable", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_instantiatable_type_id, TYPE_NO_INSTANTIATABLE, &no_instantiatable_info);
		g_once_init_leave (&gom_element_test_instantiatable_type_id__volatile, gom_element_test_instantiatable_type_id);
	}
	return gom_element_test_instantiatable_type_id__volatile;
}


static void _vala_gom_element_test_instantiatable_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, no_instantiatable_get_name ((NoInstantiatable*) self));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9676 "GomElementTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9682 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_instantiatable_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestInstantiatable * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, GomElementTestInstantiatable);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INSTANTIATABLE_NAME_PROPERTY:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		no_instantiatable_set_name ((NoInstantiatable*) self, g_value_get_string (value));
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9698 "GomElementTest.c"
		default:
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 38 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9704 "GomElementTest.c"
	}
}


GomElementTestTop* gom_element_test_top_construct (GType object_type) {
	GomElementTestTop * self = NULL;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTop*) gxml_gom_element_construct (object_type);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9715 "GomElementTest.c"
}


GomElementTestTop* gom_element_test_top_new (void) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_top_construct (GOM_ELEMENT_TEST_TYPE_TOP);
#line 9722 "GomElementTest.c"
}


NoInstantiatable* gom_element_test_top_get_inst (GomElementTestTop* self) {
	NoInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_ = NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = (NoInstantiatable*) _tmp0_;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9737 "GomElementTest.c"
}


void gom_element_test_top_set_inst (GomElementTestTop* self, NoInstantiatable* value) {
	NoInstantiatable* _tmp0_ = NULL;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_top_set_inst_i (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) _tmp0_) : NULL);
#line 45 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "inst");
#line 9751 "GomElementTest.c"
}


GomElementTestInstantiatable* gom_element_test_top_get_inst_i (GomElementTestTop* self) {
	GomElementTestInstantiatable* result;
	GomElementTestInstantiatable* _tmp0_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst_i;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9766 "GomElementTest.c"
}


void gom_element_test_top_set_inst_i (GomElementTestTop* self, GomElementTestInstantiatable* value) {
	GomElementTestInstantiatable* _tmp0_ = NULL;
	GomElementTestInstantiatable* _tmp1_ = NULL;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst_i);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_inst_i = _tmp1_;
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "inst-i");
#line 9785 "GomElementTest.c"
}


Property* gom_element_test_top_get_pq (GomElementTestTop* self) {
	Property* result;
	Property* _tmp0_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 9800 "GomElementTest.c"
}


void gom_element_test_top_set_pq (GomElementTestTop* self, Property* value) {
	Property* _tmp0_ = NULL;
	Property* _tmp1_ = NULL;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_pq = _tmp1_;
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "pq");
#line 9819 "GomElementTest.c"
}


static GObject * gom_element_test_top_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTop * self;
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_top_parent_class);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 50 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 9837 "GomElementTest.c"
}


static void gom_element_test_top_class_init (GomElementTestTopClass * klass) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_top_parent_class = g_type_class_peek_parent (klass);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestTopPrivate));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_top_get_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_top_set_property;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_top_constructor;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_top_finalize;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_PROPERTY, g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY, g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TOP_PQ_PROPERTY, g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 9860 "GomElementTest.c"
}


static void gom_element_test_top_instance_init (GomElementTestTop * self) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_TOP_GET_PRIVATE (self);
#line 9867 "GomElementTest.c"
}


static void gom_element_test_top_finalize (GObject* obj) {
	GomElementTestTop * self;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 47 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst_i);
#line 49 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_top_parent_class)->finalize (obj);
#line 9881 "GomElementTest.c"
}


GType gom_element_test_top_get_type (void) {
	static volatile gsize gom_element_test_top_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_top_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_top_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTop), 0, (GInstanceInitFunc) gom_element_test_top_instance_init, NULL };
		GType gom_element_test_top_type_id;
		gom_element_test_top_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTop", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_top_type_id__volatile, gom_element_test_top_type_id);
	}
	return gom_element_test_top_type_id__volatile;
}


static void _vala_gom_element_test_top_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_inst_i (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_top_get_pq (self));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9920 "GomElementTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9926 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_top_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TOP, GomElementTestTop);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_inst (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_INST_I_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_inst_i (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TOP_PQ_PROPERTY:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_top_set_pq (self, g_value_get_object (value));
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9954 "GomElementTest.c"
		default:
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 43 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 9960 "GomElementTest.c"
	}
}


GomElementTestGProperty* gom_element_test_gproperty_construct (GType object_type) {
	GomElementTestGProperty * self = NULL;
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestGProperty*) gxml_gom_string_construct (object_type);
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 9971 "GomElementTest.c"
}


GomElementTestGProperty* gom_element_test_gproperty_new (void) {
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_gproperty_construct (GOM_ELEMENT_TEST_TYPE_GPROPERTY);
#line 9978 "GomElementTest.c"
}


static void gom_element_test_gproperty_class_init (GomElementTestGPropertyClass * klass) {
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gproperty_parent_class = g_type_class_peek_parent (klass);
#line 9985 "GomElementTest.c"
}


static void gom_element_test_gproperty_property_interface_init (PropertyIface * iface) {
#line 52 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gproperty_property_parent_iface = g_type_interface_peek_parent (iface);
#line 9992 "GomElementTest.c"
}


static void gom_element_test_gproperty_instance_init (GomElementTestGProperty * self) {
}


GType gom_element_test_gproperty_get_type (void) {
	static volatile gsize gom_element_test_gproperty_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gproperty_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGPropertyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gproperty_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGProperty), 0, (GInstanceInitFunc) gom_element_test_gproperty_instance_init, NULL };
		static const GInterfaceInfo property_info = { (GInterfaceInitFunc) gom_element_test_gproperty_property_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_gproperty_type_id;
		gom_element_test_gproperty_type_id = g_type_register_static (GXML_TYPE_GOM_STRING, "GomElementTestGProperty", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_gproperty_type_id, TYPE_PROPERTY, &property_info);
		g_once_init_leave (&gom_element_test_gproperty_type_id__volatile, gom_element_test_gproperty_type_id);
	}
	return gom_element_test_gproperty_type_id__volatile;
}


GomElementTestGTop* gom_element_test_gtop_construct (GType object_type) {
	GomElementTestGTop * self = NULL;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestGTop*) gxml_gom_element_construct (object_type);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10020 "GomElementTest.c"
}


GomElementTestGTop* gom_element_test_gtop_new (void) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_gtop_construct (GOM_ELEMENT_TEST_TYPE_GTOP);
#line 10027 "GomElementTest.c"
}


NoInstantiatable* gom_element_test_gtop_get_inst (GomElementTestGTop* self) {
	NoInstantiatable* result;
	NoInstantiatable* _tmp0_ = NULL;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10042 "GomElementTest.c"
}


void gom_element_test_gtop_set_inst (GomElementTestGTop* self, NoInstantiatable* value) {
	NoInstantiatable* _tmp0_ = NULL;
	NoInstantiatable* _tmp1_ = NULL;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_inst = _tmp1_;
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "inst");
#line 10061 "GomElementTest.c"
}


GomElementTestInstantiatable* gom_element_test_gtop_get_inst_i (GomElementTestGTop* self) {
	GomElementTestInstantiatable* result;
	NoInstantiatable* _tmp0_ = NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_inst;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE) ? ((GomElementTestInstantiatable*) _tmp0_) : NULL;
#line 56 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10076 "GomElementTest.c"
}


void gom_element_test_gtop_set_inst_i (GomElementTestGTop* self, GomElementTestInstantiatable* value) {
	GomElementTestInstantiatable* _tmp0_ = NULL;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_set_inst (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_NO_INSTANTIATABLE) ? ((NoInstantiatable*) _tmp0_) : NULL);
#line 57 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "inst-i");
#line 10090 "GomElementTest.c"
}


GomElementTestGProperty* gom_element_test_gtop_get_gpq (GomElementTestGTop* self) {
	GomElementTestGProperty* result;
	Property* _tmp0_ = NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GOM_ELEMENT_TEST_TYPE_GPROPERTY) ? ((GomElementTestGProperty*) _tmp0_) : NULL;
#line 62 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10105 "GomElementTest.c"
}


void gom_element_test_gtop_set_gpq (GomElementTestGTop* self, GomElementTestGProperty* value) {
	GomElementTestGProperty* _tmp0_ = NULL;
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_set_pq (self, G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, TYPE_PROPERTY) ? ((Property*) _tmp0_) : NULL);
#line 63 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "gpq");
#line 10119 "GomElementTest.c"
}


Property* gom_element_test_gtop_get_pq (GomElementTestGTop* self) {
	Property* result;
	Property* _tmp0_ = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_pq;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10134 "GomElementTest.c"
}


void gom_element_test_gtop_set_pq (GomElementTestGTop* self, Property* value) {
	Property* _tmp0_ = NULL;
	Property* _tmp1_ = NULL;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_pq = _tmp1_;
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "pq");
#line 10153 "GomElementTest.c"
}


static GObject * gom_element_test_gtop_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestGTop * self;
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_gtop_parent_class);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Top");
#line 70 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10171 "GomElementTest.c"
}


static void gom_element_test_gtop_class_init (GomElementTestGTopClass * klass) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_gtop_parent_class = g_type_class_peek_parent (klass);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestGTopPrivate));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_gtop_get_property;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_gtop_set_property;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_gtop_constructor;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_gtop_finalize;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_PROPERTY, g_param_spec_object ("inst", "inst", "inst", TYPE_NO_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY, g_param_spec_object ("inst-i", "inst-i", "inst-i", GOM_ELEMENT_TEST_TYPE_INSTANTIATABLE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY, g_param_spec_object ("gpq", "::pq", "gpq", GOM_ELEMENT_TEST_TYPE_GPROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY, g_param_spec_object ("pq", "::pq", "pq", TYPE_PROPERTY, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10196 "GomElementTest.c"
}


static void gom_element_test_gtop_instance_init (GomElementTestGTop * self) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_GTOP_GET_PRIVATE (self);
#line 10203 "GomElementTest.c"
}


static void gom_element_test_gtop_finalize (GObject* obj) {
	GomElementTestGTop * self;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 54 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_inst);
#line 69 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_pq);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_gtop_parent_class)->finalize (obj);
#line 10217 "GomElementTest.c"
}


GType gom_element_test_gtop_get_type (void) {
	static volatile gsize gom_element_test_gtop_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_gtop_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestGTopClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_gtop_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestGTop), 0, (GInstanceInitFunc) gom_element_test_gtop_instance_init, NULL };
		GType gom_element_test_gtop_type_id;
		gom_element_test_gtop_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestGTop", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_gtop_type_id__volatile, gom_element_test_gtop_type_id);
	}
	return gom_element_test_gtop_type_id__volatile;
}


static void _vala_gom_element_test_gtop_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_inst_i (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_gpq (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_gtop_get_pq (self));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10262 "GomElementTest.c"
		default:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10268 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_gtop_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestGTop * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_GTOP, GomElementTestGTop);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_inst (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_INST_I_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_inst_i (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_GPQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_gpq (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_GTOP_PQ_PROPERTY:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_gtop_set_pq (self, g_value_get_object (value));
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10302 "GomElementTest.c"
		default:
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 53 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10308 "GomElementTest.c"
	}
}


GomElementTestPotion* gom_element_test_potion_construct (GType object_type) {
	GomElementTestPotion * self = NULL;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestPotion*) gxml_gom_element_construct (object_type);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10319 "GomElementTest.c"
}


GomElementTestPotion* gom_element_test_potion_new (void) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_potion_construct (GOM_ELEMENT_TEST_TYPE_POTION);
#line 10326 "GomElementTest.c"
}


const gchar* gom_element_test_potion_get_cname (GomElementTestPotion* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10341 "GomElementTest.c"
}


void gom_element_test_potion_set_cname (GomElementTestPotion* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_cname = _tmp1_;
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "cname");
#line 10360 "GomElementTest.c"
}


GomElementTestIngredient* gom_element_test_potion_get_ingredient (GomElementTestPotion* self) {
	GomElementTestIngredient* result;
	GomElementTestIngredient* _tmp0_ = NULL;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_ingredient;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10375 "GomElementTest.c"
}


void gom_element_test_potion_set_ingredient (GomElementTestPotion* self, GomElementTestIngredient* value) {
	GomElementTestIngredient* _tmp0_ = NULL;
	GomElementTestIngredient* _tmp1_ = NULL;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ingredient);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_ingredient = _tmp1_;
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "ingredient");
#line 10394 "GomElementTest.c"
}


static GObject * gom_element_test_potion_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestPotion * self;
	GError * _inner_error_ = NULL;
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_potion_parent_class);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 77 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "Potion");
#line 10411 "GomElementTest.c"
	{
#line 79 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://c.org/1.0", &_inner_error_);
#line 79 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10417 "GomElementTest.c"
			goto __catch272_g_error;
		}
	}
	goto __finally272;
	__catch272_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:80: %s", _tmp3_);
#line 80 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 10447 "GomElementTest.c"
	}
	__finally272:
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 78 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 10456 "GomElementTest.c"
	}
#line 76 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10460 "GomElementTest.c"
}


static void gom_element_test_potion_class_init (GomElementTestPotionClass * klass) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_potion_parent_class = g_type_class_peek_parent (klass);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestPotionPrivate));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_potion_get_property;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_potion_set_property;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_potion_constructor;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_potion_finalize;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY, g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY, g_param_spec_object ("ingredient", "ingredient", "ingredient", GOM_ELEMENT_TEST_TYPE_INGREDIENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10481 "GomElementTest.c"
}


static void gom_element_test_potion_instance_init (GomElementTestPotion * self) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_POTION_GET_PRIVATE (self);
#line 10488 "GomElementTest.c"
}


static void gom_element_test_potion_finalize (GObject* obj) {
	GomElementTestPotion * self;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 74 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 75 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ingredient);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_potion_parent_class)->finalize (obj);
#line 10502 "GomElementTest.c"
}


GType gom_element_test_potion_get_type (void) {
	static volatile gsize gom_element_test_potion_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_potion_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestPotionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_potion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestPotion), 0, (GInstanceInitFunc) gom_element_test_potion_instance_init, NULL };
		GType gom_element_test_potion_type_id;
		gom_element_test_potion_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestPotion", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_potion_type_id__volatile, gom_element_test_potion_type_id);
	}
	return gom_element_test_potion_type_id__volatile;
}


static void _vala_gom_element_test_potion_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_potion_get_cname (self));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_potion_get_ingredient (self));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10535 "GomElementTest.c"
		default:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10541 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_potion_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestPotion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_POTION, GomElementTestPotion);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_CNAME_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_potion_set_cname (self, g_value_get_string (value));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_POTION_INGREDIENT_PROPERTY:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_potion_set_ingredient (self, g_value_get_object (value));
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10563 "GomElementTest.c"
		default:
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 72 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10569 "GomElementTest.c"
	}
}


static gchar* gom_element_test_ingredient_real_get_map_key (GXmlMappeableElement* base) {
	GomElementTestIngredient * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredient*) base;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 88 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10589 "GomElementTest.c"
}


GomElementTestIngredient* gom_element_test_ingredient_construct (GType object_type) {
	GomElementTestIngredient * self = NULL;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredient*) gxml_gom_element_construct (object_type);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10599 "GomElementTest.c"
}


GomElementTestIngredient* gom_element_test_ingredient_new (void) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_ingredient_construct (GOM_ELEMENT_TEST_TYPE_INGREDIENT);
#line 10606 "GomElementTest.c"
}


const gchar* gom_element_test_ingredient_get_cname (GomElementTestIngredient* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10621 "GomElementTest.c"
}


void gom_element_test_ingredient_set_cname (GomElementTestIngredient* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_cname = _tmp1_;
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "cname");
#line 10640 "GomElementTest.c"
}


GomElementTestMethodMap* gom_element_test_ingredient_get_methods (GomElementTestIngredient* self) {
	GomElementTestMethodMap* result;
	GomElementTestMethodMap* _tmp0_ = NULL;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_methods;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10655 "GomElementTest.c"
}


void gom_element_test_ingredient_set_methods (GomElementTestIngredient* self, GomElementTestMethodMap* value) {
	GomElementTestMethodMap* _tmp0_ = NULL;
	GomElementTestMethodMap* _tmp1_ = NULL;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_methods);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_methods = _tmp1_;
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "methods");
#line 10674 "GomElementTest.c"
}


static GObject * gom_element_test_ingredient_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredient * self;
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_parent_class);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "ingredient");
#line 87 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10692 "GomElementTest.c"
}


GomElementTestIngredientMap* gom_element_test_ingredient_map_construct (GType object_type) {
	GomElementTestIngredientMap * self = NULL;
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestIngredientMap*) gxml_gom_hash_map_construct (object_type);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10702 "GomElementTest.c"
}


GomElementTestIngredientMap* gom_element_test_ingredient_map_new (void) {
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_ingredient_map_construct (GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP);
#line 10709 "GomElementTest.c"
}


static GObject * gom_element_test_ingredient_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestIngredientMap * self;
	GError * _inner_error_ = NULL;
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_ingredient_map_parent_class);
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_INGREDIENT_TYPE_MAP, GomElementTestIngredientMap);
#line 10724 "GomElementTest.c"
	{
#line 92 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_INGREDIENT, &_inner_error_);
#line 92 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 10730 "GomElementTest.c"
			goto __catch273_g_error;
		}
	}
	goto __finally273;
	__catch273_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:93: %s", _tmp3_);
#line 93 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 10760 "GomElementTest.c"
	}
	__finally273:
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 91 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 10769 "GomElementTest.c"
	}
#line 90 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 10773 "GomElementTest.c"
}


static void gom_element_test_ingredient_map_class_init (GomElementTestIngredientMapClass * klass) {
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_map_parent_class = g_type_class_peek_parent (klass);
#line 89 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_map_constructor;
#line 10782 "GomElementTest.c"
}


static void gom_element_test_ingredient_map_instance_init (GomElementTestIngredientMap * self) {
}


GType gom_element_test_ingredient_map_get_type (void) {
	static volatile gsize gom_element_test_ingredient_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredientMap), 0, (GInstanceInitFunc) gom_element_test_ingredient_map_instance_init, NULL };
		GType gom_element_test_ingredient_map_type_id;
		gom_element_test_ingredient_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestIngredientMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_ingredient_map_type_id__volatile, gom_element_test_ingredient_map_type_id);
	}
	return gom_element_test_ingredient_map_type_id__volatile;
}


static void gom_element_test_ingredient_class_init (GomElementTestIngredientClass * klass) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_parent_class = g_type_class_peek_parent (klass);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestIngredientPrivate));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_ingredient_get_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_ingredient_set_property;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_ingredient_constructor;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_ingredient_finalize;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY, g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY, g_param_spec_object ("methods", "methods", "methods", GOM_ELEMENT_TEST_METHOD_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 10819 "GomElementTest.c"
}


static void gom_element_test_ingredient_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_ingredient_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*)(GXmlMappeableElement*)) gom_element_test_ingredient_real_get_map_key;
#line 10828 "GomElementTest.c"
}


static void gom_element_test_ingredient_instance_init (GomElementTestIngredient * self) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_INGREDIENT_GET_PRIVATE (self);
#line 10835 "GomElementTest.c"
}


static void gom_element_test_ingredient_finalize (GObject* obj) {
	GomElementTestIngredient * self;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 85 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 86 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_methods);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_ingredient_parent_class)->finalize (obj);
#line 10849 "GomElementTest.c"
}


GType gom_element_test_ingredient_get_type (void) {
	static volatile gsize gom_element_test_ingredient_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_ingredient_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestIngredientClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_ingredient_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestIngredient), 0, (GInstanceInitFunc) gom_element_test_ingredient_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_ingredient_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_ingredient_type_id;
		gom_element_test_ingredient_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestIngredient", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_ingredient_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_ingredient_type_id__volatile, gom_element_test_ingredient_type_id);
	}
	return gom_element_test_ingredient_type_id__volatile;
}


static void _vala_gom_element_test_ingredient_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_ingredient_get_cname (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_ingredient_get_methods (self));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10884 "GomElementTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10890 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_ingredient_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestIngredient * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_INGREDIENT, GomElementTestIngredient);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_CNAME_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_ingredient_set_cname (self, g_value_get_string (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_INGREDIENT_METHODS_PROPERTY:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_ingredient_set_methods (self, g_value_get_object (value));
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10912 "GomElementTest.c"
		default:
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 83 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 10918 "GomElementTest.c"
	}
}


static gchar* gom_element_test_method_real_get_map_key (GXmlMappeableElement* base) {
	GomElementTestMethod * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethod*) base;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 101 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10938 "GomElementTest.c"
}


GomElementTestMethod* gom_element_test_method_construct (GType object_type) {
	GomElementTestMethod * self = NULL;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethod*) gxml_gom_element_construct (object_type);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 10948 "GomElementTest.c"
}


GomElementTestMethod* gom_element_test_method_new (void) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_method_construct (GOM_ELEMENT_TEST_TYPE_METHOD);
#line 10955 "GomElementTest.c"
}


const gchar* gom_element_test_method_get_cname (GomElementTestMethod* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cname;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 10970 "GomElementTest.c"
}


void gom_element_test_method_set_cname (GomElementTestMethod* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_cname = _tmp1_;
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "cname");
#line 10989 "GomElementTest.c"
}


static GObject * gom_element_test_method_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethod * self;
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_parent_class);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "method");
#line 100 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11007 "GomElementTest.c"
}


GomElementTestMethodMap* gom_element_test_method_map_construct (GType object_type) {
	GomElementTestMethodMap * self = NULL;
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestMethodMap*) gxml_gom_hash_map_construct (object_type);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 11017 "GomElementTest.c"
}


GomElementTestMethodMap* gom_element_test_method_map_new (void) {
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_method_map_construct (GOM_ELEMENT_TEST_METHOD_TYPE_MAP);
#line 11024 "GomElementTest.c"
}


static GObject * gom_element_test_method_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestMethodMap * self;
	GError * _inner_error_ = NULL;
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_method_map_parent_class);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_METHOD_TYPE_MAP, GomElementTestMethodMap);
#line 11039 "GomElementTest.c"
	{
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_METHOD, &_inner_error_);
#line 105 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11045 "GomElementTest.c"
			goto __catch274_g_error;
		}
	}
	goto __finally274;
	__catch274_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:106: %s", _tmp3_);
#line 106 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 11075 "GomElementTest.c"
	}
	__finally274:
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 104 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 11084 "GomElementTest.c"
	}
#line 103 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11088 "GomElementTest.c"
}


static void gom_element_test_method_map_class_init (GomElementTestMethodMapClass * klass) {
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_map_parent_class = g_type_class_peek_parent (klass);
#line 102 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_map_constructor;
#line 11097 "GomElementTest.c"
}


static void gom_element_test_method_map_instance_init (GomElementTestMethodMap * self) {
}


GType gom_element_test_method_map_get_type (void) {
	static volatile gsize gom_element_test_method_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethodMap), 0, (GInstanceInitFunc) gom_element_test_method_map_instance_init, NULL };
		GType gom_element_test_method_map_type_id;
		gom_element_test_method_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestMethodMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_method_map_type_id__volatile, gom_element_test_method_map_type_id);
	}
	return gom_element_test_method_map_type_id__volatile;
}


static void gom_element_test_method_class_init (GomElementTestMethodClass * klass) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_parent_class = g_type_class_peek_parent (klass);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestMethodPrivate));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_method_get_property;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_method_set_property;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_method_constructor;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_method_finalize;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY, g_param_spec_string ("cname", "::c:name", "cname", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11132 "GomElementTest.c"
}


static void gom_element_test_method_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_method_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*)(GXmlMappeableElement*)) gom_element_test_method_real_get_map_key;
#line 11141 "GomElementTest.c"
}


static void gom_element_test_method_instance_init (GomElementTestMethod * self) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_METHOD_GET_PRIVATE (self);
#line 11148 "GomElementTest.c"
}


static void gom_element_test_method_finalize (GObject* obj) {
	GomElementTestMethod * self;
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 99 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cname);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_method_parent_class)->finalize (obj);
#line 11160 "GomElementTest.c"
}


GType gom_element_test_method_get_type (void) {
	static volatile gsize gom_element_test_method_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_method_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestMethodClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_method_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestMethod), 0, (GInstanceInitFunc) gom_element_test_method_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_method_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_method_type_id;
		gom_element_test_method_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestMethod", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_method_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_method_type_id__volatile, gom_element_test_method_type_id);
	}
	return gom_element_test_method_type_id__volatile;
}


static void _vala_gom_element_test_method_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_method_get_cname (self));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11189 "GomElementTest.c"
		default:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11195 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_method_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestMethod * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_METHOD, GomElementTestMethod);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_METHOD_CNAME_PROPERTY:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_method_set_cname (self, g_value_get_string (value));
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11211 "GomElementTest.c"
		default:
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 97 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11217 "GomElementTest.c"
	}
}


GomElementTestRepository* gom_element_test_repository_construct (GType object_type) {
	GomElementTestRepository * self = NULL;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestRepository*) gxml_gom_element_construct (object_type);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 11228 "GomElementTest.c"
}


GomElementTestRepository* gom_element_test_repository_new (void) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_repository_construct (GOM_ELEMENT_TEST_TYPE_REPOSITORY);
#line 11235 "GomElementTest.c"
}


const gchar* gom_element_test_repository_get_version (GomElementTestRepository* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11250 "GomElementTest.c"
}


void gom_element_test_repository_set_version (GomElementTestRepository* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_version = _tmp1_;
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "version");
#line 11269 "GomElementTest.c"
}


GomElementTestNamespace* gom_element_test_repository_get_ns (GomElementTestRepository* self) {
	GomElementTestNamespace* result;
	GomElementTestNamespace* _tmp0_ = NULL;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_ns;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11284 "GomElementTest.c"
}


void gom_element_test_repository_set_ns (GomElementTestRepository* self, GomElementTestNamespace* value) {
	GomElementTestNamespace* _tmp0_ = NULL;
	GomElementTestNamespace* _tmp1_ = NULL;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ns);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_ns = _tmp1_;
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "ns");
#line 11303 "GomElementTest.c"
}


static GObject * gom_element_test_repository_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestRepository * self;
	GError * _inner_error_ = NULL;
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_repository_parent_class);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 118 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "repository");
#line 11320 "GomElementTest.c"
	{
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns", "http://www.gtk.org/introspection/core/1.0", &_inner_error_);
#line 120 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11326 "GomElementTest.c"
			goto __catch275_g_error;
		}
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:c", "http://www.gtk.org/introspection/c/1.0", &_inner_error_);
#line 122 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11333 "GomElementTest.c"
			goto __catch275_g_error;
		}
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_dom_element_set_attribute_ns ((GXmlDomElement*) self, "http://www.w3.org/2000/xmlns", "xmlns:glib", "http://www.gtk.org/introspection/glib/1.0", &_inner_error_);
#line 124 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11340 "GomElementTest.c"
			goto __catch275_g_error;
		}
	}
	goto __finally275;
	__catch275_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:126: %s", _tmp3_);
#line 126 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 11370 "GomElementTest.c"
	}
	__finally275:
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 119 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 11379 "GomElementTest.c"
	}
#line 127 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_repository_set_version (self, "1.2");
#line 117 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11385 "GomElementTest.c"
}


static void gom_element_test_repository_class_init (GomElementTestRepositoryClass * klass) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_repository_parent_class = g_type_class_peek_parent (klass);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestRepositoryPrivate));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_repository_get_property;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_repository_set_property;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_repository_constructor;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_repository_finalize;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY, g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY, g_param_spec_object ("ns", "ns", "ns", GOM_ELEMENT_TEST_TYPE_NAMESPACE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11406 "GomElementTest.c"
}


static void gom_element_test_repository_instance_init (GomElementTestRepository * self) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_REPOSITORY_GET_PRIVATE (self);
#line 11413 "GomElementTest.c"
}


static void gom_element_test_repository_finalize (GObject* obj) {
	GomElementTestRepository * self;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 113 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 115 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_ns);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_repository_parent_class)->finalize (obj);
#line 11427 "GomElementTest.c"
}


GType gom_element_test_repository_get_type (void) {
	static volatile gsize gom_element_test_repository_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_repository_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestRepositoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_repository_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestRepository), 0, (GInstanceInitFunc) gom_element_test_repository_instance_init, NULL };
		GType gom_element_test_repository_type_id;
		gom_element_test_repository_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestRepository", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_repository_type_id__volatile, gom_element_test_repository_type_id);
	}
	return gom_element_test_repository_type_id__volatile;
}


static void _vala_gom_element_test_repository_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_repository_get_version (self));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_repository_get_ns (self));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11460 "GomElementTest.c"
		default:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11466 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_repository_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestRepository * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_REPOSITORY, GomElementTestRepository);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_VERSION_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_repository_set_version (self, g_value_get_string (value));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_REPOSITORY_NS_PROPERTY:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_repository_set_ns (self, g_value_get_object (value));
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11488 "GomElementTest.c"
		default:
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 110 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11494 "GomElementTest.c"
	}
}


GomElementTestNamespace* gom_element_test_namespace_construct (GType object_type) {
	GomElementTestNamespace * self = NULL;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestNamespace*) gxml_gom_element_construct (object_type);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 11505 "GomElementTest.c"
}


GomElementTestNamespace* gom_element_test_namespace_new (void) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_namespace_construct (GOM_ELEMENT_TEST_TYPE_NAMESPACE);
#line 11512 "GomElementTest.c"
}


const gchar* gom_element_test_namespace_get_name (GomElementTestNamespace* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11527 "GomElementTest.c"
}


void gom_element_test_namespace_set_name (GomElementTestNamespace* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_name = _tmp1_;
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 11546 "GomElementTest.c"
}


const gchar* gom_element_test_namespace_get_version (GomElementTestNamespace* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11561 "GomElementTest.c"
}


void gom_element_test_namespace_set_version (GomElementTestNamespace* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_version = _tmp1_;
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "version");
#line 11580 "GomElementTest.c"
}


const gchar* gom_element_test_namespace_get_cprefix (GomElementTestNamespace* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11595 "GomElementTest.c"
}


void gom_element_test_namespace_set_cprefix (GomElementTestNamespace* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_cprefix = _tmp1_;
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "cprefix");
#line 11614 "GomElementTest.c"
}


GomElementTestTClassMap* gom_element_test_namespace_get_classes (GomElementTestNamespace* self) {
	GomElementTestTClassMap* result;
	GomElementTestTClassMap* _tmp0_ = NULL;
	GomElementTestTClassMap* _tmp1_ = NULL;
#line 140 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 141 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (_tmp0_ == NULL) {
#line 142 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_object_set_instance_property ((GXmlGomObject*) self, "classes");
#line 11630 "GomElementTest.c"
	}
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = self->priv->_classes;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 143 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11638 "GomElementTest.c"
}


void gom_element_test_namespace_set_classes (GomElementTestNamespace* self, GomElementTestTClassMap* value) {
	GomElementTestTClassMap* _tmp0_ = NULL;
	GomElementTestTClassMap* _tmp5_ = NULL;
	GomElementTestTClassMap* _tmp6_ = NULL;
	GError * _inner_error_ = NULL;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 146 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_classes;
#line 146 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (_tmp0_ != NULL) {
#line 11653 "GomElementTest.c"
		{
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			gxml_gom_object_clean_property_elements ((GXmlGomObject*) self, "classes", &_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11659 "GomElementTest.c"
				goto __catch276_g_error;
			}
		}
		goto __finally276;
		__catch276_g_error:
		{
			GError* e = NULL;
			GError* _tmp1_ = NULL;
			const gchar* _tmp2_ = NULL;
			gchar* _tmp3_ = NULL;
			gchar* _tmp4_ = NULL;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			e = _inner_error_;
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_inner_error_ = NULL;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp1_ = e;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp2_ = _tmp1_->message;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp3_ = g_strconcat ("Error: ", _tmp2_, NULL);
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_tmp4_ = _tmp3_;
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_warning ("GomElementTest.vala:148: %s", _tmp4_);
#line 148 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_free0 (_tmp4_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			_g_error_free0 (e);
#line 11689 "GomElementTest.c"
		}
		__finally276:
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			g_clear_error (&_inner_error_);
#line 147 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
			return;
#line 11700 "GomElementTest.c"
		}
	}
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp5_ = value;
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 150 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_classes = _tmp6_;
#line 145 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "classes");
#line 11713 "GomElementTest.c"
}


static GObject * gom_element_test_namespace_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestNamespace * self;
	GomElementTestTClassMap* _tmp0_ = NULL;
	GError * _inner_error_ = NULL;
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_namespace_parent_class);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 154 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "namespace");
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = gom_element_test_tclass_map_new ();
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 155 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_classes = _tmp0_;
#line 11737 "GomElementTest.c"
	{
		GomElementTestTClassMap* _tmp1_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = self->priv->_classes;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_base_collection_initialize_element ((GXmlBaseCollection*) _tmp1_, (GXmlGomElement*) self, &_inner_error_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 11746 "GomElementTest.c"
			goto __catch277_g_error;
		}
	}
	goto __finally277;
	__catch277_g_error:
	{
		GError* e = NULL;
		GError* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = e;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_->message;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp4_ = g_strconcat ("Error: ", _tmp3_, NULL);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp5_ = _tmp4_;
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:157: %s", _tmp5_);
#line 157 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp5_);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 11776 "GomElementTest.c"
	}
	__finally277:
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 156 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 11785 "GomElementTest.c"
	}
#line 153 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 11789 "GomElementTest.c"
}


static void gom_element_test_namespace_class_init (GomElementTestNamespaceClass * klass) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_namespace_parent_class = g_type_class_peek_parent (klass);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestNamespacePrivate));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_namespace_get_property;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_namespace_set_property;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_namespace_constructor;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_namespace_finalize;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY, g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY, g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY, g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY, g_param_spec_object ("classes", "classes", "classes", GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 11814 "GomElementTest.c"
}


static void gom_element_test_namespace_instance_init (GomElementTestNamespace * self) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_NAMESPACE_GET_PRIVATE (self);
#line 11821 "GomElementTest.c"
}


static void gom_element_test_namespace_finalize (GObject* obj) {
	GomElementTestNamespace * self;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 132 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_object_unref0 (self->priv->_classes);
#line 134 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 136 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 138 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_namespace_parent_class)->finalize (obj);
#line 11839 "GomElementTest.c"
}


GType gom_element_test_namespace_get_type (void) {
	static volatile gsize gom_element_test_namespace_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_namespace_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestNamespaceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_namespace_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestNamespace), 0, (GInstanceInitFunc) gom_element_test_namespace_instance_init, NULL };
		GType gom_element_test_namespace_type_id;
		gom_element_test_namespace_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestNamespace", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_namespace_type_id__volatile, gom_element_test_namespace_type_id);
	}
	return gom_element_test_namespace_type_id__volatile;
}


static void _vala_gom_element_test_namespace_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_name (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_version (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_namespace_get_cprefix (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_object (value, gom_element_test_namespace_get_classes (self));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11884 "GomElementTest.c"
		default:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11890 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_namespace_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestNamespace * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_NAMESPACE, GomElementTestNamespace);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_NAME_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_name (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_VERSION_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_version (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CPREFIX_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_cprefix (self, g_value_get_string (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_NAMESPACE_CLASSES_PROPERTY:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_namespace_set_classes (self, g_value_get_object (value));
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11924 "GomElementTest.c"
		default:
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 130 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 11930 "GomElementTest.c"
	}
}


static gchar* gom_element_test_tclass_real_get_map_key (GXmlMappeableElement* base) {
	GomElementTestTClass * self;
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClass*) base;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp1_;
#line 173 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11950 "GomElementTest.c"
}


GomElementTestTClass* gom_element_test_tclass_construct (GType object_type) {
	GomElementTestTClass * self = NULL;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClass*) gxml_gom_element_construct (object_type);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 11960 "GomElementTest.c"
}


GomElementTestTClass* gom_element_test_tclass_new (void) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_tclass_construct (GOM_ELEMENT_TEST_TYPE_TCLASS);
#line 11967 "GomElementTest.c"
}


const gchar* gom_element_test_tclass_get_name (GomElementTestTClass* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_name;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 11982 "GomElementTest.c"
}


void gom_element_test_tclass_set_name (GomElementTestTClass* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_name = _tmp1_;
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "name");
#line 12001 "GomElementTest.c"
}


const gchar* gom_element_test_tclass_get_version (GomElementTestTClass* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_version;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 12016 "GomElementTest.c"
}


void gom_element_test_tclass_set_version (GomElementTestTClass* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_version = _tmp1_;
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "version");
#line 12035 "GomElementTest.c"
}


const gchar* gom_element_test_tclass_get_cprefix (GomElementTestTClass* self) {
	const gchar* result;
	const gchar* _tmp0_ = NULL;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = self->priv->_cprefix;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	result = _tmp0_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return result;
#line 12050 "GomElementTest.c"
}


void gom_element_test_tclass_set_cprefix (GomElementTestTClass* self, const gchar* value) {
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_return_if_fail (self != NULL);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp0_ = value;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv->_cprefix = _tmp1_;
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_notify ((GObject *) self, "cprefix");
#line 12069 "GomElementTest.c"
}


static GObject * gom_element_test_tclass_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClass * self;
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_parent_class);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 170 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gxml_gom_element_initialize ((GXmlGomElement*) self, "class");
#line 169 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 12087 "GomElementTest.c"
}


GomElementTestTClassMap* gom_element_test_tclass_map_construct (GType object_type) {
	GomElementTestTClassMap * self = NULL;
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = (GomElementTestTClassMap*) gxml_gom_hash_map_construct (object_type);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return self;
#line 12097 "GomElementTest.c"
}


GomElementTestTClassMap* gom_element_test_tclass_map_new (void) {
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return gom_element_test_tclass_map_construct (GOM_ELEMENT_TEST_TCLASS_TYPE_MAP);
#line 12104 "GomElementTest.c"
}


static GObject * gom_element_test_tclass_map_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GomElementTestTClassMap * self;
	GError * _inner_error_ = NULL;
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	parent_class = G_OBJECT_CLASS (gom_element_test_tclass_map_parent_class);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TCLASS_TYPE_MAP, GomElementTestTClassMap);
#line 12119 "GomElementTest.c"
	{
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gxml_gom_collection_initialize ((GXmlGomCollection*) self, GOM_ELEMENT_TEST_TYPE_TCLASS, &_inner_error_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 12125 "GomElementTest.c"
			goto __catch278_g_error;
		}
	}
	goto __finally278;
	__catch278_g_error:
	{
		GError* e = NULL;
		GError* _tmp0_ = NULL;
		const gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		e = _inner_error_;
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_inner_error_ = NULL;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp0_ = e;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp1_ = _tmp0_->message;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp2_ = g_strconcat ("Error: ", _tmp1_, NULL);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_tmp3_ = _tmp2_;
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_warning ("GomElementTest.vala:177: %s", _tmp3_);
#line 177 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_free0 (_tmp3_);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		_g_error_free0 (e);
#line 12155 "GomElementTest.c"
	}
	__finally278:
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 176 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_clear_error (&_inner_error_);
#line 12164 "GomElementTest.c"
	}
#line 175 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	return obj;
#line 12168 "GomElementTest.c"
}


static void gom_element_test_tclass_map_class_init (GomElementTestTClassMapClass * klass) {
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_map_parent_class = g_type_class_peek_parent (klass);
#line 174 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_map_constructor;
#line 12177 "GomElementTest.c"
}


static void gom_element_test_tclass_map_instance_init (GomElementTestTClassMap * self) {
}


GType gom_element_test_tclass_map_get_type (void) {
	static volatile gsize gom_element_test_tclass_map_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_map_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassMapClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_map_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClassMap), 0, (GInstanceInitFunc) gom_element_test_tclass_map_instance_init, NULL };
		GType gom_element_test_tclass_map_type_id;
		gom_element_test_tclass_map_type_id = g_type_register_static (GXML_TYPE_GOM_HASH_MAP, "GomElementTestTClassMap", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_tclass_map_type_id__volatile, gom_element_test_tclass_map_type_id);
	}
	return gom_element_test_tclass_map_type_id__volatile;
}


static void gom_element_test_tclass_class_init (GomElementTestTClassClass * klass) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_parent_class = g_type_class_peek_parent (klass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_type_class_add_private (klass, sizeof (GomElementTestTClassPrivate));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_gom_element_test_tclass_get_property;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_gom_element_test_tclass_set_property;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->constructor = gom_element_test_tclass_constructor;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (klass)->finalize = gom_element_test_tclass_finalize;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY, g_param_spec_string ("name", "::name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY, g_param_spec_string ("version", "::version", "version", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY, g_param_spec_string ("cprefix", "::c:prefix", "cprefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 12216 "GomElementTest.c"
}


static void gom_element_test_tclass_gxml_mappeable_element_interface_init (GXmlMappeableElementIface * iface) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_tclass_gxml_mappeable_element_parent_iface = g_type_interface_peek_parent (iface);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	iface->get_map_key = (gchar* (*)(GXmlMappeableElement*)) gom_element_test_tclass_real_get_map_key;
#line 12225 "GomElementTest.c"
}


static void gom_element_test_tclass_instance_init (GomElementTestTClass * self) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self->priv = GOM_ELEMENT_TEST_TCLASS_GET_PRIVATE (self);
#line 12232 "GomElementTest.c"
}


static void gom_element_test_tclass_finalize (GObject* obj) {
	GomElementTestTClass * self;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 163 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_name);
#line 165 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_version);
#line 167 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	_g_free0 (self->priv->_cprefix);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	G_OBJECT_CLASS (gom_element_test_tclass_parent_class)->finalize (obj);
#line 12248 "GomElementTest.c"
}


GType gom_element_test_tclass_get_type (void) {
	static volatile gsize gom_element_test_tclass_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_tclass_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestTClassClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_tclass_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTestTClass), 0, (GInstanceInitFunc) gom_element_test_tclass_instance_init, NULL };
		static const GInterfaceInfo gxml_mappeable_element_info = { (GInterfaceInitFunc) gom_element_test_tclass_gxml_mappeable_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gom_element_test_tclass_type_id;
		gom_element_test_tclass_type_id = g_type_register_static (GXML_TYPE_GOM_ELEMENT, "GomElementTestTClass", &g_define_type_info, 0);
		g_type_add_interface_static (gom_element_test_tclass_type_id, GXML_TYPE_MAPPEABLE_ELEMENT, &gxml_mappeable_element_info);
		g_once_init_leave (&gom_element_test_tclass_type_id__volatile, gom_element_test_tclass_type_id);
	}
	return gom_element_test_tclass_type_id__volatile;
}


static void _vala_gom_element_test_tclass_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_name (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_version (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		g_value_set_string (value, gom_element_test_tclass_get_cprefix (self));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 12289 "GomElementTest.c"
		default:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 12295 "GomElementTest.c"
	}
}


static void _vala_gom_element_test_tclass_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GomElementTestTClass * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GOM_ELEMENT_TEST_TYPE_TCLASS, GomElementTestTClass);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	switch (property_id) {
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_NAME_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_name (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_VERSION_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_version (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		case GOM_ELEMENT_TEST_TCLASS_CPREFIX_PROPERTY:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		gom_element_test_tclass_set_cprefix (self, g_value_get_string (value));
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 12323 "GomElementTest.c"
		default:
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 160 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
		break;
#line 12329 "GomElementTest.c"
	}
}


static void gom_element_test_class_init (GomElementTestClass * klass) {
#line 30 "/home/despinosa/Proyectos/gxml/test/GomElementTest.vala"
	gom_element_test_parent_class = g_type_class_peek_parent (klass);
#line 12337 "GomElementTest.c"
}


static void gom_element_test_instance_init (GomElementTest * self) {
}


GType gom_element_test_get_type (void) {
	static volatile gsize gom_element_test_type_id__volatile = 0;
	if (g_once_init_enter (&gom_element_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GomElementTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gom_element_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GomElementTest), 0, (GInstanceInitFunc) gom_element_test_instance_init, NULL };
		GType gom_element_test_type_id;
		gom_element_test_type_id = g_type_register_static (TYPE_GXML_TEST, "GomElementTest", &g_define_type_info, 0);
		g_once_init_leave (&gom_element_test_type_id__volatile, gom_element_test_type_id);
	}
	return gom_element_test_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



